/* Generated by Cython 3.0.11 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "tbstock.utils.utils",
        "sources": [
            "./tbstock/utils/utils.py"
        ]
    },
    "module_name": "tbstock.utils.utils"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_11" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x03000BF0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(Py_GIL_DISABLED) || defined(Py_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 0
  #endif
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__;  (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__tbstock__utils__utils
#define __PYX_HAVE_API__tbstock__utils__utils
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "tbstock/utils/utils.py",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg
    #define __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg  /* no-op, __Pyx_Arg_FASTCALL is direct and this needs
                                                   to have the same reference counting */
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyObject_Str.proto */
#define __Pyx_PyObject_Str(obj)\
    (likely(PyString_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObjectCall2Args.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right)
    #endif
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_ConcatInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_ConcatInPlaceSafe(left, right) ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_ConcatInPlace(left, right))

/* StrConcatInPlace.proto */
#if PY_MAJOR_VERSION >= 3
    #define __Pyx_PyStr_Concat __Pyx_PyUnicode_Concat
    #define __Pyx_PyStr_ConcatInPlace __Pyx_PyUnicode_ConcatInPlace
#else
    #define __Pyx_PyStr_Concat PyNumber_Add
    #define __Pyx_PyStr_ConcatInPlace PyNumber_InPlaceAdd
#endif
#define __Pyx_PyStr_ConcatSafe(a, b) ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
    PyNumber_Add(a, b) : __Pyx_PyStr_Concat(a, b))
#define __Pyx_PyStr_ConcatInPlaceSafe(a, b) ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
    PyNumber_InPlaceAdd(a, b) : __Pyx_PyStr_ConcatInPlace(a, b))

/* StringJoin.proto */
#if PY_MAJOR_VERSION < 3
#define __Pyx_PyString_Join __Pyx_PyBytes_Join
#define __Pyx_PyBaseString_Join(s, v) (PyUnicode_CheckExact(s) ? PyUnicode_Join(s, v) : __Pyx_PyBytes_Join(s, v))
#else
#define __Pyx_PyString_Join PyUnicode_Join
#define __Pyx_PyBaseString_Join PyUnicode_Join
#endif
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyObjectFormat.proto */
#if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* s, PyObject* f);
#else
#define __Pyx_PyObject_Format(s, f) PyObject_Format(s, f)
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* pybytes_as_double.proto */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj);
static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length);
static CYTHON_INLINE double __Pyx_PyBytes_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
    as_c_string = PyBytes_AS_STRING(obj);
    size = PyBytes_GET_SIZE(obj);
#else
    if (PyBytes_AsStringAndSize(obj, &as_c_string, &size) < 0) {
        return (double)-1;
    }
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}
static CYTHON_INLINE double __Pyx_PyByteArray_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
    as_c_string = PyByteArray_AS_STRING(obj);
    size = PyByteArray_GET_SIZE(obj);
#else
    as_c_string = PyByteArray_AsString(obj);
    if (as_c_string == NULL) {
        return (double)-1;
    }
    size = PyByteArray_Size(obj);
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}

/* pyunicode_as_double.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
static const char* __Pyx__PyUnicode_AsDouble_Copy(const void* data, const int kind, char* buffer, Py_ssize_t start, Py_ssize_t end) {
    int last_was_punctuation;
    Py_ssize_t i;
    last_was_punctuation = 1;
    for (i=start; i <= end; i++) {
        Py_UCS4 chr = PyUnicode_READ(kind, data, i);
        int is_punctuation = (chr == '_') | (chr == '.');
        *buffer = (char)chr;
        buffer += (chr != '_');
        if (unlikely(chr > 127)) goto parse_failure;
        if (unlikely(last_was_punctuation & is_punctuation)) goto parse_failure;
        last_was_punctuation = is_punctuation;
    }
    if (unlikely(last_was_punctuation)) goto parse_failure;
    *buffer = '\0';
    return buffer;
parse_failure:
    return NULL;
}
static double __Pyx__PyUnicode_AsDouble_inf_nan(const void* data, int kind, Py_ssize_t start, Py_ssize_t length) {
    int matches = 1;
    Py_UCS4 chr;
    Py_UCS4 sign = PyUnicode_READ(kind, data, start);
    int is_signed = (sign == '-') | (sign == '+');
    start += is_signed;
    length -= is_signed;
    switch (PyUnicode_READ(kind, data, start)) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'a') | (chr == 'A');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'n') | (chr == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'f') | (chr == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+3);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+4);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+5);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+6);
            matches &= (chr == 't') | (chr == 'T');
            chr = PyUnicode_READ(kind, data, start+7);
            matches &= (chr == 'y') | (chr == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static double __Pyx_PyUnicode_AsDouble_WithSpaces(PyObject *obj) {
    double value;
    const char *last;
    char *end;
    Py_ssize_t start, length = PyUnicode_GET_LENGTH(obj);
    const int kind = PyUnicode_KIND(obj);
    const void* data = PyUnicode_DATA(obj);
    start = 0;
    while (Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, start)))
        start++;
    while (start < length - 1 && Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, length - 1)))
        length--;
    length -= start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyUnicode_AsDouble_inf_nan(data, kind, start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    if (length < 40) {
        char number[40];
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((length + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}
#endif
static CYTHON_INLINE double __Pyx_PyUnicode_AsDouble(PyObject *obj) {
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(__Pyx_PyUnicode_READY(obj) == -1))
        return (double)-1;
    if (likely(PyUnicode_IS_ASCII(obj))) {
        const char *s;
        Py_ssize_t length;
        s = PyUnicode_AsUTF8AndSize(obj, &length);
        return __Pyx__PyBytes_AsDouble(obj, s, length);
    }
    return __Pyx_PyUnicode_AsDouble_WithSpaces(obj);
#else
    return __Pyx_SlowPyString_AsDouble(obj);
#endif
}

/* pystring_as_double.proto */
static CYTHON_INLINE double __Pyx_PyString_AsDouble(PyObject *obj) {
    #if PY_MAJOR_VERSION >= 3
    (void)__Pyx_PyBytes_AsDouble;
    return __Pyx_PyUnicode_AsDouble(obj);
    #else
    (void)__Pyx_PyUnicode_AsDouble;
    return __Pyx_PyBytes_AsDouble(obj);
    #endif
}

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CyFunctionClassCell.proto */
static int __Pyx_CyFunction_InitClassCell(PyObject *cyfunctions, PyObject *classobj);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */

/* Module declarations from "tbstock.utils.utils" */
static PyObject *__pyx_7genexpr__pyx_v_7tbstock_5utils_5utils_i;
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "tbstock.utils.utils"
extern int __pyx_module_is_main_tbstock__utils__utils;
int __pyx_module_is_main_tbstock__utils__utils = 0;

/* Implementation of "tbstock.utils.utils" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_super;
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_IOError;
/* #### Code section: string_decls ### */
static const char __pyx_k_[] = "\347\233\256\345\275\225 ";
static const char __pyx_k_1[] = "1";
static const char __pyx_k_2[] = "2";
static const char __pyx_k_3[] = "3";
static const char __pyx_k_4[] = "4";
static const char __pyx_k_5[] = "5";
static const char __pyx_k_7[] = "7";
static const char __pyx_k_8[] = "8";
static const char __pyx_k_R[] = "\346\267\261\346\210\220\346\214\207R";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_b[] = "b";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_d[] = "^\\d";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_s[] = "\\s+";
static const char __pyx_k_w[] = "w";
static const char __pyx_k_00[] = "00";
static const char __pyx_k_01[] = "01";
static const char __pyx_k_10[] = "10";
static const char __pyx_k_30[] = "30";
static const char __pyx_k_50[] = "\345\214\227\350\257\20150";
static const char __pyx_k_60[] = "60";
static const char __pyx_k_68[] = "68";
static const char __pyx_k_ST[] = "ST";
static const char __pyx_k_XX[] = ".XX";
static const char __pyx_k__2[] = " \350\242\253\345\210\233\345\273\272.";
static const char __pyx_k__3[] = " \345\267\262\345\255\230\345\234\250.";
static const char __pyx_k__4[] = "";
static const char __pyx_k__5[] = "-";
static const char __pyx_k__6[] = "\344\270\212\350\257\201\346\214\207\346\225\260";
static const char __pyx_k__7[] = "\346\267\261\350\257\201\346\210\220\346\214\207";
static const char __pyx_k__8[] = "\345\210\233\344\270\232\346\235\277\346\214\207";
static const char __pyx_k__9[] = "\344\270\255\350\257\201\345\205\250\346\214\207";
static const char __pyx_k_ak[] = "ak";
static const char __pyx_k_bj[] = "bj";
static const char __pyx_k_df[] = "df";
static const char __pyx_k_dt[] = "dt";
static const char __pyx_k_f1[] = "f1";
static const char __pyx_k_f2[] = "f2";
static const char __pyx_k_f3[] = "f3";
static const char __pyx_k_f4[] = "f4";
static const char __pyx_k_f5[] = "f5";
static const char __pyx_k_f6[] = "f6";
static const char __pyx_k_f7[] = "f7";
static const char __pyx_k_f8[] = "f8";
static const char __pyx_k_f9[] = "f9";
static const char __pyx_k_lt[] = "lt";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_pd[] = "pd";
static const char __pyx_k_rc[] = "rc";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_rt[] = "rt";
static const char __pyx_k_sh[] = "sh";
static const char __pyx_k_sz[] = "sz";
static const char __pyx_k_xx[] = "xx";
static const char __pyx_k_02d[] = "02d";
static const char __pyx_k_100[] = "\344\270\255\345\260\217100";
static const char __pyx_k_150[] = "\344\270\212\350\257\201150";
static const char __pyx_k_180[] = "\344\270\212\350\257\201180";
static const char __pyx_k_200[] = "\344\270\255\350\257\201200";
static const char __pyx_k_300[] = "\346\262\252\346\267\261300";
static const char __pyx_k_380[] = "\344\270\212\350\257\201380";
static const char __pyx_k_500[] = "\344\270\255\350\257\201500";
static const char __pyx_k_800[] = "\344\270\255\350\257\201800";
static const char __pyx_k_A50[] = "\344\270\255\350\257\201A50";
static const char __pyx_k__10[] = "\357\274\242\350\202\241\346\214\207\346\225\260";
static const char __pyx_k__11[] = "\345\233\275\345\200\272\346\214\207\346\225\260";
static const char __pyx_k__12[] = "\344\274\201\345\200\272\346\214\207\346\225\260";
static const char __pyx_k__13[] = "\345\237\272\351\207\221\346\214\207\346\225\260";
static const char __pyx_k__14[] = "\346\210\220\344\273\275\357\274\242\346\214\207";
static const char __pyx_k__15[] = "\346\267\261\350\257\201\347\273\274\346\214\207";
static const char __pyx_k__16[] = "\345\210\233\344\270\232\345\244\247\347\233\230";
static const char __pyx_k__17[] = "\345\210\233\344\270\232\345\260\217\347\233\230";
static const char __pyx_k__18[] = "\346\226\260\346\214\207\346\225\260";
static const char __pyx_k__19[] = ".";
static const char __pyx_k__22[] = "(\346\261\237\350\213\217|\346\265\231\346\261\237|\345\256\211\345\276\275|\344\270\212\346\265\267|\345\214\227\344\272\254|\345\244\251\346\264\245|\346\262\263\345\214\227|\345\261\261\350\245\277|\345\206\205\350\222\231\345\217\244|\350\276\275\345\256\201|\345\220\211\346\236\227|\351\273\221\351\276\231\346\261\237|\346\261\237\350\245\277|\347\246\217\345\273\272|\345\261\261\344\270\234|\346\262\263\345\215\227|\346\271\226\345\214\227|\346\271\226\345\215\227|\345\271\277\344\270\234|\345\271\277\350\245\277|\346\265\267\345\215\227|\351\207\215\345\272\206|\345\233\233\345\267\235|\350\264\265\345\267\236|\344\272\221\345\215\227|\350\245\277\350\227\217|\351\231\225\350\245\277|\347\224\230\350\202\203|\351\235\222\346\265\267|\345\256\201\345\244\217|\346\226\260\347\226\206|\351\246\231\346\270\257|\346\276\263\351\227\250|\345\217\260\346\271\276)";
static const char __pyx_k__28[] = ",";
static const char __pyx_k__29[] = "\n";
static const char __pyx_k__30[] = "                        ";
static const char __pyx_k__31[] = "[";
static const char __pyx_k__32[] = "]";
static const char __pyx_k__33[] = ",\n";
static const char __pyx_k__36[] = " ";
static const char __pyx_k__38[] = "\344\273\243\347\240\201";
static const char __pyx_k__39[] = "*";
static const char __pyx_k_add[] = "add";
static const char __pyx_k_arg[] = "arg";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_day[] = "day";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_f10[] = "f10";
static const char __pyx_k_f11[] = "f11";
static const char __pyx_k_f12[] = "f12";
static const char __pyx_k_f13[] = "f13";
static const char __pyx_k_f14[] = "f14";
static const char __pyx_k_f15[] = "f15";
static const char __pyx_k_f16[] = "f16";
static const char __pyx_k_f17[] = "f17";
static const char __pyx_k_f18[] = "f18";
static const char __pyx_k_f20[] = "f20";
static const char __pyx_k_f21[] = "f21";
static const char __pyx_k_f22[] = "f22";
static const char __pyx_k_f23[] = "f23";
static const char __pyx_k_f24[] = "f24";
static const char __pyx_k_f25[] = "f25";
static const char __pyx_k_f26[] = "f26";
static const char __pyx_k_f62[] = "f62";
static const char __pyx_k_inf[] = "inf";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_map[] = "map";
static const char __pyx_k_num[] = "num";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_out[] = "out";
static const char __pyx_k_row[] = "row";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sub[] = "sub";
static const char __pyx_k_sum[] = "sum";
static const char __pyx_k_svr[] = "svr";
static const char __pyx_k_0101[] = "0101";
static const char __pyx_k_1000[] = "\344\270\255\350\257\2011000";
static const char __pyx_k_100R[] = "\346\267\261\350\257\201100R";
static const char __pyx_k_2000[] = "\344\270\255\350\257\2012000";
static const char __pyx_k_50MB[] = "50MB";
static const char __pyx_k_50_2[] = "\347\247\221\345\210\23350";
static const char __pyx_k_50_3[] = "\346\267\261\344\270\273\346\235\27750";
static const char __pyx_k_50_4[] = "\344\270\212\350\257\20150";
static const char __pyx_k_50_5[] = "\346\267\261\350\257\20150";
static const char __pyx_k_50_6[] = "\345\244\256\350\247\20650";
static const char __pyx_k_Dict[] = "Dict";
static const char __pyx_k_INFO[] = "INFO";
static const char __pyx_k_List[] = "List";
static const char __pyx_k_XSHG[] = "XSHG";
static const char __pyx_k__111[] = "?";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_bool[] = "bool";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_date[] = "date";
static const char __pyx_k_days[] = "days";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_diff[] = "diff";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_f115[] = "f115";
static const char __pyx_k_f128[] = "f128";
static const char __pyx_k_f136[] = "f136";
static const char __pyx_k_f140[] = "f140";
static const char __pyx_k_f141[] = "f141";
static const char __pyx_k_f152[] = "f152";
static const char __pyx_k_file[] = "file";
static const char __pyx_k_find[] = "find";
static const char __pyx_k_full[] = "full";
static const char __pyx_k_hour[] = "hour";
static const char __pyx_k_info[] = "info";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_json[] = "json";
static const char __pyx_k_keys[] = "keys";
static const char __pyx_k_list[] = "list";
static const char __pyx_k_load[] = "load";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_mode[] = "mode";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_next[] = "next";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_path[] = "path";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_test[] = "test";
static const char __pyx_k_text[] = "text";
static const char __pyx_k_week[] = "week";
static const char __pyx_k_xx_2[] = "xx.";
static const char __pyx_k_year[] = "year";
static const char __pyx_k_100_2[] = "\344\270\255\350\257\201100";
static const char __pyx_k_100_3[] = "\344\270\212\350\257\201100";
static const char __pyx_k_200_2[] = "\345\210\233\344\270\232200";
static const char __pyx_k_300_2[] = "\346\267\261\350\257\201300";
static const char __pyx_k_300_3[] = "\344\270\255\345\260\217300";
static const char __pyx_k_Union[] = "Union";
static const char __pyx_k_Y_m_d[] = "%Y%m%d";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_dtype[] = "dtype";
static const char __pyx_k_dumps[] = "dumps";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_group[] = "group";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_inf_2[] = "-inf";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_level[] = "level";
static const char __pyx_k_list1[] = "list1";
static const char __pyx_k_list2[] = "list2";
static const char __pyx_k_list3[] = "list3";
static const char __pyx_k_match[] = "match";
static const char __pyx_k_month[] = "month";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_today[] = "today";
static const char __pyx_k_total[] = "total";
static const char __pyx_k_trade[] = "trade";
static const char __pyx_k_upper[] = "upper";
static const char __pyx_k_utf_8[] = "utf-8";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_000001[] = "000001";
static const char __pyx_k_000003[] = "000003";
static const char __pyx_k_000009[] = "000009";
static const char __pyx_k_000010[] = "000010";
static const char __pyx_k_000011[] = "000011";
static const char __pyx_k_000012[] = "000012";
static const char __pyx_k_000013[] = "000013";
static const char __pyx_k_000016[] = "000016";
static const char __pyx_k_000132[] = "000132";
static const char __pyx_k_000133[] = "000133";
static const char __pyx_k_000300[] = "000300";
static const char __pyx_k_000688[] = "000688";
static const char __pyx_k_000852[] = "000852";
static const char __pyx_k_000903[] = "000903";
static const char __pyx_k_000904[] = "000904";
static const char __pyx_k_000905[] = "000905";
static const char __pyx_k_000906[] = "000906";
static const char __pyx_k_000985[] = "000985";
static const char __pyx_k_399001[] = "399001";
static const char __pyx_k_399002[] = "399002";
static const char __pyx_k_399003[] = "399003";
static const char __pyx_k_399004[] = "399004";
static const char __pyx_k_399005[] = "399005";
static const char __pyx_k_399006[] = "399006";
static const char __pyx_k_399007[] = "399007";
static const char __pyx_k_399008[] = "399008";
static const char __pyx_k_399019[] = "399019";
static const char __pyx_k_399020[] = "399020";
static const char __pyx_k_399100[] = "399100";
static const char __pyx_k_399106[] = "399106";
static const char __pyx_k_399293[] = "399293";
static const char __pyx_k_399550[] = "399550";
static const char __pyx_k_399750[] = "399750";
static const char __pyx_k_399850[] = "399850";
static const char __pyx_k_899050[] = "899050";
static const char __pyx_k_930050[] = "930050";
static const char __pyx_k_932000[] = "932000";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_chunks[] = "chunks";
static const char __pyx_k_coerce[] = "coerce";
static const char __pyx_k_dict_2[] = "dict";
static const char __pyx_k_dlmkts[] = "dlmkts";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_errors[] = "errors";
static const char __pyx_k_exists[] = "exists";
static const char __pyx_k_failed[] = " failed.";
static const char __pyx_k_fillna[] = "fillna";
static const char __pyx_k_getcwd[] = "getcwd";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_indent[] = "indent";
static const char __pyx_k_kwargs[] = "kwargs";
static const char __pyx_k_logger[] = "logger";
static const char __pyx_k_loguru[] = "loguru";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_pandas[] = "pandas";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_return[] = "return";
static const char __pyx_k_system[] = "system";
static const char __pyx_k_test_2[] = "__test__";
static const char __pyx_k_typing[] = "typing";
static const char __pyx_k_14_days[] = "14 days";
static const char __pyx_k_Counter[] = "Counter";
static const char __pyx_k_IOError[] = "IOError";
static const char __pyx_k_akshare[] = "##############################\346\233\264\346\226\260akshare\345\244\261\350\264\245";
static const char __pyx_k_code_ip[] = "code_ip";
static const char __pyx_k_data_in[] = "data_in";
static const char __pyx_k_default[] = "default";
static const char __pyx_k_dirname[] = "dirname";
static const char __pyx_k_enqueue[] = "enqueue";
static const char __pyx_k_findall[] = "findall";
static const char __pyx_k_groupby[] = "groupby";
static const char __pyx_k_inplace[] = "inplace";
static const char __pyx_k_pattern[] = "pattern";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_regions[] = "regions";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_updated[] = "updated";
static const char __pyx_k_use_cls[] = "use_cls";
static const char __pyx_k_warning[] = "warning";
static const char __pyx_k_weekday[] = "weekday";
static const char __pyx_k_write_f[] = "write_f";
static const char __pyx_k_20180101[] = "20180101";
static const char __pyx_k_all_list[] = "all_list";
static const char __pyx_k_baostock[] = "##############################\346\233\264\346\226\260baostock\345\244\261\350\264\245";
static const char __pyx_k_calendar[] = "calendar";
static const char __pyx_k_date_str[] = "date_str: ";
static const char __pyx_k_datetime[] = "datetime";
static const char __pyx_k_encoding[] = "encoding";
static const char __pyx_k_end_date[] = "end_date";
static const char __pyx_k_interval[] = "interval";
static const char __pyx_k_json_str[] = "json_str";
static const char __pyx_k_limit_up[] = "limit_up";
static const char __pyx_k_list_str[] = "list_str";
static const char __pyx_k_logs_dir[] = "logs_dir";
static const char __pyx_k_makedirs[] = "makedirs";
static const char __pyx_k_one_shot[] = "_one_shot";
static const char __pyx_k_previous[] = "previous";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_rotation[] = "rotation";
static const char __pyx_k_sessions[] = "sessions";
static const char __pyx_k_set_name[] = "__set_name__";
static const char __pyx_k_str_dict[] = "str_dict";
static const char __pyx_k_strftime[] = "strftime";
static const char __pyx_k_strptime[] = "strptime";
static const char __pyx_k_year_end[] = "year_end";
static const char __pyx_k_year_int[] = "year_int";
static const char __pyx_k_year_str[] = "year_str";
static const char __pyx_k_DataFrame[] = "DataFrame";
static const char __pyx_k_Json_file[] = "Json file ";
static const char __pyx_k_MyEncoder[] = "MyEncoder";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_akshare_2[] = "akshare";
static const char __pyx_k_all_index[] = "all_index";
static const char __pyx_k_ascending[] = "ascending";
static const char __pyx_k_attr_name[] = "attr_name";
static const char __pyx_k_audio_dir[] = "audio_dir";
static const char __pyx_k_data_list[] = "data_list";
static const char __pyx_k_date_type[] = "date_type";
static const char __pyx_k_directory[] = "directory";
static const char __pyx_k_full_code[] = "full_code";
static const char __pyx_k_input_str[] = "input_str";
static const char __pyx_k_isoformat[] = "isoformat";
static const char __pyx_k_listUnion[] = "listUnion";
static const char __pyx_k_log_trace[] = "log_trace";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_month_str[] = "month_str";
static const char __pyx_k_not_found[] = " not found.";
static const char __pyx_k_retention[] = "retention";
static const char __pyx_k_stock_log[] = "stock.log";
static const char __pyx_k_text_tail[] = "text_tail";
static const char __pyx_k_timedelta[] = "timedelta";
static const char __pyx_k_updateLib[] = "updateLib";
static const char __pyx_k_year_list[] = "year_list";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_attr_value[] = "attr_value";
static const char __pyx_k_attributes[] = "attributes";
static const char __pyx_k_date_str_2[] = "date_str";
static const char __pyx_k_given_date[] = "given_date";
static const char __pyx_k_index_code[] = "index_code";
static const char __pyx_k_index_name[] = "index_name";
static const char __pyx_k_is_session[] = "is_session";
static const char __pyx_k_iterencode[] = "iterencode";
static const char __pyx_k_monthrange[] = "monthrange";
static const char __pyx_k_start_date[] = "start_date";
static const char __pyx_k_stock_code[] = "stock_code";
static const char __pyx_k_stock_name[] = "stock_name";
static const char __pyx_k_today_date[] = "today_date";
static const char __pyx_k_trade_date[] = "trade_date";
static const char __pyx_k_trade_year[] = "trade_year";
static const char __pyx_k_union_list[] = "union_list";
static const char __pyx_k_year_start[] = "year_start";
static const char __pyx_k_JSONEncoder[] = "JSONEncoder";
static const char __pyx_k_assets_imgs[] = "/assets/imgs/";
static const char __pyx_k_assets_logs[] = "../assets/logs/";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_comma_index[] = "comma_index";
static const char __pyx_k_cookies_dir[] = "cookies_dir";
static const char __pyx_k_end_of_week[] = "end_of_week";
static const char __pyx_k_isocalendar[] = "isocalendar";
static const char __pyx_k_json_string[] = "json_string";
static const char __pyx_k_list_2_dict[] = "list_2_dict";
static const char __pyx_k_mro_entries[] = "__mro_entries__";
static const char __pyx_k_sh_calendar[] = "sh_calendar";
static const char __pyx_k_sort_values[] = "sort_values";
static const char __pyx_k_to_datetime[] = "to_datetime";
static const char __pyx_k_trade_month[] = "trade_month";
static const char __pyx_k_update_json[] = "update_json";
static const char __pyx_k_week_number[] = "week_number";
static const char __pyx_k_current_date[] = "current_date";
static const char __pyx_k_ensure_ascii[] = "ensure_ascii";
static const char __pyx_k_get_calendar[] = "get_calendar";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_is_session_2[] = "is_session: ";
static const char __pyx_k_list_end_idx[] = "list_end_idx";
static const char __pyx_k_loadJsonData[] = "loadJsonData";
static const char __pyx_k_month12_days[] = "month12_days";
static const char __pyx_k_new_date_str[] = "new date_str: ";
static const char __pyx_k_next_session[] = "next_session: ";
static const char __pyx_k_now_datetime[] = "now_datetime";
static const char __pyx_k_pd_DataFrame[] = "pd.DataFrame()";
static const char __pyx_k_session_open[] = "session_open: ";
static const char __pyx_k_stock_tfp_em[] = "stock_tfp_em";
static const char __pyx_k_testCalendar[] = "testCalendar";
static const char __pyx_k_wrapped_text[] = "wrapped_text";
static const char __pyx_k_PicklingError[] = "PicklingError";
static const char __pyx_k_all_data_list[] = "all_data_list";
static const char __pyx_k_assets_audios[] = "../assets/audios/";
static const char __pyx_k_assets_videos[] = "/assets/videos/";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_combined_list[] = "combined_list";
static const char __pyx_k_cover_img_dir[] = "cover_img_dir";
static const char __pyx_k_datetime64_ns[] = "datetime64[ns]";
static const char __pyx_k_first_weekday[] = "first_weekday";
static const char __pyx_k_init_subclass[] = "__init_subclass__";
static const char __pyx_k_intersec_list[] = "intersec_list";
static const char __pyx_k_list_end_idxs[] = "list_end_idxs";
static const char __pyx_k_session_close[] = "session_close: ";
static const char __pyx_k_start_of_week[] = "start_of_week";
static const char __pyx_k_strategyCount[] = "strategyCount";
static const char __pyx_k_strategy_name[] = "strategy_name";
static const char __pyx_k_Open_json_file[] = "Open json file ";
static const char __pyx_k_assets_cookies[] = "../assets/cookies/";
static const char __pyx_k_dumpJsonToFile[] = "dumpJsonToFile";
static const char __pyx_k_json_file_name[] = "json_file_name";
static const char __pyx_k_list_start_idx[] = "list_start_idx";
static const char __pyx_k_load_json_file[] = "load_json_file";
static const char __pyx_k_next_session_2[] = "next_session";
static const char __pyx_k_number_of_days[] = "number_of_days";
static const char __pyx_k_session_offset[] = "session_offset: ";
static const char __pyx_k_session_open_2[] = "session_open";
static const char __pyx_k_startWithDigit[] = "startWithDigit";
static const char __pyx_k_type_next_date[] = "type next date = ";
static const char __pyx_k_updatelog_json[] = "_updatelog.json";
static const char __pyx_k_Union_Dict_None[] = "Union[Dict, None]";
static const char __pyx_k_Union_List_None[] = "Union[List, None]";
static const char __pyx_k_checkCreatePath[] = "checkCreatePath";
static const char __pyx_k_date_to_session[] = "date_to_session";
static const char __pyx_k_full_stock_code[] = "full_stock_code";
static const char __pyx_k_getStockLimitUp[] = "getStockLimitUp";
static const char __pyx_k_has_update_file[] = "has_update_file";
static const char __pyx_k_insert_newlines[] = "insert_newlines";
static const char __pyx_k_is_serializable[] = "is_serializable";
static const char __pyx_k_list_start_idxs[] = "list_start_idxs";
static const char __pyx_k_session_close_2[] = "session_close";
static const char __pyx_k_stock_tfp_em_df[] = "stock_tfp_em_df";
static const char __pyx_k_MyEncoder_encode[] = "MyEncoder.encode";
static const char __pyx_k_assets_cover_img[] = "/assets/cover_img/";
static const char __pyx_k_cleaned_list_str[] = "cleaned_list_str";
static const char __pyx_k_edge_driver_path[] = "edge_driver_path";
static const char __pyx_k_getFullStockCode[] = "getFullStockCode";
static const char __pyx_k_getIndexCodeName[] = "getIndexCodeName";
static const char __pyx_k_latest_trade_day[] = "latest_trade_day";
static const char __pyx_k_listIntersection[] = "listIntersection";
static const char __pyx_k_previous_session[] = "previous_session";
static const char __pyx_k_session_offset_2[] = "session_offset";
static const char __pyx_k_MyEncoder_default[] = "MyEncoder.default";
static const char __pyx_k_current_directory[] = "current_directory";
static const char __pyx_k_getLatestTradeDay[] = "getLatestTradeDay";
static const char __pyx_k_intersection_list[] = "intersection_list";
static const char __pyx_k_negative_infinity[] = "negative_infinity";
static const char __pyx_k_positive_infinity[] = "positive_infinity";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_exchange_calendars[] = "exchange_calendars";
static const char __pyx_k_getSuspendedStocks[] = "getSuspendedStocks";
static const char __pyx_k_img_save_path_root[] = "img_save_path_root";
static const char __pyx_k_isWeekLastTradeDay[] = "isWeekLastTradeDay";
static const char __pyx_k_isYearLastTradeDay[] = "isYearLastTradeDay";
static const char __pyx_k_latest_trade_day_2[] = "latest_trade_day = ";
static const char __pyx_k_previous_session_2[] = "previous_session: ";
static const char __pyx_k_strategy_code_list[] = "strategy_code_list";
static const char __pyx_k_update_db_logs_dir[] = "update_db_logs_dir";
static const char __pyx_k_update_lib_succeed[] = "update_lib_succeed";
static const char __pyx_k_current_directory_2[] = "current_directory = ";
static const char __pyx_k_getDateDistribution[] = "getDateDistribution";
static const char __pyx_k_getYearStartEndDate[] = "getYearStartEndDate";
static const char __pyx_k_isMonthLastTradeDay[] = "isMonthLastTradeDay";
static const char __pyx_k_tbstock_utils_utils[] = "tbstock.utils.utils";
static const char __pyx_k_are_non_trading_days[] = " are non-trading days";
static const char __pyx_k_getMonthStartEndDate[] = "getMonthStartEndDate";
static const char __pyx_k_isAPrimaryBoardStock[] = "isAPrimaryBoardStock";
static const char __pyx_k_splitDataframeByYear[] = "splitDataframeByYear";
static const char __pyx_k_suspended_stock_list[] = "suspended_stock_list";
static const char __pyx_k_video_save_path_root[] = "video_save_path_root";
static const char __pyx_k_Start_this_log_record[] = "Start this log record.\n";
static const char __pyx_k_assets_update_db_logs[] = "../assets/update_db_logs/";
static const char __pyx_k_check_serializability[] = "check_serializability";
static const char __pyx_k_getWeekStartEndByDate[] = "getWeekStartEndByDate";
static const char __pyx_k_isStockDataSaveToMysql[] = "isStockDataSaveToMysql";
static const char __pyx_k_non_serializable_attrs[] = "non_serializable_attrs";
static const char __pyx_k_tbstock_utils_utils_py[] = "tbstock/utils/utils.py";
static const char __pyx_k_update_strategy_logs_dir[] = "update_strategy_logs_dir";
static const char __pyx_k_MyEncoder_insert_newlines[] = "MyEncoder.insert_newlines";
static const char __pyx_k_data_must_be_a_dictionary[] = "data must be a dictionary";
static const char __pyx_k_assets_update_strategy_logs[] = "../assets/update_strategy_logs/";
static const char __pyx_k_pip_install_akshare_upgrade[] = "pip install akshare --upgrade";
static const char __pyx_k_All_days_in_the_week_of_this[] = "All days in the week of this ";
static const char __pyx_k_extractAdministrativeRegions[] = "extractAdministrativeRegions";
static const char __pyx_k_pip_install_baostock_upgrade[] = "pip install baostock --upgrade";
static const char __pyx_k_home_paco_norm_envs_softwares_e[] = "/home/paco/norm_envs/softwares/edgedriver_linux64/msedgedriver";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_checkCreatePath(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_directory); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_2getLatestTradeDay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_today_date); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_4getIndexCodeName(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_6updateLib(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_8is_serializable(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_10check_serializability(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_12testCalendar(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_14extractAdministrativeRegions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_16startWithDigit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_input_str); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_18listIntersection(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data_list, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_20listUnion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data_list, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_22strategyCount(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_24getFullStockCode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_stock_code, PyObject *__pyx_v_mode); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_26isAPrimaryBoardStock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_stock_code); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_28getStockLimitUp(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_stock_code, PyObject *__pyx_v_stock_name); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_30splitDataframeByYear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data_in); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_9MyEncoder_default(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_9MyEncoder_2insert_newlines(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_interval); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_9MyEncoder_4encode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_32loadJsonData(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_load_json_file, PyObject *__pyx_v_json_file_name); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_34dumpJsonToFile(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_load_json_file, PyObject *__pyx_v_update_json, PyObject *__pyx_v_json_file_name, PyObject *__pyx_v_use_cls); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_36getYearStartEndDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_year_str, PyObject *__pyx_v_mode); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_38getDateDistribution(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_start_date, PyObject *__pyx_v_end_date); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_40getMonthStartEndDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_year_str, PyObject *__pyx_v_month_str, PyObject *__pyx_v_mode); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_42getSuspendedStocks(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_44getWeekStartEndByDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_given_date, PyObject *__pyx_v_mode); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_46isStockDataSaveToMysql(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_48isWeekLastTradeDay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_50isMonthLastTradeDay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_52isYearLastTradeDay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date); /* proto */
static PyObject *__pyx_pf_7tbstock_5utils_5utils_54test(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyObject *__pyx_kp_u_;
  PyObject *__pyx_kp_s_00;
  PyObject *__pyx_kp_s_000001;
  PyObject *__pyx_kp_s_000003;
  PyObject *__pyx_kp_s_000009;
  PyObject *__pyx_kp_s_000010;
  PyObject *__pyx_kp_s_000011;
  PyObject *__pyx_kp_s_000012;
  PyObject *__pyx_kp_s_000013;
  PyObject *__pyx_kp_s_000016;
  PyObject *__pyx_kp_s_000132;
  PyObject *__pyx_kp_s_000133;
  PyObject *__pyx_kp_s_000300;
  PyObject *__pyx_kp_s_000688;
  PyObject *__pyx_kp_s_000852;
  PyObject *__pyx_kp_s_000903;
  PyObject *__pyx_kp_s_000904;
  PyObject *__pyx_kp_s_000905;
  PyObject *__pyx_kp_s_000906;
  PyObject *__pyx_kp_s_000985;
  PyObject *__pyx_kp_u_01;
  PyObject *__pyx_kp_s_0101;
  PyObject *__pyx_kp_u_02d;
  PyObject *__pyx_kp_s_1;
  PyObject *__pyx_kp_s_10;
  PyObject *__pyx_kp_s_100;
  PyObject *__pyx_kp_s_1000;
  PyObject *__pyx_kp_s_100R;
  PyObject *__pyx_kp_s_100_2;
  PyObject *__pyx_kp_s_100_3;
  PyObject *__pyx_kp_s_14_days;
  PyObject *__pyx_kp_s_150;
  PyObject *__pyx_kp_s_180;
  PyObject *__pyx_kp_s_2;
  PyObject *__pyx_kp_s_200;
  PyObject *__pyx_kp_s_2000;
  PyObject *__pyx_kp_s_200_2;
  PyObject *__pyx_kp_s_20180101;
  PyObject *__pyx_kp_s_3;
  PyObject *__pyx_kp_s_30;
  PyObject *__pyx_kp_s_300;
  PyObject *__pyx_kp_s_300_2;
  PyObject *__pyx_kp_s_300_3;
  PyObject *__pyx_kp_s_380;
  PyObject *__pyx_kp_s_399001;
  PyObject *__pyx_kp_s_399002;
  PyObject *__pyx_kp_s_399003;
  PyObject *__pyx_kp_s_399004;
  PyObject *__pyx_kp_s_399005;
  PyObject *__pyx_kp_s_399006;
  PyObject *__pyx_kp_s_399007;
  PyObject *__pyx_kp_s_399008;
  PyObject *__pyx_kp_s_399019;
  PyObject *__pyx_kp_s_399020;
  PyObject *__pyx_kp_s_399100;
  PyObject *__pyx_kp_s_399106;
  PyObject *__pyx_kp_s_399293;
  PyObject *__pyx_kp_s_399550;
  PyObject *__pyx_kp_s_399750;
  PyObject *__pyx_kp_s_399850;
  PyObject *__pyx_kp_s_4;
  PyObject *__pyx_kp_s_5;
  PyObject *__pyx_kp_s_50;
  PyObject *__pyx_kp_s_500;
  PyObject *__pyx_kp_s_50MB;
  PyObject *__pyx_kp_s_50_2;
  PyObject *__pyx_kp_s_50_3;
  PyObject *__pyx_kp_s_50_4;
  PyObject *__pyx_kp_s_50_5;
  PyObject *__pyx_kp_s_50_6;
  PyObject *__pyx_kp_s_60;
  PyObject *__pyx_kp_s_68;
  PyObject *__pyx_kp_s_7;
  PyObject *__pyx_kp_s_8;
  PyObject *__pyx_kp_s_800;
  PyObject *__pyx_kp_s_899050;
  PyObject *__pyx_kp_s_930050;
  PyObject *__pyx_kp_s_932000;
  PyObject *__pyx_kp_s_A50;
  PyObject *__pyx_kp_u_All_days_in_the_week_of_this;
  PyObject *__pyx_n_s_Counter;
  PyObject *__pyx_n_s_DataFrame;
  PyObject *__pyx_n_s_Dict;
  PyObject *__pyx_n_s_INFO;
  PyObject *__pyx_n_s_IOError;
  PyObject *__pyx_n_s_JSONEncoder;
  PyObject *__pyx_kp_u_Json_file;
  PyObject *__pyx_n_s_List;
  PyObject *__pyx_n_s_MyEncoder;
  PyObject *__pyx_n_s_MyEncoder_default;
  PyObject *__pyx_n_s_MyEncoder_encode;
  PyObject *__pyx_n_s_MyEncoder_insert_newlines;
  PyObject *__pyx_kp_u_Open_json_file;
  PyObject *__pyx_n_s_PicklingError;
  PyObject *__pyx_kp_s_R;
  PyObject *__pyx_n_s_ST;
  PyObject *__pyx_kp_s_Start_this_log_record;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_n_s_Union;
  PyObject *__pyx_kp_s_Union_Dict_None;
  PyObject *__pyx_kp_s_Union_List_None;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_n_s_XSHG;
  PyObject *__pyx_kp_s_XX;
  PyObject *__pyx_kp_s_Y_m_d;
  PyObject *__pyx_kp_s__10;
  PyObject *__pyx_kp_s__11;
  PyObject *__pyx_n_s__111;
  PyObject *__pyx_kp_s__12;
  PyObject *__pyx_kp_s__13;
  PyObject *__pyx_kp_s__14;
  PyObject *__pyx_kp_s__15;
  PyObject *__pyx_kp_s__16;
  PyObject *__pyx_kp_s__17;
  PyObject *__pyx_kp_s__18;
  PyObject *__pyx_kp_s__19;
  PyObject *__pyx_kp_u__19;
  PyObject *__pyx_kp_u__2;
  PyObject *__pyx_kp_s__22;
  PyObject *__pyx_kp_s__28;
  PyObject *__pyx_kp_s__29;
  PyObject *__pyx_kp_u__3;
  PyObject *__pyx_kp_s__30;
  PyObject *__pyx_kp_s__31;
  PyObject *__pyx_kp_s__32;
  PyObject *__pyx_kp_s__33;
  PyObject *__pyx_kp_s__36;
  PyObject *__pyx_kp_s__38;
  PyObject *__pyx_n_s__39;
  PyObject *__pyx_kp_s__4;
  PyObject *__pyx_kp_s__5;
  PyObject *__pyx_kp_s__6;
  PyObject *__pyx_kp_s__7;
  PyObject *__pyx_kp_s__8;
  PyObject *__pyx_kp_s__9;
  PyObject *__pyx_n_s_a;
  PyObject *__pyx_n_s_add;
  PyObject *__pyx_n_s_ak;
  PyObject *__pyx_kp_s_akshare;
  PyObject *__pyx_n_s_akshare_2;
  PyObject *__pyx_n_s_all_data_list;
  PyObject *__pyx_n_s_all_index;
  PyObject *__pyx_n_s_all_list;
  PyObject *__pyx_n_s_append;
  PyObject *__pyx_kp_u_are_non_trading_days;
  PyObject *__pyx_n_s_arg;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_n_s_ascending;
  PyObject *__pyx_kp_s_assets_audios;
  PyObject *__pyx_kp_s_assets_cookies;
  PyObject *__pyx_kp_s_assets_cover_img;
  PyObject *__pyx_kp_s_assets_imgs;
  PyObject *__pyx_kp_s_assets_logs;
  PyObject *__pyx_kp_s_assets_update_db_logs;
  PyObject *__pyx_kp_s_assets_update_strategy_logs;
  PyObject *__pyx_kp_s_assets_videos;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_attr_name;
  PyObject *__pyx_n_s_attr_value;
  PyObject *__pyx_n_s_attributes;
  PyObject *__pyx_n_s_audio_dir;
  PyObject *__pyx_n_s_b;
  PyObject *__pyx_kp_s_baostock;
  PyObject *__pyx_n_s_bj;
  PyObject *__pyx_n_s_bool;
  PyObject *__pyx_n_s_c;
  PyObject *__pyx_n_s_calendar;
  PyObject *__pyx_n_s_checkCreatePath;
  PyObject *__pyx_n_s_check_serializability;
  PyObject *__pyx_n_s_chunks;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_cleaned_list_str;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_cls;
  PyObject *__pyx_n_s_code_ip;
  PyObject *__pyx_n_s_coerce;
  PyObject *__pyx_n_s_collections;
  PyObject *__pyx_n_s_combined_list;
  PyObject *__pyx_n_s_comma_index;
  PyObject *__pyx_n_s_cookies_dir;
  PyObject *__pyx_n_s_count;
  PyObject *__pyx_n_s_cover_img_dir;
  PyObject *__pyx_n_s_current_date;
  PyObject *__pyx_n_s_current_directory;
  PyObject *__pyx_kp_s_current_directory_2;
  PyObject *__pyx_kp_s_d;
  PyObject *__pyx_n_s_data;
  PyObject *__pyx_n_s_data_in;
  PyObject *__pyx_n_s_data_list;
  PyObject *__pyx_kp_s_data_must_be_a_dictionary;
  PyObject *__pyx_n_s_date;
  PyObject *__pyx_kp_s_date_str;
  PyObject *__pyx_n_s_date_str_2;
  PyObject *__pyx_n_s_date_to_session;
  PyObject *__pyx_n_s_date_type;
  PyObject *__pyx_n_s_datetime;
  PyObject *__pyx_kp_s_datetime64_ns;
  PyObject *__pyx_n_s_day;
  PyObject *__pyx_n_s_days;
  PyObject *__pyx_n_s_default;
  PyObject *__pyx_n_s_df;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_n_s_dict_2;
  PyObject *__pyx_n_s_diff;
  PyObject *__pyx_n_s_directory;
  PyObject *__pyx_n_s_dirname;
  PyObject *__pyx_n_s_dlmkts;
  PyObject *__pyx_n_s_doc;
  PyObject *__pyx_n_s_dt;
  PyObject *__pyx_n_s_dtype;
  PyObject *__pyx_n_s_dumpJsonToFile;
  PyObject *__pyx_n_s_dumps;
  PyObject *__pyx_n_s_edge_driver_path;
  PyObject *__pyx_n_s_encode;
  PyObject *__pyx_n_s_encoding;
  PyObject *__pyx_n_s_end_date;
  PyObject *__pyx_n_s_end_of_week;
  PyObject *__pyx_n_s_enqueue;
  PyObject *__pyx_n_s_ensure_ascii;
  PyObject *__pyx_n_s_enter;
  PyObject *__pyx_n_s_error;
  PyObject *__pyx_n_s_errors;
  PyObject *__pyx_n_s_exchange_calendars;
  PyObject *__pyx_n_s_exists;
  PyObject *__pyx_n_s_exit;
  PyObject *__pyx_n_s_extractAdministrativeRegions;
  PyObject *__pyx_n_s_f1;
  PyObject *__pyx_n_s_f10;
  PyObject *__pyx_n_s_f11;
  PyObject *__pyx_n_s_f115;
  PyObject *__pyx_n_s_f12;
  PyObject *__pyx_n_s_f128;
  PyObject *__pyx_n_s_f13;
  PyObject *__pyx_n_s_f136;
  PyObject *__pyx_n_s_f14;
  PyObject *__pyx_n_s_f140;
  PyObject *__pyx_n_s_f141;
  PyObject *__pyx_n_s_f15;
  PyObject *__pyx_n_s_f152;
  PyObject *__pyx_n_s_f16;
  PyObject *__pyx_n_s_f17;
  PyObject *__pyx_n_s_f18;
  PyObject *__pyx_n_s_f2;
  PyObject *__pyx_n_s_f20;
  PyObject *__pyx_n_s_f21;
  PyObject *__pyx_n_s_f22;
  PyObject *__pyx_n_s_f23;
  PyObject *__pyx_n_s_f24;
  PyObject *__pyx_n_s_f25;
  PyObject *__pyx_n_s_f26;
  PyObject *__pyx_n_s_f3;
  PyObject *__pyx_n_s_f4;
  PyObject *__pyx_n_s_f5;
  PyObject *__pyx_n_s_f6;
  PyObject *__pyx_n_s_f62;
  PyObject *__pyx_n_s_f7;
  PyObject *__pyx_n_s_f8;
  PyObject *__pyx_n_s_f9;
  PyObject *__pyx_kp_u_failed;
  PyObject *__pyx_n_s_file;
  PyObject *__pyx_n_s_fillna;
  PyObject *__pyx_n_s_find;
  PyObject *__pyx_n_s_findall;
  PyObject *__pyx_n_s_first_weekday;
  PyObject *__pyx_n_s_full;
  PyObject *__pyx_n_s_full_code;
  PyObject *__pyx_n_s_full_stock_code;
  PyObject *__pyx_n_s_getDateDistribution;
  PyObject *__pyx_n_s_getFullStockCode;
  PyObject *__pyx_n_s_getIndexCodeName;
  PyObject *__pyx_n_s_getLatestTradeDay;
  PyObject *__pyx_n_s_getMonthStartEndDate;
  PyObject *__pyx_n_s_getStockLimitUp;
  PyObject *__pyx_n_s_getSuspendedStocks;
  PyObject *__pyx_n_s_getWeekStartEndByDate;
  PyObject *__pyx_n_s_getYearStartEndDate;
  PyObject *__pyx_n_s_get_calendar;
  PyObject *__pyx_n_s_getcwd;
  PyObject *__pyx_n_s_given_date;
  PyObject *__pyx_n_s_group;
  PyObject *__pyx_n_s_groupby;
  PyObject *__pyx_n_s_has_update_file;
  PyObject *__pyx_kp_s_home_paco_norm_envs_softwares_e;
  PyObject *__pyx_n_s_hour;
  PyObject *__pyx_n_s_i;
  PyObject *__pyx_n_s_img_save_path_root;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_indent;
  PyObject *__pyx_n_s_index;
  PyObject *__pyx_n_s_index_code;
  PyObject *__pyx_n_s_index_name;
  PyObject *__pyx_n_s_inf;
  PyObject *__pyx_kp_s_inf_2;
  PyObject *__pyx_n_s_info;
  PyObject *__pyx_n_s_init_subclass;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_inplace;
  PyObject *__pyx_n_s_input_str;
  PyObject *__pyx_n_s_insert_newlines;
  PyObject *__pyx_n_s_intersec_list;
  PyObject *__pyx_n_s_intersection_list;
  PyObject *__pyx_n_s_interval;
  PyObject *__pyx_n_s_isAPrimaryBoardStock;
  PyObject *__pyx_n_s_isMonthLastTradeDay;
  PyObject *__pyx_n_s_isStockDataSaveToMysql;
  PyObject *__pyx_n_s_isWeekLastTradeDay;
  PyObject *__pyx_n_s_isYearLastTradeDay;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_n_s_is_serializable;
  PyObject *__pyx_n_s_is_session;
  PyObject *__pyx_kp_s_is_session_2;
  PyObject *__pyx_n_s_isocalendar;
  PyObject *__pyx_n_s_isoformat;
  PyObject *__pyx_n_s_items;
  PyObject *__pyx_n_s_iterencode;
  PyObject *__pyx_n_s_join;
  PyObject *__pyx_n_s_json;
  PyObject *__pyx_n_s_json_file_name;
  PyObject *__pyx_n_s_json_str;
  PyObject *__pyx_n_s_json_string;
  PyObject *__pyx_n_s_key;
  PyObject *__pyx_n_s_keys;
  PyObject *__pyx_n_s_kwargs;
  PyObject *__pyx_n_s_latest_trade_day;
  PyObject *__pyx_kp_u_latest_trade_day_2;
  PyObject *__pyx_n_s_level;
  PyObject *__pyx_n_s_limit_up;
  PyObject *__pyx_n_s_list;
  PyObject *__pyx_n_s_list1;
  PyObject *__pyx_n_s_list2;
  PyObject *__pyx_n_s_list3;
  PyObject *__pyx_n_s_listIntersection;
  PyObject *__pyx_n_s_listUnion;
  PyObject *__pyx_n_s_list_2_dict;
  PyObject *__pyx_n_s_list_end_idx;
  PyObject *__pyx_n_s_list_end_idxs;
  PyObject *__pyx_n_s_list_start_idx;
  PyObject *__pyx_n_s_list_start_idxs;
  PyObject *__pyx_n_s_list_str;
  PyObject *__pyx_n_s_load;
  PyObject *__pyx_n_s_loadJsonData;
  PyObject *__pyx_n_s_load_json_file;
  PyObject *__pyx_n_s_log_trace;
  PyObject *__pyx_n_s_logger;
  PyObject *__pyx_n_s_logs_dir;
  PyObject *__pyx_n_s_loguru;
  PyObject *__pyx_n_s_lt;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_makedirs;
  PyObject *__pyx_n_s_map;
  PyObject *__pyx_n_s_match;
  PyObject *__pyx_n_s_metaclass;
  PyObject *__pyx_n_s_mode;
  PyObject *__pyx_n_s_module;
  PyObject *__pyx_n_s_month;
  PyObject *__pyx_n_s_month12_days;
  PyObject *__pyx_n_s_month_str;
  PyObject *__pyx_n_s_monthrange;
  PyObject *__pyx_n_s_mro_entries;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_negative_infinity;
  PyObject *__pyx_kp_s_new_date_str;
  PyObject *__pyx_n_s_next;
  PyObject *__pyx_kp_s_next_session;
  PyObject *__pyx_n_s_next_session_2;
  PyObject *__pyx_n_s_non_serializable_attrs;
  PyObject *__pyx_kp_u_not_found;
  PyObject *__pyx_n_s_now_datetime;
  PyObject *__pyx_n_s_num;
  PyObject *__pyx_n_s_number_of_days;
  PyObject *__pyx_n_s_obj;
  PyObject *__pyx_n_s_one_shot;
  PyObject *__pyx_n_s_open;
  PyObject *__pyx_n_s_os;
  PyObject *__pyx_n_s_out;
  PyObject *__pyx_n_s_pandas;
  PyObject *__pyx_n_s_path;
  PyObject *__pyx_n_s_pattern;
  PyObject *__pyx_n_s_pd;
  PyObject *__pyx_kp_s_pd_DataFrame;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_kp_s_pip_install_akshare_upgrade;
  PyObject *__pyx_kp_s_pip_install_baostock_upgrade;
  PyObject *__pyx_n_s_positive_infinity;
  PyObject *__pyx_n_s_prepare;
  PyObject *__pyx_n_s_previous;
  PyObject *__pyx_n_s_previous_session;
  PyObject *__pyx_kp_s_previous_session_2;
  PyObject *__pyx_n_s_print;
  PyObject *__pyx_n_s_qualname;
  PyObject *__pyx_n_s_r;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_rc;
  PyObject *__pyx_n_s_re;
  PyObject *__pyx_n_s_regions;
  PyObject *__pyx_n_s_replace;
  PyObject *__pyx_n_s_result;
  PyObject *__pyx_n_s_retention;
  PyObject *__pyx_n_s_return;
  PyObject *__pyx_n_s_rotation;
  PyObject *__pyx_n_s_row;
  PyObject *__pyx_n_s_rt;
  PyObject *__pyx_kp_s_s;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_kp_s_session_close;
  PyObject *__pyx_n_s_session_close_2;
  PyObject *__pyx_kp_s_session_offset;
  PyObject *__pyx_n_s_session_offset_2;
  PyObject *__pyx_kp_s_session_open;
  PyObject *__pyx_n_s_session_open_2;
  PyObject *__pyx_n_s_sessions;
  PyObject *__pyx_n_s_set_name;
  PyObject *__pyx_n_s_sh;
  PyObject *__pyx_n_s_sh_calendar;
  PyObject *__pyx_n_s_sort_values;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_splitDataframeByYear;
  PyObject *__pyx_n_s_startWithDigit;
  PyObject *__pyx_n_s_start_date;
  PyObject *__pyx_n_s_start_of_week;
  PyObject *__pyx_n_s_stock_code;
  PyObject *__pyx_kp_s_stock_log;
  PyObject *__pyx_n_s_stock_name;
  PyObject *__pyx_n_s_stock_tfp_em;
  PyObject *__pyx_n_s_stock_tfp_em_df;
  PyObject *__pyx_n_s_str;
  PyObject *__pyx_n_s_str_dict;
  PyObject *__pyx_n_s_strategyCount;
  PyObject *__pyx_n_s_strategy_code_list;
  PyObject *__pyx_n_s_strategy_name;
  PyObject *__pyx_n_s_strftime;
  PyObject *__pyx_n_s_strptime;
  PyObject *__pyx_n_s_sub;
  PyObject *__pyx_n_s_sum;
  PyObject *__pyx_n_s_super;
  PyObject *__pyx_n_s_suspended_stock_list;
  PyObject *__pyx_n_s_svr;
  PyObject *__pyx_n_s_system;
  PyObject *__pyx_n_s_sz;
  PyObject *__pyx_n_s_tbstock_utils_utils;
  PyObject *__pyx_kp_s_tbstock_utils_utils_py;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_testCalendar;
  PyObject *__pyx_n_s_test_2;
  PyObject *__pyx_n_s_text;
  PyObject *__pyx_n_s_text_tail;
  PyObject *__pyx_n_s_timedelta;
  PyObject *__pyx_n_s_to_datetime;
  PyObject *__pyx_n_s_today;
  PyObject *__pyx_n_s_today_date;
  PyObject *__pyx_n_s_total;
  PyObject *__pyx_n_s_trade;
  PyObject *__pyx_n_s_trade_date;
  PyObject *__pyx_n_s_trade_month;
  PyObject *__pyx_n_s_trade_year;
  PyObject *__pyx_kp_s_type_next_date;
  PyObject *__pyx_n_s_typing;
  PyObject *__pyx_n_s_union_list;
  PyObject *__pyx_n_s_updateLib;
  PyObject *__pyx_n_s_update_db_logs_dir;
  PyObject *__pyx_n_s_update_json;
  PyObject *__pyx_n_s_update_lib_succeed;
  PyObject *__pyx_n_s_update_strategy_logs_dir;
  PyObject *__pyx_n_s_updated;
  PyObject *__pyx_kp_s_updatelog_json;
  PyObject *__pyx_n_s_upper;
  PyObject *__pyx_n_s_use_cls;
  PyObject *__pyx_kp_s_utf_8;
  PyObject *__pyx_n_s_video_save_path_root;
  PyObject *__pyx_n_s_w;
  PyObject *__pyx_n_s_warning;
  PyObject *__pyx_n_s_week;
  PyObject *__pyx_n_s_week_number;
  PyObject *__pyx_n_s_weekday;
  PyObject *__pyx_n_s_wrapped_text;
  PyObject *__pyx_n_s_write;
  PyObject *__pyx_n_s_write_f;
  PyObject *__pyx_n_s_xx;
  PyObject *__pyx_kp_s_xx_2;
  PyObject *__pyx_n_s_year;
  PyObject *__pyx_n_s_year_end;
  PyObject *__pyx_n_s_year_int;
  PyObject *__pyx_n_s_year_list;
  PyObject *__pyx_n_s_year_start;
  PyObject *__pyx_n_s_year_str;
  PyObject *__pyx_float_0_0;
  PyObject *__pyx_float_0_1;
  PyObject *__pyx_float_0_2;
  PyObject *__pyx_float_0_7;
  PyObject *__pyx_float_0_8;
  PyObject *__pyx_float_0_9;
  PyObject *__pyx_float_1_0;
  PyObject *__pyx_float_1_1;
  PyObject *__pyx_float_1_3;
  PyObject *__pyx_float_1_5;
  PyObject *__pyx_float_1_6;
  PyObject *__pyx_float_1_9;
  PyObject *__pyx_float_2_3;
  PyObject *__pyx_float_2_6;
  PyObject *__pyx_float_2_7;
  PyObject *__pyx_float_3_0;
  PyObject *__pyx_float_3_6;
  PyObject *__pyx_float_0_01;
  PyObject *__pyx_float_0_02;
  PyObject *__pyx_float_0_03;
  PyObject *__pyx_float_0_04;
  PyObject *__pyx_float_0_05;
  PyObject *__pyx_float_0_06;
  PyObject *__pyx_float_0_08;
  PyObject *__pyx_float_0_14;
  PyObject *__pyx_float_0_15;
  PyObject *__pyx_float_0_16;
  PyObject *__pyx_float_0_17;
  PyObject *__pyx_float_0_18;
  PyObject *__pyx_float_0_24;
  PyObject *__pyx_float_0_25;
  PyObject *__pyx_float_0_29;
  PyObject *__pyx_float_0_33;
  PyObject *__pyx_float_0_34;
  PyObject *__pyx_float_0_37;
  PyObject *__pyx_float_0_38;
  PyObject *__pyx_float_0_42;
  PyObject *__pyx_float_0_44;
  PyObject *__pyx_float_0_47;
  PyObject *__pyx_float_0_54;
  PyObject *__pyx_float_0_57;
  PyObject *__pyx_float_0_61;
  PyObject *__pyx_float_0_65;
  PyObject *__pyx_float_0_66;
  PyObject *__pyx_float_0_69;
  PyObject *__pyx_float_0_77;
  PyObject *__pyx_float_0_78;
  PyObject *__pyx_float_0_82;
  PyObject *__pyx_float_0_83;
  PyObject *__pyx_float_0_84;
  PyObject *__pyx_float_0_87;
  PyObject *__pyx_float_0_89;
  PyObject *__pyx_float_0_91;
  PyObject *__pyx_float_0_92;
  PyObject *__pyx_float_0_93;
  PyObject *__pyx_float_0_95;
  PyObject *__pyx_float_0_96;
  PyObject *__pyx_float_0_97;
  PyObject *__pyx_float_0_98;
  PyObject *__pyx_float_0_99;
  PyObject *__pyx_float_1_01;
  PyObject *__pyx_float_1_03;
  PyObject *__pyx_float_1_04;
  PyObject *__pyx_float_1_05;
  PyObject *__pyx_float_1_08;
  PyObject *__pyx_float_1_09;
  PyObject *__pyx_float_1_11;
  PyObject *__pyx_float_1_12;
  PyObject *__pyx_float_1_14;
  PyObject *__pyx_float_1_21;
  PyObject *__pyx_float_1_22;
  PyObject *__pyx_float_1_24;
  PyObject *__pyx_float_1_28;
  PyObject *__pyx_float_1_29;
  PyObject *__pyx_float_1_31;
  PyObject *__pyx_float_1_34;
  PyObject *__pyx_float_1_37;
  PyObject *__pyx_float_1_39;
  PyObject *__pyx_float_1_41;
  PyObject *__pyx_float_1_42;
  PyObject *__pyx_float_1_48;
  PyObject *__pyx_float_1_49;
  PyObject *__pyx_float_1_51;
  PyObject *__pyx_float_1_52;
  PyObject *__pyx_float_1_53;
  PyObject *__pyx_float_1_55;
  PyObject *__pyx_float_1_56;
  PyObject *__pyx_float_1_63;
  PyObject *__pyx_float_1_65;
  PyObject *__pyx_float_1_66;
  PyObject *__pyx_float_1_69;
  PyObject *__pyx_float_1_83;
  PyObject *__pyx_float_1_88;
  PyObject *__pyx_float_1_96;
  PyObject *__pyx_float_1_97;
  PyObject *__pyx_float_1_98;
  PyObject *__pyx_float_2_01;
  PyObject *__pyx_float_2_07;
  PyObject *__pyx_float_2_08;
  PyObject *__pyx_float_2_19;
  PyObject *__pyx_float_2_25;
  PyObject *__pyx_float_2_26;
  PyObject *__pyx_float_2_28;
  PyObject *__pyx_float_2_31;
  PyObject *__pyx_float_2_41;
  PyObject *__pyx_float_2_48;
  PyObject *__pyx_float_2_49;
  PyObject *__pyx_float_2_52;
  PyObject *__pyx_float_2_57;
  PyObject *__pyx_float_2_62;
  PyObject *__pyx_float_2_77;
  PyObject *__pyx_float_2_81;
  PyObject *__pyx_float_3_07;
  PyObject *__pyx_float_3_12;
  PyObject *__pyx_float_3_35;
  PyObject *__pyx_float_3_83;
  PyObject *__pyx_float_3_94;
  PyObject *__pyx_float_3_99;
  PyObject *__pyx_float_33_8;
  PyObject *__pyx_float_4_17;
  PyObject *__pyx_float_4_54;
  PyObject *__pyx_float_5_64;
  PyObject *__pyx_float_5_94;
  PyObject *__pyx_float_6_33;
  PyObject *__pyx_float_6_79;
  PyObject *__pyx_float_6_81;
  PyObject *__pyx_float_15_27;
  PyObject *__pyx_float_22_72;
  PyObject *__pyx_float_25_27;
  PyObject *__pyx_float_60_05;
  PyObject *__pyx_float_1022_9;
  PyObject *__pyx_float_1031_8;
  PyObject *__pyx_float_1853_0;
  PyObject *__pyx_float_212_89;
  PyObject *__pyx_float_212_93;
  PyObject *__pyx_float_212_94;
  PyObject *__pyx_float_212_96;
  PyObject *__pyx_float_227_77;
  PyObject *__pyx_float_228_24;
  PyObject *__pyx_float_228_28;
  PyObject *__pyx_float_234_61;
  PyObject *__pyx_float_2631_7;
  PyObject *__pyx_float_286_71;
  PyObject *__pyx_float_286_73;
  PyObject *__pyx_float_286_75;
  PyObject *__pyx_float_3987_1;
  PyObject *__pyx_float_4190_2;
  PyObject *__pyx_float_5155_7;
  PyObject *__pyx_float_5190_0;
  PyObject *__pyx_float_5198_9;
  PyObject *__pyx_float_5220_0;
  PyObject *__pyx_float_5228_8;
  PyObject *__pyx_float_5805_4;
  PyObject *__pyx_float_5809_3;
  PyObject *__pyx_float_6500_9;
  PyObject *__pyx_float_6635_4;
  PyObject *__pyx_float_6765_7;
  PyObject *__pyx_float_726_77;
  PyObject *__pyx_float_728_11;
  PyObject *__pyx_float_729_84;
  PyObject *__pyx_float_731_52;
  PyObject *__pyx_float_733_56;
  PyObject *__pyx_float_737_93;
  PyObject *__pyx_float_739_05;
  PyObject *__pyx_float_743_23;
  PyObject *__pyx_float_744_39;
  PyObject *__pyx_float_749_42;
  PyObject *__pyx_float_7577_1;
  PyObject *__pyx_float_7893_4;
  PyObject *__pyx_float_7944_1;
  PyObject *__pyx_float_9343_8;
  PyObject *__pyx_float_1007_63;
  PyObject *__pyx_float_1008_59;
  PyObject *__pyx_float_1018_36;
  PyObject *__pyx_float_1130_64;
  PyObject *__pyx_float_1139_84;
  PyObject *__pyx_float_1147_42;
  PyObject *__pyx_float_1150_35;
  PyObject *__pyx_float_1153_16;
  PyObject *__pyx_float_1408_48;
  PyObject *__pyx_float_1417_17;
  PyObject *__pyx_float_1428_83;
  PyObject *__pyx_float_1429_59;
  PyObject *__pyx_float_1432_13;
  PyObject *__pyx_float_1661_57;
  PyObject *__pyx_float_1677_68;
  PyObject *__pyx_float_1679_31;
  PyObject *__pyx_float_1683_87;
  PyObject *__pyx_float_1693_48;
  PyObject *__pyx_float_1764_84;
  PyObject *__pyx_float_1781_07;
  PyObject *__pyx_float_1812_46;
  PyObject *__pyx_float_1820_45;
  PyObject *__pyx_float_1820_74;
  PyObject *__pyx_float_1849_49;
  PyObject *__pyx_float_1865_28;
  PyObject *__pyx_float_1883_29;
  PyObject *__pyx_float_1890_25;
  PyObject *__pyx_float_2444_93;
  PyObject *__pyx_float_2457_26;
  PyObject *__pyx_float_2467_89;
  PyObject *__pyx_float_2473_17;
  PyObject *__pyx_float_2476_46;
  PyObject *__pyx_float_2585_19;
  PyObject *__pyx_float_2611_09;
  PyObject *__pyx_float_2614_69;
  PyObject *__pyx_float_2650_98;
  PyObject *__pyx_float_3031_04;
  PyObject *__pyx_float_3048_79;
  PyObject *__pyx_float_3051_28;
  PyObject *__pyx_float_3053_92;
  PyObject *__pyx_float_3065_02;
  PyObject *__pyx_float_3276_87;
  PyObject *__pyx_float_3305_01;
  PyObject *__pyx_float_3367_67;
  PyObject *__pyx_float_3382_54;
  PyObject *__pyx_float_3386_95;
  PyObject *__pyx_float_3390_29;
  PyObject *__pyx_float_3411_14;
  PyObject *__pyx_float_3435_35;
  PyObject *__pyx_float_3435_84;
  PyObject *__pyx_float_3442_73;
  PyObject *__pyx_float_3552_09;
  PyObject *__pyx_float_3574_11;
  PyObject *__pyx_float_3592_25;
  PyObject *__pyx_float_3594_63;
  PyObject *__pyx_float_3603_07;
  PyObject *__pyx_float_3757_42;
  PyObject *__pyx_float_3761_37;
  PyObject *__pyx_float_3784_58;
  PyObject *__pyx_float_3815_88;
  PyObject *__pyx_float_3817_47;
  PyObject *__pyx_float_3835_07;
  PyObject *__pyx_float_3840_42;
  PyObject *__pyx_float_3858_67;
  PyObject *__pyx_float_3864_01;
  PyObject *__pyx_float_3872_92;
  PyObject *__pyx_float_3907_11;
  PyObject *__pyx_float_3937_27;
  PyObject *__pyx_float_3977_71;
  PyObject *__pyx_float_3979_35;
  PyObject *__pyx_float_4091_72;
  PyObject *__pyx_float_4120_29;
  PyObject *__pyx_float_4127_98;
  PyObject *__pyx_float_4136_21;
  PyObject *__pyx_float_4149_23;
  PyObject *__pyx_float_4158_24;
  PyObject *__pyx_float_4192_82;
  PyObject *__pyx_float_4203_02;
  PyObject *__pyx_float_4223_36;
  PyObject *__pyx_float_5096_08;
  PyObject *__pyx_float_5126_06;
  PyObject *__pyx_float_5130_87;
  PyObject *__pyx_float_5153_54;
  PyObject *__pyx_float_5153_59;
  PyObject *__pyx_float_5159_17;
  PyObject *__pyx_float_5172_05;
  PyObject *__pyx_float_5174_86;
  PyObject *__pyx_float_5187_77;
  PyObject *__pyx_float_5190_01;
  PyObject *__pyx_float_5192_26;
  PyObject *__pyx_float_5205_05;
  PyObject *__pyx_float_5208_98;
  PyObject *__pyx_float_5247_15;
  PyObject *__pyx_float_5258_82;
  PyObject *__pyx_float_5688_88;
  PyObject *__pyx_float_5734_42;
  PyObject *__pyx_float_5747_23;
  PyObject *__pyx_float_5790_92;
  PyObject *__pyx_float_5793_29;
  PyObject *__pyx_float_5848_18;
  PyObject *__pyx_float_5856_89;
  PyObject *__pyx_float_5868_62;
  PyObject *__pyx_float_5964_03;
  PyObject *__pyx_float_5994_52;
  PyObject *__pyx_float_6018_11;
  PyObject *__pyx_float_6029_51;
  PyObject *__pyx_float_6042_92;
  PyObject *__pyx_float_6557_41;
  PyObject *__pyx_float_6651_35;
  PyObject *__pyx_float_6656_99;
  PyObject *__pyx_float_6677_79;
  PyObject *__pyx_float_6709_81;
  PyObject *__pyx_float_6740_32;
  PyObject *__pyx_float_6747_41;
  PyObject *__pyx_float_7525_19;
  PyObject *__pyx_float_7583_68;
  PyObject *__pyx_float_7602_37;
  PyObject *__pyx_float_7624_17;
  PyObject *__pyx_float_7814_84;
  PyObject *__pyx_float_7831_78;
  PyObject *__pyx_float_7839_59;
  PyObject *__pyx_float_7860_74;
  PyObject *__pyx_float_7876_76;
  PyObject *__pyx_float_7899_72;
  PyObject *__pyx_float_7910_66;
  PyObject *__pyx_float_7911_67;
  PyObject *__pyx_float_7912_57;
  PyObject *__pyx_float_7937_92;
  PyObject *__pyx_float_7946_23;
  PyObject *__pyx_float_7957_87;
  PyObject *__pyx_float_7980_24;
  PyObject *__pyx_float_9181_89;
  PyObject *__pyx_float_9255_68;
  PyObject *__pyx_float_9340_01;
  PyObject *__pyx_float_9366_34;
  PyObject *__pyx_float_11945_41;
  PyObject *__pyx_float_12041_42;
  PyObject *__pyx_float_12145_82;
  PyObject *__pyx_float_12156_05;
  PyObject *__pyx_float_12185_37;
  PyObject *__pyx_float_500282_0;
  PyObject *__pyx_float_23948464_0;
  PyObject *__pyx_float_140532459_6;
  PyObject *__pyx_float_2244259683_0;
  PyObject *__pyx_float_2377053666_0;
  PyObject *__pyx_float_10894972910_0;
  PyObject *__pyx_float_14464539893_0;
  PyObject *__pyx_float_15092302335_0;
  PyObject *__pyx_float_36121085540_7;
  PyObject *__pyx_float_45120126315_0;
  PyObject *__pyx_float_58648181396_0;
  PyObject *__pyx_float_61566668750_0;
  PyObject *__pyx_float_64786605_7657;
  PyObject *__pyx_float_70813170022_0;
  PyObject *__pyx_float_81258098177_0;
  PyObject *__pyx_float_89734052295_0;
  PyObject *__pyx_float_98770455187_0;
  PyObject *__pyx_float_115940476191_2;
  PyObject *__pyx_float_118553769519_2;
  PyObject *__pyx_float_127151511671_8;
  PyObject *__pyx_float_127527613173_0;
  PyObject *__pyx_float_159799015973_0;
  PyObject *__pyx_float_213001530097_8;
  PyObject *__pyx_float_30233745384_79;
  PyObject *__pyx_float_318911097485_6;
  PyObject *__pyx_float_331555299617_0;
  PyObject *__pyx_float_34325273049_37;
  PyObject *__pyx_float_39340183896_48;
  PyObject *__pyx_float_42696102285_67;
  PyObject *__pyx_float_50489872605_94;
  PyObject *__pyx_float_61288819659_89;
  PyObject *__pyx_float_691633876518_0;
  PyObject *__pyx_float_82167390867_05;
  PyObject *__pyx_float_146640016315_48;
  PyObject *__pyx_float_182415895155_26;
  PyObject *__pyx_float_215440232173_34;
  PyObject *__pyx_float_390925480569_42;
  PyObject *__pyx_float_397900984221_1357;
  PyObject *__pyx_float_397920913934_3657;
  PyObject *__pyx_float_neg_0_2;
  PyObject *__pyx_float_neg_0_5;
  PyObject *__pyx_float_neg_0_7;
  PyObject *__pyx_float_neg_0_9;
  PyObject *__pyx_float_neg_1_5;
  PyObject *__pyx_float_neg_5_3;
  PyObject *__pyx_float_neg_0_01;
  PyObject *__pyx_float_neg_0_02;
  PyObject *__pyx_float_neg_0_03;
  PyObject *__pyx_float_neg_0_04;
  PyObject *__pyx_float_neg_0_05;
  PyObject *__pyx_float_neg_0_06;
  PyObject *__pyx_float_neg_0_07;
  PyObject *__pyx_float_neg_0_08;
  PyObject *__pyx_float_neg_0_19;
  PyObject *__pyx_float_neg_0_33;
  PyObject *__pyx_float_neg_0_38;
  PyObject *__pyx_float_neg_0_39;
  PyObject *__pyx_float_neg_0_41;
  PyObject *__pyx_float_neg_0_43;
  PyObject *__pyx_float_neg_0_45;
  PyObject *__pyx_float_neg_0_47;
  PyObject *__pyx_float_neg_0_56;
  PyObject *__pyx_float_neg_0_66;
  PyObject *__pyx_float_neg_0_69;
  PyObject *__pyx_float_neg_0_71;
  PyObject *__pyx_float_neg_0_79;
  PyObject *__pyx_float_neg_0_81;
  PyObject *__pyx_float_neg_0_86;
  PyObject *__pyx_float_neg_0_87;
  PyObject *__pyx_float_neg_0_98;
  PyObject *__pyx_float_neg_1_06;
  PyObject *__pyx_float_neg_1_21;
  PyObject *__pyx_float_neg_1_22;
  PyObject *__pyx_float_neg_1_33;
  PyObject *__pyx_float_neg_1_38;
  PyObject *__pyx_float_neg_1_45;
  PyObject *__pyx_float_neg_1_65;
  PyObject *__pyx_float_neg_1_66;
  PyObject *__pyx_float_neg_1_79;
  PyObject *__pyx_float_neg_1_96;
  PyObject *__pyx_float_neg_2_16;
  PyObject *__pyx_float_neg_2_17;
  PyObject *__pyx_float_neg_2_35;
  PyObject *__pyx_float_neg_2_42;
  PyObject *__pyx_float_neg_2_63;
  PyObject *__pyx_float_neg_2_82;
  PyObject *__pyx_float_neg_21_3;
  PyObject *__pyx_float_neg_3_81;
  PyObject *__pyx_float_neg_4_04;
  PyObject *__pyx_float_neg_4_06;
  PyObject *__pyx_float_neg_4_45;
  PyObject *__pyx_float_neg_5_18;
  PyObject *__pyx_float_neg_5_83;
  PyObject *__pyx_float_neg_6_58;
  PyObject *__pyx_float_neg_7_28;
  PyObject *__pyx_float_neg_7_43;
  PyObject *__pyx_float_neg_7_58;
  PyObject *__pyx_float_neg_7_69;
  PyObject *__pyx_float_neg_8_13;
  PyObject *__pyx_float_neg_8_23;
  PyObject *__pyx_float_neg_8_27;
  PyObject *__pyx_float_neg_8_63;
  PyObject *__pyx_float_neg_9_99;
  PyObject *__pyx_float_neg_10_63;
  PyObject *__pyx_float_neg_104_4;
  PyObject *__pyx_float_neg_11_66;
  PyObject *__pyx_float_neg_12_42;
  PyObject *__pyx_float_neg_12_46;
  PyObject *__pyx_float_neg_13_39;
  PyObject *__pyx_float_neg_15_62;
  PyObject *__pyx_float_neg_16_02;
  PyObject *__pyx_float_neg_18_14;
  PyObject *__pyx_float_neg_18_25;
  PyObject *__pyx_float_neg_18_48;
  PyObject *__pyx_float_neg_19_82;
  PyObject *__pyx_float_neg_21_32;
  PyObject *__pyx_float_neg_21_51;
  PyObject *__pyx_float_neg_23_57;
  PyObject *__pyx_float_neg_23_59;
  PyObject *__pyx_float_neg_24_21;
  PyObject *__pyx_float_neg_30_51;
  PyObject *__pyx_float_neg_32_25;
  PyObject *__pyx_float_neg_39_38;
  PyObject *__pyx_float_neg_42_08;
  PyObject *__pyx_float_neg_44_38;
  PyObject *__pyx_float_neg_57_26;
  PyObject *__pyx_float_neg_70_98;
  PyObject *__pyx_float_neg_81_94;
  PyObject *__pyx_float_neg_84_33;
  PyObject *__pyx_float_neg_99_58;
  PyObject *__pyx_float_neg_2997454_0;
  PyObject *__pyx_float_neg_4803766_0;
  PyObject *__pyx_float_neg_12984032_0;
  PyObject *__pyx_float_neg_53971303_0;
  PyObject *__pyx_float_neg_235770368_0;
  PyObject *__pyx_float_neg_250665728_0;
  PyObject *__pyx_float_neg_635090960_0;
  PyObject *__pyx_float_neg_661239776_0;
  PyObject *__pyx_float_neg_698863952_0;
  PyObject *__pyx_float_neg_918841824_0;
  PyObject *__pyx_float_neg_1140853760_0;
  PyObject *__pyx_float_neg_1171835776_0;
  PyObject *__pyx_float_neg_1468038656_0;
  PyObject *__pyx_float_neg_1476325632_0;
  PyObject *__pyx_float_neg_1963587072_0;
  PyObject *__pyx_float_neg_2227974912_0;
  PyObject *__pyx_float_neg_2339542272_0;
  PyObject *__pyx_float_neg_2428805376_0;
  PyObject *__pyx_float_neg_2440455424_0;
  PyObject *__pyx_float_neg_2491724208_0;
  PyObject *__pyx_float_neg_2509978624_0;
  PyObject *__pyx_float_neg_2539908352_0;
  PyObject *__pyx_float_neg_2622219776_0;
  PyObject *__pyx_float_neg_4380916480_0;
  PyObject *__pyx_float_neg_5655776512_0;
  PyObject *__pyx_float_neg_5744585216_0;
  PyObject *__pyx_float_neg_6014713856_0;
  PyObject *__pyx_float_neg_7491039488_0;
  PyObject *__pyx_float_neg_8801696000_0;
  PyObject *__pyx_float_neg_8813961984_0;
  PyObject *__pyx_float_neg_10169320192_0;
  PyObject *__pyx_float_neg_13886649344_0;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_2;
  PyObject *__pyx_int_4;
  PyObject *__pyx_int_6;
  PyObject *__pyx_int_12;
  PyObject *__pyx_int_15;
  PyObject *__pyx_int_37;
  PyObject *__pyx_int_300;
  PyObject *__pyx_int_167926;
  PyObject *__pyx_int_571666;
  PyObject *__pyx_int_2223662;
  PyObject *__pyx_int_2419271;
  PyObject *__pyx_int_7898580;
  PyObject *__pyx_int_8576647;
  PyObject *__pyx_int_10592446;
  PyObject *__pyx_int_14249490;
  PyObject *__pyx_int_16720502;
  PyObject *__pyx_int_18144804;
  PyObject *__pyx_int_21744403;
  PyObject *__pyx_int_25169964;
  PyObject *__pyx_int_26315144;
  PyObject *__pyx_int_27364120;
  PyObject *__pyx_int_32037354;
  PyObject *__pyx_int_34126920;
  PyObject *__pyx_int_35394350;
  PyObject *__pyx_int_36436105;
  PyObject *__pyx_int_48122566;
  PyObject *__pyx_int_58645358;
  PyObject *__pyx_int_59724479;
  PyObject *__pyx_int_66238981;
  PyObject *__pyx_int_83828686;
  PyObject *__pyx_int_88973758;
  PyObject *__pyx_int_113527478;
  PyObject *__pyx_int_130320202;
  PyObject *__pyx_int_131103026;
  PyObject *__pyx_int_133117037;
  PyObject *__pyx_int_182994245;
  PyObject *__pyx_int_199724618;
  PyObject *__pyx_int_244630504;
  PyObject *__pyx_int_259052823;
  PyObject *__pyx_int_316342484;
  PyObject *__pyx_int_371100958;
  PyObject *__pyx_int_391479032;
  PyObject *__pyx_int_392337786;
  PyObject *__pyx_int_541037598;
  PyObject *__pyx_int_677188186;
  PyObject *__pyx_int_8855649026;
  PyObject *__pyx_int_12717649349;
  PyObject *__pyx_int_53136528234;
  PyObject *__pyx_int_53299789831;
  PyObject *__pyx_int_168229436395;
  PyObject *__pyx_int_313032053358;
  PyObject *__pyx_int_515063456666;
  PyObject *__pyx_int_626306385346;
  PyObject *__pyx_int_824243981862;
  PyObject *__pyx_int_0x9507d62c436;
  PyObject *__pyx_int_0x9660e6b8684;
  PyObject *__pyx_int_0x977cef39562;
  PyObject *__pyx_int_0x9c81f15f8f5;
  PyObject *__pyx_int_0xa5646e4f052;
  PyObject *__pyx_int_0xa573354fb9d;
  PyObject *__pyx_int_0xb294917799f;
  PyObject *__pyx_int_0xb38e85961b8;
  PyObject *__pyx_int_0xbaef60da2c6;
  PyObject *__pyx_int_0xca8cd5800f9;
  PyObject *__pyx_int_0xe4562e88120;
  PyObject *__pyx_int_0xfc88ab58e0b;
  PyObject *__pyx_int_1110800675511;
  PyObject *__pyx_int_1175767851306;
  PyObject *__pyx_int_1436971721042;
  PyObject *__pyx_int_1708631550165;
  PyObject *__pyx_int_1821738041432;
  PyObject *__pyx_int_1845844064964;
  PyObject *__pyx_int_2968508455751;
  PyObject *__pyx_int_3490375050807;
  PyObject *__pyx_int_3491811426635;
  PyObject *__pyx_int_4800328458344;
  PyObject *__pyx_int_4998916135670;
  PyObject *__pyx_int_5332514997228;
  PyObject *__pyx_int_5531341956881;
  PyObject *__pyx_int_5992127393523;
  PyObject *__pyx_int_6118478847123;
  PyObject *__pyx_int_6629036171731;
  PyObject *__pyx_int_6897201046540;
  PyObject *__pyx_int_7235995254645;
  PyObject *__pyx_int_7325541012743;
  PyObject *__pyx_int_7428389236896;
  PyObject *__pyx_int_7507095323631;
  PyObject *__pyx_int_7694238899256;
  PyObject *__pyx_int_7884280772830;
  PyObject *__pyx_int_8607232746956;
  PyObject *__pyx_int_9597572050458;
  PyObject *__pyx_int_9790143307451;
  PyObject *__pyx_int_9890708337231;
  PyObject *__pyx_int_0x105293ff5bfe;
  PyObject *__pyx_int_0x120f2085deb4;
  PyObject *__pyx_int_0x1312c5fef504;
  PyObject *__pyx_int_0x157f527fb1d4;
  PyObject *__pyx_int_0x15b1120a25de;
  PyObject *__pyx_int_0x15bd71393949;
  PyObject *__pyx_int_0x1839ab81d6a2;
  PyObject *__pyx_int_0x193c10d5c555;
  PyObject *__pyx_int_0x196f90195cb3;
  PyObject *__pyx_int_0x19a936e9e6f2;
  PyObject *__pyx_int_0x19b59fd426fa;
  PyObject *__pyx_int_0x22f9a2787068;
  PyObject *__pyx_int_0x2528aad29cbb;
  PyObject *__pyx_int_0x27eebfaf00e2;
  PyObject *__pyx_int_0x2b17e83d52a2;
  PyObject *__pyx_int_0x2c4a1fdb349e;
  PyObject *__pyx_int_0x2f7ef1b78d0e;
  PyObject *__pyx_int_0x3d0738b72996;
  PyObject *__pyx_int_0x433f57b789fe;
  PyObject *__pyx_int_neg_1;
  PyObject *__pyx_int_neg_5;
  PyObject *__pyx_slice__26;
  PyObject *__pyx_slice__27;
  PyObject *__pyx_slice__42;
  PyObject *__pyx_tuple__20;
  PyObject *__pyx_tuple__21;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__24;
  PyObject *__pyx_tuple__25;
  PyObject *__pyx_tuple__34;
  PyObject *__pyx_tuple__35;
  PyObject *__pyx_tuple__37;
  PyObject *__pyx_tuple__40;
  PyObject *__pyx_tuple__41;
  PyObject *__pyx_tuple__43;
  PyObject *__pyx_tuple__44;
  PyObject *__pyx_tuple__46;
  PyObject *__pyx_tuple__48;
  PyObject *__pyx_tuple__50;
  PyObject *__pyx_tuple__52;
  PyObject *__pyx_tuple__54;
  PyObject *__pyx_tuple__56;
  PyObject *__pyx_tuple__58;
  PyObject *__pyx_tuple__60;
  PyObject *__pyx_tuple__62;
  PyObject *__pyx_tuple__64;
  PyObject *__pyx_tuple__65;
  PyObject *__pyx_tuple__67;
  PyObject *__pyx_tuple__69;
  PyObject *__pyx_tuple__71;
  PyObject *__pyx_tuple__72;
  PyObject *__pyx_tuple__74;
  PyObject *__pyx_tuple__76;
  PyObject *__pyx_tuple__78;
  PyObject *__pyx_tuple__80;
  PyObject *__pyx_tuple__82;
  PyObject *__pyx_tuple__84;
  PyObject *__pyx_tuple__86;
  PyObject *__pyx_tuple__87;
  PyObject *__pyx_tuple__89;
  PyObject *__pyx_tuple__90;
  PyObject *__pyx_tuple__92;
  PyObject *__pyx_tuple__93;
  PyObject *__pyx_tuple__95;
  PyObject *__pyx_tuple__97;
  PyObject *__pyx_tuple__99;
  PyObject *__pyx_tuple__101;
  PyObject *__pyx_tuple__103;
  PyObject *__pyx_tuple__105;
  PyObject *__pyx_tuple__107;
  PyObject *__pyx_tuple__109;
  PyObject *__pyx_codeobj__45;
  PyObject *__pyx_codeobj__47;
  PyObject *__pyx_codeobj__49;
  PyObject *__pyx_codeobj__51;
  PyObject *__pyx_codeobj__53;
  PyObject *__pyx_codeobj__55;
  PyObject *__pyx_codeobj__57;
  PyObject *__pyx_codeobj__59;
  PyObject *__pyx_codeobj__61;
  PyObject *__pyx_codeobj__63;
  PyObject *__pyx_codeobj__66;
  PyObject *__pyx_codeobj__68;
  PyObject *__pyx_codeobj__70;
  PyObject *__pyx_codeobj__73;
  PyObject *__pyx_codeobj__75;
  PyObject *__pyx_codeobj__77;
  PyObject *__pyx_codeobj__79;
  PyObject *__pyx_codeobj__81;
  PyObject *__pyx_codeobj__83;
  PyObject *__pyx_codeobj__85;
  PyObject *__pyx_codeobj__88;
  PyObject *__pyx_codeobj__91;
  PyObject *__pyx_codeobj__94;
  PyObject *__pyx_codeobj__96;
  PyObject *__pyx_codeobj__98;
  PyObject *__pyx_codeobj__100;
  PyObject *__pyx_codeobj__102;
  PyObject *__pyx_codeobj__104;
  PyObject *__pyx_codeobj__106;
  PyObject *__pyx_codeobj__108;
  PyObject *__pyx_codeobj__110;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_kp_u_);
  Py_CLEAR(clear_module_state->__pyx_kp_s_00);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000001);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000003);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000009);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000010);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000011);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000012);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000013);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000016);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000132);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000133);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000300);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000688);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000852);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000903);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000904);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000905);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000906);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000985);
  Py_CLEAR(clear_module_state->__pyx_kp_u_01);
  Py_CLEAR(clear_module_state->__pyx_kp_s_0101);
  Py_CLEAR(clear_module_state->__pyx_kp_u_02d);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1);
  Py_CLEAR(clear_module_state->__pyx_kp_s_10);
  Py_CLEAR(clear_module_state->__pyx_kp_s_100);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1000);
  Py_CLEAR(clear_module_state->__pyx_kp_s_100R);
  Py_CLEAR(clear_module_state->__pyx_kp_s_100_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_100_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_14_days);
  Py_CLEAR(clear_module_state->__pyx_kp_s_150);
  Py_CLEAR(clear_module_state->__pyx_kp_s_180);
  Py_CLEAR(clear_module_state->__pyx_kp_s_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_200);
  Py_CLEAR(clear_module_state->__pyx_kp_s_2000);
  Py_CLEAR(clear_module_state->__pyx_kp_s_200_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_20180101);
  Py_CLEAR(clear_module_state->__pyx_kp_s_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_30);
  Py_CLEAR(clear_module_state->__pyx_kp_s_300);
  Py_CLEAR(clear_module_state->__pyx_kp_s_300_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_300_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_380);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399001);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399002);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399003);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399004);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399005);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399006);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399007);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399008);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399019);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399020);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399100);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399106);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399293);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399550);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399750);
  Py_CLEAR(clear_module_state->__pyx_kp_s_399850);
  Py_CLEAR(clear_module_state->__pyx_kp_s_4);
  Py_CLEAR(clear_module_state->__pyx_kp_s_5);
  Py_CLEAR(clear_module_state->__pyx_kp_s_50);
  Py_CLEAR(clear_module_state->__pyx_kp_s_500);
  Py_CLEAR(clear_module_state->__pyx_kp_s_50MB);
  Py_CLEAR(clear_module_state->__pyx_kp_s_50_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_50_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_50_4);
  Py_CLEAR(clear_module_state->__pyx_kp_s_50_5);
  Py_CLEAR(clear_module_state->__pyx_kp_s_50_6);
  Py_CLEAR(clear_module_state->__pyx_kp_s_60);
  Py_CLEAR(clear_module_state->__pyx_kp_s_68);
  Py_CLEAR(clear_module_state->__pyx_kp_s_7);
  Py_CLEAR(clear_module_state->__pyx_kp_s_8);
  Py_CLEAR(clear_module_state->__pyx_kp_s_800);
  Py_CLEAR(clear_module_state->__pyx_kp_s_899050);
  Py_CLEAR(clear_module_state->__pyx_kp_s_930050);
  Py_CLEAR(clear_module_state->__pyx_kp_s_932000);
  Py_CLEAR(clear_module_state->__pyx_kp_s_A50);
  Py_CLEAR(clear_module_state->__pyx_kp_u_All_days_in_the_week_of_this);
  Py_CLEAR(clear_module_state->__pyx_n_s_Counter);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataFrame);
  Py_CLEAR(clear_module_state->__pyx_n_s_Dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_INFO);
  Py_CLEAR(clear_module_state->__pyx_n_s_IOError);
  Py_CLEAR(clear_module_state->__pyx_n_s_JSONEncoder);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Json_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_List);
  Py_CLEAR(clear_module_state->__pyx_n_s_MyEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_MyEncoder_default);
  Py_CLEAR(clear_module_state->__pyx_n_s_MyEncoder_encode);
  Py_CLEAR(clear_module_state->__pyx_n_s_MyEncoder_insert_newlines);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Open_json_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_PicklingError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_R);
  Py_CLEAR(clear_module_state->__pyx_n_s_ST);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Start_this_log_record);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_Union);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Union_Dict_None);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Union_List_None);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_n_s_XSHG);
  Py_CLEAR(clear_module_state->__pyx_kp_s_XX);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Y_m_d);
  Py_CLEAR(clear_module_state->__pyx_kp_s__10);
  Py_CLEAR(clear_module_state->__pyx_kp_s__11);
  Py_CLEAR(clear_module_state->__pyx_n_s__111);
  Py_CLEAR(clear_module_state->__pyx_kp_s__12);
  Py_CLEAR(clear_module_state->__pyx_kp_s__13);
  Py_CLEAR(clear_module_state->__pyx_kp_s__14);
  Py_CLEAR(clear_module_state->__pyx_kp_s__15);
  Py_CLEAR(clear_module_state->__pyx_kp_s__16);
  Py_CLEAR(clear_module_state->__pyx_kp_s__17);
  Py_CLEAR(clear_module_state->__pyx_kp_s__18);
  Py_CLEAR(clear_module_state->__pyx_kp_s__19);
  Py_CLEAR(clear_module_state->__pyx_kp_u__19);
  Py_CLEAR(clear_module_state->__pyx_kp_u__2);
  Py_CLEAR(clear_module_state->__pyx_kp_s__22);
  Py_CLEAR(clear_module_state->__pyx_kp_s__28);
  Py_CLEAR(clear_module_state->__pyx_kp_s__29);
  Py_CLEAR(clear_module_state->__pyx_kp_u__3);
  Py_CLEAR(clear_module_state->__pyx_kp_s__30);
  Py_CLEAR(clear_module_state->__pyx_kp_s__31);
  Py_CLEAR(clear_module_state->__pyx_kp_s__32);
  Py_CLEAR(clear_module_state->__pyx_kp_s__33);
  Py_CLEAR(clear_module_state->__pyx_kp_s__36);
  Py_CLEAR(clear_module_state->__pyx_kp_s__38);
  Py_CLEAR(clear_module_state->__pyx_n_s__39);
  Py_CLEAR(clear_module_state->__pyx_kp_s__4);
  Py_CLEAR(clear_module_state->__pyx_kp_s__5);
  Py_CLEAR(clear_module_state->__pyx_kp_s__6);
  Py_CLEAR(clear_module_state->__pyx_kp_s__7);
  Py_CLEAR(clear_module_state->__pyx_kp_s__8);
  Py_CLEAR(clear_module_state->__pyx_kp_s__9);
  Py_CLEAR(clear_module_state->__pyx_n_s_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_add);
  Py_CLEAR(clear_module_state->__pyx_n_s_ak);
  Py_CLEAR(clear_module_state->__pyx_kp_s_akshare);
  Py_CLEAR(clear_module_state->__pyx_n_s_akshare_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_all_data_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_all_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_all_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_append);
  Py_CLEAR(clear_module_state->__pyx_kp_u_are_non_trading_days);
  Py_CLEAR(clear_module_state->__pyx_n_s_arg);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_ascending);
  Py_CLEAR(clear_module_state->__pyx_kp_s_assets_audios);
  Py_CLEAR(clear_module_state->__pyx_kp_s_assets_cookies);
  Py_CLEAR(clear_module_state->__pyx_kp_s_assets_cover_img);
  Py_CLEAR(clear_module_state->__pyx_kp_s_assets_imgs);
  Py_CLEAR(clear_module_state->__pyx_kp_s_assets_logs);
  Py_CLEAR(clear_module_state->__pyx_kp_s_assets_update_db_logs);
  Py_CLEAR(clear_module_state->__pyx_kp_s_assets_update_strategy_logs);
  Py_CLEAR(clear_module_state->__pyx_kp_s_assets_videos);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_attr_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_attr_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_attributes);
  Py_CLEAR(clear_module_state->__pyx_n_s_audio_dir);
  Py_CLEAR(clear_module_state->__pyx_n_s_b);
  Py_CLEAR(clear_module_state->__pyx_kp_s_baostock);
  Py_CLEAR(clear_module_state->__pyx_n_s_bj);
  Py_CLEAR(clear_module_state->__pyx_n_s_bool);
  Py_CLEAR(clear_module_state->__pyx_n_s_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_calendar);
  Py_CLEAR(clear_module_state->__pyx_n_s_checkCreatePath);
  Py_CLEAR(clear_module_state->__pyx_n_s_check_serializability);
  Py_CLEAR(clear_module_state->__pyx_n_s_chunks);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_cleaned_list_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_cls);
  Py_CLEAR(clear_module_state->__pyx_n_s_code_ip);
  Py_CLEAR(clear_module_state->__pyx_n_s_coerce);
  Py_CLEAR(clear_module_state->__pyx_n_s_collections);
  Py_CLEAR(clear_module_state->__pyx_n_s_combined_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_comma_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_cookies_dir);
  Py_CLEAR(clear_module_state->__pyx_n_s_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_cover_img_dir);
  Py_CLEAR(clear_module_state->__pyx_n_s_current_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_current_directory);
  Py_CLEAR(clear_module_state->__pyx_kp_s_current_directory_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_data_in);
  Py_CLEAR(clear_module_state->__pyx_n_s_data_list);
  Py_CLEAR(clear_module_state->__pyx_kp_s_data_must_be_a_dictionary);
  Py_CLEAR(clear_module_state->__pyx_n_s_date);
  Py_CLEAR(clear_module_state->__pyx_kp_s_date_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_date_str_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_date_to_session);
  Py_CLEAR(clear_module_state->__pyx_n_s_date_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_datetime);
  Py_CLEAR(clear_module_state->__pyx_kp_s_datetime64_ns);
  Py_CLEAR(clear_module_state->__pyx_n_s_day);
  Py_CLEAR(clear_module_state->__pyx_n_s_days);
  Py_CLEAR(clear_module_state->__pyx_n_s_default);
  Py_CLEAR(clear_module_state->__pyx_n_s_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_directory);
  Py_CLEAR(clear_module_state->__pyx_n_s_dirname);
  Py_CLEAR(clear_module_state->__pyx_n_s_dlmkts);
  Py_CLEAR(clear_module_state->__pyx_n_s_doc);
  Py_CLEAR(clear_module_state->__pyx_n_s_dt);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtype);
  Py_CLEAR(clear_module_state->__pyx_n_s_dumpJsonToFile);
  Py_CLEAR(clear_module_state->__pyx_n_s_dumps);
  Py_CLEAR(clear_module_state->__pyx_n_s_edge_driver_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_encode);
  Py_CLEAR(clear_module_state->__pyx_n_s_encoding);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_of_week);
  Py_CLEAR(clear_module_state->__pyx_n_s_enqueue);
  Py_CLEAR(clear_module_state->__pyx_n_s_ensure_ascii);
  Py_CLEAR(clear_module_state->__pyx_n_s_enter);
  Py_CLEAR(clear_module_state->__pyx_n_s_error);
  Py_CLEAR(clear_module_state->__pyx_n_s_errors);
  Py_CLEAR(clear_module_state->__pyx_n_s_exchange_calendars);
  Py_CLEAR(clear_module_state->__pyx_n_s_exists);
  Py_CLEAR(clear_module_state->__pyx_n_s_exit);
  Py_CLEAR(clear_module_state->__pyx_n_s_extractAdministrativeRegions);
  Py_CLEAR(clear_module_state->__pyx_n_s_f1);
  Py_CLEAR(clear_module_state->__pyx_n_s_f10);
  Py_CLEAR(clear_module_state->__pyx_n_s_f11);
  Py_CLEAR(clear_module_state->__pyx_n_s_f115);
  Py_CLEAR(clear_module_state->__pyx_n_s_f12);
  Py_CLEAR(clear_module_state->__pyx_n_s_f128);
  Py_CLEAR(clear_module_state->__pyx_n_s_f13);
  Py_CLEAR(clear_module_state->__pyx_n_s_f136);
  Py_CLEAR(clear_module_state->__pyx_n_s_f14);
  Py_CLEAR(clear_module_state->__pyx_n_s_f140);
  Py_CLEAR(clear_module_state->__pyx_n_s_f141);
  Py_CLEAR(clear_module_state->__pyx_n_s_f15);
  Py_CLEAR(clear_module_state->__pyx_n_s_f152);
  Py_CLEAR(clear_module_state->__pyx_n_s_f16);
  Py_CLEAR(clear_module_state->__pyx_n_s_f17);
  Py_CLEAR(clear_module_state->__pyx_n_s_f18);
  Py_CLEAR(clear_module_state->__pyx_n_s_f2);
  Py_CLEAR(clear_module_state->__pyx_n_s_f20);
  Py_CLEAR(clear_module_state->__pyx_n_s_f21);
  Py_CLEAR(clear_module_state->__pyx_n_s_f22);
  Py_CLEAR(clear_module_state->__pyx_n_s_f23);
  Py_CLEAR(clear_module_state->__pyx_n_s_f24);
  Py_CLEAR(clear_module_state->__pyx_n_s_f25);
  Py_CLEAR(clear_module_state->__pyx_n_s_f26);
  Py_CLEAR(clear_module_state->__pyx_n_s_f3);
  Py_CLEAR(clear_module_state->__pyx_n_s_f4);
  Py_CLEAR(clear_module_state->__pyx_n_s_f5);
  Py_CLEAR(clear_module_state->__pyx_n_s_f6);
  Py_CLEAR(clear_module_state->__pyx_n_s_f62);
  Py_CLEAR(clear_module_state->__pyx_n_s_f7);
  Py_CLEAR(clear_module_state->__pyx_n_s_f8);
  Py_CLEAR(clear_module_state->__pyx_n_s_f9);
  Py_CLEAR(clear_module_state->__pyx_kp_u_failed);
  Py_CLEAR(clear_module_state->__pyx_n_s_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_fillna);
  Py_CLEAR(clear_module_state->__pyx_n_s_find);
  Py_CLEAR(clear_module_state->__pyx_n_s_findall);
  Py_CLEAR(clear_module_state->__pyx_n_s_first_weekday);
  Py_CLEAR(clear_module_state->__pyx_n_s_full);
  Py_CLEAR(clear_module_state->__pyx_n_s_full_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_full_stock_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_getDateDistribution);
  Py_CLEAR(clear_module_state->__pyx_n_s_getFullStockCode);
  Py_CLEAR(clear_module_state->__pyx_n_s_getIndexCodeName);
  Py_CLEAR(clear_module_state->__pyx_n_s_getLatestTradeDay);
  Py_CLEAR(clear_module_state->__pyx_n_s_getMonthStartEndDate);
  Py_CLEAR(clear_module_state->__pyx_n_s_getStockLimitUp);
  Py_CLEAR(clear_module_state->__pyx_n_s_getSuspendedStocks);
  Py_CLEAR(clear_module_state->__pyx_n_s_getWeekStartEndByDate);
  Py_CLEAR(clear_module_state->__pyx_n_s_getYearStartEndDate);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_calendar);
  Py_CLEAR(clear_module_state->__pyx_n_s_getcwd);
  Py_CLEAR(clear_module_state->__pyx_n_s_given_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_group);
  Py_CLEAR(clear_module_state->__pyx_n_s_groupby);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_update_file);
  Py_CLEAR(clear_module_state->__pyx_kp_s_home_paco_norm_envs_softwares_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_hour);
  Py_CLEAR(clear_module_state->__pyx_n_s_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_img_save_path_root);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_indent);
  Py_CLEAR(clear_module_state->__pyx_n_s_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_inf);
  Py_CLEAR(clear_module_state->__pyx_kp_s_inf_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_subclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_inplace);
  Py_CLEAR(clear_module_state->__pyx_n_s_input_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_insert_newlines);
  Py_CLEAR(clear_module_state->__pyx_n_s_intersec_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_intersection_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_interval);
  Py_CLEAR(clear_module_state->__pyx_n_s_isAPrimaryBoardStock);
  Py_CLEAR(clear_module_state->__pyx_n_s_isMonthLastTradeDay);
  Py_CLEAR(clear_module_state->__pyx_n_s_isStockDataSaveToMysql);
  Py_CLEAR(clear_module_state->__pyx_n_s_isWeekLastTradeDay);
  Py_CLEAR(clear_module_state->__pyx_n_s_isYearLastTradeDay);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_serializable);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_session);
  Py_CLEAR(clear_module_state->__pyx_kp_s_is_session_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_isocalendar);
  Py_CLEAR(clear_module_state->__pyx_n_s_isoformat);
  Py_CLEAR(clear_module_state->__pyx_n_s_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_iterencode);
  Py_CLEAR(clear_module_state->__pyx_n_s_join);
  Py_CLEAR(clear_module_state->__pyx_n_s_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_json_file_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_json_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_json_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_kwargs);
  Py_CLEAR(clear_module_state->__pyx_n_s_latest_trade_day);
  Py_CLEAR(clear_module_state->__pyx_kp_u_latest_trade_day_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_level);
  Py_CLEAR(clear_module_state->__pyx_n_s_limit_up);
  Py_CLEAR(clear_module_state->__pyx_n_s_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_list1);
  Py_CLEAR(clear_module_state->__pyx_n_s_list2);
  Py_CLEAR(clear_module_state->__pyx_n_s_list3);
  Py_CLEAR(clear_module_state->__pyx_n_s_listIntersection);
  Py_CLEAR(clear_module_state->__pyx_n_s_listUnion);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_2_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_end_idx);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_end_idxs);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_start_idx);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_start_idxs);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_loadJsonData);
  Py_CLEAR(clear_module_state->__pyx_n_s_load_json_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_log_trace);
  Py_CLEAR(clear_module_state->__pyx_n_s_logger);
  Py_CLEAR(clear_module_state->__pyx_n_s_logs_dir);
  Py_CLEAR(clear_module_state->__pyx_n_s_loguru);
  Py_CLEAR(clear_module_state->__pyx_n_s_lt);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_makedirs);
  Py_CLEAR(clear_module_state->__pyx_n_s_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_match);
  Py_CLEAR(clear_module_state->__pyx_n_s_metaclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_module);
  Py_CLEAR(clear_module_state->__pyx_n_s_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_month12_days);
  Py_CLEAR(clear_module_state->__pyx_n_s_month_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_monthrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_mro_entries);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_negative_infinity);
  Py_CLEAR(clear_module_state->__pyx_kp_s_new_date_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_next);
  Py_CLEAR(clear_module_state->__pyx_kp_s_next_session);
  Py_CLEAR(clear_module_state->__pyx_n_s_next_session_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_non_serializable_attrs);
  Py_CLEAR(clear_module_state->__pyx_kp_u_not_found);
  Py_CLEAR(clear_module_state->__pyx_n_s_now_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_num);
  Py_CLEAR(clear_module_state->__pyx_n_s_number_of_days);
  Py_CLEAR(clear_module_state->__pyx_n_s_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_one_shot);
  Py_CLEAR(clear_module_state->__pyx_n_s_open);
  Py_CLEAR(clear_module_state->__pyx_n_s_os);
  Py_CLEAR(clear_module_state->__pyx_n_s_out);
  Py_CLEAR(clear_module_state->__pyx_n_s_pandas);
  Py_CLEAR(clear_module_state->__pyx_n_s_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_pattern);
  Py_CLEAR(clear_module_state->__pyx_n_s_pd);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pd_DataFrame);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pip_install_akshare_upgrade);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pip_install_baostock_upgrade);
  Py_CLEAR(clear_module_state->__pyx_n_s_positive_infinity);
  Py_CLEAR(clear_module_state->__pyx_n_s_prepare);
  Py_CLEAR(clear_module_state->__pyx_n_s_previous);
  Py_CLEAR(clear_module_state->__pyx_n_s_previous_session);
  Py_CLEAR(clear_module_state->__pyx_kp_s_previous_session_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_print);
  Py_CLEAR(clear_module_state->__pyx_n_s_qualname);
  Py_CLEAR(clear_module_state->__pyx_n_s_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_rc);
  Py_CLEAR(clear_module_state->__pyx_n_s_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_regions);
  Py_CLEAR(clear_module_state->__pyx_n_s_replace);
  Py_CLEAR(clear_module_state->__pyx_n_s_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_retention);
  Py_CLEAR(clear_module_state->__pyx_n_s_return);
  Py_CLEAR(clear_module_state->__pyx_n_s_rotation);
  Py_CLEAR(clear_module_state->__pyx_n_s_row);
  Py_CLEAR(clear_module_state->__pyx_n_s_rt);
  Py_CLEAR(clear_module_state->__pyx_kp_s_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_kp_s_session_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_session_close_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_session_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_session_offset_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_session_open);
  Py_CLEAR(clear_module_state->__pyx_n_s_session_open_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_sessions);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_sh);
  Py_CLEAR(clear_module_state->__pyx_n_s_sh_calendar);
  Py_CLEAR(clear_module_state->__pyx_n_s_sort_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_splitDataframeByYear);
  Py_CLEAR(clear_module_state->__pyx_n_s_startWithDigit);
  Py_CLEAR(clear_module_state->__pyx_n_s_start_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_start_of_week);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_code);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stock_log);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_tfp_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_tfp_em_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_str_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_strategyCount);
  Py_CLEAR(clear_module_state->__pyx_n_s_strategy_code_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_strategy_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_strftime);
  Py_CLEAR(clear_module_state->__pyx_n_s_strptime);
  Py_CLEAR(clear_module_state->__pyx_n_s_sub);
  Py_CLEAR(clear_module_state->__pyx_n_s_sum);
  Py_CLEAR(clear_module_state->__pyx_n_s_super);
  Py_CLEAR(clear_module_state->__pyx_n_s_suspended_stock_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_svr);
  Py_CLEAR(clear_module_state->__pyx_n_s_system);
  Py_CLEAR(clear_module_state->__pyx_n_s_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_tbstock_utils_utils);
  Py_CLEAR(clear_module_state->__pyx_kp_s_tbstock_utils_utils_py);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_testCalendar);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_text);
  Py_CLEAR(clear_module_state->__pyx_n_s_text_tail);
  Py_CLEAR(clear_module_state->__pyx_n_s_timedelta);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_today);
  Py_CLEAR(clear_module_state->__pyx_n_s_today_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_total);
  Py_CLEAR(clear_module_state->__pyx_n_s_trade);
  Py_CLEAR(clear_module_state->__pyx_n_s_trade_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_trade_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_trade_year);
  Py_CLEAR(clear_module_state->__pyx_kp_s_type_next_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_typing);
  Py_CLEAR(clear_module_state->__pyx_n_s_union_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_updateLib);
  Py_CLEAR(clear_module_state->__pyx_n_s_update_db_logs_dir);
  Py_CLEAR(clear_module_state->__pyx_n_s_update_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_update_lib_succeed);
  Py_CLEAR(clear_module_state->__pyx_n_s_update_strategy_logs_dir);
  Py_CLEAR(clear_module_state->__pyx_n_s_updated);
  Py_CLEAR(clear_module_state->__pyx_kp_s_updatelog_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_upper);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_cls);
  Py_CLEAR(clear_module_state->__pyx_kp_s_utf_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_video_save_path_root);
  Py_CLEAR(clear_module_state->__pyx_n_s_w);
  Py_CLEAR(clear_module_state->__pyx_n_s_warning);
  Py_CLEAR(clear_module_state->__pyx_n_s_week);
  Py_CLEAR(clear_module_state->__pyx_n_s_week_number);
  Py_CLEAR(clear_module_state->__pyx_n_s_weekday);
  Py_CLEAR(clear_module_state->__pyx_n_s_wrapped_text);
  Py_CLEAR(clear_module_state->__pyx_n_s_write);
  Py_CLEAR(clear_module_state->__pyx_n_s_write_f);
  Py_CLEAR(clear_module_state->__pyx_n_s_xx);
  Py_CLEAR(clear_module_state->__pyx_kp_s_xx_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_year);
  Py_CLEAR(clear_module_state->__pyx_n_s_year_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_year_int);
  Py_CLEAR(clear_module_state->__pyx_n_s_year_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_year_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_year_str);
  Py_CLEAR(clear_module_state->__pyx_float_0_0);
  Py_CLEAR(clear_module_state->__pyx_float_0_1);
  Py_CLEAR(clear_module_state->__pyx_float_0_2);
  Py_CLEAR(clear_module_state->__pyx_float_0_7);
  Py_CLEAR(clear_module_state->__pyx_float_0_8);
  Py_CLEAR(clear_module_state->__pyx_float_0_9);
  Py_CLEAR(clear_module_state->__pyx_float_1_0);
  Py_CLEAR(clear_module_state->__pyx_float_1_1);
  Py_CLEAR(clear_module_state->__pyx_float_1_3);
  Py_CLEAR(clear_module_state->__pyx_float_1_5);
  Py_CLEAR(clear_module_state->__pyx_float_1_6);
  Py_CLEAR(clear_module_state->__pyx_float_1_9);
  Py_CLEAR(clear_module_state->__pyx_float_2_3);
  Py_CLEAR(clear_module_state->__pyx_float_2_6);
  Py_CLEAR(clear_module_state->__pyx_float_2_7);
  Py_CLEAR(clear_module_state->__pyx_float_3_0);
  Py_CLEAR(clear_module_state->__pyx_float_3_6);
  Py_CLEAR(clear_module_state->__pyx_float_0_01);
  Py_CLEAR(clear_module_state->__pyx_float_0_02);
  Py_CLEAR(clear_module_state->__pyx_float_0_03);
  Py_CLEAR(clear_module_state->__pyx_float_0_04);
  Py_CLEAR(clear_module_state->__pyx_float_0_05);
  Py_CLEAR(clear_module_state->__pyx_float_0_06);
  Py_CLEAR(clear_module_state->__pyx_float_0_08);
  Py_CLEAR(clear_module_state->__pyx_float_0_14);
  Py_CLEAR(clear_module_state->__pyx_float_0_15);
  Py_CLEAR(clear_module_state->__pyx_float_0_16);
  Py_CLEAR(clear_module_state->__pyx_float_0_17);
  Py_CLEAR(clear_module_state->__pyx_float_0_18);
  Py_CLEAR(clear_module_state->__pyx_float_0_24);
  Py_CLEAR(clear_module_state->__pyx_float_0_25);
  Py_CLEAR(clear_module_state->__pyx_float_0_29);
  Py_CLEAR(clear_module_state->__pyx_float_0_33);
  Py_CLEAR(clear_module_state->__pyx_float_0_34);
  Py_CLEAR(clear_module_state->__pyx_float_0_37);
  Py_CLEAR(clear_module_state->__pyx_float_0_38);
  Py_CLEAR(clear_module_state->__pyx_float_0_42);
  Py_CLEAR(clear_module_state->__pyx_float_0_44);
  Py_CLEAR(clear_module_state->__pyx_float_0_47);
  Py_CLEAR(clear_module_state->__pyx_float_0_54);
  Py_CLEAR(clear_module_state->__pyx_float_0_57);
  Py_CLEAR(clear_module_state->__pyx_float_0_61);
  Py_CLEAR(clear_module_state->__pyx_float_0_65);
  Py_CLEAR(clear_module_state->__pyx_float_0_66);
  Py_CLEAR(clear_module_state->__pyx_float_0_69);
  Py_CLEAR(clear_module_state->__pyx_float_0_77);
  Py_CLEAR(clear_module_state->__pyx_float_0_78);
  Py_CLEAR(clear_module_state->__pyx_float_0_82);
  Py_CLEAR(clear_module_state->__pyx_float_0_83);
  Py_CLEAR(clear_module_state->__pyx_float_0_84);
  Py_CLEAR(clear_module_state->__pyx_float_0_87);
  Py_CLEAR(clear_module_state->__pyx_float_0_89);
  Py_CLEAR(clear_module_state->__pyx_float_0_91);
  Py_CLEAR(clear_module_state->__pyx_float_0_92);
  Py_CLEAR(clear_module_state->__pyx_float_0_93);
  Py_CLEAR(clear_module_state->__pyx_float_0_95);
  Py_CLEAR(clear_module_state->__pyx_float_0_96);
  Py_CLEAR(clear_module_state->__pyx_float_0_97);
  Py_CLEAR(clear_module_state->__pyx_float_0_98);
  Py_CLEAR(clear_module_state->__pyx_float_0_99);
  Py_CLEAR(clear_module_state->__pyx_float_1_01);
  Py_CLEAR(clear_module_state->__pyx_float_1_03);
  Py_CLEAR(clear_module_state->__pyx_float_1_04);
  Py_CLEAR(clear_module_state->__pyx_float_1_05);
  Py_CLEAR(clear_module_state->__pyx_float_1_08);
  Py_CLEAR(clear_module_state->__pyx_float_1_09);
  Py_CLEAR(clear_module_state->__pyx_float_1_11);
  Py_CLEAR(clear_module_state->__pyx_float_1_12);
  Py_CLEAR(clear_module_state->__pyx_float_1_14);
  Py_CLEAR(clear_module_state->__pyx_float_1_21);
  Py_CLEAR(clear_module_state->__pyx_float_1_22);
  Py_CLEAR(clear_module_state->__pyx_float_1_24);
  Py_CLEAR(clear_module_state->__pyx_float_1_28);
  Py_CLEAR(clear_module_state->__pyx_float_1_29);
  Py_CLEAR(clear_module_state->__pyx_float_1_31);
  Py_CLEAR(clear_module_state->__pyx_float_1_34);
  Py_CLEAR(clear_module_state->__pyx_float_1_37);
  Py_CLEAR(clear_module_state->__pyx_float_1_39);
  Py_CLEAR(clear_module_state->__pyx_float_1_41);
  Py_CLEAR(clear_module_state->__pyx_float_1_42);
  Py_CLEAR(clear_module_state->__pyx_float_1_48);
  Py_CLEAR(clear_module_state->__pyx_float_1_49);
  Py_CLEAR(clear_module_state->__pyx_float_1_51);
  Py_CLEAR(clear_module_state->__pyx_float_1_52);
  Py_CLEAR(clear_module_state->__pyx_float_1_53);
  Py_CLEAR(clear_module_state->__pyx_float_1_55);
  Py_CLEAR(clear_module_state->__pyx_float_1_56);
  Py_CLEAR(clear_module_state->__pyx_float_1_63);
  Py_CLEAR(clear_module_state->__pyx_float_1_65);
  Py_CLEAR(clear_module_state->__pyx_float_1_66);
  Py_CLEAR(clear_module_state->__pyx_float_1_69);
  Py_CLEAR(clear_module_state->__pyx_float_1_83);
  Py_CLEAR(clear_module_state->__pyx_float_1_88);
  Py_CLEAR(clear_module_state->__pyx_float_1_96);
  Py_CLEAR(clear_module_state->__pyx_float_1_97);
  Py_CLEAR(clear_module_state->__pyx_float_1_98);
  Py_CLEAR(clear_module_state->__pyx_float_2_01);
  Py_CLEAR(clear_module_state->__pyx_float_2_07);
  Py_CLEAR(clear_module_state->__pyx_float_2_08);
  Py_CLEAR(clear_module_state->__pyx_float_2_19);
  Py_CLEAR(clear_module_state->__pyx_float_2_25);
  Py_CLEAR(clear_module_state->__pyx_float_2_26);
  Py_CLEAR(clear_module_state->__pyx_float_2_28);
  Py_CLEAR(clear_module_state->__pyx_float_2_31);
  Py_CLEAR(clear_module_state->__pyx_float_2_41);
  Py_CLEAR(clear_module_state->__pyx_float_2_48);
  Py_CLEAR(clear_module_state->__pyx_float_2_49);
  Py_CLEAR(clear_module_state->__pyx_float_2_52);
  Py_CLEAR(clear_module_state->__pyx_float_2_57);
  Py_CLEAR(clear_module_state->__pyx_float_2_62);
  Py_CLEAR(clear_module_state->__pyx_float_2_77);
  Py_CLEAR(clear_module_state->__pyx_float_2_81);
  Py_CLEAR(clear_module_state->__pyx_float_3_07);
  Py_CLEAR(clear_module_state->__pyx_float_3_12);
  Py_CLEAR(clear_module_state->__pyx_float_3_35);
  Py_CLEAR(clear_module_state->__pyx_float_3_83);
  Py_CLEAR(clear_module_state->__pyx_float_3_94);
  Py_CLEAR(clear_module_state->__pyx_float_3_99);
  Py_CLEAR(clear_module_state->__pyx_float_33_8);
  Py_CLEAR(clear_module_state->__pyx_float_4_17);
  Py_CLEAR(clear_module_state->__pyx_float_4_54);
  Py_CLEAR(clear_module_state->__pyx_float_5_64);
  Py_CLEAR(clear_module_state->__pyx_float_5_94);
  Py_CLEAR(clear_module_state->__pyx_float_6_33);
  Py_CLEAR(clear_module_state->__pyx_float_6_79);
  Py_CLEAR(clear_module_state->__pyx_float_6_81);
  Py_CLEAR(clear_module_state->__pyx_float_15_27);
  Py_CLEAR(clear_module_state->__pyx_float_22_72);
  Py_CLEAR(clear_module_state->__pyx_float_25_27);
  Py_CLEAR(clear_module_state->__pyx_float_60_05);
  Py_CLEAR(clear_module_state->__pyx_float_1022_9);
  Py_CLEAR(clear_module_state->__pyx_float_1031_8);
  Py_CLEAR(clear_module_state->__pyx_float_1853_0);
  Py_CLEAR(clear_module_state->__pyx_float_212_89);
  Py_CLEAR(clear_module_state->__pyx_float_212_93);
  Py_CLEAR(clear_module_state->__pyx_float_212_94);
  Py_CLEAR(clear_module_state->__pyx_float_212_96);
  Py_CLEAR(clear_module_state->__pyx_float_227_77);
  Py_CLEAR(clear_module_state->__pyx_float_228_24);
  Py_CLEAR(clear_module_state->__pyx_float_228_28);
  Py_CLEAR(clear_module_state->__pyx_float_234_61);
  Py_CLEAR(clear_module_state->__pyx_float_2631_7);
  Py_CLEAR(clear_module_state->__pyx_float_286_71);
  Py_CLEAR(clear_module_state->__pyx_float_286_73);
  Py_CLEAR(clear_module_state->__pyx_float_286_75);
  Py_CLEAR(clear_module_state->__pyx_float_3987_1);
  Py_CLEAR(clear_module_state->__pyx_float_4190_2);
  Py_CLEAR(clear_module_state->__pyx_float_5155_7);
  Py_CLEAR(clear_module_state->__pyx_float_5190_0);
  Py_CLEAR(clear_module_state->__pyx_float_5198_9);
  Py_CLEAR(clear_module_state->__pyx_float_5220_0);
  Py_CLEAR(clear_module_state->__pyx_float_5228_8);
  Py_CLEAR(clear_module_state->__pyx_float_5805_4);
  Py_CLEAR(clear_module_state->__pyx_float_5809_3);
  Py_CLEAR(clear_module_state->__pyx_float_6500_9);
  Py_CLEAR(clear_module_state->__pyx_float_6635_4);
  Py_CLEAR(clear_module_state->__pyx_float_6765_7);
  Py_CLEAR(clear_module_state->__pyx_float_726_77);
  Py_CLEAR(clear_module_state->__pyx_float_728_11);
  Py_CLEAR(clear_module_state->__pyx_float_729_84);
  Py_CLEAR(clear_module_state->__pyx_float_731_52);
  Py_CLEAR(clear_module_state->__pyx_float_733_56);
  Py_CLEAR(clear_module_state->__pyx_float_737_93);
  Py_CLEAR(clear_module_state->__pyx_float_739_05);
  Py_CLEAR(clear_module_state->__pyx_float_743_23);
  Py_CLEAR(clear_module_state->__pyx_float_744_39);
  Py_CLEAR(clear_module_state->__pyx_float_749_42);
  Py_CLEAR(clear_module_state->__pyx_float_7577_1);
  Py_CLEAR(clear_module_state->__pyx_float_7893_4);
  Py_CLEAR(clear_module_state->__pyx_float_7944_1);
  Py_CLEAR(clear_module_state->__pyx_float_9343_8);
  Py_CLEAR(clear_module_state->__pyx_float_1007_63);
  Py_CLEAR(clear_module_state->__pyx_float_1008_59);
  Py_CLEAR(clear_module_state->__pyx_float_1018_36);
  Py_CLEAR(clear_module_state->__pyx_float_1130_64);
  Py_CLEAR(clear_module_state->__pyx_float_1139_84);
  Py_CLEAR(clear_module_state->__pyx_float_1147_42);
  Py_CLEAR(clear_module_state->__pyx_float_1150_35);
  Py_CLEAR(clear_module_state->__pyx_float_1153_16);
  Py_CLEAR(clear_module_state->__pyx_float_1408_48);
  Py_CLEAR(clear_module_state->__pyx_float_1417_17);
  Py_CLEAR(clear_module_state->__pyx_float_1428_83);
  Py_CLEAR(clear_module_state->__pyx_float_1429_59);
  Py_CLEAR(clear_module_state->__pyx_float_1432_13);
  Py_CLEAR(clear_module_state->__pyx_float_1661_57);
  Py_CLEAR(clear_module_state->__pyx_float_1677_68);
  Py_CLEAR(clear_module_state->__pyx_float_1679_31);
  Py_CLEAR(clear_module_state->__pyx_float_1683_87);
  Py_CLEAR(clear_module_state->__pyx_float_1693_48);
  Py_CLEAR(clear_module_state->__pyx_float_1764_84);
  Py_CLEAR(clear_module_state->__pyx_float_1781_07);
  Py_CLEAR(clear_module_state->__pyx_float_1812_46);
  Py_CLEAR(clear_module_state->__pyx_float_1820_45);
  Py_CLEAR(clear_module_state->__pyx_float_1820_74);
  Py_CLEAR(clear_module_state->__pyx_float_1849_49);
  Py_CLEAR(clear_module_state->__pyx_float_1865_28);
  Py_CLEAR(clear_module_state->__pyx_float_1883_29);
  Py_CLEAR(clear_module_state->__pyx_float_1890_25);
  Py_CLEAR(clear_module_state->__pyx_float_2444_93);
  Py_CLEAR(clear_module_state->__pyx_float_2457_26);
  Py_CLEAR(clear_module_state->__pyx_float_2467_89);
  Py_CLEAR(clear_module_state->__pyx_float_2473_17);
  Py_CLEAR(clear_module_state->__pyx_float_2476_46);
  Py_CLEAR(clear_module_state->__pyx_float_2585_19);
  Py_CLEAR(clear_module_state->__pyx_float_2611_09);
  Py_CLEAR(clear_module_state->__pyx_float_2614_69);
  Py_CLEAR(clear_module_state->__pyx_float_2650_98);
  Py_CLEAR(clear_module_state->__pyx_float_3031_04);
  Py_CLEAR(clear_module_state->__pyx_float_3048_79);
  Py_CLEAR(clear_module_state->__pyx_float_3051_28);
  Py_CLEAR(clear_module_state->__pyx_float_3053_92);
  Py_CLEAR(clear_module_state->__pyx_float_3065_02);
  Py_CLEAR(clear_module_state->__pyx_float_3276_87);
  Py_CLEAR(clear_module_state->__pyx_float_3305_01);
  Py_CLEAR(clear_module_state->__pyx_float_3367_67);
  Py_CLEAR(clear_module_state->__pyx_float_3382_54);
  Py_CLEAR(clear_module_state->__pyx_float_3386_95);
  Py_CLEAR(clear_module_state->__pyx_float_3390_29);
  Py_CLEAR(clear_module_state->__pyx_float_3411_14);
  Py_CLEAR(clear_module_state->__pyx_float_3435_35);
  Py_CLEAR(clear_module_state->__pyx_float_3435_84);
  Py_CLEAR(clear_module_state->__pyx_float_3442_73);
  Py_CLEAR(clear_module_state->__pyx_float_3552_09);
  Py_CLEAR(clear_module_state->__pyx_float_3574_11);
  Py_CLEAR(clear_module_state->__pyx_float_3592_25);
  Py_CLEAR(clear_module_state->__pyx_float_3594_63);
  Py_CLEAR(clear_module_state->__pyx_float_3603_07);
  Py_CLEAR(clear_module_state->__pyx_float_3757_42);
  Py_CLEAR(clear_module_state->__pyx_float_3761_37);
  Py_CLEAR(clear_module_state->__pyx_float_3784_58);
  Py_CLEAR(clear_module_state->__pyx_float_3815_88);
  Py_CLEAR(clear_module_state->__pyx_float_3817_47);
  Py_CLEAR(clear_module_state->__pyx_float_3835_07);
  Py_CLEAR(clear_module_state->__pyx_float_3840_42);
  Py_CLEAR(clear_module_state->__pyx_float_3858_67);
  Py_CLEAR(clear_module_state->__pyx_float_3864_01);
  Py_CLEAR(clear_module_state->__pyx_float_3872_92);
  Py_CLEAR(clear_module_state->__pyx_float_3907_11);
  Py_CLEAR(clear_module_state->__pyx_float_3937_27);
  Py_CLEAR(clear_module_state->__pyx_float_3977_71);
  Py_CLEAR(clear_module_state->__pyx_float_3979_35);
  Py_CLEAR(clear_module_state->__pyx_float_4091_72);
  Py_CLEAR(clear_module_state->__pyx_float_4120_29);
  Py_CLEAR(clear_module_state->__pyx_float_4127_98);
  Py_CLEAR(clear_module_state->__pyx_float_4136_21);
  Py_CLEAR(clear_module_state->__pyx_float_4149_23);
  Py_CLEAR(clear_module_state->__pyx_float_4158_24);
  Py_CLEAR(clear_module_state->__pyx_float_4192_82);
  Py_CLEAR(clear_module_state->__pyx_float_4203_02);
  Py_CLEAR(clear_module_state->__pyx_float_4223_36);
  Py_CLEAR(clear_module_state->__pyx_float_5096_08);
  Py_CLEAR(clear_module_state->__pyx_float_5126_06);
  Py_CLEAR(clear_module_state->__pyx_float_5130_87);
  Py_CLEAR(clear_module_state->__pyx_float_5153_54);
  Py_CLEAR(clear_module_state->__pyx_float_5153_59);
  Py_CLEAR(clear_module_state->__pyx_float_5159_17);
  Py_CLEAR(clear_module_state->__pyx_float_5172_05);
  Py_CLEAR(clear_module_state->__pyx_float_5174_86);
  Py_CLEAR(clear_module_state->__pyx_float_5187_77);
  Py_CLEAR(clear_module_state->__pyx_float_5190_01);
  Py_CLEAR(clear_module_state->__pyx_float_5192_26);
  Py_CLEAR(clear_module_state->__pyx_float_5205_05);
  Py_CLEAR(clear_module_state->__pyx_float_5208_98);
  Py_CLEAR(clear_module_state->__pyx_float_5247_15);
  Py_CLEAR(clear_module_state->__pyx_float_5258_82);
  Py_CLEAR(clear_module_state->__pyx_float_5688_88);
  Py_CLEAR(clear_module_state->__pyx_float_5734_42);
  Py_CLEAR(clear_module_state->__pyx_float_5747_23);
  Py_CLEAR(clear_module_state->__pyx_float_5790_92);
  Py_CLEAR(clear_module_state->__pyx_float_5793_29);
  Py_CLEAR(clear_module_state->__pyx_float_5848_18);
  Py_CLEAR(clear_module_state->__pyx_float_5856_89);
  Py_CLEAR(clear_module_state->__pyx_float_5868_62);
  Py_CLEAR(clear_module_state->__pyx_float_5964_03);
  Py_CLEAR(clear_module_state->__pyx_float_5994_52);
  Py_CLEAR(clear_module_state->__pyx_float_6018_11);
  Py_CLEAR(clear_module_state->__pyx_float_6029_51);
  Py_CLEAR(clear_module_state->__pyx_float_6042_92);
  Py_CLEAR(clear_module_state->__pyx_float_6557_41);
  Py_CLEAR(clear_module_state->__pyx_float_6651_35);
  Py_CLEAR(clear_module_state->__pyx_float_6656_99);
  Py_CLEAR(clear_module_state->__pyx_float_6677_79);
  Py_CLEAR(clear_module_state->__pyx_float_6709_81);
  Py_CLEAR(clear_module_state->__pyx_float_6740_32);
  Py_CLEAR(clear_module_state->__pyx_float_6747_41);
  Py_CLEAR(clear_module_state->__pyx_float_7525_19);
  Py_CLEAR(clear_module_state->__pyx_float_7583_68);
  Py_CLEAR(clear_module_state->__pyx_float_7602_37);
  Py_CLEAR(clear_module_state->__pyx_float_7624_17);
  Py_CLEAR(clear_module_state->__pyx_float_7814_84);
  Py_CLEAR(clear_module_state->__pyx_float_7831_78);
  Py_CLEAR(clear_module_state->__pyx_float_7839_59);
  Py_CLEAR(clear_module_state->__pyx_float_7860_74);
  Py_CLEAR(clear_module_state->__pyx_float_7876_76);
  Py_CLEAR(clear_module_state->__pyx_float_7899_72);
  Py_CLEAR(clear_module_state->__pyx_float_7910_66);
  Py_CLEAR(clear_module_state->__pyx_float_7911_67);
  Py_CLEAR(clear_module_state->__pyx_float_7912_57);
  Py_CLEAR(clear_module_state->__pyx_float_7937_92);
  Py_CLEAR(clear_module_state->__pyx_float_7946_23);
  Py_CLEAR(clear_module_state->__pyx_float_7957_87);
  Py_CLEAR(clear_module_state->__pyx_float_7980_24);
  Py_CLEAR(clear_module_state->__pyx_float_9181_89);
  Py_CLEAR(clear_module_state->__pyx_float_9255_68);
  Py_CLEAR(clear_module_state->__pyx_float_9340_01);
  Py_CLEAR(clear_module_state->__pyx_float_9366_34);
  Py_CLEAR(clear_module_state->__pyx_float_11945_41);
  Py_CLEAR(clear_module_state->__pyx_float_12041_42);
  Py_CLEAR(clear_module_state->__pyx_float_12145_82);
  Py_CLEAR(clear_module_state->__pyx_float_12156_05);
  Py_CLEAR(clear_module_state->__pyx_float_12185_37);
  Py_CLEAR(clear_module_state->__pyx_float_500282_0);
  Py_CLEAR(clear_module_state->__pyx_float_23948464_0);
  Py_CLEAR(clear_module_state->__pyx_float_140532459_6);
  Py_CLEAR(clear_module_state->__pyx_float_2244259683_0);
  Py_CLEAR(clear_module_state->__pyx_float_2377053666_0);
  Py_CLEAR(clear_module_state->__pyx_float_10894972910_0);
  Py_CLEAR(clear_module_state->__pyx_float_14464539893_0);
  Py_CLEAR(clear_module_state->__pyx_float_15092302335_0);
  Py_CLEAR(clear_module_state->__pyx_float_36121085540_7);
  Py_CLEAR(clear_module_state->__pyx_float_45120126315_0);
  Py_CLEAR(clear_module_state->__pyx_float_58648181396_0);
  Py_CLEAR(clear_module_state->__pyx_float_61566668750_0);
  Py_CLEAR(clear_module_state->__pyx_float_64786605_7657);
  Py_CLEAR(clear_module_state->__pyx_float_70813170022_0);
  Py_CLEAR(clear_module_state->__pyx_float_81258098177_0);
  Py_CLEAR(clear_module_state->__pyx_float_89734052295_0);
  Py_CLEAR(clear_module_state->__pyx_float_98770455187_0);
  Py_CLEAR(clear_module_state->__pyx_float_115940476191_2);
  Py_CLEAR(clear_module_state->__pyx_float_118553769519_2);
  Py_CLEAR(clear_module_state->__pyx_float_127151511671_8);
  Py_CLEAR(clear_module_state->__pyx_float_127527613173_0);
  Py_CLEAR(clear_module_state->__pyx_float_159799015973_0);
  Py_CLEAR(clear_module_state->__pyx_float_213001530097_8);
  Py_CLEAR(clear_module_state->__pyx_float_30233745384_79);
  Py_CLEAR(clear_module_state->__pyx_float_318911097485_6);
  Py_CLEAR(clear_module_state->__pyx_float_331555299617_0);
  Py_CLEAR(clear_module_state->__pyx_float_34325273049_37);
  Py_CLEAR(clear_module_state->__pyx_float_39340183896_48);
  Py_CLEAR(clear_module_state->__pyx_float_42696102285_67);
  Py_CLEAR(clear_module_state->__pyx_float_50489872605_94);
  Py_CLEAR(clear_module_state->__pyx_float_61288819659_89);
  Py_CLEAR(clear_module_state->__pyx_float_691633876518_0);
  Py_CLEAR(clear_module_state->__pyx_float_82167390867_05);
  Py_CLEAR(clear_module_state->__pyx_float_146640016315_48);
  Py_CLEAR(clear_module_state->__pyx_float_182415895155_26);
  Py_CLEAR(clear_module_state->__pyx_float_215440232173_34);
  Py_CLEAR(clear_module_state->__pyx_float_390925480569_42);
  Py_CLEAR(clear_module_state->__pyx_float_397900984221_1357);
  Py_CLEAR(clear_module_state->__pyx_float_397920913934_3657);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_2);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_5);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_7);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_9);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_5);
  Py_CLEAR(clear_module_state->__pyx_float_neg_5_3);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_01);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_02);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_03);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_04);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_05);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_06);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_07);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_08);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_19);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_33);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_38);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_39);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_41);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_43);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_45);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_47);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_56);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_66);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_69);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_71);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_79);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_81);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_86);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_87);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_98);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_06);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_21);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_22);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_33);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_38);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_45);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_65);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_66);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_79);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_96);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2_16);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2_17);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2_35);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2_42);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2_63);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2_82);
  Py_CLEAR(clear_module_state->__pyx_float_neg_21_3);
  Py_CLEAR(clear_module_state->__pyx_float_neg_3_81);
  Py_CLEAR(clear_module_state->__pyx_float_neg_4_04);
  Py_CLEAR(clear_module_state->__pyx_float_neg_4_06);
  Py_CLEAR(clear_module_state->__pyx_float_neg_4_45);
  Py_CLEAR(clear_module_state->__pyx_float_neg_5_18);
  Py_CLEAR(clear_module_state->__pyx_float_neg_5_83);
  Py_CLEAR(clear_module_state->__pyx_float_neg_6_58);
  Py_CLEAR(clear_module_state->__pyx_float_neg_7_28);
  Py_CLEAR(clear_module_state->__pyx_float_neg_7_43);
  Py_CLEAR(clear_module_state->__pyx_float_neg_7_58);
  Py_CLEAR(clear_module_state->__pyx_float_neg_7_69);
  Py_CLEAR(clear_module_state->__pyx_float_neg_8_13);
  Py_CLEAR(clear_module_state->__pyx_float_neg_8_23);
  Py_CLEAR(clear_module_state->__pyx_float_neg_8_27);
  Py_CLEAR(clear_module_state->__pyx_float_neg_8_63);
  Py_CLEAR(clear_module_state->__pyx_float_neg_9_99);
  Py_CLEAR(clear_module_state->__pyx_float_neg_10_63);
  Py_CLEAR(clear_module_state->__pyx_float_neg_104_4);
  Py_CLEAR(clear_module_state->__pyx_float_neg_11_66);
  Py_CLEAR(clear_module_state->__pyx_float_neg_12_42);
  Py_CLEAR(clear_module_state->__pyx_float_neg_12_46);
  Py_CLEAR(clear_module_state->__pyx_float_neg_13_39);
  Py_CLEAR(clear_module_state->__pyx_float_neg_15_62);
  Py_CLEAR(clear_module_state->__pyx_float_neg_16_02);
  Py_CLEAR(clear_module_state->__pyx_float_neg_18_14);
  Py_CLEAR(clear_module_state->__pyx_float_neg_18_25);
  Py_CLEAR(clear_module_state->__pyx_float_neg_18_48);
  Py_CLEAR(clear_module_state->__pyx_float_neg_19_82);
  Py_CLEAR(clear_module_state->__pyx_float_neg_21_32);
  Py_CLEAR(clear_module_state->__pyx_float_neg_21_51);
  Py_CLEAR(clear_module_state->__pyx_float_neg_23_57);
  Py_CLEAR(clear_module_state->__pyx_float_neg_23_59);
  Py_CLEAR(clear_module_state->__pyx_float_neg_24_21);
  Py_CLEAR(clear_module_state->__pyx_float_neg_30_51);
  Py_CLEAR(clear_module_state->__pyx_float_neg_32_25);
  Py_CLEAR(clear_module_state->__pyx_float_neg_39_38);
  Py_CLEAR(clear_module_state->__pyx_float_neg_42_08);
  Py_CLEAR(clear_module_state->__pyx_float_neg_44_38);
  Py_CLEAR(clear_module_state->__pyx_float_neg_57_26);
  Py_CLEAR(clear_module_state->__pyx_float_neg_70_98);
  Py_CLEAR(clear_module_state->__pyx_float_neg_81_94);
  Py_CLEAR(clear_module_state->__pyx_float_neg_84_33);
  Py_CLEAR(clear_module_state->__pyx_float_neg_99_58);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2997454_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_4803766_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_12984032_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_53971303_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_235770368_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_250665728_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_635090960_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_661239776_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_698863952_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_918841824_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1140853760_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1171835776_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1468038656_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1476325632_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1963587072_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2227974912_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2339542272_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2428805376_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2440455424_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2491724208_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2509978624_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2539908352_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2622219776_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_4380916480_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_5655776512_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_5744585216_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_6014713856_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_7491039488_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_8801696000_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_8813961984_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_10169320192_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_13886649344_0);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_2);
  Py_CLEAR(clear_module_state->__pyx_int_4);
  Py_CLEAR(clear_module_state->__pyx_int_6);
  Py_CLEAR(clear_module_state->__pyx_int_12);
  Py_CLEAR(clear_module_state->__pyx_int_15);
  Py_CLEAR(clear_module_state->__pyx_int_37);
  Py_CLEAR(clear_module_state->__pyx_int_300);
  Py_CLEAR(clear_module_state->__pyx_int_167926);
  Py_CLEAR(clear_module_state->__pyx_int_571666);
  Py_CLEAR(clear_module_state->__pyx_int_2223662);
  Py_CLEAR(clear_module_state->__pyx_int_2419271);
  Py_CLEAR(clear_module_state->__pyx_int_7898580);
  Py_CLEAR(clear_module_state->__pyx_int_8576647);
  Py_CLEAR(clear_module_state->__pyx_int_10592446);
  Py_CLEAR(clear_module_state->__pyx_int_14249490);
  Py_CLEAR(clear_module_state->__pyx_int_16720502);
  Py_CLEAR(clear_module_state->__pyx_int_18144804);
  Py_CLEAR(clear_module_state->__pyx_int_21744403);
  Py_CLEAR(clear_module_state->__pyx_int_25169964);
  Py_CLEAR(clear_module_state->__pyx_int_26315144);
  Py_CLEAR(clear_module_state->__pyx_int_27364120);
  Py_CLEAR(clear_module_state->__pyx_int_32037354);
  Py_CLEAR(clear_module_state->__pyx_int_34126920);
  Py_CLEAR(clear_module_state->__pyx_int_35394350);
  Py_CLEAR(clear_module_state->__pyx_int_36436105);
  Py_CLEAR(clear_module_state->__pyx_int_48122566);
  Py_CLEAR(clear_module_state->__pyx_int_58645358);
  Py_CLEAR(clear_module_state->__pyx_int_59724479);
  Py_CLEAR(clear_module_state->__pyx_int_66238981);
  Py_CLEAR(clear_module_state->__pyx_int_83828686);
  Py_CLEAR(clear_module_state->__pyx_int_88973758);
  Py_CLEAR(clear_module_state->__pyx_int_113527478);
  Py_CLEAR(clear_module_state->__pyx_int_130320202);
  Py_CLEAR(clear_module_state->__pyx_int_131103026);
  Py_CLEAR(clear_module_state->__pyx_int_133117037);
  Py_CLEAR(clear_module_state->__pyx_int_182994245);
  Py_CLEAR(clear_module_state->__pyx_int_199724618);
  Py_CLEAR(clear_module_state->__pyx_int_244630504);
  Py_CLEAR(clear_module_state->__pyx_int_259052823);
  Py_CLEAR(clear_module_state->__pyx_int_316342484);
  Py_CLEAR(clear_module_state->__pyx_int_371100958);
  Py_CLEAR(clear_module_state->__pyx_int_391479032);
  Py_CLEAR(clear_module_state->__pyx_int_392337786);
  Py_CLEAR(clear_module_state->__pyx_int_541037598);
  Py_CLEAR(clear_module_state->__pyx_int_677188186);
  Py_CLEAR(clear_module_state->__pyx_int_8855649026);
  Py_CLEAR(clear_module_state->__pyx_int_12717649349);
  Py_CLEAR(clear_module_state->__pyx_int_53136528234);
  Py_CLEAR(clear_module_state->__pyx_int_53299789831);
  Py_CLEAR(clear_module_state->__pyx_int_168229436395);
  Py_CLEAR(clear_module_state->__pyx_int_313032053358);
  Py_CLEAR(clear_module_state->__pyx_int_515063456666);
  Py_CLEAR(clear_module_state->__pyx_int_626306385346);
  Py_CLEAR(clear_module_state->__pyx_int_824243981862);
  Py_CLEAR(clear_module_state->__pyx_int_0x9507d62c436);
  Py_CLEAR(clear_module_state->__pyx_int_0x9660e6b8684);
  Py_CLEAR(clear_module_state->__pyx_int_0x977cef39562);
  Py_CLEAR(clear_module_state->__pyx_int_0x9c81f15f8f5);
  Py_CLEAR(clear_module_state->__pyx_int_0xa5646e4f052);
  Py_CLEAR(clear_module_state->__pyx_int_0xa573354fb9d);
  Py_CLEAR(clear_module_state->__pyx_int_0xb294917799f);
  Py_CLEAR(clear_module_state->__pyx_int_0xb38e85961b8);
  Py_CLEAR(clear_module_state->__pyx_int_0xbaef60da2c6);
  Py_CLEAR(clear_module_state->__pyx_int_0xca8cd5800f9);
  Py_CLEAR(clear_module_state->__pyx_int_0xe4562e88120);
  Py_CLEAR(clear_module_state->__pyx_int_0xfc88ab58e0b);
  Py_CLEAR(clear_module_state->__pyx_int_1110800675511);
  Py_CLEAR(clear_module_state->__pyx_int_1175767851306);
  Py_CLEAR(clear_module_state->__pyx_int_1436971721042);
  Py_CLEAR(clear_module_state->__pyx_int_1708631550165);
  Py_CLEAR(clear_module_state->__pyx_int_1821738041432);
  Py_CLEAR(clear_module_state->__pyx_int_1845844064964);
  Py_CLEAR(clear_module_state->__pyx_int_2968508455751);
  Py_CLEAR(clear_module_state->__pyx_int_3490375050807);
  Py_CLEAR(clear_module_state->__pyx_int_3491811426635);
  Py_CLEAR(clear_module_state->__pyx_int_4800328458344);
  Py_CLEAR(clear_module_state->__pyx_int_4998916135670);
  Py_CLEAR(clear_module_state->__pyx_int_5332514997228);
  Py_CLEAR(clear_module_state->__pyx_int_5531341956881);
  Py_CLEAR(clear_module_state->__pyx_int_5992127393523);
  Py_CLEAR(clear_module_state->__pyx_int_6118478847123);
  Py_CLEAR(clear_module_state->__pyx_int_6629036171731);
  Py_CLEAR(clear_module_state->__pyx_int_6897201046540);
  Py_CLEAR(clear_module_state->__pyx_int_7235995254645);
  Py_CLEAR(clear_module_state->__pyx_int_7325541012743);
  Py_CLEAR(clear_module_state->__pyx_int_7428389236896);
  Py_CLEAR(clear_module_state->__pyx_int_7507095323631);
  Py_CLEAR(clear_module_state->__pyx_int_7694238899256);
  Py_CLEAR(clear_module_state->__pyx_int_7884280772830);
  Py_CLEAR(clear_module_state->__pyx_int_8607232746956);
  Py_CLEAR(clear_module_state->__pyx_int_9597572050458);
  Py_CLEAR(clear_module_state->__pyx_int_9790143307451);
  Py_CLEAR(clear_module_state->__pyx_int_9890708337231);
  Py_CLEAR(clear_module_state->__pyx_int_0x105293ff5bfe);
  Py_CLEAR(clear_module_state->__pyx_int_0x120f2085deb4);
  Py_CLEAR(clear_module_state->__pyx_int_0x1312c5fef504);
  Py_CLEAR(clear_module_state->__pyx_int_0x157f527fb1d4);
  Py_CLEAR(clear_module_state->__pyx_int_0x15b1120a25de);
  Py_CLEAR(clear_module_state->__pyx_int_0x15bd71393949);
  Py_CLEAR(clear_module_state->__pyx_int_0x1839ab81d6a2);
  Py_CLEAR(clear_module_state->__pyx_int_0x193c10d5c555);
  Py_CLEAR(clear_module_state->__pyx_int_0x196f90195cb3);
  Py_CLEAR(clear_module_state->__pyx_int_0x19a936e9e6f2);
  Py_CLEAR(clear_module_state->__pyx_int_0x19b59fd426fa);
  Py_CLEAR(clear_module_state->__pyx_int_0x22f9a2787068);
  Py_CLEAR(clear_module_state->__pyx_int_0x2528aad29cbb);
  Py_CLEAR(clear_module_state->__pyx_int_0x27eebfaf00e2);
  Py_CLEAR(clear_module_state->__pyx_int_0x2b17e83d52a2);
  Py_CLEAR(clear_module_state->__pyx_int_0x2c4a1fdb349e);
  Py_CLEAR(clear_module_state->__pyx_int_0x2f7ef1b78d0e);
  Py_CLEAR(clear_module_state->__pyx_int_0x3d0738b72996);
  Py_CLEAR(clear_module_state->__pyx_int_0x433f57b789fe);
  Py_CLEAR(clear_module_state->__pyx_int_neg_1);
  Py_CLEAR(clear_module_state->__pyx_int_neg_5);
  Py_CLEAR(clear_module_state->__pyx_slice__26);
  Py_CLEAR(clear_module_state->__pyx_slice__27);
  Py_CLEAR(clear_module_state->__pyx_slice__42);
  Py_CLEAR(clear_module_state->__pyx_tuple__20);
  Py_CLEAR(clear_module_state->__pyx_tuple__21);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__24);
  Py_CLEAR(clear_module_state->__pyx_tuple__25);
  Py_CLEAR(clear_module_state->__pyx_tuple__34);
  Py_CLEAR(clear_module_state->__pyx_tuple__35);
  Py_CLEAR(clear_module_state->__pyx_tuple__37);
  Py_CLEAR(clear_module_state->__pyx_tuple__40);
  Py_CLEAR(clear_module_state->__pyx_tuple__41);
  Py_CLEAR(clear_module_state->__pyx_tuple__43);
  Py_CLEAR(clear_module_state->__pyx_tuple__44);
  Py_CLEAR(clear_module_state->__pyx_tuple__46);
  Py_CLEAR(clear_module_state->__pyx_tuple__48);
  Py_CLEAR(clear_module_state->__pyx_tuple__50);
  Py_CLEAR(clear_module_state->__pyx_tuple__52);
  Py_CLEAR(clear_module_state->__pyx_tuple__54);
  Py_CLEAR(clear_module_state->__pyx_tuple__56);
  Py_CLEAR(clear_module_state->__pyx_tuple__58);
  Py_CLEAR(clear_module_state->__pyx_tuple__60);
  Py_CLEAR(clear_module_state->__pyx_tuple__62);
  Py_CLEAR(clear_module_state->__pyx_tuple__64);
  Py_CLEAR(clear_module_state->__pyx_tuple__65);
  Py_CLEAR(clear_module_state->__pyx_tuple__67);
  Py_CLEAR(clear_module_state->__pyx_tuple__69);
  Py_CLEAR(clear_module_state->__pyx_tuple__71);
  Py_CLEAR(clear_module_state->__pyx_tuple__72);
  Py_CLEAR(clear_module_state->__pyx_tuple__74);
  Py_CLEAR(clear_module_state->__pyx_tuple__76);
  Py_CLEAR(clear_module_state->__pyx_tuple__78);
  Py_CLEAR(clear_module_state->__pyx_tuple__80);
  Py_CLEAR(clear_module_state->__pyx_tuple__82);
  Py_CLEAR(clear_module_state->__pyx_tuple__84);
  Py_CLEAR(clear_module_state->__pyx_tuple__86);
  Py_CLEAR(clear_module_state->__pyx_tuple__87);
  Py_CLEAR(clear_module_state->__pyx_tuple__89);
  Py_CLEAR(clear_module_state->__pyx_tuple__90);
  Py_CLEAR(clear_module_state->__pyx_tuple__92);
  Py_CLEAR(clear_module_state->__pyx_tuple__93);
  Py_CLEAR(clear_module_state->__pyx_tuple__95);
  Py_CLEAR(clear_module_state->__pyx_tuple__97);
  Py_CLEAR(clear_module_state->__pyx_tuple__99);
  Py_CLEAR(clear_module_state->__pyx_tuple__101);
  Py_CLEAR(clear_module_state->__pyx_tuple__103);
  Py_CLEAR(clear_module_state->__pyx_tuple__105);
  Py_CLEAR(clear_module_state->__pyx_tuple__107);
  Py_CLEAR(clear_module_state->__pyx_tuple__109);
  Py_CLEAR(clear_module_state->__pyx_codeobj__45);
  Py_CLEAR(clear_module_state->__pyx_codeobj__47);
  Py_CLEAR(clear_module_state->__pyx_codeobj__49);
  Py_CLEAR(clear_module_state->__pyx_codeobj__51);
  Py_CLEAR(clear_module_state->__pyx_codeobj__53);
  Py_CLEAR(clear_module_state->__pyx_codeobj__55);
  Py_CLEAR(clear_module_state->__pyx_codeobj__57);
  Py_CLEAR(clear_module_state->__pyx_codeobj__59);
  Py_CLEAR(clear_module_state->__pyx_codeobj__61);
  Py_CLEAR(clear_module_state->__pyx_codeobj__63);
  Py_CLEAR(clear_module_state->__pyx_codeobj__66);
  Py_CLEAR(clear_module_state->__pyx_codeobj__68);
  Py_CLEAR(clear_module_state->__pyx_codeobj__70);
  Py_CLEAR(clear_module_state->__pyx_codeobj__73);
  Py_CLEAR(clear_module_state->__pyx_codeobj__75);
  Py_CLEAR(clear_module_state->__pyx_codeobj__77);
  Py_CLEAR(clear_module_state->__pyx_codeobj__79);
  Py_CLEAR(clear_module_state->__pyx_codeobj__81);
  Py_CLEAR(clear_module_state->__pyx_codeobj__83);
  Py_CLEAR(clear_module_state->__pyx_codeobj__85);
  Py_CLEAR(clear_module_state->__pyx_codeobj__88);
  Py_CLEAR(clear_module_state->__pyx_codeobj__91);
  Py_CLEAR(clear_module_state->__pyx_codeobj__94);
  Py_CLEAR(clear_module_state->__pyx_codeobj__96);
  Py_CLEAR(clear_module_state->__pyx_codeobj__98);
  Py_CLEAR(clear_module_state->__pyx_codeobj__100);
  Py_CLEAR(clear_module_state->__pyx_codeobj__102);
  Py_CLEAR(clear_module_state->__pyx_codeobj__104);
  Py_CLEAR(clear_module_state->__pyx_codeobj__106);
  Py_CLEAR(clear_module_state->__pyx_codeobj__108);
  Py_CLEAR(clear_module_state->__pyx_codeobj__110);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_kp_u_);
  Py_VISIT(traverse_module_state->__pyx_kp_s_00);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000001);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000003);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000009);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000010);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000011);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000012);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000013);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000016);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000132);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000133);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000300);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000688);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000852);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000903);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000904);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000905);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000906);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000985);
  Py_VISIT(traverse_module_state->__pyx_kp_u_01);
  Py_VISIT(traverse_module_state->__pyx_kp_s_0101);
  Py_VISIT(traverse_module_state->__pyx_kp_u_02d);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1);
  Py_VISIT(traverse_module_state->__pyx_kp_s_10);
  Py_VISIT(traverse_module_state->__pyx_kp_s_100);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1000);
  Py_VISIT(traverse_module_state->__pyx_kp_s_100R);
  Py_VISIT(traverse_module_state->__pyx_kp_s_100_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_100_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_14_days);
  Py_VISIT(traverse_module_state->__pyx_kp_s_150);
  Py_VISIT(traverse_module_state->__pyx_kp_s_180);
  Py_VISIT(traverse_module_state->__pyx_kp_s_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_200);
  Py_VISIT(traverse_module_state->__pyx_kp_s_2000);
  Py_VISIT(traverse_module_state->__pyx_kp_s_200_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_20180101);
  Py_VISIT(traverse_module_state->__pyx_kp_s_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_30);
  Py_VISIT(traverse_module_state->__pyx_kp_s_300);
  Py_VISIT(traverse_module_state->__pyx_kp_s_300_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_300_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_380);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399001);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399002);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399003);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399004);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399005);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399006);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399007);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399008);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399019);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399020);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399100);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399106);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399293);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399550);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399750);
  Py_VISIT(traverse_module_state->__pyx_kp_s_399850);
  Py_VISIT(traverse_module_state->__pyx_kp_s_4);
  Py_VISIT(traverse_module_state->__pyx_kp_s_5);
  Py_VISIT(traverse_module_state->__pyx_kp_s_50);
  Py_VISIT(traverse_module_state->__pyx_kp_s_500);
  Py_VISIT(traverse_module_state->__pyx_kp_s_50MB);
  Py_VISIT(traverse_module_state->__pyx_kp_s_50_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_50_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_50_4);
  Py_VISIT(traverse_module_state->__pyx_kp_s_50_5);
  Py_VISIT(traverse_module_state->__pyx_kp_s_50_6);
  Py_VISIT(traverse_module_state->__pyx_kp_s_60);
  Py_VISIT(traverse_module_state->__pyx_kp_s_68);
  Py_VISIT(traverse_module_state->__pyx_kp_s_7);
  Py_VISIT(traverse_module_state->__pyx_kp_s_8);
  Py_VISIT(traverse_module_state->__pyx_kp_s_800);
  Py_VISIT(traverse_module_state->__pyx_kp_s_899050);
  Py_VISIT(traverse_module_state->__pyx_kp_s_930050);
  Py_VISIT(traverse_module_state->__pyx_kp_s_932000);
  Py_VISIT(traverse_module_state->__pyx_kp_s_A50);
  Py_VISIT(traverse_module_state->__pyx_kp_u_All_days_in_the_week_of_this);
  Py_VISIT(traverse_module_state->__pyx_n_s_Counter);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataFrame);
  Py_VISIT(traverse_module_state->__pyx_n_s_Dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_INFO);
  Py_VISIT(traverse_module_state->__pyx_n_s_IOError);
  Py_VISIT(traverse_module_state->__pyx_n_s_JSONEncoder);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Json_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_List);
  Py_VISIT(traverse_module_state->__pyx_n_s_MyEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_MyEncoder_default);
  Py_VISIT(traverse_module_state->__pyx_n_s_MyEncoder_encode);
  Py_VISIT(traverse_module_state->__pyx_n_s_MyEncoder_insert_newlines);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Open_json_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_PicklingError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_R);
  Py_VISIT(traverse_module_state->__pyx_n_s_ST);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Start_this_log_record);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_Union);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Union_Dict_None);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Union_List_None);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_n_s_XSHG);
  Py_VISIT(traverse_module_state->__pyx_kp_s_XX);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Y_m_d);
  Py_VISIT(traverse_module_state->__pyx_kp_s__10);
  Py_VISIT(traverse_module_state->__pyx_kp_s__11);
  Py_VISIT(traverse_module_state->__pyx_n_s__111);
  Py_VISIT(traverse_module_state->__pyx_kp_s__12);
  Py_VISIT(traverse_module_state->__pyx_kp_s__13);
  Py_VISIT(traverse_module_state->__pyx_kp_s__14);
  Py_VISIT(traverse_module_state->__pyx_kp_s__15);
  Py_VISIT(traverse_module_state->__pyx_kp_s__16);
  Py_VISIT(traverse_module_state->__pyx_kp_s__17);
  Py_VISIT(traverse_module_state->__pyx_kp_s__18);
  Py_VISIT(traverse_module_state->__pyx_kp_s__19);
  Py_VISIT(traverse_module_state->__pyx_kp_u__19);
  Py_VISIT(traverse_module_state->__pyx_kp_u__2);
  Py_VISIT(traverse_module_state->__pyx_kp_s__22);
  Py_VISIT(traverse_module_state->__pyx_kp_s__28);
  Py_VISIT(traverse_module_state->__pyx_kp_s__29);
  Py_VISIT(traverse_module_state->__pyx_kp_u__3);
  Py_VISIT(traverse_module_state->__pyx_kp_s__30);
  Py_VISIT(traverse_module_state->__pyx_kp_s__31);
  Py_VISIT(traverse_module_state->__pyx_kp_s__32);
  Py_VISIT(traverse_module_state->__pyx_kp_s__33);
  Py_VISIT(traverse_module_state->__pyx_kp_s__36);
  Py_VISIT(traverse_module_state->__pyx_kp_s__38);
  Py_VISIT(traverse_module_state->__pyx_n_s__39);
  Py_VISIT(traverse_module_state->__pyx_kp_s__4);
  Py_VISIT(traverse_module_state->__pyx_kp_s__5);
  Py_VISIT(traverse_module_state->__pyx_kp_s__6);
  Py_VISIT(traverse_module_state->__pyx_kp_s__7);
  Py_VISIT(traverse_module_state->__pyx_kp_s__8);
  Py_VISIT(traverse_module_state->__pyx_kp_s__9);
  Py_VISIT(traverse_module_state->__pyx_n_s_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_add);
  Py_VISIT(traverse_module_state->__pyx_n_s_ak);
  Py_VISIT(traverse_module_state->__pyx_kp_s_akshare);
  Py_VISIT(traverse_module_state->__pyx_n_s_akshare_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_all_data_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_all_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_all_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_append);
  Py_VISIT(traverse_module_state->__pyx_kp_u_are_non_trading_days);
  Py_VISIT(traverse_module_state->__pyx_n_s_arg);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_ascending);
  Py_VISIT(traverse_module_state->__pyx_kp_s_assets_audios);
  Py_VISIT(traverse_module_state->__pyx_kp_s_assets_cookies);
  Py_VISIT(traverse_module_state->__pyx_kp_s_assets_cover_img);
  Py_VISIT(traverse_module_state->__pyx_kp_s_assets_imgs);
  Py_VISIT(traverse_module_state->__pyx_kp_s_assets_logs);
  Py_VISIT(traverse_module_state->__pyx_kp_s_assets_update_db_logs);
  Py_VISIT(traverse_module_state->__pyx_kp_s_assets_update_strategy_logs);
  Py_VISIT(traverse_module_state->__pyx_kp_s_assets_videos);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_attr_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_attr_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_attributes);
  Py_VISIT(traverse_module_state->__pyx_n_s_audio_dir);
  Py_VISIT(traverse_module_state->__pyx_n_s_b);
  Py_VISIT(traverse_module_state->__pyx_kp_s_baostock);
  Py_VISIT(traverse_module_state->__pyx_n_s_bj);
  Py_VISIT(traverse_module_state->__pyx_n_s_bool);
  Py_VISIT(traverse_module_state->__pyx_n_s_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_calendar);
  Py_VISIT(traverse_module_state->__pyx_n_s_checkCreatePath);
  Py_VISIT(traverse_module_state->__pyx_n_s_check_serializability);
  Py_VISIT(traverse_module_state->__pyx_n_s_chunks);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_cleaned_list_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_cls);
  Py_VISIT(traverse_module_state->__pyx_n_s_code_ip);
  Py_VISIT(traverse_module_state->__pyx_n_s_coerce);
  Py_VISIT(traverse_module_state->__pyx_n_s_collections);
  Py_VISIT(traverse_module_state->__pyx_n_s_combined_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_comma_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_cookies_dir);
  Py_VISIT(traverse_module_state->__pyx_n_s_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_cover_img_dir);
  Py_VISIT(traverse_module_state->__pyx_n_s_current_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_current_directory);
  Py_VISIT(traverse_module_state->__pyx_kp_s_current_directory_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_data_in);
  Py_VISIT(traverse_module_state->__pyx_n_s_data_list);
  Py_VISIT(traverse_module_state->__pyx_kp_s_data_must_be_a_dictionary);
  Py_VISIT(traverse_module_state->__pyx_n_s_date);
  Py_VISIT(traverse_module_state->__pyx_kp_s_date_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_date_str_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_date_to_session);
  Py_VISIT(traverse_module_state->__pyx_n_s_date_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_datetime);
  Py_VISIT(traverse_module_state->__pyx_kp_s_datetime64_ns);
  Py_VISIT(traverse_module_state->__pyx_n_s_day);
  Py_VISIT(traverse_module_state->__pyx_n_s_days);
  Py_VISIT(traverse_module_state->__pyx_n_s_default);
  Py_VISIT(traverse_module_state->__pyx_n_s_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_directory);
  Py_VISIT(traverse_module_state->__pyx_n_s_dirname);
  Py_VISIT(traverse_module_state->__pyx_n_s_dlmkts);
  Py_VISIT(traverse_module_state->__pyx_n_s_doc);
  Py_VISIT(traverse_module_state->__pyx_n_s_dt);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtype);
  Py_VISIT(traverse_module_state->__pyx_n_s_dumpJsonToFile);
  Py_VISIT(traverse_module_state->__pyx_n_s_dumps);
  Py_VISIT(traverse_module_state->__pyx_n_s_edge_driver_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_encode);
  Py_VISIT(traverse_module_state->__pyx_n_s_encoding);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_of_week);
  Py_VISIT(traverse_module_state->__pyx_n_s_enqueue);
  Py_VISIT(traverse_module_state->__pyx_n_s_ensure_ascii);
  Py_VISIT(traverse_module_state->__pyx_n_s_enter);
  Py_VISIT(traverse_module_state->__pyx_n_s_error);
  Py_VISIT(traverse_module_state->__pyx_n_s_errors);
  Py_VISIT(traverse_module_state->__pyx_n_s_exchange_calendars);
  Py_VISIT(traverse_module_state->__pyx_n_s_exists);
  Py_VISIT(traverse_module_state->__pyx_n_s_exit);
  Py_VISIT(traverse_module_state->__pyx_n_s_extractAdministrativeRegions);
  Py_VISIT(traverse_module_state->__pyx_n_s_f1);
  Py_VISIT(traverse_module_state->__pyx_n_s_f10);
  Py_VISIT(traverse_module_state->__pyx_n_s_f11);
  Py_VISIT(traverse_module_state->__pyx_n_s_f115);
  Py_VISIT(traverse_module_state->__pyx_n_s_f12);
  Py_VISIT(traverse_module_state->__pyx_n_s_f128);
  Py_VISIT(traverse_module_state->__pyx_n_s_f13);
  Py_VISIT(traverse_module_state->__pyx_n_s_f136);
  Py_VISIT(traverse_module_state->__pyx_n_s_f14);
  Py_VISIT(traverse_module_state->__pyx_n_s_f140);
  Py_VISIT(traverse_module_state->__pyx_n_s_f141);
  Py_VISIT(traverse_module_state->__pyx_n_s_f15);
  Py_VISIT(traverse_module_state->__pyx_n_s_f152);
  Py_VISIT(traverse_module_state->__pyx_n_s_f16);
  Py_VISIT(traverse_module_state->__pyx_n_s_f17);
  Py_VISIT(traverse_module_state->__pyx_n_s_f18);
  Py_VISIT(traverse_module_state->__pyx_n_s_f2);
  Py_VISIT(traverse_module_state->__pyx_n_s_f20);
  Py_VISIT(traverse_module_state->__pyx_n_s_f21);
  Py_VISIT(traverse_module_state->__pyx_n_s_f22);
  Py_VISIT(traverse_module_state->__pyx_n_s_f23);
  Py_VISIT(traverse_module_state->__pyx_n_s_f24);
  Py_VISIT(traverse_module_state->__pyx_n_s_f25);
  Py_VISIT(traverse_module_state->__pyx_n_s_f26);
  Py_VISIT(traverse_module_state->__pyx_n_s_f3);
  Py_VISIT(traverse_module_state->__pyx_n_s_f4);
  Py_VISIT(traverse_module_state->__pyx_n_s_f5);
  Py_VISIT(traverse_module_state->__pyx_n_s_f6);
  Py_VISIT(traverse_module_state->__pyx_n_s_f62);
  Py_VISIT(traverse_module_state->__pyx_n_s_f7);
  Py_VISIT(traverse_module_state->__pyx_n_s_f8);
  Py_VISIT(traverse_module_state->__pyx_n_s_f9);
  Py_VISIT(traverse_module_state->__pyx_kp_u_failed);
  Py_VISIT(traverse_module_state->__pyx_n_s_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_fillna);
  Py_VISIT(traverse_module_state->__pyx_n_s_find);
  Py_VISIT(traverse_module_state->__pyx_n_s_findall);
  Py_VISIT(traverse_module_state->__pyx_n_s_first_weekday);
  Py_VISIT(traverse_module_state->__pyx_n_s_full);
  Py_VISIT(traverse_module_state->__pyx_n_s_full_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_full_stock_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_getDateDistribution);
  Py_VISIT(traverse_module_state->__pyx_n_s_getFullStockCode);
  Py_VISIT(traverse_module_state->__pyx_n_s_getIndexCodeName);
  Py_VISIT(traverse_module_state->__pyx_n_s_getLatestTradeDay);
  Py_VISIT(traverse_module_state->__pyx_n_s_getMonthStartEndDate);
  Py_VISIT(traverse_module_state->__pyx_n_s_getStockLimitUp);
  Py_VISIT(traverse_module_state->__pyx_n_s_getSuspendedStocks);
  Py_VISIT(traverse_module_state->__pyx_n_s_getWeekStartEndByDate);
  Py_VISIT(traverse_module_state->__pyx_n_s_getYearStartEndDate);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_calendar);
  Py_VISIT(traverse_module_state->__pyx_n_s_getcwd);
  Py_VISIT(traverse_module_state->__pyx_n_s_given_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_group);
  Py_VISIT(traverse_module_state->__pyx_n_s_groupby);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_update_file);
  Py_VISIT(traverse_module_state->__pyx_kp_s_home_paco_norm_envs_softwares_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_hour);
  Py_VISIT(traverse_module_state->__pyx_n_s_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_img_save_path_root);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_indent);
  Py_VISIT(traverse_module_state->__pyx_n_s_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_inf);
  Py_VISIT(traverse_module_state->__pyx_kp_s_inf_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_subclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_inplace);
  Py_VISIT(traverse_module_state->__pyx_n_s_input_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_insert_newlines);
  Py_VISIT(traverse_module_state->__pyx_n_s_intersec_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_intersection_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_interval);
  Py_VISIT(traverse_module_state->__pyx_n_s_isAPrimaryBoardStock);
  Py_VISIT(traverse_module_state->__pyx_n_s_isMonthLastTradeDay);
  Py_VISIT(traverse_module_state->__pyx_n_s_isStockDataSaveToMysql);
  Py_VISIT(traverse_module_state->__pyx_n_s_isWeekLastTradeDay);
  Py_VISIT(traverse_module_state->__pyx_n_s_isYearLastTradeDay);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_serializable);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_session);
  Py_VISIT(traverse_module_state->__pyx_kp_s_is_session_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_isocalendar);
  Py_VISIT(traverse_module_state->__pyx_n_s_isoformat);
  Py_VISIT(traverse_module_state->__pyx_n_s_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_iterencode);
  Py_VISIT(traverse_module_state->__pyx_n_s_join);
  Py_VISIT(traverse_module_state->__pyx_n_s_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_json_file_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_json_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_json_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_kwargs);
  Py_VISIT(traverse_module_state->__pyx_n_s_latest_trade_day);
  Py_VISIT(traverse_module_state->__pyx_kp_u_latest_trade_day_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_level);
  Py_VISIT(traverse_module_state->__pyx_n_s_limit_up);
  Py_VISIT(traverse_module_state->__pyx_n_s_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_list1);
  Py_VISIT(traverse_module_state->__pyx_n_s_list2);
  Py_VISIT(traverse_module_state->__pyx_n_s_list3);
  Py_VISIT(traverse_module_state->__pyx_n_s_listIntersection);
  Py_VISIT(traverse_module_state->__pyx_n_s_listUnion);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_2_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_end_idx);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_end_idxs);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_start_idx);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_start_idxs);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_loadJsonData);
  Py_VISIT(traverse_module_state->__pyx_n_s_load_json_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_log_trace);
  Py_VISIT(traverse_module_state->__pyx_n_s_logger);
  Py_VISIT(traverse_module_state->__pyx_n_s_logs_dir);
  Py_VISIT(traverse_module_state->__pyx_n_s_loguru);
  Py_VISIT(traverse_module_state->__pyx_n_s_lt);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_makedirs);
  Py_VISIT(traverse_module_state->__pyx_n_s_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_match);
  Py_VISIT(traverse_module_state->__pyx_n_s_metaclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_module);
  Py_VISIT(traverse_module_state->__pyx_n_s_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_month12_days);
  Py_VISIT(traverse_module_state->__pyx_n_s_month_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_monthrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_mro_entries);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_negative_infinity);
  Py_VISIT(traverse_module_state->__pyx_kp_s_new_date_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_next);
  Py_VISIT(traverse_module_state->__pyx_kp_s_next_session);
  Py_VISIT(traverse_module_state->__pyx_n_s_next_session_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_non_serializable_attrs);
  Py_VISIT(traverse_module_state->__pyx_kp_u_not_found);
  Py_VISIT(traverse_module_state->__pyx_n_s_now_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_num);
  Py_VISIT(traverse_module_state->__pyx_n_s_number_of_days);
  Py_VISIT(traverse_module_state->__pyx_n_s_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_one_shot);
  Py_VISIT(traverse_module_state->__pyx_n_s_open);
  Py_VISIT(traverse_module_state->__pyx_n_s_os);
  Py_VISIT(traverse_module_state->__pyx_n_s_out);
  Py_VISIT(traverse_module_state->__pyx_n_s_pandas);
  Py_VISIT(traverse_module_state->__pyx_n_s_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_pattern);
  Py_VISIT(traverse_module_state->__pyx_n_s_pd);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pd_DataFrame);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pip_install_akshare_upgrade);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pip_install_baostock_upgrade);
  Py_VISIT(traverse_module_state->__pyx_n_s_positive_infinity);
  Py_VISIT(traverse_module_state->__pyx_n_s_prepare);
  Py_VISIT(traverse_module_state->__pyx_n_s_previous);
  Py_VISIT(traverse_module_state->__pyx_n_s_previous_session);
  Py_VISIT(traverse_module_state->__pyx_kp_s_previous_session_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_print);
  Py_VISIT(traverse_module_state->__pyx_n_s_qualname);
  Py_VISIT(traverse_module_state->__pyx_n_s_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_rc);
  Py_VISIT(traverse_module_state->__pyx_n_s_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_regions);
  Py_VISIT(traverse_module_state->__pyx_n_s_replace);
  Py_VISIT(traverse_module_state->__pyx_n_s_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_retention);
  Py_VISIT(traverse_module_state->__pyx_n_s_return);
  Py_VISIT(traverse_module_state->__pyx_n_s_rotation);
  Py_VISIT(traverse_module_state->__pyx_n_s_row);
  Py_VISIT(traverse_module_state->__pyx_n_s_rt);
  Py_VISIT(traverse_module_state->__pyx_kp_s_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_kp_s_session_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_session_close_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_session_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_session_offset_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_session_open);
  Py_VISIT(traverse_module_state->__pyx_n_s_session_open_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_sessions);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_sh);
  Py_VISIT(traverse_module_state->__pyx_n_s_sh_calendar);
  Py_VISIT(traverse_module_state->__pyx_n_s_sort_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_splitDataframeByYear);
  Py_VISIT(traverse_module_state->__pyx_n_s_startWithDigit);
  Py_VISIT(traverse_module_state->__pyx_n_s_start_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_start_of_week);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_code);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stock_log);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_tfp_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_tfp_em_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_str_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_strategyCount);
  Py_VISIT(traverse_module_state->__pyx_n_s_strategy_code_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_strategy_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_strftime);
  Py_VISIT(traverse_module_state->__pyx_n_s_strptime);
  Py_VISIT(traverse_module_state->__pyx_n_s_sub);
  Py_VISIT(traverse_module_state->__pyx_n_s_sum);
  Py_VISIT(traverse_module_state->__pyx_n_s_super);
  Py_VISIT(traverse_module_state->__pyx_n_s_suspended_stock_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_svr);
  Py_VISIT(traverse_module_state->__pyx_n_s_system);
  Py_VISIT(traverse_module_state->__pyx_n_s_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_tbstock_utils_utils);
  Py_VISIT(traverse_module_state->__pyx_kp_s_tbstock_utils_utils_py);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_testCalendar);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_text);
  Py_VISIT(traverse_module_state->__pyx_n_s_text_tail);
  Py_VISIT(traverse_module_state->__pyx_n_s_timedelta);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_today);
  Py_VISIT(traverse_module_state->__pyx_n_s_today_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_total);
  Py_VISIT(traverse_module_state->__pyx_n_s_trade);
  Py_VISIT(traverse_module_state->__pyx_n_s_trade_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_trade_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_trade_year);
  Py_VISIT(traverse_module_state->__pyx_kp_s_type_next_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_typing);
  Py_VISIT(traverse_module_state->__pyx_n_s_union_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_updateLib);
  Py_VISIT(traverse_module_state->__pyx_n_s_update_db_logs_dir);
  Py_VISIT(traverse_module_state->__pyx_n_s_update_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_update_lib_succeed);
  Py_VISIT(traverse_module_state->__pyx_n_s_update_strategy_logs_dir);
  Py_VISIT(traverse_module_state->__pyx_n_s_updated);
  Py_VISIT(traverse_module_state->__pyx_kp_s_updatelog_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_upper);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_cls);
  Py_VISIT(traverse_module_state->__pyx_kp_s_utf_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_video_save_path_root);
  Py_VISIT(traverse_module_state->__pyx_n_s_w);
  Py_VISIT(traverse_module_state->__pyx_n_s_warning);
  Py_VISIT(traverse_module_state->__pyx_n_s_week);
  Py_VISIT(traverse_module_state->__pyx_n_s_week_number);
  Py_VISIT(traverse_module_state->__pyx_n_s_weekday);
  Py_VISIT(traverse_module_state->__pyx_n_s_wrapped_text);
  Py_VISIT(traverse_module_state->__pyx_n_s_write);
  Py_VISIT(traverse_module_state->__pyx_n_s_write_f);
  Py_VISIT(traverse_module_state->__pyx_n_s_xx);
  Py_VISIT(traverse_module_state->__pyx_kp_s_xx_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_year);
  Py_VISIT(traverse_module_state->__pyx_n_s_year_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_year_int);
  Py_VISIT(traverse_module_state->__pyx_n_s_year_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_year_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_year_str);
  Py_VISIT(traverse_module_state->__pyx_float_0_0);
  Py_VISIT(traverse_module_state->__pyx_float_0_1);
  Py_VISIT(traverse_module_state->__pyx_float_0_2);
  Py_VISIT(traverse_module_state->__pyx_float_0_7);
  Py_VISIT(traverse_module_state->__pyx_float_0_8);
  Py_VISIT(traverse_module_state->__pyx_float_0_9);
  Py_VISIT(traverse_module_state->__pyx_float_1_0);
  Py_VISIT(traverse_module_state->__pyx_float_1_1);
  Py_VISIT(traverse_module_state->__pyx_float_1_3);
  Py_VISIT(traverse_module_state->__pyx_float_1_5);
  Py_VISIT(traverse_module_state->__pyx_float_1_6);
  Py_VISIT(traverse_module_state->__pyx_float_1_9);
  Py_VISIT(traverse_module_state->__pyx_float_2_3);
  Py_VISIT(traverse_module_state->__pyx_float_2_6);
  Py_VISIT(traverse_module_state->__pyx_float_2_7);
  Py_VISIT(traverse_module_state->__pyx_float_3_0);
  Py_VISIT(traverse_module_state->__pyx_float_3_6);
  Py_VISIT(traverse_module_state->__pyx_float_0_01);
  Py_VISIT(traverse_module_state->__pyx_float_0_02);
  Py_VISIT(traverse_module_state->__pyx_float_0_03);
  Py_VISIT(traverse_module_state->__pyx_float_0_04);
  Py_VISIT(traverse_module_state->__pyx_float_0_05);
  Py_VISIT(traverse_module_state->__pyx_float_0_06);
  Py_VISIT(traverse_module_state->__pyx_float_0_08);
  Py_VISIT(traverse_module_state->__pyx_float_0_14);
  Py_VISIT(traverse_module_state->__pyx_float_0_15);
  Py_VISIT(traverse_module_state->__pyx_float_0_16);
  Py_VISIT(traverse_module_state->__pyx_float_0_17);
  Py_VISIT(traverse_module_state->__pyx_float_0_18);
  Py_VISIT(traverse_module_state->__pyx_float_0_24);
  Py_VISIT(traverse_module_state->__pyx_float_0_25);
  Py_VISIT(traverse_module_state->__pyx_float_0_29);
  Py_VISIT(traverse_module_state->__pyx_float_0_33);
  Py_VISIT(traverse_module_state->__pyx_float_0_34);
  Py_VISIT(traverse_module_state->__pyx_float_0_37);
  Py_VISIT(traverse_module_state->__pyx_float_0_38);
  Py_VISIT(traverse_module_state->__pyx_float_0_42);
  Py_VISIT(traverse_module_state->__pyx_float_0_44);
  Py_VISIT(traverse_module_state->__pyx_float_0_47);
  Py_VISIT(traverse_module_state->__pyx_float_0_54);
  Py_VISIT(traverse_module_state->__pyx_float_0_57);
  Py_VISIT(traverse_module_state->__pyx_float_0_61);
  Py_VISIT(traverse_module_state->__pyx_float_0_65);
  Py_VISIT(traverse_module_state->__pyx_float_0_66);
  Py_VISIT(traverse_module_state->__pyx_float_0_69);
  Py_VISIT(traverse_module_state->__pyx_float_0_77);
  Py_VISIT(traverse_module_state->__pyx_float_0_78);
  Py_VISIT(traverse_module_state->__pyx_float_0_82);
  Py_VISIT(traverse_module_state->__pyx_float_0_83);
  Py_VISIT(traverse_module_state->__pyx_float_0_84);
  Py_VISIT(traverse_module_state->__pyx_float_0_87);
  Py_VISIT(traverse_module_state->__pyx_float_0_89);
  Py_VISIT(traverse_module_state->__pyx_float_0_91);
  Py_VISIT(traverse_module_state->__pyx_float_0_92);
  Py_VISIT(traverse_module_state->__pyx_float_0_93);
  Py_VISIT(traverse_module_state->__pyx_float_0_95);
  Py_VISIT(traverse_module_state->__pyx_float_0_96);
  Py_VISIT(traverse_module_state->__pyx_float_0_97);
  Py_VISIT(traverse_module_state->__pyx_float_0_98);
  Py_VISIT(traverse_module_state->__pyx_float_0_99);
  Py_VISIT(traverse_module_state->__pyx_float_1_01);
  Py_VISIT(traverse_module_state->__pyx_float_1_03);
  Py_VISIT(traverse_module_state->__pyx_float_1_04);
  Py_VISIT(traverse_module_state->__pyx_float_1_05);
  Py_VISIT(traverse_module_state->__pyx_float_1_08);
  Py_VISIT(traverse_module_state->__pyx_float_1_09);
  Py_VISIT(traverse_module_state->__pyx_float_1_11);
  Py_VISIT(traverse_module_state->__pyx_float_1_12);
  Py_VISIT(traverse_module_state->__pyx_float_1_14);
  Py_VISIT(traverse_module_state->__pyx_float_1_21);
  Py_VISIT(traverse_module_state->__pyx_float_1_22);
  Py_VISIT(traverse_module_state->__pyx_float_1_24);
  Py_VISIT(traverse_module_state->__pyx_float_1_28);
  Py_VISIT(traverse_module_state->__pyx_float_1_29);
  Py_VISIT(traverse_module_state->__pyx_float_1_31);
  Py_VISIT(traverse_module_state->__pyx_float_1_34);
  Py_VISIT(traverse_module_state->__pyx_float_1_37);
  Py_VISIT(traverse_module_state->__pyx_float_1_39);
  Py_VISIT(traverse_module_state->__pyx_float_1_41);
  Py_VISIT(traverse_module_state->__pyx_float_1_42);
  Py_VISIT(traverse_module_state->__pyx_float_1_48);
  Py_VISIT(traverse_module_state->__pyx_float_1_49);
  Py_VISIT(traverse_module_state->__pyx_float_1_51);
  Py_VISIT(traverse_module_state->__pyx_float_1_52);
  Py_VISIT(traverse_module_state->__pyx_float_1_53);
  Py_VISIT(traverse_module_state->__pyx_float_1_55);
  Py_VISIT(traverse_module_state->__pyx_float_1_56);
  Py_VISIT(traverse_module_state->__pyx_float_1_63);
  Py_VISIT(traverse_module_state->__pyx_float_1_65);
  Py_VISIT(traverse_module_state->__pyx_float_1_66);
  Py_VISIT(traverse_module_state->__pyx_float_1_69);
  Py_VISIT(traverse_module_state->__pyx_float_1_83);
  Py_VISIT(traverse_module_state->__pyx_float_1_88);
  Py_VISIT(traverse_module_state->__pyx_float_1_96);
  Py_VISIT(traverse_module_state->__pyx_float_1_97);
  Py_VISIT(traverse_module_state->__pyx_float_1_98);
  Py_VISIT(traverse_module_state->__pyx_float_2_01);
  Py_VISIT(traverse_module_state->__pyx_float_2_07);
  Py_VISIT(traverse_module_state->__pyx_float_2_08);
  Py_VISIT(traverse_module_state->__pyx_float_2_19);
  Py_VISIT(traverse_module_state->__pyx_float_2_25);
  Py_VISIT(traverse_module_state->__pyx_float_2_26);
  Py_VISIT(traverse_module_state->__pyx_float_2_28);
  Py_VISIT(traverse_module_state->__pyx_float_2_31);
  Py_VISIT(traverse_module_state->__pyx_float_2_41);
  Py_VISIT(traverse_module_state->__pyx_float_2_48);
  Py_VISIT(traverse_module_state->__pyx_float_2_49);
  Py_VISIT(traverse_module_state->__pyx_float_2_52);
  Py_VISIT(traverse_module_state->__pyx_float_2_57);
  Py_VISIT(traverse_module_state->__pyx_float_2_62);
  Py_VISIT(traverse_module_state->__pyx_float_2_77);
  Py_VISIT(traverse_module_state->__pyx_float_2_81);
  Py_VISIT(traverse_module_state->__pyx_float_3_07);
  Py_VISIT(traverse_module_state->__pyx_float_3_12);
  Py_VISIT(traverse_module_state->__pyx_float_3_35);
  Py_VISIT(traverse_module_state->__pyx_float_3_83);
  Py_VISIT(traverse_module_state->__pyx_float_3_94);
  Py_VISIT(traverse_module_state->__pyx_float_3_99);
  Py_VISIT(traverse_module_state->__pyx_float_33_8);
  Py_VISIT(traverse_module_state->__pyx_float_4_17);
  Py_VISIT(traverse_module_state->__pyx_float_4_54);
  Py_VISIT(traverse_module_state->__pyx_float_5_64);
  Py_VISIT(traverse_module_state->__pyx_float_5_94);
  Py_VISIT(traverse_module_state->__pyx_float_6_33);
  Py_VISIT(traverse_module_state->__pyx_float_6_79);
  Py_VISIT(traverse_module_state->__pyx_float_6_81);
  Py_VISIT(traverse_module_state->__pyx_float_15_27);
  Py_VISIT(traverse_module_state->__pyx_float_22_72);
  Py_VISIT(traverse_module_state->__pyx_float_25_27);
  Py_VISIT(traverse_module_state->__pyx_float_60_05);
  Py_VISIT(traverse_module_state->__pyx_float_1022_9);
  Py_VISIT(traverse_module_state->__pyx_float_1031_8);
  Py_VISIT(traverse_module_state->__pyx_float_1853_0);
  Py_VISIT(traverse_module_state->__pyx_float_212_89);
  Py_VISIT(traverse_module_state->__pyx_float_212_93);
  Py_VISIT(traverse_module_state->__pyx_float_212_94);
  Py_VISIT(traverse_module_state->__pyx_float_212_96);
  Py_VISIT(traverse_module_state->__pyx_float_227_77);
  Py_VISIT(traverse_module_state->__pyx_float_228_24);
  Py_VISIT(traverse_module_state->__pyx_float_228_28);
  Py_VISIT(traverse_module_state->__pyx_float_234_61);
  Py_VISIT(traverse_module_state->__pyx_float_2631_7);
  Py_VISIT(traverse_module_state->__pyx_float_286_71);
  Py_VISIT(traverse_module_state->__pyx_float_286_73);
  Py_VISIT(traverse_module_state->__pyx_float_286_75);
  Py_VISIT(traverse_module_state->__pyx_float_3987_1);
  Py_VISIT(traverse_module_state->__pyx_float_4190_2);
  Py_VISIT(traverse_module_state->__pyx_float_5155_7);
  Py_VISIT(traverse_module_state->__pyx_float_5190_0);
  Py_VISIT(traverse_module_state->__pyx_float_5198_9);
  Py_VISIT(traverse_module_state->__pyx_float_5220_0);
  Py_VISIT(traverse_module_state->__pyx_float_5228_8);
  Py_VISIT(traverse_module_state->__pyx_float_5805_4);
  Py_VISIT(traverse_module_state->__pyx_float_5809_3);
  Py_VISIT(traverse_module_state->__pyx_float_6500_9);
  Py_VISIT(traverse_module_state->__pyx_float_6635_4);
  Py_VISIT(traverse_module_state->__pyx_float_6765_7);
  Py_VISIT(traverse_module_state->__pyx_float_726_77);
  Py_VISIT(traverse_module_state->__pyx_float_728_11);
  Py_VISIT(traverse_module_state->__pyx_float_729_84);
  Py_VISIT(traverse_module_state->__pyx_float_731_52);
  Py_VISIT(traverse_module_state->__pyx_float_733_56);
  Py_VISIT(traverse_module_state->__pyx_float_737_93);
  Py_VISIT(traverse_module_state->__pyx_float_739_05);
  Py_VISIT(traverse_module_state->__pyx_float_743_23);
  Py_VISIT(traverse_module_state->__pyx_float_744_39);
  Py_VISIT(traverse_module_state->__pyx_float_749_42);
  Py_VISIT(traverse_module_state->__pyx_float_7577_1);
  Py_VISIT(traverse_module_state->__pyx_float_7893_4);
  Py_VISIT(traverse_module_state->__pyx_float_7944_1);
  Py_VISIT(traverse_module_state->__pyx_float_9343_8);
  Py_VISIT(traverse_module_state->__pyx_float_1007_63);
  Py_VISIT(traverse_module_state->__pyx_float_1008_59);
  Py_VISIT(traverse_module_state->__pyx_float_1018_36);
  Py_VISIT(traverse_module_state->__pyx_float_1130_64);
  Py_VISIT(traverse_module_state->__pyx_float_1139_84);
  Py_VISIT(traverse_module_state->__pyx_float_1147_42);
  Py_VISIT(traverse_module_state->__pyx_float_1150_35);
  Py_VISIT(traverse_module_state->__pyx_float_1153_16);
  Py_VISIT(traverse_module_state->__pyx_float_1408_48);
  Py_VISIT(traverse_module_state->__pyx_float_1417_17);
  Py_VISIT(traverse_module_state->__pyx_float_1428_83);
  Py_VISIT(traverse_module_state->__pyx_float_1429_59);
  Py_VISIT(traverse_module_state->__pyx_float_1432_13);
  Py_VISIT(traverse_module_state->__pyx_float_1661_57);
  Py_VISIT(traverse_module_state->__pyx_float_1677_68);
  Py_VISIT(traverse_module_state->__pyx_float_1679_31);
  Py_VISIT(traverse_module_state->__pyx_float_1683_87);
  Py_VISIT(traverse_module_state->__pyx_float_1693_48);
  Py_VISIT(traverse_module_state->__pyx_float_1764_84);
  Py_VISIT(traverse_module_state->__pyx_float_1781_07);
  Py_VISIT(traverse_module_state->__pyx_float_1812_46);
  Py_VISIT(traverse_module_state->__pyx_float_1820_45);
  Py_VISIT(traverse_module_state->__pyx_float_1820_74);
  Py_VISIT(traverse_module_state->__pyx_float_1849_49);
  Py_VISIT(traverse_module_state->__pyx_float_1865_28);
  Py_VISIT(traverse_module_state->__pyx_float_1883_29);
  Py_VISIT(traverse_module_state->__pyx_float_1890_25);
  Py_VISIT(traverse_module_state->__pyx_float_2444_93);
  Py_VISIT(traverse_module_state->__pyx_float_2457_26);
  Py_VISIT(traverse_module_state->__pyx_float_2467_89);
  Py_VISIT(traverse_module_state->__pyx_float_2473_17);
  Py_VISIT(traverse_module_state->__pyx_float_2476_46);
  Py_VISIT(traverse_module_state->__pyx_float_2585_19);
  Py_VISIT(traverse_module_state->__pyx_float_2611_09);
  Py_VISIT(traverse_module_state->__pyx_float_2614_69);
  Py_VISIT(traverse_module_state->__pyx_float_2650_98);
  Py_VISIT(traverse_module_state->__pyx_float_3031_04);
  Py_VISIT(traverse_module_state->__pyx_float_3048_79);
  Py_VISIT(traverse_module_state->__pyx_float_3051_28);
  Py_VISIT(traverse_module_state->__pyx_float_3053_92);
  Py_VISIT(traverse_module_state->__pyx_float_3065_02);
  Py_VISIT(traverse_module_state->__pyx_float_3276_87);
  Py_VISIT(traverse_module_state->__pyx_float_3305_01);
  Py_VISIT(traverse_module_state->__pyx_float_3367_67);
  Py_VISIT(traverse_module_state->__pyx_float_3382_54);
  Py_VISIT(traverse_module_state->__pyx_float_3386_95);
  Py_VISIT(traverse_module_state->__pyx_float_3390_29);
  Py_VISIT(traverse_module_state->__pyx_float_3411_14);
  Py_VISIT(traverse_module_state->__pyx_float_3435_35);
  Py_VISIT(traverse_module_state->__pyx_float_3435_84);
  Py_VISIT(traverse_module_state->__pyx_float_3442_73);
  Py_VISIT(traverse_module_state->__pyx_float_3552_09);
  Py_VISIT(traverse_module_state->__pyx_float_3574_11);
  Py_VISIT(traverse_module_state->__pyx_float_3592_25);
  Py_VISIT(traverse_module_state->__pyx_float_3594_63);
  Py_VISIT(traverse_module_state->__pyx_float_3603_07);
  Py_VISIT(traverse_module_state->__pyx_float_3757_42);
  Py_VISIT(traverse_module_state->__pyx_float_3761_37);
  Py_VISIT(traverse_module_state->__pyx_float_3784_58);
  Py_VISIT(traverse_module_state->__pyx_float_3815_88);
  Py_VISIT(traverse_module_state->__pyx_float_3817_47);
  Py_VISIT(traverse_module_state->__pyx_float_3835_07);
  Py_VISIT(traverse_module_state->__pyx_float_3840_42);
  Py_VISIT(traverse_module_state->__pyx_float_3858_67);
  Py_VISIT(traverse_module_state->__pyx_float_3864_01);
  Py_VISIT(traverse_module_state->__pyx_float_3872_92);
  Py_VISIT(traverse_module_state->__pyx_float_3907_11);
  Py_VISIT(traverse_module_state->__pyx_float_3937_27);
  Py_VISIT(traverse_module_state->__pyx_float_3977_71);
  Py_VISIT(traverse_module_state->__pyx_float_3979_35);
  Py_VISIT(traverse_module_state->__pyx_float_4091_72);
  Py_VISIT(traverse_module_state->__pyx_float_4120_29);
  Py_VISIT(traverse_module_state->__pyx_float_4127_98);
  Py_VISIT(traverse_module_state->__pyx_float_4136_21);
  Py_VISIT(traverse_module_state->__pyx_float_4149_23);
  Py_VISIT(traverse_module_state->__pyx_float_4158_24);
  Py_VISIT(traverse_module_state->__pyx_float_4192_82);
  Py_VISIT(traverse_module_state->__pyx_float_4203_02);
  Py_VISIT(traverse_module_state->__pyx_float_4223_36);
  Py_VISIT(traverse_module_state->__pyx_float_5096_08);
  Py_VISIT(traverse_module_state->__pyx_float_5126_06);
  Py_VISIT(traverse_module_state->__pyx_float_5130_87);
  Py_VISIT(traverse_module_state->__pyx_float_5153_54);
  Py_VISIT(traverse_module_state->__pyx_float_5153_59);
  Py_VISIT(traverse_module_state->__pyx_float_5159_17);
  Py_VISIT(traverse_module_state->__pyx_float_5172_05);
  Py_VISIT(traverse_module_state->__pyx_float_5174_86);
  Py_VISIT(traverse_module_state->__pyx_float_5187_77);
  Py_VISIT(traverse_module_state->__pyx_float_5190_01);
  Py_VISIT(traverse_module_state->__pyx_float_5192_26);
  Py_VISIT(traverse_module_state->__pyx_float_5205_05);
  Py_VISIT(traverse_module_state->__pyx_float_5208_98);
  Py_VISIT(traverse_module_state->__pyx_float_5247_15);
  Py_VISIT(traverse_module_state->__pyx_float_5258_82);
  Py_VISIT(traverse_module_state->__pyx_float_5688_88);
  Py_VISIT(traverse_module_state->__pyx_float_5734_42);
  Py_VISIT(traverse_module_state->__pyx_float_5747_23);
  Py_VISIT(traverse_module_state->__pyx_float_5790_92);
  Py_VISIT(traverse_module_state->__pyx_float_5793_29);
  Py_VISIT(traverse_module_state->__pyx_float_5848_18);
  Py_VISIT(traverse_module_state->__pyx_float_5856_89);
  Py_VISIT(traverse_module_state->__pyx_float_5868_62);
  Py_VISIT(traverse_module_state->__pyx_float_5964_03);
  Py_VISIT(traverse_module_state->__pyx_float_5994_52);
  Py_VISIT(traverse_module_state->__pyx_float_6018_11);
  Py_VISIT(traverse_module_state->__pyx_float_6029_51);
  Py_VISIT(traverse_module_state->__pyx_float_6042_92);
  Py_VISIT(traverse_module_state->__pyx_float_6557_41);
  Py_VISIT(traverse_module_state->__pyx_float_6651_35);
  Py_VISIT(traverse_module_state->__pyx_float_6656_99);
  Py_VISIT(traverse_module_state->__pyx_float_6677_79);
  Py_VISIT(traverse_module_state->__pyx_float_6709_81);
  Py_VISIT(traverse_module_state->__pyx_float_6740_32);
  Py_VISIT(traverse_module_state->__pyx_float_6747_41);
  Py_VISIT(traverse_module_state->__pyx_float_7525_19);
  Py_VISIT(traverse_module_state->__pyx_float_7583_68);
  Py_VISIT(traverse_module_state->__pyx_float_7602_37);
  Py_VISIT(traverse_module_state->__pyx_float_7624_17);
  Py_VISIT(traverse_module_state->__pyx_float_7814_84);
  Py_VISIT(traverse_module_state->__pyx_float_7831_78);
  Py_VISIT(traverse_module_state->__pyx_float_7839_59);
  Py_VISIT(traverse_module_state->__pyx_float_7860_74);
  Py_VISIT(traverse_module_state->__pyx_float_7876_76);
  Py_VISIT(traverse_module_state->__pyx_float_7899_72);
  Py_VISIT(traverse_module_state->__pyx_float_7910_66);
  Py_VISIT(traverse_module_state->__pyx_float_7911_67);
  Py_VISIT(traverse_module_state->__pyx_float_7912_57);
  Py_VISIT(traverse_module_state->__pyx_float_7937_92);
  Py_VISIT(traverse_module_state->__pyx_float_7946_23);
  Py_VISIT(traverse_module_state->__pyx_float_7957_87);
  Py_VISIT(traverse_module_state->__pyx_float_7980_24);
  Py_VISIT(traverse_module_state->__pyx_float_9181_89);
  Py_VISIT(traverse_module_state->__pyx_float_9255_68);
  Py_VISIT(traverse_module_state->__pyx_float_9340_01);
  Py_VISIT(traverse_module_state->__pyx_float_9366_34);
  Py_VISIT(traverse_module_state->__pyx_float_11945_41);
  Py_VISIT(traverse_module_state->__pyx_float_12041_42);
  Py_VISIT(traverse_module_state->__pyx_float_12145_82);
  Py_VISIT(traverse_module_state->__pyx_float_12156_05);
  Py_VISIT(traverse_module_state->__pyx_float_12185_37);
  Py_VISIT(traverse_module_state->__pyx_float_500282_0);
  Py_VISIT(traverse_module_state->__pyx_float_23948464_0);
  Py_VISIT(traverse_module_state->__pyx_float_140532459_6);
  Py_VISIT(traverse_module_state->__pyx_float_2244259683_0);
  Py_VISIT(traverse_module_state->__pyx_float_2377053666_0);
  Py_VISIT(traverse_module_state->__pyx_float_10894972910_0);
  Py_VISIT(traverse_module_state->__pyx_float_14464539893_0);
  Py_VISIT(traverse_module_state->__pyx_float_15092302335_0);
  Py_VISIT(traverse_module_state->__pyx_float_36121085540_7);
  Py_VISIT(traverse_module_state->__pyx_float_45120126315_0);
  Py_VISIT(traverse_module_state->__pyx_float_58648181396_0);
  Py_VISIT(traverse_module_state->__pyx_float_61566668750_0);
  Py_VISIT(traverse_module_state->__pyx_float_64786605_7657);
  Py_VISIT(traverse_module_state->__pyx_float_70813170022_0);
  Py_VISIT(traverse_module_state->__pyx_float_81258098177_0);
  Py_VISIT(traverse_module_state->__pyx_float_89734052295_0);
  Py_VISIT(traverse_module_state->__pyx_float_98770455187_0);
  Py_VISIT(traverse_module_state->__pyx_float_115940476191_2);
  Py_VISIT(traverse_module_state->__pyx_float_118553769519_2);
  Py_VISIT(traverse_module_state->__pyx_float_127151511671_8);
  Py_VISIT(traverse_module_state->__pyx_float_127527613173_0);
  Py_VISIT(traverse_module_state->__pyx_float_159799015973_0);
  Py_VISIT(traverse_module_state->__pyx_float_213001530097_8);
  Py_VISIT(traverse_module_state->__pyx_float_30233745384_79);
  Py_VISIT(traverse_module_state->__pyx_float_318911097485_6);
  Py_VISIT(traverse_module_state->__pyx_float_331555299617_0);
  Py_VISIT(traverse_module_state->__pyx_float_34325273049_37);
  Py_VISIT(traverse_module_state->__pyx_float_39340183896_48);
  Py_VISIT(traverse_module_state->__pyx_float_42696102285_67);
  Py_VISIT(traverse_module_state->__pyx_float_50489872605_94);
  Py_VISIT(traverse_module_state->__pyx_float_61288819659_89);
  Py_VISIT(traverse_module_state->__pyx_float_691633876518_0);
  Py_VISIT(traverse_module_state->__pyx_float_82167390867_05);
  Py_VISIT(traverse_module_state->__pyx_float_146640016315_48);
  Py_VISIT(traverse_module_state->__pyx_float_182415895155_26);
  Py_VISIT(traverse_module_state->__pyx_float_215440232173_34);
  Py_VISIT(traverse_module_state->__pyx_float_390925480569_42);
  Py_VISIT(traverse_module_state->__pyx_float_397900984221_1357);
  Py_VISIT(traverse_module_state->__pyx_float_397920913934_3657);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_2);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_5);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_7);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_9);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_5);
  Py_VISIT(traverse_module_state->__pyx_float_neg_5_3);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_01);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_02);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_03);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_04);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_05);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_06);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_07);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_08);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_19);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_33);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_38);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_39);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_41);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_43);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_45);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_47);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_56);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_66);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_69);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_71);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_79);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_81);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_86);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_87);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_98);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_06);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_21);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_22);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_33);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_38);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_45);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_65);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_66);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_79);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_96);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2_16);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2_17);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2_35);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2_42);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2_63);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2_82);
  Py_VISIT(traverse_module_state->__pyx_float_neg_21_3);
  Py_VISIT(traverse_module_state->__pyx_float_neg_3_81);
  Py_VISIT(traverse_module_state->__pyx_float_neg_4_04);
  Py_VISIT(traverse_module_state->__pyx_float_neg_4_06);
  Py_VISIT(traverse_module_state->__pyx_float_neg_4_45);
  Py_VISIT(traverse_module_state->__pyx_float_neg_5_18);
  Py_VISIT(traverse_module_state->__pyx_float_neg_5_83);
  Py_VISIT(traverse_module_state->__pyx_float_neg_6_58);
  Py_VISIT(traverse_module_state->__pyx_float_neg_7_28);
  Py_VISIT(traverse_module_state->__pyx_float_neg_7_43);
  Py_VISIT(traverse_module_state->__pyx_float_neg_7_58);
  Py_VISIT(traverse_module_state->__pyx_float_neg_7_69);
  Py_VISIT(traverse_module_state->__pyx_float_neg_8_13);
  Py_VISIT(traverse_module_state->__pyx_float_neg_8_23);
  Py_VISIT(traverse_module_state->__pyx_float_neg_8_27);
  Py_VISIT(traverse_module_state->__pyx_float_neg_8_63);
  Py_VISIT(traverse_module_state->__pyx_float_neg_9_99);
  Py_VISIT(traverse_module_state->__pyx_float_neg_10_63);
  Py_VISIT(traverse_module_state->__pyx_float_neg_104_4);
  Py_VISIT(traverse_module_state->__pyx_float_neg_11_66);
  Py_VISIT(traverse_module_state->__pyx_float_neg_12_42);
  Py_VISIT(traverse_module_state->__pyx_float_neg_12_46);
  Py_VISIT(traverse_module_state->__pyx_float_neg_13_39);
  Py_VISIT(traverse_module_state->__pyx_float_neg_15_62);
  Py_VISIT(traverse_module_state->__pyx_float_neg_16_02);
  Py_VISIT(traverse_module_state->__pyx_float_neg_18_14);
  Py_VISIT(traverse_module_state->__pyx_float_neg_18_25);
  Py_VISIT(traverse_module_state->__pyx_float_neg_18_48);
  Py_VISIT(traverse_module_state->__pyx_float_neg_19_82);
  Py_VISIT(traverse_module_state->__pyx_float_neg_21_32);
  Py_VISIT(traverse_module_state->__pyx_float_neg_21_51);
  Py_VISIT(traverse_module_state->__pyx_float_neg_23_57);
  Py_VISIT(traverse_module_state->__pyx_float_neg_23_59);
  Py_VISIT(traverse_module_state->__pyx_float_neg_24_21);
  Py_VISIT(traverse_module_state->__pyx_float_neg_30_51);
  Py_VISIT(traverse_module_state->__pyx_float_neg_32_25);
  Py_VISIT(traverse_module_state->__pyx_float_neg_39_38);
  Py_VISIT(traverse_module_state->__pyx_float_neg_42_08);
  Py_VISIT(traverse_module_state->__pyx_float_neg_44_38);
  Py_VISIT(traverse_module_state->__pyx_float_neg_57_26);
  Py_VISIT(traverse_module_state->__pyx_float_neg_70_98);
  Py_VISIT(traverse_module_state->__pyx_float_neg_81_94);
  Py_VISIT(traverse_module_state->__pyx_float_neg_84_33);
  Py_VISIT(traverse_module_state->__pyx_float_neg_99_58);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2997454_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_4803766_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_12984032_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_53971303_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_235770368_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_250665728_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_635090960_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_661239776_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_698863952_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_918841824_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1140853760_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1171835776_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1468038656_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1476325632_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1963587072_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2227974912_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2339542272_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2428805376_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2440455424_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2491724208_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2509978624_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2539908352_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2622219776_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_4380916480_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_5655776512_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_5744585216_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_6014713856_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_7491039488_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_8801696000_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_8813961984_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_10169320192_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_13886649344_0);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_2);
  Py_VISIT(traverse_module_state->__pyx_int_4);
  Py_VISIT(traverse_module_state->__pyx_int_6);
  Py_VISIT(traverse_module_state->__pyx_int_12);
  Py_VISIT(traverse_module_state->__pyx_int_15);
  Py_VISIT(traverse_module_state->__pyx_int_37);
  Py_VISIT(traverse_module_state->__pyx_int_300);
  Py_VISIT(traverse_module_state->__pyx_int_167926);
  Py_VISIT(traverse_module_state->__pyx_int_571666);
  Py_VISIT(traverse_module_state->__pyx_int_2223662);
  Py_VISIT(traverse_module_state->__pyx_int_2419271);
  Py_VISIT(traverse_module_state->__pyx_int_7898580);
  Py_VISIT(traverse_module_state->__pyx_int_8576647);
  Py_VISIT(traverse_module_state->__pyx_int_10592446);
  Py_VISIT(traverse_module_state->__pyx_int_14249490);
  Py_VISIT(traverse_module_state->__pyx_int_16720502);
  Py_VISIT(traverse_module_state->__pyx_int_18144804);
  Py_VISIT(traverse_module_state->__pyx_int_21744403);
  Py_VISIT(traverse_module_state->__pyx_int_25169964);
  Py_VISIT(traverse_module_state->__pyx_int_26315144);
  Py_VISIT(traverse_module_state->__pyx_int_27364120);
  Py_VISIT(traverse_module_state->__pyx_int_32037354);
  Py_VISIT(traverse_module_state->__pyx_int_34126920);
  Py_VISIT(traverse_module_state->__pyx_int_35394350);
  Py_VISIT(traverse_module_state->__pyx_int_36436105);
  Py_VISIT(traverse_module_state->__pyx_int_48122566);
  Py_VISIT(traverse_module_state->__pyx_int_58645358);
  Py_VISIT(traverse_module_state->__pyx_int_59724479);
  Py_VISIT(traverse_module_state->__pyx_int_66238981);
  Py_VISIT(traverse_module_state->__pyx_int_83828686);
  Py_VISIT(traverse_module_state->__pyx_int_88973758);
  Py_VISIT(traverse_module_state->__pyx_int_113527478);
  Py_VISIT(traverse_module_state->__pyx_int_130320202);
  Py_VISIT(traverse_module_state->__pyx_int_131103026);
  Py_VISIT(traverse_module_state->__pyx_int_133117037);
  Py_VISIT(traverse_module_state->__pyx_int_182994245);
  Py_VISIT(traverse_module_state->__pyx_int_199724618);
  Py_VISIT(traverse_module_state->__pyx_int_244630504);
  Py_VISIT(traverse_module_state->__pyx_int_259052823);
  Py_VISIT(traverse_module_state->__pyx_int_316342484);
  Py_VISIT(traverse_module_state->__pyx_int_371100958);
  Py_VISIT(traverse_module_state->__pyx_int_391479032);
  Py_VISIT(traverse_module_state->__pyx_int_392337786);
  Py_VISIT(traverse_module_state->__pyx_int_541037598);
  Py_VISIT(traverse_module_state->__pyx_int_677188186);
  Py_VISIT(traverse_module_state->__pyx_int_8855649026);
  Py_VISIT(traverse_module_state->__pyx_int_12717649349);
  Py_VISIT(traverse_module_state->__pyx_int_53136528234);
  Py_VISIT(traverse_module_state->__pyx_int_53299789831);
  Py_VISIT(traverse_module_state->__pyx_int_168229436395);
  Py_VISIT(traverse_module_state->__pyx_int_313032053358);
  Py_VISIT(traverse_module_state->__pyx_int_515063456666);
  Py_VISIT(traverse_module_state->__pyx_int_626306385346);
  Py_VISIT(traverse_module_state->__pyx_int_824243981862);
  Py_VISIT(traverse_module_state->__pyx_int_0x9507d62c436);
  Py_VISIT(traverse_module_state->__pyx_int_0x9660e6b8684);
  Py_VISIT(traverse_module_state->__pyx_int_0x977cef39562);
  Py_VISIT(traverse_module_state->__pyx_int_0x9c81f15f8f5);
  Py_VISIT(traverse_module_state->__pyx_int_0xa5646e4f052);
  Py_VISIT(traverse_module_state->__pyx_int_0xa573354fb9d);
  Py_VISIT(traverse_module_state->__pyx_int_0xb294917799f);
  Py_VISIT(traverse_module_state->__pyx_int_0xb38e85961b8);
  Py_VISIT(traverse_module_state->__pyx_int_0xbaef60da2c6);
  Py_VISIT(traverse_module_state->__pyx_int_0xca8cd5800f9);
  Py_VISIT(traverse_module_state->__pyx_int_0xe4562e88120);
  Py_VISIT(traverse_module_state->__pyx_int_0xfc88ab58e0b);
  Py_VISIT(traverse_module_state->__pyx_int_1110800675511);
  Py_VISIT(traverse_module_state->__pyx_int_1175767851306);
  Py_VISIT(traverse_module_state->__pyx_int_1436971721042);
  Py_VISIT(traverse_module_state->__pyx_int_1708631550165);
  Py_VISIT(traverse_module_state->__pyx_int_1821738041432);
  Py_VISIT(traverse_module_state->__pyx_int_1845844064964);
  Py_VISIT(traverse_module_state->__pyx_int_2968508455751);
  Py_VISIT(traverse_module_state->__pyx_int_3490375050807);
  Py_VISIT(traverse_module_state->__pyx_int_3491811426635);
  Py_VISIT(traverse_module_state->__pyx_int_4800328458344);
  Py_VISIT(traverse_module_state->__pyx_int_4998916135670);
  Py_VISIT(traverse_module_state->__pyx_int_5332514997228);
  Py_VISIT(traverse_module_state->__pyx_int_5531341956881);
  Py_VISIT(traverse_module_state->__pyx_int_5992127393523);
  Py_VISIT(traverse_module_state->__pyx_int_6118478847123);
  Py_VISIT(traverse_module_state->__pyx_int_6629036171731);
  Py_VISIT(traverse_module_state->__pyx_int_6897201046540);
  Py_VISIT(traverse_module_state->__pyx_int_7235995254645);
  Py_VISIT(traverse_module_state->__pyx_int_7325541012743);
  Py_VISIT(traverse_module_state->__pyx_int_7428389236896);
  Py_VISIT(traverse_module_state->__pyx_int_7507095323631);
  Py_VISIT(traverse_module_state->__pyx_int_7694238899256);
  Py_VISIT(traverse_module_state->__pyx_int_7884280772830);
  Py_VISIT(traverse_module_state->__pyx_int_8607232746956);
  Py_VISIT(traverse_module_state->__pyx_int_9597572050458);
  Py_VISIT(traverse_module_state->__pyx_int_9790143307451);
  Py_VISIT(traverse_module_state->__pyx_int_9890708337231);
  Py_VISIT(traverse_module_state->__pyx_int_0x105293ff5bfe);
  Py_VISIT(traverse_module_state->__pyx_int_0x120f2085deb4);
  Py_VISIT(traverse_module_state->__pyx_int_0x1312c5fef504);
  Py_VISIT(traverse_module_state->__pyx_int_0x157f527fb1d4);
  Py_VISIT(traverse_module_state->__pyx_int_0x15b1120a25de);
  Py_VISIT(traverse_module_state->__pyx_int_0x15bd71393949);
  Py_VISIT(traverse_module_state->__pyx_int_0x1839ab81d6a2);
  Py_VISIT(traverse_module_state->__pyx_int_0x193c10d5c555);
  Py_VISIT(traverse_module_state->__pyx_int_0x196f90195cb3);
  Py_VISIT(traverse_module_state->__pyx_int_0x19a936e9e6f2);
  Py_VISIT(traverse_module_state->__pyx_int_0x19b59fd426fa);
  Py_VISIT(traverse_module_state->__pyx_int_0x22f9a2787068);
  Py_VISIT(traverse_module_state->__pyx_int_0x2528aad29cbb);
  Py_VISIT(traverse_module_state->__pyx_int_0x27eebfaf00e2);
  Py_VISIT(traverse_module_state->__pyx_int_0x2b17e83d52a2);
  Py_VISIT(traverse_module_state->__pyx_int_0x2c4a1fdb349e);
  Py_VISIT(traverse_module_state->__pyx_int_0x2f7ef1b78d0e);
  Py_VISIT(traverse_module_state->__pyx_int_0x3d0738b72996);
  Py_VISIT(traverse_module_state->__pyx_int_0x433f57b789fe);
  Py_VISIT(traverse_module_state->__pyx_int_neg_1);
  Py_VISIT(traverse_module_state->__pyx_int_neg_5);
  Py_VISIT(traverse_module_state->__pyx_slice__26);
  Py_VISIT(traverse_module_state->__pyx_slice__27);
  Py_VISIT(traverse_module_state->__pyx_slice__42);
  Py_VISIT(traverse_module_state->__pyx_tuple__20);
  Py_VISIT(traverse_module_state->__pyx_tuple__21);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__24);
  Py_VISIT(traverse_module_state->__pyx_tuple__25);
  Py_VISIT(traverse_module_state->__pyx_tuple__34);
  Py_VISIT(traverse_module_state->__pyx_tuple__35);
  Py_VISIT(traverse_module_state->__pyx_tuple__37);
  Py_VISIT(traverse_module_state->__pyx_tuple__40);
  Py_VISIT(traverse_module_state->__pyx_tuple__41);
  Py_VISIT(traverse_module_state->__pyx_tuple__43);
  Py_VISIT(traverse_module_state->__pyx_tuple__44);
  Py_VISIT(traverse_module_state->__pyx_tuple__46);
  Py_VISIT(traverse_module_state->__pyx_tuple__48);
  Py_VISIT(traverse_module_state->__pyx_tuple__50);
  Py_VISIT(traverse_module_state->__pyx_tuple__52);
  Py_VISIT(traverse_module_state->__pyx_tuple__54);
  Py_VISIT(traverse_module_state->__pyx_tuple__56);
  Py_VISIT(traverse_module_state->__pyx_tuple__58);
  Py_VISIT(traverse_module_state->__pyx_tuple__60);
  Py_VISIT(traverse_module_state->__pyx_tuple__62);
  Py_VISIT(traverse_module_state->__pyx_tuple__64);
  Py_VISIT(traverse_module_state->__pyx_tuple__65);
  Py_VISIT(traverse_module_state->__pyx_tuple__67);
  Py_VISIT(traverse_module_state->__pyx_tuple__69);
  Py_VISIT(traverse_module_state->__pyx_tuple__71);
  Py_VISIT(traverse_module_state->__pyx_tuple__72);
  Py_VISIT(traverse_module_state->__pyx_tuple__74);
  Py_VISIT(traverse_module_state->__pyx_tuple__76);
  Py_VISIT(traverse_module_state->__pyx_tuple__78);
  Py_VISIT(traverse_module_state->__pyx_tuple__80);
  Py_VISIT(traverse_module_state->__pyx_tuple__82);
  Py_VISIT(traverse_module_state->__pyx_tuple__84);
  Py_VISIT(traverse_module_state->__pyx_tuple__86);
  Py_VISIT(traverse_module_state->__pyx_tuple__87);
  Py_VISIT(traverse_module_state->__pyx_tuple__89);
  Py_VISIT(traverse_module_state->__pyx_tuple__90);
  Py_VISIT(traverse_module_state->__pyx_tuple__92);
  Py_VISIT(traverse_module_state->__pyx_tuple__93);
  Py_VISIT(traverse_module_state->__pyx_tuple__95);
  Py_VISIT(traverse_module_state->__pyx_tuple__97);
  Py_VISIT(traverse_module_state->__pyx_tuple__99);
  Py_VISIT(traverse_module_state->__pyx_tuple__101);
  Py_VISIT(traverse_module_state->__pyx_tuple__103);
  Py_VISIT(traverse_module_state->__pyx_tuple__105);
  Py_VISIT(traverse_module_state->__pyx_tuple__107);
  Py_VISIT(traverse_module_state->__pyx_tuple__109);
  Py_VISIT(traverse_module_state->__pyx_codeobj__45);
  Py_VISIT(traverse_module_state->__pyx_codeobj__47);
  Py_VISIT(traverse_module_state->__pyx_codeobj__49);
  Py_VISIT(traverse_module_state->__pyx_codeobj__51);
  Py_VISIT(traverse_module_state->__pyx_codeobj__53);
  Py_VISIT(traverse_module_state->__pyx_codeobj__55);
  Py_VISIT(traverse_module_state->__pyx_codeobj__57);
  Py_VISIT(traverse_module_state->__pyx_codeobj__59);
  Py_VISIT(traverse_module_state->__pyx_codeobj__61);
  Py_VISIT(traverse_module_state->__pyx_codeobj__63);
  Py_VISIT(traverse_module_state->__pyx_codeobj__66);
  Py_VISIT(traverse_module_state->__pyx_codeobj__68);
  Py_VISIT(traverse_module_state->__pyx_codeobj__70);
  Py_VISIT(traverse_module_state->__pyx_codeobj__73);
  Py_VISIT(traverse_module_state->__pyx_codeobj__75);
  Py_VISIT(traverse_module_state->__pyx_codeobj__77);
  Py_VISIT(traverse_module_state->__pyx_codeobj__79);
  Py_VISIT(traverse_module_state->__pyx_codeobj__81);
  Py_VISIT(traverse_module_state->__pyx_codeobj__83);
  Py_VISIT(traverse_module_state->__pyx_codeobj__85);
  Py_VISIT(traverse_module_state->__pyx_codeobj__88);
  Py_VISIT(traverse_module_state->__pyx_codeobj__91);
  Py_VISIT(traverse_module_state->__pyx_codeobj__94);
  Py_VISIT(traverse_module_state->__pyx_codeobj__96);
  Py_VISIT(traverse_module_state->__pyx_codeobj__98);
  Py_VISIT(traverse_module_state->__pyx_codeobj__100);
  Py_VISIT(traverse_module_state->__pyx_codeobj__102);
  Py_VISIT(traverse_module_state->__pyx_codeobj__104);
  Py_VISIT(traverse_module_state->__pyx_codeobj__106);
  Py_VISIT(traverse_module_state->__pyx_codeobj__108);
  Py_VISIT(traverse_module_state->__pyx_codeobj__110);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_kp_u_ __pyx_mstate_global->__pyx_kp_u_
#define __pyx_kp_s_00 __pyx_mstate_global->__pyx_kp_s_00
#define __pyx_kp_s_000001 __pyx_mstate_global->__pyx_kp_s_000001
#define __pyx_kp_s_000003 __pyx_mstate_global->__pyx_kp_s_000003
#define __pyx_kp_s_000009 __pyx_mstate_global->__pyx_kp_s_000009
#define __pyx_kp_s_000010 __pyx_mstate_global->__pyx_kp_s_000010
#define __pyx_kp_s_000011 __pyx_mstate_global->__pyx_kp_s_000011
#define __pyx_kp_s_000012 __pyx_mstate_global->__pyx_kp_s_000012
#define __pyx_kp_s_000013 __pyx_mstate_global->__pyx_kp_s_000013
#define __pyx_kp_s_000016 __pyx_mstate_global->__pyx_kp_s_000016
#define __pyx_kp_s_000132 __pyx_mstate_global->__pyx_kp_s_000132
#define __pyx_kp_s_000133 __pyx_mstate_global->__pyx_kp_s_000133
#define __pyx_kp_s_000300 __pyx_mstate_global->__pyx_kp_s_000300
#define __pyx_kp_s_000688 __pyx_mstate_global->__pyx_kp_s_000688
#define __pyx_kp_s_000852 __pyx_mstate_global->__pyx_kp_s_000852
#define __pyx_kp_s_000903 __pyx_mstate_global->__pyx_kp_s_000903
#define __pyx_kp_s_000904 __pyx_mstate_global->__pyx_kp_s_000904
#define __pyx_kp_s_000905 __pyx_mstate_global->__pyx_kp_s_000905
#define __pyx_kp_s_000906 __pyx_mstate_global->__pyx_kp_s_000906
#define __pyx_kp_s_000985 __pyx_mstate_global->__pyx_kp_s_000985
#define __pyx_kp_u_01 __pyx_mstate_global->__pyx_kp_u_01
#define __pyx_kp_s_0101 __pyx_mstate_global->__pyx_kp_s_0101
#define __pyx_kp_u_02d __pyx_mstate_global->__pyx_kp_u_02d
#define __pyx_kp_s_1 __pyx_mstate_global->__pyx_kp_s_1
#define __pyx_kp_s_10 __pyx_mstate_global->__pyx_kp_s_10
#define __pyx_kp_s_100 __pyx_mstate_global->__pyx_kp_s_100
#define __pyx_kp_s_1000 __pyx_mstate_global->__pyx_kp_s_1000
#define __pyx_kp_s_100R __pyx_mstate_global->__pyx_kp_s_100R
#define __pyx_kp_s_100_2 __pyx_mstate_global->__pyx_kp_s_100_2
#define __pyx_kp_s_100_3 __pyx_mstate_global->__pyx_kp_s_100_3
#define __pyx_kp_s_14_days __pyx_mstate_global->__pyx_kp_s_14_days
#define __pyx_kp_s_150 __pyx_mstate_global->__pyx_kp_s_150
#define __pyx_kp_s_180 __pyx_mstate_global->__pyx_kp_s_180
#define __pyx_kp_s_2 __pyx_mstate_global->__pyx_kp_s_2
#define __pyx_kp_s_200 __pyx_mstate_global->__pyx_kp_s_200
#define __pyx_kp_s_2000 __pyx_mstate_global->__pyx_kp_s_2000
#define __pyx_kp_s_200_2 __pyx_mstate_global->__pyx_kp_s_200_2
#define __pyx_kp_s_20180101 __pyx_mstate_global->__pyx_kp_s_20180101
#define __pyx_kp_s_3 __pyx_mstate_global->__pyx_kp_s_3
#define __pyx_kp_s_30 __pyx_mstate_global->__pyx_kp_s_30
#define __pyx_kp_s_300 __pyx_mstate_global->__pyx_kp_s_300
#define __pyx_kp_s_300_2 __pyx_mstate_global->__pyx_kp_s_300_2
#define __pyx_kp_s_300_3 __pyx_mstate_global->__pyx_kp_s_300_3
#define __pyx_kp_s_380 __pyx_mstate_global->__pyx_kp_s_380
#define __pyx_kp_s_399001 __pyx_mstate_global->__pyx_kp_s_399001
#define __pyx_kp_s_399002 __pyx_mstate_global->__pyx_kp_s_399002
#define __pyx_kp_s_399003 __pyx_mstate_global->__pyx_kp_s_399003
#define __pyx_kp_s_399004 __pyx_mstate_global->__pyx_kp_s_399004
#define __pyx_kp_s_399005 __pyx_mstate_global->__pyx_kp_s_399005
#define __pyx_kp_s_399006 __pyx_mstate_global->__pyx_kp_s_399006
#define __pyx_kp_s_399007 __pyx_mstate_global->__pyx_kp_s_399007
#define __pyx_kp_s_399008 __pyx_mstate_global->__pyx_kp_s_399008
#define __pyx_kp_s_399019 __pyx_mstate_global->__pyx_kp_s_399019
#define __pyx_kp_s_399020 __pyx_mstate_global->__pyx_kp_s_399020
#define __pyx_kp_s_399100 __pyx_mstate_global->__pyx_kp_s_399100
#define __pyx_kp_s_399106 __pyx_mstate_global->__pyx_kp_s_399106
#define __pyx_kp_s_399293 __pyx_mstate_global->__pyx_kp_s_399293
#define __pyx_kp_s_399550 __pyx_mstate_global->__pyx_kp_s_399550
#define __pyx_kp_s_399750 __pyx_mstate_global->__pyx_kp_s_399750
#define __pyx_kp_s_399850 __pyx_mstate_global->__pyx_kp_s_399850
#define __pyx_kp_s_4 __pyx_mstate_global->__pyx_kp_s_4
#define __pyx_kp_s_5 __pyx_mstate_global->__pyx_kp_s_5
#define __pyx_kp_s_50 __pyx_mstate_global->__pyx_kp_s_50
#define __pyx_kp_s_500 __pyx_mstate_global->__pyx_kp_s_500
#define __pyx_kp_s_50MB __pyx_mstate_global->__pyx_kp_s_50MB
#define __pyx_kp_s_50_2 __pyx_mstate_global->__pyx_kp_s_50_2
#define __pyx_kp_s_50_3 __pyx_mstate_global->__pyx_kp_s_50_3
#define __pyx_kp_s_50_4 __pyx_mstate_global->__pyx_kp_s_50_4
#define __pyx_kp_s_50_5 __pyx_mstate_global->__pyx_kp_s_50_5
#define __pyx_kp_s_50_6 __pyx_mstate_global->__pyx_kp_s_50_6
#define __pyx_kp_s_60 __pyx_mstate_global->__pyx_kp_s_60
#define __pyx_kp_s_68 __pyx_mstate_global->__pyx_kp_s_68
#define __pyx_kp_s_7 __pyx_mstate_global->__pyx_kp_s_7
#define __pyx_kp_s_8 __pyx_mstate_global->__pyx_kp_s_8
#define __pyx_kp_s_800 __pyx_mstate_global->__pyx_kp_s_800
#define __pyx_kp_s_899050 __pyx_mstate_global->__pyx_kp_s_899050
#define __pyx_kp_s_930050 __pyx_mstate_global->__pyx_kp_s_930050
#define __pyx_kp_s_932000 __pyx_mstate_global->__pyx_kp_s_932000
#define __pyx_kp_s_A50 __pyx_mstate_global->__pyx_kp_s_A50
#define __pyx_kp_u_All_days_in_the_week_of_this __pyx_mstate_global->__pyx_kp_u_All_days_in_the_week_of_this
#define __pyx_n_s_Counter __pyx_mstate_global->__pyx_n_s_Counter
#define __pyx_n_s_DataFrame __pyx_mstate_global->__pyx_n_s_DataFrame
#define __pyx_n_s_Dict __pyx_mstate_global->__pyx_n_s_Dict
#define __pyx_n_s_INFO __pyx_mstate_global->__pyx_n_s_INFO
#define __pyx_n_s_IOError __pyx_mstate_global->__pyx_n_s_IOError
#define __pyx_n_s_JSONEncoder __pyx_mstate_global->__pyx_n_s_JSONEncoder
#define __pyx_kp_u_Json_file __pyx_mstate_global->__pyx_kp_u_Json_file
#define __pyx_n_s_List __pyx_mstate_global->__pyx_n_s_List
#define __pyx_n_s_MyEncoder __pyx_mstate_global->__pyx_n_s_MyEncoder
#define __pyx_n_s_MyEncoder_default __pyx_mstate_global->__pyx_n_s_MyEncoder_default
#define __pyx_n_s_MyEncoder_encode __pyx_mstate_global->__pyx_n_s_MyEncoder_encode
#define __pyx_n_s_MyEncoder_insert_newlines __pyx_mstate_global->__pyx_n_s_MyEncoder_insert_newlines
#define __pyx_kp_u_Open_json_file __pyx_mstate_global->__pyx_kp_u_Open_json_file
#define __pyx_n_s_PicklingError __pyx_mstate_global->__pyx_n_s_PicklingError
#define __pyx_kp_s_R __pyx_mstate_global->__pyx_kp_s_R
#define __pyx_n_s_ST __pyx_mstate_global->__pyx_n_s_ST
#define __pyx_kp_s_Start_this_log_record __pyx_mstate_global->__pyx_kp_s_Start_this_log_record
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_n_s_Union __pyx_mstate_global->__pyx_n_s_Union
#define __pyx_kp_s_Union_Dict_None __pyx_mstate_global->__pyx_kp_s_Union_Dict_None
#define __pyx_kp_s_Union_List_None __pyx_mstate_global->__pyx_kp_s_Union_List_None
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_n_s_XSHG __pyx_mstate_global->__pyx_n_s_XSHG
#define __pyx_kp_s_XX __pyx_mstate_global->__pyx_kp_s_XX
#define __pyx_kp_s_Y_m_d __pyx_mstate_global->__pyx_kp_s_Y_m_d
#define __pyx_kp_s__10 __pyx_mstate_global->__pyx_kp_s__10
#define __pyx_kp_s__11 __pyx_mstate_global->__pyx_kp_s__11
#define __pyx_n_s__111 __pyx_mstate_global->__pyx_n_s__111
#define __pyx_kp_s__12 __pyx_mstate_global->__pyx_kp_s__12
#define __pyx_kp_s__13 __pyx_mstate_global->__pyx_kp_s__13
#define __pyx_kp_s__14 __pyx_mstate_global->__pyx_kp_s__14
#define __pyx_kp_s__15 __pyx_mstate_global->__pyx_kp_s__15
#define __pyx_kp_s__16 __pyx_mstate_global->__pyx_kp_s__16
#define __pyx_kp_s__17 __pyx_mstate_global->__pyx_kp_s__17
#define __pyx_kp_s__18 __pyx_mstate_global->__pyx_kp_s__18
#define __pyx_kp_s__19 __pyx_mstate_global->__pyx_kp_s__19
#define __pyx_kp_u__19 __pyx_mstate_global->__pyx_kp_u__19
#define __pyx_kp_u__2 __pyx_mstate_global->__pyx_kp_u__2
#define __pyx_kp_s__22 __pyx_mstate_global->__pyx_kp_s__22
#define __pyx_kp_s__28 __pyx_mstate_global->__pyx_kp_s__28
#define __pyx_kp_s__29 __pyx_mstate_global->__pyx_kp_s__29
#define __pyx_kp_u__3 __pyx_mstate_global->__pyx_kp_u__3
#define __pyx_kp_s__30 __pyx_mstate_global->__pyx_kp_s__30
#define __pyx_kp_s__31 __pyx_mstate_global->__pyx_kp_s__31
#define __pyx_kp_s__32 __pyx_mstate_global->__pyx_kp_s__32
#define __pyx_kp_s__33 __pyx_mstate_global->__pyx_kp_s__33
#define __pyx_kp_s__36 __pyx_mstate_global->__pyx_kp_s__36
#define __pyx_kp_s__38 __pyx_mstate_global->__pyx_kp_s__38
#define __pyx_n_s__39 __pyx_mstate_global->__pyx_n_s__39
#define __pyx_kp_s__4 __pyx_mstate_global->__pyx_kp_s__4
#define __pyx_kp_s__5 __pyx_mstate_global->__pyx_kp_s__5
#define __pyx_kp_s__6 __pyx_mstate_global->__pyx_kp_s__6
#define __pyx_kp_s__7 __pyx_mstate_global->__pyx_kp_s__7
#define __pyx_kp_s__8 __pyx_mstate_global->__pyx_kp_s__8
#define __pyx_kp_s__9 __pyx_mstate_global->__pyx_kp_s__9
#define __pyx_n_s_a __pyx_mstate_global->__pyx_n_s_a
#define __pyx_n_s_add __pyx_mstate_global->__pyx_n_s_add
#define __pyx_n_s_ak __pyx_mstate_global->__pyx_n_s_ak
#define __pyx_kp_s_akshare __pyx_mstate_global->__pyx_kp_s_akshare
#define __pyx_n_s_akshare_2 __pyx_mstate_global->__pyx_n_s_akshare_2
#define __pyx_n_s_all_data_list __pyx_mstate_global->__pyx_n_s_all_data_list
#define __pyx_n_s_all_index __pyx_mstate_global->__pyx_n_s_all_index
#define __pyx_n_s_all_list __pyx_mstate_global->__pyx_n_s_all_list
#define __pyx_n_s_append __pyx_mstate_global->__pyx_n_s_append
#define __pyx_kp_u_are_non_trading_days __pyx_mstate_global->__pyx_kp_u_are_non_trading_days
#define __pyx_n_s_arg __pyx_mstate_global->__pyx_n_s_arg
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_n_s_ascending __pyx_mstate_global->__pyx_n_s_ascending
#define __pyx_kp_s_assets_audios __pyx_mstate_global->__pyx_kp_s_assets_audios
#define __pyx_kp_s_assets_cookies __pyx_mstate_global->__pyx_kp_s_assets_cookies
#define __pyx_kp_s_assets_cover_img __pyx_mstate_global->__pyx_kp_s_assets_cover_img
#define __pyx_kp_s_assets_imgs __pyx_mstate_global->__pyx_kp_s_assets_imgs
#define __pyx_kp_s_assets_logs __pyx_mstate_global->__pyx_kp_s_assets_logs
#define __pyx_kp_s_assets_update_db_logs __pyx_mstate_global->__pyx_kp_s_assets_update_db_logs
#define __pyx_kp_s_assets_update_strategy_logs __pyx_mstate_global->__pyx_kp_s_assets_update_strategy_logs
#define __pyx_kp_s_assets_videos __pyx_mstate_global->__pyx_kp_s_assets_videos
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_attr_name __pyx_mstate_global->__pyx_n_s_attr_name
#define __pyx_n_s_attr_value __pyx_mstate_global->__pyx_n_s_attr_value
#define __pyx_n_s_attributes __pyx_mstate_global->__pyx_n_s_attributes
#define __pyx_n_s_audio_dir __pyx_mstate_global->__pyx_n_s_audio_dir
#define __pyx_n_s_b __pyx_mstate_global->__pyx_n_s_b
#define __pyx_kp_s_baostock __pyx_mstate_global->__pyx_kp_s_baostock
#define __pyx_n_s_bj __pyx_mstate_global->__pyx_n_s_bj
#define __pyx_n_s_bool __pyx_mstate_global->__pyx_n_s_bool
#define __pyx_n_s_c __pyx_mstate_global->__pyx_n_s_c
#define __pyx_n_s_calendar __pyx_mstate_global->__pyx_n_s_calendar
#define __pyx_n_s_checkCreatePath __pyx_mstate_global->__pyx_n_s_checkCreatePath
#define __pyx_n_s_check_serializability __pyx_mstate_global->__pyx_n_s_check_serializability
#define __pyx_n_s_chunks __pyx_mstate_global->__pyx_n_s_chunks
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_cleaned_list_str __pyx_mstate_global->__pyx_n_s_cleaned_list_str
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_cls __pyx_mstate_global->__pyx_n_s_cls
#define __pyx_n_s_code_ip __pyx_mstate_global->__pyx_n_s_code_ip
#define __pyx_n_s_coerce __pyx_mstate_global->__pyx_n_s_coerce
#define __pyx_n_s_collections __pyx_mstate_global->__pyx_n_s_collections
#define __pyx_n_s_combined_list __pyx_mstate_global->__pyx_n_s_combined_list
#define __pyx_n_s_comma_index __pyx_mstate_global->__pyx_n_s_comma_index
#define __pyx_n_s_cookies_dir __pyx_mstate_global->__pyx_n_s_cookies_dir
#define __pyx_n_s_count __pyx_mstate_global->__pyx_n_s_count
#define __pyx_n_s_cover_img_dir __pyx_mstate_global->__pyx_n_s_cover_img_dir
#define __pyx_n_s_current_date __pyx_mstate_global->__pyx_n_s_current_date
#define __pyx_n_s_current_directory __pyx_mstate_global->__pyx_n_s_current_directory
#define __pyx_kp_s_current_directory_2 __pyx_mstate_global->__pyx_kp_s_current_directory_2
#define __pyx_kp_s_d __pyx_mstate_global->__pyx_kp_s_d
#define __pyx_n_s_data __pyx_mstate_global->__pyx_n_s_data
#define __pyx_n_s_data_in __pyx_mstate_global->__pyx_n_s_data_in
#define __pyx_n_s_data_list __pyx_mstate_global->__pyx_n_s_data_list
#define __pyx_kp_s_data_must_be_a_dictionary __pyx_mstate_global->__pyx_kp_s_data_must_be_a_dictionary
#define __pyx_n_s_date __pyx_mstate_global->__pyx_n_s_date
#define __pyx_kp_s_date_str __pyx_mstate_global->__pyx_kp_s_date_str
#define __pyx_n_s_date_str_2 __pyx_mstate_global->__pyx_n_s_date_str_2
#define __pyx_n_s_date_to_session __pyx_mstate_global->__pyx_n_s_date_to_session
#define __pyx_n_s_date_type __pyx_mstate_global->__pyx_n_s_date_type
#define __pyx_n_s_datetime __pyx_mstate_global->__pyx_n_s_datetime
#define __pyx_kp_s_datetime64_ns __pyx_mstate_global->__pyx_kp_s_datetime64_ns
#define __pyx_n_s_day __pyx_mstate_global->__pyx_n_s_day
#define __pyx_n_s_days __pyx_mstate_global->__pyx_n_s_days
#define __pyx_n_s_default __pyx_mstate_global->__pyx_n_s_default
#define __pyx_n_s_df __pyx_mstate_global->__pyx_n_s_df
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_n_s_dict_2 __pyx_mstate_global->__pyx_n_s_dict_2
#define __pyx_n_s_diff __pyx_mstate_global->__pyx_n_s_diff
#define __pyx_n_s_directory __pyx_mstate_global->__pyx_n_s_directory
#define __pyx_n_s_dirname __pyx_mstate_global->__pyx_n_s_dirname
#define __pyx_n_s_dlmkts __pyx_mstate_global->__pyx_n_s_dlmkts
#define __pyx_n_s_doc __pyx_mstate_global->__pyx_n_s_doc
#define __pyx_n_s_dt __pyx_mstate_global->__pyx_n_s_dt
#define __pyx_n_s_dtype __pyx_mstate_global->__pyx_n_s_dtype
#define __pyx_n_s_dumpJsonToFile __pyx_mstate_global->__pyx_n_s_dumpJsonToFile
#define __pyx_n_s_dumps __pyx_mstate_global->__pyx_n_s_dumps
#define __pyx_n_s_edge_driver_path __pyx_mstate_global->__pyx_n_s_edge_driver_path
#define __pyx_n_s_encode __pyx_mstate_global->__pyx_n_s_encode
#define __pyx_n_s_encoding __pyx_mstate_global->__pyx_n_s_encoding
#define __pyx_n_s_end_date __pyx_mstate_global->__pyx_n_s_end_date
#define __pyx_n_s_end_of_week __pyx_mstate_global->__pyx_n_s_end_of_week
#define __pyx_n_s_enqueue __pyx_mstate_global->__pyx_n_s_enqueue
#define __pyx_n_s_ensure_ascii __pyx_mstate_global->__pyx_n_s_ensure_ascii
#define __pyx_n_s_enter __pyx_mstate_global->__pyx_n_s_enter
#define __pyx_n_s_error __pyx_mstate_global->__pyx_n_s_error
#define __pyx_n_s_errors __pyx_mstate_global->__pyx_n_s_errors
#define __pyx_n_s_exchange_calendars __pyx_mstate_global->__pyx_n_s_exchange_calendars
#define __pyx_n_s_exists __pyx_mstate_global->__pyx_n_s_exists
#define __pyx_n_s_exit __pyx_mstate_global->__pyx_n_s_exit
#define __pyx_n_s_extractAdministrativeRegions __pyx_mstate_global->__pyx_n_s_extractAdministrativeRegions
#define __pyx_n_s_f1 __pyx_mstate_global->__pyx_n_s_f1
#define __pyx_n_s_f10 __pyx_mstate_global->__pyx_n_s_f10
#define __pyx_n_s_f11 __pyx_mstate_global->__pyx_n_s_f11
#define __pyx_n_s_f115 __pyx_mstate_global->__pyx_n_s_f115
#define __pyx_n_s_f12 __pyx_mstate_global->__pyx_n_s_f12
#define __pyx_n_s_f128 __pyx_mstate_global->__pyx_n_s_f128
#define __pyx_n_s_f13 __pyx_mstate_global->__pyx_n_s_f13
#define __pyx_n_s_f136 __pyx_mstate_global->__pyx_n_s_f136
#define __pyx_n_s_f14 __pyx_mstate_global->__pyx_n_s_f14
#define __pyx_n_s_f140 __pyx_mstate_global->__pyx_n_s_f140
#define __pyx_n_s_f141 __pyx_mstate_global->__pyx_n_s_f141
#define __pyx_n_s_f15 __pyx_mstate_global->__pyx_n_s_f15
#define __pyx_n_s_f152 __pyx_mstate_global->__pyx_n_s_f152
#define __pyx_n_s_f16 __pyx_mstate_global->__pyx_n_s_f16
#define __pyx_n_s_f17 __pyx_mstate_global->__pyx_n_s_f17
#define __pyx_n_s_f18 __pyx_mstate_global->__pyx_n_s_f18
#define __pyx_n_s_f2 __pyx_mstate_global->__pyx_n_s_f2
#define __pyx_n_s_f20 __pyx_mstate_global->__pyx_n_s_f20
#define __pyx_n_s_f21 __pyx_mstate_global->__pyx_n_s_f21
#define __pyx_n_s_f22 __pyx_mstate_global->__pyx_n_s_f22
#define __pyx_n_s_f23 __pyx_mstate_global->__pyx_n_s_f23
#define __pyx_n_s_f24 __pyx_mstate_global->__pyx_n_s_f24
#define __pyx_n_s_f25 __pyx_mstate_global->__pyx_n_s_f25
#define __pyx_n_s_f26 __pyx_mstate_global->__pyx_n_s_f26
#define __pyx_n_s_f3 __pyx_mstate_global->__pyx_n_s_f3
#define __pyx_n_s_f4 __pyx_mstate_global->__pyx_n_s_f4
#define __pyx_n_s_f5 __pyx_mstate_global->__pyx_n_s_f5
#define __pyx_n_s_f6 __pyx_mstate_global->__pyx_n_s_f6
#define __pyx_n_s_f62 __pyx_mstate_global->__pyx_n_s_f62
#define __pyx_n_s_f7 __pyx_mstate_global->__pyx_n_s_f7
#define __pyx_n_s_f8 __pyx_mstate_global->__pyx_n_s_f8
#define __pyx_n_s_f9 __pyx_mstate_global->__pyx_n_s_f9
#define __pyx_kp_u_failed __pyx_mstate_global->__pyx_kp_u_failed
#define __pyx_n_s_file __pyx_mstate_global->__pyx_n_s_file
#define __pyx_n_s_fillna __pyx_mstate_global->__pyx_n_s_fillna
#define __pyx_n_s_find __pyx_mstate_global->__pyx_n_s_find
#define __pyx_n_s_findall __pyx_mstate_global->__pyx_n_s_findall
#define __pyx_n_s_first_weekday __pyx_mstate_global->__pyx_n_s_first_weekday
#define __pyx_n_s_full __pyx_mstate_global->__pyx_n_s_full
#define __pyx_n_s_full_code __pyx_mstate_global->__pyx_n_s_full_code
#define __pyx_n_s_full_stock_code __pyx_mstate_global->__pyx_n_s_full_stock_code
#define __pyx_n_s_getDateDistribution __pyx_mstate_global->__pyx_n_s_getDateDistribution
#define __pyx_n_s_getFullStockCode __pyx_mstate_global->__pyx_n_s_getFullStockCode
#define __pyx_n_s_getIndexCodeName __pyx_mstate_global->__pyx_n_s_getIndexCodeName
#define __pyx_n_s_getLatestTradeDay __pyx_mstate_global->__pyx_n_s_getLatestTradeDay
#define __pyx_n_s_getMonthStartEndDate __pyx_mstate_global->__pyx_n_s_getMonthStartEndDate
#define __pyx_n_s_getStockLimitUp __pyx_mstate_global->__pyx_n_s_getStockLimitUp
#define __pyx_n_s_getSuspendedStocks __pyx_mstate_global->__pyx_n_s_getSuspendedStocks
#define __pyx_n_s_getWeekStartEndByDate __pyx_mstate_global->__pyx_n_s_getWeekStartEndByDate
#define __pyx_n_s_getYearStartEndDate __pyx_mstate_global->__pyx_n_s_getYearStartEndDate
#define __pyx_n_s_get_calendar __pyx_mstate_global->__pyx_n_s_get_calendar
#define __pyx_n_s_getcwd __pyx_mstate_global->__pyx_n_s_getcwd
#define __pyx_n_s_given_date __pyx_mstate_global->__pyx_n_s_given_date
#define __pyx_n_s_group __pyx_mstate_global->__pyx_n_s_group
#define __pyx_n_s_groupby __pyx_mstate_global->__pyx_n_s_groupby
#define __pyx_n_s_has_update_file __pyx_mstate_global->__pyx_n_s_has_update_file
#define __pyx_kp_s_home_paco_norm_envs_softwares_e __pyx_mstate_global->__pyx_kp_s_home_paco_norm_envs_softwares_e
#define __pyx_n_s_hour __pyx_mstate_global->__pyx_n_s_hour
#define __pyx_n_s_i __pyx_mstate_global->__pyx_n_s_i
#define __pyx_n_s_img_save_path_root __pyx_mstate_global->__pyx_n_s_img_save_path_root
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_indent __pyx_mstate_global->__pyx_n_s_indent
#define __pyx_n_s_index __pyx_mstate_global->__pyx_n_s_index
#define __pyx_n_s_index_code __pyx_mstate_global->__pyx_n_s_index_code
#define __pyx_n_s_index_name __pyx_mstate_global->__pyx_n_s_index_name
#define __pyx_n_s_inf __pyx_mstate_global->__pyx_n_s_inf
#define __pyx_kp_s_inf_2 __pyx_mstate_global->__pyx_kp_s_inf_2
#define __pyx_n_s_info __pyx_mstate_global->__pyx_n_s_info
#define __pyx_n_s_init_subclass __pyx_mstate_global->__pyx_n_s_init_subclass
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_inplace __pyx_mstate_global->__pyx_n_s_inplace
#define __pyx_n_s_input_str __pyx_mstate_global->__pyx_n_s_input_str
#define __pyx_n_s_insert_newlines __pyx_mstate_global->__pyx_n_s_insert_newlines
#define __pyx_n_s_intersec_list __pyx_mstate_global->__pyx_n_s_intersec_list
#define __pyx_n_s_intersection_list __pyx_mstate_global->__pyx_n_s_intersection_list
#define __pyx_n_s_interval __pyx_mstate_global->__pyx_n_s_interval
#define __pyx_n_s_isAPrimaryBoardStock __pyx_mstate_global->__pyx_n_s_isAPrimaryBoardStock
#define __pyx_n_s_isMonthLastTradeDay __pyx_mstate_global->__pyx_n_s_isMonthLastTradeDay
#define __pyx_n_s_isStockDataSaveToMysql __pyx_mstate_global->__pyx_n_s_isStockDataSaveToMysql
#define __pyx_n_s_isWeekLastTradeDay __pyx_mstate_global->__pyx_n_s_isWeekLastTradeDay
#define __pyx_n_s_isYearLastTradeDay __pyx_mstate_global->__pyx_n_s_isYearLastTradeDay
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_n_s_is_serializable __pyx_mstate_global->__pyx_n_s_is_serializable
#define __pyx_n_s_is_session __pyx_mstate_global->__pyx_n_s_is_session
#define __pyx_kp_s_is_session_2 __pyx_mstate_global->__pyx_kp_s_is_session_2
#define __pyx_n_s_isocalendar __pyx_mstate_global->__pyx_n_s_isocalendar
#define __pyx_n_s_isoformat __pyx_mstate_global->__pyx_n_s_isoformat
#define __pyx_n_s_items __pyx_mstate_global->__pyx_n_s_items
#define __pyx_n_s_iterencode __pyx_mstate_global->__pyx_n_s_iterencode
#define __pyx_n_s_join __pyx_mstate_global->__pyx_n_s_join
#define __pyx_n_s_json __pyx_mstate_global->__pyx_n_s_json
#define __pyx_n_s_json_file_name __pyx_mstate_global->__pyx_n_s_json_file_name
#define __pyx_n_s_json_str __pyx_mstate_global->__pyx_n_s_json_str
#define __pyx_n_s_json_string __pyx_mstate_global->__pyx_n_s_json_string
#define __pyx_n_s_key __pyx_mstate_global->__pyx_n_s_key
#define __pyx_n_s_keys __pyx_mstate_global->__pyx_n_s_keys
#define __pyx_n_s_kwargs __pyx_mstate_global->__pyx_n_s_kwargs
#define __pyx_n_s_latest_trade_day __pyx_mstate_global->__pyx_n_s_latest_trade_day
#define __pyx_kp_u_latest_trade_day_2 __pyx_mstate_global->__pyx_kp_u_latest_trade_day_2
#define __pyx_n_s_level __pyx_mstate_global->__pyx_n_s_level
#define __pyx_n_s_limit_up __pyx_mstate_global->__pyx_n_s_limit_up
#define __pyx_n_s_list __pyx_mstate_global->__pyx_n_s_list
#define __pyx_n_s_list1 __pyx_mstate_global->__pyx_n_s_list1
#define __pyx_n_s_list2 __pyx_mstate_global->__pyx_n_s_list2
#define __pyx_n_s_list3 __pyx_mstate_global->__pyx_n_s_list3
#define __pyx_n_s_listIntersection __pyx_mstate_global->__pyx_n_s_listIntersection
#define __pyx_n_s_listUnion __pyx_mstate_global->__pyx_n_s_listUnion
#define __pyx_n_s_list_2_dict __pyx_mstate_global->__pyx_n_s_list_2_dict
#define __pyx_n_s_list_end_idx __pyx_mstate_global->__pyx_n_s_list_end_idx
#define __pyx_n_s_list_end_idxs __pyx_mstate_global->__pyx_n_s_list_end_idxs
#define __pyx_n_s_list_start_idx __pyx_mstate_global->__pyx_n_s_list_start_idx
#define __pyx_n_s_list_start_idxs __pyx_mstate_global->__pyx_n_s_list_start_idxs
#define __pyx_n_s_list_str __pyx_mstate_global->__pyx_n_s_list_str
#define __pyx_n_s_load __pyx_mstate_global->__pyx_n_s_load
#define __pyx_n_s_loadJsonData __pyx_mstate_global->__pyx_n_s_loadJsonData
#define __pyx_n_s_load_json_file __pyx_mstate_global->__pyx_n_s_load_json_file
#define __pyx_n_s_log_trace __pyx_mstate_global->__pyx_n_s_log_trace
#define __pyx_n_s_logger __pyx_mstate_global->__pyx_n_s_logger
#define __pyx_n_s_logs_dir __pyx_mstate_global->__pyx_n_s_logs_dir
#define __pyx_n_s_loguru __pyx_mstate_global->__pyx_n_s_loguru
#define __pyx_n_s_lt __pyx_mstate_global->__pyx_n_s_lt
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_makedirs __pyx_mstate_global->__pyx_n_s_makedirs
#define __pyx_n_s_map __pyx_mstate_global->__pyx_n_s_map
#define __pyx_n_s_match __pyx_mstate_global->__pyx_n_s_match
#define __pyx_n_s_metaclass __pyx_mstate_global->__pyx_n_s_metaclass
#define __pyx_n_s_mode __pyx_mstate_global->__pyx_n_s_mode
#define __pyx_n_s_module __pyx_mstate_global->__pyx_n_s_module
#define __pyx_n_s_month __pyx_mstate_global->__pyx_n_s_month
#define __pyx_n_s_month12_days __pyx_mstate_global->__pyx_n_s_month12_days
#define __pyx_n_s_month_str __pyx_mstate_global->__pyx_n_s_month_str
#define __pyx_n_s_monthrange __pyx_mstate_global->__pyx_n_s_monthrange
#define __pyx_n_s_mro_entries __pyx_mstate_global->__pyx_n_s_mro_entries
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_negative_infinity __pyx_mstate_global->__pyx_n_s_negative_infinity
#define __pyx_kp_s_new_date_str __pyx_mstate_global->__pyx_kp_s_new_date_str
#define __pyx_n_s_next __pyx_mstate_global->__pyx_n_s_next
#define __pyx_kp_s_next_session __pyx_mstate_global->__pyx_kp_s_next_session
#define __pyx_n_s_next_session_2 __pyx_mstate_global->__pyx_n_s_next_session_2
#define __pyx_n_s_non_serializable_attrs __pyx_mstate_global->__pyx_n_s_non_serializable_attrs
#define __pyx_kp_u_not_found __pyx_mstate_global->__pyx_kp_u_not_found
#define __pyx_n_s_now_datetime __pyx_mstate_global->__pyx_n_s_now_datetime
#define __pyx_n_s_num __pyx_mstate_global->__pyx_n_s_num
#define __pyx_n_s_number_of_days __pyx_mstate_global->__pyx_n_s_number_of_days
#define __pyx_n_s_obj __pyx_mstate_global->__pyx_n_s_obj
#define __pyx_n_s_one_shot __pyx_mstate_global->__pyx_n_s_one_shot
#define __pyx_n_s_open __pyx_mstate_global->__pyx_n_s_open
#define __pyx_n_s_os __pyx_mstate_global->__pyx_n_s_os
#define __pyx_n_s_out __pyx_mstate_global->__pyx_n_s_out
#define __pyx_n_s_pandas __pyx_mstate_global->__pyx_n_s_pandas
#define __pyx_n_s_path __pyx_mstate_global->__pyx_n_s_path
#define __pyx_n_s_pattern __pyx_mstate_global->__pyx_n_s_pattern
#define __pyx_n_s_pd __pyx_mstate_global->__pyx_n_s_pd
#define __pyx_kp_s_pd_DataFrame __pyx_mstate_global->__pyx_kp_s_pd_DataFrame
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_kp_s_pip_install_akshare_upgrade __pyx_mstate_global->__pyx_kp_s_pip_install_akshare_upgrade
#define __pyx_kp_s_pip_install_baostock_upgrade __pyx_mstate_global->__pyx_kp_s_pip_install_baostock_upgrade
#define __pyx_n_s_positive_infinity __pyx_mstate_global->__pyx_n_s_positive_infinity
#define __pyx_n_s_prepare __pyx_mstate_global->__pyx_n_s_prepare
#define __pyx_n_s_previous __pyx_mstate_global->__pyx_n_s_previous
#define __pyx_n_s_previous_session __pyx_mstate_global->__pyx_n_s_previous_session
#define __pyx_kp_s_previous_session_2 __pyx_mstate_global->__pyx_kp_s_previous_session_2
#define __pyx_n_s_print __pyx_mstate_global->__pyx_n_s_print
#define __pyx_n_s_qualname __pyx_mstate_global->__pyx_n_s_qualname
#define __pyx_n_s_r __pyx_mstate_global->__pyx_n_s_r
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_rc __pyx_mstate_global->__pyx_n_s_rc
#define __pyx_n_s_re __pyx_mstate_global->__pyx_n_s_re
#define __pyx_n_s_regions __pyx_mstate_global->__pyx_n_s_regions
#define __pyx_n_s_replace __pyx_mstate_global->__pyx_n_s_replace
#define __pyx_n_s_result __pyx_mstate_global->__pyx_n_s_result
#define __pyx_n_s_retention __pyx_mstate_global->__pyx_n_s_retention
#define __pyx_n_s_return __pyx_mstate_global->__pyx_n_s_return
#define __pyx_n_s_rotation __pyx_mstate_global->__pyx_n_s_rotation
#define __pyx_n_s_row __pyx_mstate_global->__pyx_n_s_row
#define __pyx_n_s_rt __pyx_mstate_global->__pyx_n_s_rt
#define __pyx_kp_s_s __pyx_mstate_global->__pyx_kp_s_s
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_kp_s_session_close __pyx_mstate_global->__pyx_kp_s_session_close
#define __pyx_n_s_session_close_2 __pyx_mstate_global->__pyx_n_s_session_close_2
#define __pyx_kp_s_session_offset __pyx_mstate_global->__pyx_kp_s_session_offset
#define __pyx_n_s_session_offset_2 __pyx_mstate_global->__pyx_n_s_session_offset_2
#define __pyx_kp_s_session_open __pyx_mstate_global->__pyx_kp_s_session_open
#define __pyx_n_s_session_open_2 __pyx_mstate_global->__pyx_n_s_session_open_2
#define __pyx_n_s_sessions __pyx_mstate_global->__pyx_n_s_sessions
#define __pyx_n_s_set_name __pyx_mstate_global->__pyx_n_s_set_name
#define __pyx_n_s_sh __pyx_mstate_global->__pyx_n_s_sh
#define __pyx_n_s_sh_calendar __pyx_mstate_global->__pyx_n_s_sh_calendar
#define __pyx_n_s_sort_values __pyx_mstate_global->__pyx_n_s_sort_values
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_splitDataframeByYear __pyx_mstate_global->__pyx_n_s_splitDataframeByYear
#define __pyx_n_s_startWithDigit __pyx_mstate_global->__pyx_n_s_startWithDigit
#define __pyx_n_s_start_date __pyx_mstate_global->__pyx_n_s_start_date
#define __pyx_n_s_start_of_week __pyx_mstate_global->__pyx_n_s_start_of_week
#define __pyx_n_s_stock_code __pyx_mstate_global->__pyx_n_s_stock_code
#define __pyx_kp_s_stock_log __pyx_mstate_global->__pyx_kp_s_stock_log
#define __pyx_n_s_stock_name __pyx_mstate_global->__pyx_n_s_stock_name
#define __pyx_n_s_stock_tfp_em __pyx_mstate_global->__pyx_n_s_stock_tfp_em
#define __pyx_n_s_stock_tfp_em_df __pyx_mstate_global->__pyx_n_s_stock_tfp_em_df
#define __pyx_n_s_str __pyx_mstate_global->__pyx_n_s_str
#define __pyx_n_s_str_dict __pyx_mstate_global->__pyx_n_s_str_dict
#define __pyx_n_s_strategyCount __pyx_mstate_global->__pyx_n_s_strategyCount
#define __pyx_n_s_strategy_code_list __pyx_mstate_global->__pyx_n_s_strategy_code_list
#define __pyx_n_s_strategy_name __pyx_mstate_global->__pyx_n_s_strategy_name
#define __pyx_n_s_strftime __pyx_mstate_global->__pyx_n_s_strftime
#define __pyx_n_s_strptime __pyx_mstate_global->__pyx_n_s_strptime
#define __pyx_n_s_sub __pyx_mstate_global->__pyx_n_s_sub
#define __pyx_n_s_sum __pyx_mstate_global->__pyx_n_s_sum
#define __pyx_n_s_super __pyx_mstate_global->__pyx_n_s_super
#define __pyx_n_s_suspended_stock_list __pyx_mstate_global->__pyx_n_s_suspended_stock_list
#define __pyx_n_s_svr __pyx_mstate_global->__pyx_n_s_svr
#define __pyx_n_s_system __pyx_mstate_global->__pyx_n_s_system
#define __pyx_n_s_sz __pyx_mstate_global->__pyx_n_s_sz
#define __pyx_n_s_tbstock_utils_utils __pyx_mstate_global->__pyx_n_s_tbstock_utils_utils
#define __pyx_kp_s_tbstock_utils_utils_py __pyx_mstate_global->__pyx_kp_s_tbstock_utils_utils_py
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_testCalendar __pyx_mstate_global->__pyx_n_s_testCalendar
#define __pyx_n_s_test_2 __pyx_mstate_global->__pyx_n_s_test_2
#define __pyx_n_s_text __pyx_mstate_global->__pyx_n_s_text
#define __pyx_n_s_text_tail __pyx_mstate_global->__pyx_n_s_text_tail
#define __pyx_n_s_timedelta __pyx_mstate_global->__pyx_n_s_timedelta
#define __pyx_n_s_to_datetime __pyx_mstate_global->__pyx_n_s_to_datetime
#define __pyx_n_s_today __pyx_mstate_global->__pyx_n_s_today
#define __pyx_n_s_today_date __pyx_mstate_global->__pyx_n_s_today_date
#define __pyx_n_s_total __pyx_mstate_global->__pyx_n_s_total
#define __pyx_n_s_trade __pyx_mstate_global->__pyx_n_s_trade
#define __pyx_n_s_trade_date __pyx_mstate_global->__pyx_n_s_trade_date
#define __pyx_n_s_trade_month __pyx_mstate_global->__pyx_n_s_trade_month
#define __pyx_n_s_trade_year __pyx_mstate_global->__pyx_n_s_trade_year
#define __pyx_kp_s_type_next_date __pyx_mstate_global->__pyx_kp_s_type_next_date
#define __pyx_n_s_typing __pyx_mstate_global->__pyx_n_s_typing
#define __pyx_n_s_union_list __pyx_mstate_global->__pyx_n_s_union_list
#define __pyx_n_s_updateLib __pyx_mstate_global->__pyx_n_s_updateLib
#define __pyx_n_s_update_db_logs_dir __pyx_mstate_global->__pyx_n_s_update_db_logs_dir
#define __pyx_n_s_update_json __pyx_mstate_global->__pyx_n_s_update_json
#define __pyx_n_s_update_lib_succeed __pyx_mstate_global->__pyx_n_s_update_lib_succeed
#define __pyx_n_s_update_strategy_logs_dir __pyx_mstate_global->__pyx_n_s_update_strategy_logs_dir
#define __pyx_n_s_updated __pyx_mstate_global->__pyx_n_s_updated
#define __pyx_kp_s_updatelog_json __pyx_mstate_global->__pyx_kp_s_updatelog_json
#define __pyx_n_s_upper __pyx_mstate_global->__pyx_n_s_upper
#define __pyx_n_s_use_cls __pyx_mstate_global->__pyx_n_s_use_cls
#define __pyx_kp_s_utf_8 __pyx_mstate_global->__pyx_kp_s_utf_8
#define __pyx_n_s_video_save_path_root __pyx_mstate_global->__pyx_n_s_video_save_path_root
#define __pyx_n_s_w __pyx_mstate_global->__pyx_n_s_w
#define __pyx_n_s_warning __pyx_mstate_global->__pyx_n_s_warning
#define __pyx_n_s_week __pyx_mstate_global->__pyx_n_s_week
#define __pyx_n_s_week_number __pyx_mstate_global->__pyx_n_s_week_number
#define __pyx_n_s_weekday __pyx_mstate_global->__pyx_n_s_weekday
#define __pyx_n_s_wrapped_text __pyx_mstate_global->__pyx_n_s_wrapped_text
#define __pyx_n_s_write __pyx_mstate_global->__pyx_n_s_write
#define __pyx_n_s_write_f __pyx_mstate_global->__pyx_n_s_write_f
#define __pyx_n_s_xx __pyx_mstate_global->__pyx_n_s_xx
#define __pyx_kp_s_xx_2 __pyx_mstate_global->__pyx_kp_s_xx_2
#define __pyx_n_s_year __pyx_mstate_global->__pyx_n_s_year
#define __pyx_n_s_year_end __pyx_mstate_global->__pyx_n_s_year_end
#define __pyx_n_s_year_int __pyx_mstate_global->__pyx_n_s_year_int
#define __pyx_n_s_year_list __pyx_mstate_global->__pyx_n_s_year_list
#define __pyx_n_s_year_start __pyx_mstate_global->__pyx_n_s_year_start
#define __pyx_n_s_year_str __pyx_mstate_global->__pyx_n_s_year_str
#define __pyx_float_0_0 __pyx_mstate_global->__pyx_float_0_0
#define __pyx_float_0_1 __pyx_mstate_global->__pyx_float_0_1
#define __pyx_float_0_2 __pyx_mstate_global->__pyx_float_0_2
#define __pyx_float_0_7 __pyx_mstate_global->__pyx_float_0_7
#define __pyx_float_0_8 __pyx_mstate_global->__pyx_float_0_8
#define __pyx_float_0_9 __pyx_mstate_global->__pyx_float_0_9
#define __pyx_float_1_0 __pyx_mstate_global->__pyx_float_1_0
#define __pyx_float_1_1 __pyx_mstate_global->__pyx_float_1_1
#define __pyx_float_1_3 __pyx_mstate_global->__pyx_float_1_3
#define __pyx_float_1_5 __pyx_mstate_global->__pyx_float_1_5
#define __pyx_float_1_6 __pyx_mstate_global->__pyx_float_1_6
#define __pyx_float_1_9 __pyx_mstate_global->__pyx_float_1_9
#define __pyx_float_2_3 __pyx_mstate_global->__pyx_float_2_3
#define __pyx_float_2_6 __pyx_mstate_global->__pyx_float_2_6
#define __pyx_float_2_7 __pyx_mstate_global->__pyx_float_2_7
#define __pyx_float_3_0 __pyx_mstate_global->__pyx_float_3_0
#define __pyx_float_3_6 __pyx_mstate_global->__pyx_float_3_6
#define __pyx_float_0_01 __pyx_mstate_global->__pyx_float_0_01
#define __pyx_float_0_02 __pyx_mstate_global->__pyx_float_0_02
#define __pyx_float_0_03 __pyx_mstate_global->__pyx_float_0_03
#define __pyx_float_0_04 __pyx_mstate_global->__pyx_float_0_04
#define __pyx_float_0_05 __pyx_mstate_global->__pyx_float_0_05
#define __pyx_float_0_06 __pyx_mstate_global->__pyx_float_0_06
#define __pyx_float_0_08 __pyx_mstate_global->__pyx_float_0_08
#define __pyx_float_0_14 __pyx_mstate_global->__pyx_float_0_14
#define __pyx_float_0_15 __pyx_mstate_global->__pyx_float_0_15
#define __pyx_float_0_16 __pyx_mstate_global->__pyx_float_0_16
#define __pyx_float_0_17 __pyx_mstate_global->__pyx_float_0_17
#define __pyx_float_0_18 __pyx_mstate_global->__pyx_float_0_18
#define __pyx_float_0_24 __pyx_mstate_global->__pyx_float_0_24
#define __pyx_float_0_25 __pyx_mstate_global->__pyx_float_0_25
#define __pyx_float_0_29 __pyx_mstate_global->__pyx_float_0_29
#define __pyx_float_0_33 __pyx_mstate_global->__pyx_float_0_33
#define __pyx_float_0_34 __pyx_mstate_global->__pyx_float_0_34
#define __pyx_float_0_37 __pyx_mstate_global->__pyx_float_0_37
#define __pyx_float_0_38 __pyx_mstate_global->__pyx_float_0_38
#define __pyx_float_0_42 __pyx_mstate_global->__pyx_float_0_42
#define __pyx_float_0_44 __pyx_mstate_global->__pyx_float_0_44
#define __pyx_float_0_47 __pyx_mstate_global->__pyx_float_0_47
#define __pyx_float_0_54 __pyx_mstate_global->__pyx_float_0_54
#define __pyx_float_0_57 __pyx_mstate_global->__pyx_float_0_57
#define __pyx_float_0_61 __pyx_mstate_global->__pyx_float_0_61
#define __pyx_float_0_65 __pyx_mstate_global->__pyx_float_0_65
#define __pyx_float_0_66 __pyx_mstate_global->__pyx_float_0_66
#define __pyx_float_0_69 __pyx_mstate_global->__pyx_float_0_69
#define __pyx_float_0_77 __pyx_mstate_global->__pyx_float_0_77
#define __pyx_float_0_78 __pyx_mstate_global->__pyx_float_0_78
#define __pyx_float_0_82 __pyx_mstate_global->__pyx_float_0_82
#define __pyx_float_0_83 __pyx_mstate_global->__pyx_float_0_83
#define __pyx_float_0_84 __pyx_mstate_global->__pyx_float_0_84
#define __pyx_float_0_87 __pyx_mstate_global->__pyx_float_0_87
#define __pyx_float_0_89 __pyx_mstate_global->__pyx_float_0_89
#define __pyx_float_0_91 __pyx_mstate_global->__pyx_float_0_91
#define __pyx_float_0_92 __pyx_mstate_global->__pyx_float_0_92
#define __pyx_float_0_93 __pyx_mstate_global->__pyx_float_0_93
#define __pyx_float_0_95 __pyx_mstate_global->__pyx_float_0_95
#define __pyx_float_0_96 __pyx_mstate_global->__pyx_float_0_96
#define __pyx_float_0_97 __pyx_mstate_global->__pyx_float_0_97
#define __pyx_float_0_98 __pyx_mstate_global->__pyx_float_0_98
#define __pyx_float_0_99 __pyx_mstate_global->__pyx_float_0_99
#define __pyx_float_1_01 __pyx_mstate_global->__pyx_float_1_01
#define __pyx_float_1_03 __pyx_mstate_global->__pyx_float_1_03
#define __pyx_float_1_04 __pyx_mstate_global->__pyx_float_1_04
#define __pyx_float_1_05 __pyx_mstate_global->__pyx_float_1_05
#define __pyx_float_1_08 __pyx_mstate_global->__pyx_float_1_08
#define __pyx_float_1_09 __pyx_mstate_global->__pyx_float_1_09
#define __pyx_float_1_11 __pyx_mstate_global->__pyx_float_1_11
#define __pyx_float_1_12 __pyx_mstate_global->__pyx_float_1_12
#define __pyx_float_1_14 __pyx_mstate_global->__pyx_float_1_14
#define __pyx_float_1_21 __pyx_mstate_global->__pyx_float_1_21
#define __pyx_float_1_22 __pyx_mstate_global->__pyx_float_1_22
#define __pyx_float_1_24 __pyx_mstate_global->__pyx_float_1_24
#define __pyx_float_1_28 __pyx_mstate_global->__pyx_float_1_28
#define __pyx_float_1_29 __pyx_mstate_global->__pyx_float_1_29
#define __pyx_float_1_31 __pyx_mstate_global->__pyx_float_1_31
#define __pyx_float_1_34 __pyx_mstate_global->__pyx_float_1_34
#define __pyx_float_1_37 __pyx_mstate_global->__pyx_float_1_37
#define __pyx_float_1_39 __pyx_mstate_global->__pyx_float_1_39
#define __pyx_float_1_41 __pyx_mstate_global->__pyx_float_1_41
#define __pyx_float_1_42 __pyx_mstate_global->__pyx_float_1_42
#define __pyx_float_1_48 __pyx_mstate_global->__pyx_float_1_48
#define __pyx_float_1_49 __pyx_mstate_global->__pyx_float_1_49
#define __pyx_float_1_51 __pyx_mstate_global->__pyx_float_1_51
#define __pyx_float_1_52 __pyx_mstate_global->__pyx_float_1_52
#define __pyx_float_1_53 __pyx_mstate_global->__pyx_float_1_53
#define __pyx_float_1_55 __pyx_mstate_global->__pyx_float_1_55
#define __pyx_float_1_56 __pyx_mstate_global->__pyx_float_1_56
#define __pyx_float_1_63 __pyx_mstate_global->__pyx_float_1_63
#define __pyx_float_1_65 __pyx_mstate_global->__pyx_float_1_65
#define __pyx_float_1_66 __pyx_mstate_global->__pyx_float_1_66
#define __pyx_float_1_69 __pyx_mstate_global->__pyx_float_1_69
#define __pyx_float_1_83 __pyx_mstate_global->__pyx_float_1_83
#define __pyx_float_1_88 __pyx_mstate_global->__pyx_float_1_88
#define __pyx_float_1_96 __pyx_mstate_global->__pyx_float_1_96
#define __pyx_float_1_97 __pyx_mstate_global->__pyx_float_1_97
#define __pyx_float_1_98 __pyx_mstate_global->__pyx_float_1_98
#define __pyx_float_2_01 __pyx_mstate_global->__pyx_float_2_01
#define __pyx_float_2_07 __pyx_mstate_global->__pyx_float_2_07
#define __pyx_float_2_08 __pyx_mstate_global->__pyx_float_2_08
#define __pyx_float_2_19 __pyx_mstate_global->__pyx_float_2_19
#define __pyx_float_2_25 __pyx_mstate_global->__pyx_float_2_25
#define __pyx_float_2_26 __pyx_mstate_global->__pyx_float_2_26
#define __pyx_float_2_28 __pyx_mstate_global->__pyx_float_2_28
#define __pyx_float_2_31 __pyx_mstate_global->__pyx_float_2_31
#define __pyx_float_2_41 __pyx_mstate_global->__pyx_float_2_41
#define __pyx_float_2_48 __pyx_mstate_global->__pyx_float_2_48
#define __pyx_float_2_49 __pyx_mstate_global->__pyx_float_2_49
#define __pyx_float_2_52 __pyx_mstate_global->__pyx_float_2_52
#define __pyx_float_2_57 __pyx_mstate_global->__pyx_float_2_57
#define __pyx_float_2_62 __pyx_mstate_global->__pyx_float_2_62
#define __pyx_float_2_77 __pyx_mstate_global->__pyx_float_2_77
#define __pyx_float_2_81 __pyx_mstate_global->__pyx_float_2_81
#define __pyx_float_3_07 __pyx_mstate_global->__pyx_float_3_07
#define __pyx_float_3_12 __pyx_mstate_global->__pyx_float_3_12
#define __pyx_float_3_35 __pyx_mstate_global->__pyx_float_3_35
#define __pyx_float_3_83 __pyx_mstate_global->__pyx_float_3_83
#define __pyx_float_3_94 __pyx_mstate_global->__pyx_float_3_94
#define __pyx_float_3_99 __pyx_mstate_global->__pyx_float_3_99
#define __pyx_float_33_8 __pyx_mstate_global->__pyx_float_33_8
#define __pyx_float_4_17 __pyx_mstate_global->__pyx_float_4_17
#define __pyx_float_4_54 __pyx_mstate_global->__pyx_float_4_54
#define __pyx_float_5_64 __pyx_mstate_global->__pyx_float_5_64
#define __pyx_float_5_94 __pyx_mstate_global->__pyx_float_5_94
#define __pyx_float_6_33 __pyx_mstate_global->__pyx_float_6_33
#define __pyx_float_6_79 __pyx_mstate_global->__pyx_float_6_79
#define __pyx_float_6_81 __pyx_mstate_global->__pyx_float_6_81
#define __pyx_float_15_27 __pyx_mstate_global->__pyx_float_15_27
#define __pyx_float_22_72 __pyx_mstate_global->__pyx_float_22_72
#define __pyx_float_25_27 __pyx_mstate_global->__pyx_float_25_27
#define __pyx_float_60_05 __pyx_mstate_global->__pyx_float_60_05
#define __pyx_float_1022_9 __pyx_mstate_global->__pyx_float_1022_9
#define __pyx_float_1031_8 __pyx_mstate_global->__pyx_float_1031_8
#define __pyx_float_1853_0 __pyx_mstate_global->__pyx_float_1853_0
#define __pyx_float_212_89 __pyx_mstate_global->__pyx_float_212_89
#define __pyx_float_212_93 __pyx_mstate_global->__pyx_float_212_93
#define __pyx_float_212_94 __pyx_mstate_global->__pyx_float_212_94
#define __pyx_float_212_96 __pyx_mstate_global->__pyx_float_212_96
#define __pyx_float_227_77 __pyx_mstate_global->__pyx_float_227_77
#define __pyx_float_228_24 __pyx_mstate_global->__pyx_float_228_24
#define __pyx_float_228_28 __pyx_mstate_global->__pyx_float_228_28
#define __pyx_float_234_61 __pyx_mstate_global->__pyx_float_234_61
#define __pyx_float_2631_7 __pyx_mstate_global->__pyx_float_2631_7
#define __pyx_float_286_71 __pyx_mstate_global->__pyx_float_286_71
#define __pyx_float_286_73 __pyx_mstate_global->__pyx_float_286_73
#define __pyx_float_286_75 __pyx_mstate_global->__pyx_float_286_75
#define __pyx_float_3987_1 __pyx_mstate_global->__pyx_float_3987_1
#define __pyx_float_4190_2 __pyx_mstate_global->__pyx_float_4190_2
#define __pyx_float_5155_7 __pyx_mstate_global->__pyx_float_5155_7
#define __pyx_float_5190_0 __pyx_mstate_global->__pyx_float_5190_0
#define __pyx_float_5198_9 __pyx_mstate_global->__pyx_float_5198_9
#define __pyx_float_5220_0 __pyx_mstate_global->__pyx_float_5220_0
#define __pyx_float_5228_8 __pyx_mstate_global->__pyx_float_5228_8
#define __pyx_float_5805_4 __pyx_mstate_global->__pyx_float_5805_4
#define __pyx_float_5809_3 __pyx_mstate_global->__pyx_float_5809_3
#define __pyx_float_6500_9 __pyx_mstate_global->__pyx_float_6500_9
#define __pyx_float_6635_4 __pyx_mstate_global->__pyx_float_6635_4
#define __pyx_float_6765_7 __pyx_mstate_global->__pyx_float_6765_7
#define __pyx_float_726_77 __pyx_mstate_global->__pyx_float_726_77
#define __pyx_float_728_11 __pyx_mstate_global->__pyx_float_728_11
#define __pyx_float_729_84 __pyx_mstate_global->__pyx_float_729_84
#define __pyx_float_731_52 __pyx_mstate_global->__pyx_float_731_52
#define __pyx_float_733_56 __pyx_mstate_global->__pyx_float_733_56
#define __pyx_float_737_93 __pyx_mstate_global->__pyx_float_737_93
#define __pyx_float_739_05 __pyx_mstate_global->__pyx_float_739_05
#define __pyx_float_743_23 __pyx_mstate_global->__pyx_float_743_23
#define __pyx_float_744_39 __pyx_mstate_global->__pyx_float_744_39
#define __pyx_float_749_42 __pyx_mstate_global->__pyx_float_749_42
#define __pyx_float_7577_1 __pyx_mstate_global->__pyx_float_7577_1
#define __pyx_float_7893_4 __pyx_mstate_global->__pyx_float_7893_4
#define __pyx_float_7944_1 __pyx_mstate_global->__pyx_float_7944_1
#define __pyx_float_9343_8 __pyx_mstate_global->__pyx_float_9343_8
#define __pyx_float_1007_63 __pyx_mstate_global->__pyx_float_1007_63
#define __pyx_float_1008_59 __pyx_mstate_global->__pyx_float_1008_59
#define __pyx_float_1018_36 __pyx_mstate_global->__pyx_float_1018_36
#define __pyx_float_1130_64 __pyx_mstate_global->__pyx_float_1130_64
#define __pyx_float_1139_84 __pyx_mstate_global->__pyx_float_1139_84
#define __pyx_float_1147_42 __pyx_mstate_global->__pyx_float_1147_42
#define __pyx_float_1150_35 __pyx_mstate_global->__pyx_float_1150_35
#define __pyx_float_1153_16 __pyx_mstate_global->__pyx_float_1153_16
#define __pyx_float_1408_48 __pyx_mstate_global->__pyx_float_1408_48
#define __pyx_float_1417_17 __pyx_mstate_global->__pyx_float_1417_17
#define __pyx_float_1428_83 __pyx_mstate_global->__pyx_float_1428_83
#define __pyx_float_1429_59 __pyx_mstate_global->__pyx_float_1429_59
#define __pyx_float_1432_13 __pyx_mstate_global->__pyx_float_1432_13
#define __pyx_float_1661_57 __pyx_mstate_global->__pyx_float_1661_57
#define __pyx_float_1677_68 __pyx_mstate_global->__pyx_float_1677_68
#define __pyx_float_1679_31 __pyx_mstate_global->__pyx_float_1679_31
#define __pyx_float_1683_87 __pyx_mstate_global->__pyx_float_1683_87
#define __pyx_float_1693_48 __pyx_mstate_global->__pyx_float_1693_48
#define __pyx_float_1764_84 __pyx_mstate_global->__pyx_float_1764_84
#define __pyx_float_1781_07 __pyx_mstate_global->__pyx_float_1781_07
#define __pyx_float_1812_46 __pyx_mstate_global->__pyx_float_1812_46
#define __pyx_float_1820_45 __pyx_mstate_global->__pyx_float_1820_45
#define __pyx_float_1820_74 __pyx_mstate_global->__pyx_float_1820_74
#define __pyx_float_1849_49 __pyx_mstate_global->__pyx_float_1849_49
#define __pyx_float_1865_28 __pyx_mstate_global->__pyx_float_1865_28
#define __pyx_float_1883_29 __pyx_mstate_global->__pyx_float_1883_29
#define __pyx_float_1890_25 __pyx_mstate_global->__pyx_float_1890_25
#define __pyx_float_2444_93 __pyx_mstate_global->__pyx_float_2444_93
#define __pyx_float_2457_26 __pyx_mstate_global->__pyx_float_2457_26
#define __pyx_float_2467_89 __pyx_mstate_global->__pyx_float_2467_89
#define __pyx_float_2473_17 __pyx_mstate_global->__pyx_float_2473_17
#define __pyx_float_2476_46 __pyx_mstate_global->__pyx_float_2476_46
#define __pyx_float_2585_19 __pyx_mstate_global->__pyx_float_2585_19
#define __pyx_float_2611_09 __pyx_mstate_global->__pyx_float_2611_09
#define __pyx_float_2614_69 __pyx_mstate_global->__pyx_float_2614_69
#define __pyx_float_2650_98 __pyx_mstate_global->__pyx_float_2650_98
#define __pyx_float_3031_04 __pyx_mstate_global->__pyx_float_3031_04
#define __pyx_float_3048_79 __pyx_mstate_global->__pyx_float_3048_79
#define __pyx_float_3051_28 __pyx_mstate_global->__pyx_float_3051_28
#define __pyx_float_3053_92 __pyx_mstate_global->__pyx_float_3053_92
#define __pyx_float_3065_02 __pyx_mstate_global->__pyx_float_3065_02
#define __pyx_float_3276_87 __pyx_mstate_global->__pyx_float_3276_87
#define __pyx_float_3305_01 __pyx_mstate_global->__pyx_float_3305_01
#define __pyx_float_3367_67 __pyx_mstate_global->__pyx_float_3367_67
#define __pyx_float_3382_54 __pyx_mstate_global->__pyx_float_3382_54
#define __pyx_float_3386_95 __pyx_mstate_global->__pyx_float_3386_95
#define __pyx_float_3390_29 __pyx_mstate_global->__pyx_float_3390_29
#define __pyx_float_3411_14 __pyx_mstate_global->__pyx_float_3411_14
#define __pyx_float_3435_35 __pyx_mstate_global->__pyx_float_3435_35
#define __pyx_float_3435_84 __pyx_mstate_global->__pyx_float_3435_84
#define __pyx_float_3442_73 __pyx_mstate_global->__pyx_float_3442_73
#define __pyx_float_3552_09 __pyx_mstate_global->__pyx_float_3552_09
#define __pyx_float_3574_11 __pyx_mstate_global->__pyx_float_3574_11
#define __pyx_float_3592_25 __pyx_mstate_global->__pyx_float_3592_25
#define __pyx_float_3594_63 __pyx_mstate_global->__pyx_float_3594_63
#define __pyx_float_3603_07 __pyx_mstate_global->__pyx_float_3603_07
#define __pyx_float_3757_42 __pyx_mstate_global->__pyx_float_3757_42
#define __pyx_float_3761_37 __pyx_mstate_global->__pyx_float_3761_37
#define __pyx_float_3784_58 __pyx_mstate_global->__pyx_float_3784_58
#define __pyx_float_3815_88 __pyx_mstate_global->__pyx_float_3815_88
#define __pyx_float_3817_47 __pyx_mstate_global->__pyx_float_3817_47
#define __pyx_float_3835_07 __pyx_mstate_global->__pyx_float_3835_07
#define __pyx_float_3840_42 __pyx_mstate_global->__pyx_float_3840_42
#define __pyx_float_3858_67 __pyx_mstate_global->__pyx_float_3858_67
#define __pyx_float_3864_01 __pyx_mstate_global->__pyx_float_3864_01
#define __pyx_float_3872_92 __pyx_mstate_global->__pyx_float_3872_92
#define __pyx_float_3907_11 __pyx_mstate_global->__pyx_float_3907_11
#define __pyx_float_3937_27 __pyx_mstate_global->__pyx_float_3937_27
#define __pyx_float_3977_71 __pyx_mstate_global->__pyx_float_3977_71
#define __pyx_float_3979_35 __pyx_mstate_global->__pyx_float_3979_35
#define __pyx_float_4091_72 __pyx_mstate_global->__pyx_float_4091_72
#define __pyx_float_4120_29 __pyx_mstate_global->__pyx_float_4120_29
#define __pyx_float_4127_98 __pyx_mstate_global->__pyx_float_4127_98
#define __pyx_float_4136_21 __pyx_mstate_global->__pyx_float_4136_21
#define __pyx_float_4149_23 __pyx_mstate_global->__pyx_float_4149_23
#define __pyx_float_4158_24 __pyx_mstate_global->__pyx_float_4158_24
#define __pyx_float_4192_82 __pyx_mstate_global->__pyx_float_4192_82
#define __pyx_float_4203_02 __pyx_mstate_global->__pyx_float_4203_02
#define __pyx_float_4223_36 __pyx_mstate_global->__pyx_float_4223_36
#define __pyx_float_5096_08 __pyx_mstate_global->__pyx_float_5096_08
#define __pyx_float_5126_06 __pyx_mstate_global->__pyx_float_5126_06
#define __pyx_float_5130_87 __pyx_mstate_global->__pyx_float_5130_87
#define __pyx_float_5153_54 __pyx_mstate_global->__pyx_float_5153_54
#define __pyx_float_5153_59 __pyx_mstate_global->__pyx_float_5153_59
#define __pyx_float_5159_17 __pyx_mstate_global->__pyx_float_5159_17
#define __pyx_float_5172_05 __pyx_mstate_global->__pyx_float_5172_05
#define __pyx_float_5174_86 __pyx_mstate_global->__pyx_float_5174_86
#define __pyx_float_5187_77 __pyx_mstate_global->__pyx_float_5187_77
#define __pyx_float_5190_01 __pyx_mstate_global->__pyx_float_5190_01
#define __pyx_float_5192_26 __pyx_mstate_global->__pyx_float_5192_26
#define __pyx_float_5205_05 __pyx_mstate_global->__pyx_float_5205_05
#define __pyx_float_5208_98 __pyx_mstate_global->__pyx_float_5208_98
#define __pyx_float_5247_15 __pyx_mstate_global->__pyx_float_5247_15
#define __pyx_float_5258_82 __pyx_mstate_global->__pyx_float_5258_82
#define __pyx_float_5688_88 __pyx_mstate_global->__pyx_float_5688_88
#define __pyx_float_5734_42 __pyx_mstate_global->__pyx_float_5734_42
#define __pyx_float_5747_23 __pyx_mstate_global->__pyx_float_5747_23
#define __pyx_float_5790_92 __pyx_mstate_global->__pyx_float_5790_92
#define __pyx_float_5793_29 __pyx_mstate_global->__pyx_float_5793_29
#define __pyx_float_5848_18 __pyx_mstate_global->__pyx_float_5848_18
#define __pyx_float_5856_89 __pyx_mstate_global->__pyx_float_5856_89
#define __pyx_float_5868_62 __pyx_mstate_global->__pyx_float_5868_62
#define __pyx_float_5964_03 __pyx_mstate_global->__pyx_float_5964_03
#define __pyx_float_5994_52 __pyx_mstate_global->__pyx_float_5994_52
#define __pyx_float_6018_11 __pyx_mstate_global->__pyx_float_6018_11
#define __pyx_float_6029_51 __pyx_mstate_global->__pyx_float_6029_51
#define __pyx_float_6042_92 __pyx_mstate_global->__pyx_float_6042_92
#define __pyx_float_6557_41 __pyx_mstate_global->__pyx_float_6557_41
#define __pyx_float_6651_35 __pyx_mstate_global->__pyx_float_6651_35
#define __pyx_float_6656_99 __pyx_mstate_global->__pyx_float_6656_99
#define __pyx_float_6677_79 __pyx_mstate_global->__pyx_float_6677_79
#define __pyx_float_6709_81 __pyx_mstate_global->__pyx_float_6709_81
#define __pyx_float_6740_32 __pyx_mstate_global->__pyx_float_6740_32
#define __pyx_float_6747_41 __pyx_mstate_global->__pyx_float_6747_41
#define __pyx_float_7525_19 __pyx_mstate_global->__pyx_float_7525_19
#define __pyx_float_7583_68 __pyx_mstate_global->__pyx_float_7583_68
#define __pyx_float_7602_37 __pyx_mstate_global->__pyx_float_7602_37
#define __pyx_float_7624_17 __pyx_mstate_global->__pyx_float_7624_17
#define __pyx_float_7814_84 __pyx_mstate_global->__pyx_float_7814_84
#define __pyx_float_7831_78 __pyx_mstate_global->__pyx_float_7831_78
#define __pyx_float_7839_59 __pyx_mstate_global->__pyx_float_7839_59
#define __pyx_float_7860_74 __pyx_mstate_global->__pyx_float_7860_74
#define __pyx_float_7876_76 __pyx_mstate_global->__pyx_float_7876_76
#define __pyx_float_7899_72 __pyx_mstate_global->__pyx_float_7899_72
#define __pyx_float_7910_66 __pyx_mstate_global->__pyx_float_7910_66
#define __pyx_float_7911_67 __pyx_mstate_global->__pyx_float_7911_67
#define __pyx_float_7912_57 __pyx_mstate_global->__pyx_float_7912_57
#define __pyx_float_7937_92 __pyx_mstate_global->__pyx_float_7937_92
#define __pyx_float_7946_23 __pyx_mstate_global->__pyx_float_7946_23
#define __pyx_float_7957_87 __pyx_mstate_global->__pyx_float_7957_87
#define __pyx_float_7980_24 __pyx_mstate_global->__pyx_float_7980_24
#define __pyx_float_9181_89 __pyx_mstate_global->__pyx_float_9181_89
#define __pyx_float_9255_68 __pyx_mstate_global->__pyx_float_9255_68
#define __pyx_float_9340_01 __pyx_mstate_global->__pyx_float_9340_01
#define __pyx_float_9366_34 __pyx_mstate_global->__pyx_float_9366_34
#define __pyx_float_11945_41 __pyx_mstate_global->__pyx_float_11945_41
#define __pyx_float_12041_42 __pyx_mstate_global->__pyx_float_12041_42
#define __pyx_float_12145_82 __pyx_mstate_global->__pyx_float_12145_82
#define __pyx_float_12156_05 __pyx_mstate_global->__pyx_float_12156_05
#define __pyx_float_12185_37 __pyx_mstate_global->__pyx_float_12185_37
#define __pyx_float_500282_0 __pyx_mstate_global->__pyx_float_500282_0
#define __pyx_float_23948464_0 __pyx_mstate_global->__pyx_float_23948464_0
#define __pyx_float_140532459_6 __pyx_mstate_global->__pyx_float_140532459_6
#define __pyx_float_2244259683_0 __pyx_mstate_global->__pyx_float_2244259683_0
#define __pyx_float_2377053666_0 __pyx_mstate_global->__pyx_float_2377053666_0
#define __pyx_float_10894972910_0 __pyx_mstate_global->__pyx_float_10894972910_0
#define __pyx_float_14464539893_0 __pyx_mstate_global->__pyx_float_14464539893_0
#define __pyx_float_15092302335_0 __pyx_mstate_global->__pyx_float_15092302335_0
#define __pyx_float_36121085540_7 __pyx_mstate_global->__pyx_float_36121085540_7
#define __pyx_float_45120126315_0 __pyx_mstate_global->__pyx_float_45120126315_0
#define __pyx_float_58648181396_0 __pyx_mstate_global->__pyx_float_58648181396_0
#define __pyx_float_61566668750_0 __pyx_mstate_global->__pyx_float_61566668750_0
#define __pyx_float_64786605_7657 __pyx_mstate_global->__pyx_float_64786605_7657
#define __pyx_float_70813170022_0 __pyx_mstate_global->__pyx_float_70813170022_0
#define __pyx_float_81258098177_0 __pyx_mstate_global->__pyx_float_81258098177_0
#define __pyx_float_89734052295_0 __pyx_mstate_global->__pyx_float_89734052295_0
#define __pyx_float_98770455187_0 __pyx_mstate_global->__pyx_float_98770455187_0
#define __pyx_float_115940476191_2 __pyx_mstate_global->__pyx_float_115940476191_2
#define __pyx_float_118553769519_2 __pyx_mstate_global->__pyx_float_118553769519_2
#define __pyx_float_127151511671_8 __pyx_mstate_global->__pyx_float_127151511671_8
#define __pyx_float_127527613173_0 __pyx_mstate_global->__pyx_float_127527613173_0
#define __pyx_float_159799015973_0 __pyx_mstate_global->__pyx_float_159799015973_0
#define __pyx_float_213001530097_8 __pyx_mstate_global->__pyx_float_213001530097_8
#define __pyx_float_30233745384_79 __pyx_mstate_global->__pyx_float_30233745384_79
#define __pyx_float_318911097485_6 __pyx_mstate_global->__pyx_float_318911097485_6
#define __pyx_float_331555299617_0 __pyx_mstate_global->__pyx_float_331555299617_0
#define __pyx_float_34325273049_37 __pyx_mstate_global->__pyx_float_34325273049_37
#define __pyx_float_39340183896_48 __pyx_mstate_global->__pyx_float_39340183896_48
#define __pyx_float_42696102285_67 __pyx_mstate_global->__pyx_float_42696102285_67
#define __pyx_float_50489872605_94 __pyx_mstate_global->__pyx_float_50489872605_94
#define __pyx_float_61288819659_89 __pyx_mstate_global->__pyx_float_61288819659_89
#define __pyx_float_691633876518_0 __pyx_mstate_global->__pyx_float_691633876518_0
#define __pyx_float_82167390867_05 __pyx_mstate_global->__pyx_float_82167390867_05
#define __pyx_float_146640016315_48 __pyx_mstate_global->__pyx_float_146640016315_48
#define __pyx_float_182415895155_26 __pyx_mstate_global->__pyx_float_182415895155_26
#define __pyx_float_215440232173_34 __pyx_mstate_global->__pyx_float_215440232173_34
#define __pyx_float_390925480569_42 __pyx_mstate_global->__pyx_float_390925480569_42
#define __pyx_float_397900984221_1357 __pyx_mstate_global->__pyx_float_397900984221_1357
#define __pyx_float_397920913934_3657 __pyx_mstate_global->__pyx_float_397920913934_3657
#define __pyx_float_neg_0_2 __pyx_mstate_global->__pyx_float_neg_0_2
#define __pyx_float_neg_0_5 __pyx_mstate_global->__pyx_float_neg_0_5
#define __pyx_float_neg_0_7 __pyx_mstate_global->__pyx_float_neg_0_7
#define __pyx_float_neg_0_9 __pyx_mstate_global->__pyx_float_neg_0_9
#define __pyx_float_neg_1_5 __pyx_mstate_global->__pyx_float_neg_1_5
#define __pyx_float_neg_5_3 __pyx_mstate_global->__pyx_float_neg_5_3
#define __pyx_float_neg_0_01 __pyx_mstate_global->__pyx_float_neg_0_01
#define __pyx_float_neg_0_02 __pyx_mstate_global->__pyx_float_neg_0_02
#define __pyx_float_neg_0_03 __pyx_mstate_global->__pyx_float_neg_0_03
#define __pyx_float_neg_0_04 __pyx_mstate_global->__pyx_float_neg_0_04
#define __pyx_float_neg_0_05 __pyx_mstate_global->__pyx_float_neg_0_05
#define __pyx_float_neg_0_06 __pyx_mstate_global->__pyx_float_neg_0_06
#define __pyx_float_neg_0_07 __pyx_mstate_global->__pyx_float_neg_0_07
#define __pyx_float_neg_0_08 __pyx_mstate_global->__pyx_float_neg_0_08
#define __pyx_float_neg_0_19 __pyx_mstate_global->__pyx_float_neg_0_19
#define __pyx_float_neg_0_33 __pyx_mstate_global->__pyx_float_neg_0_33
#define __pyx_float_neg_0_38 __pyx_mstate_global->__pyx_float_neg_0_38
#define __pyx_float_neg_0_39 __pyx_mstate_global->__pyx_float_neg_0_39
#define __pyx_float_neg_0_41 __pyx_mstate_global->__pyx_float_neg_0_41
#define __pyx_float_neg_0_43 __pyx_mstate_global->__pyx_float_neg_0_43
#define __pyx_float_neg_0_45 __pyx_mstate_global->__pyx_float_neg_0_45
#define __pyx_float_neg_0_47 __pyx_mstate_global->__pyx_float_neg_0_47
#define __pyx_float_neg_0_56 __pyx_mstate_global->__pyx_float_neg_0_56
#define __pyx_float_neg_0_66 __pyx_mstate_global->__pyx_float_neg_0_66
#define __pyx_float_neg_0_69 __pyx_mstate_global->__pyx_float_neg_0_69
#define __pyx_float_neg_0_71 __pyx_mstate_global->__pyx_float_neg_0_71
#define __pyx_float_neg_0_79 __pyx_mstate_global->__pyx_float_neg_0_79
#define __pyx_float_neg_0_81 __pyx_mstate_global->__pyx_float_neg_0_81
#define __pyx_float_neg_0_86 __pyx_mstate_global->__pyx_float_neg_0_86
#define __pyx_float_neg_0_87 __pyx_mstate_global->__pyx_float_neg_0_87
#define __pyx_float_neg_0_98 __pyx_mstate_global->__pyx_float_neg_0_98
#define __pyx_float_neg_1_06 __pyx_mstate_global->__pyx_float_neg_1_06
#define __pyx_float_neg_1_21 __pyx_mstate_global->__pyx_float_neg_1_21
#define __pyx_float_neg_1_22 __pyx_mstate_global->__pyx_float_neg_1_22
#define __pyx_float_neg_1_33 __pyx_mstate_global->__pyx_float_neg_1_33
#define __pyx_float_neg_1_38 __pyx_mstate_global->__pyx_float_neg_1_38
#define __pyx_float_neg_1_45 __pyx_mstate_global->__pyx_float_neg_1_45
#define __pyx_float_neg_1_65 __pyx_mstate_global->__pyx_float_neg_1_65
#define __pyx_float_neg_1_66 __pyx_mstate_global->__pyx_float_neg_1_66
#define __pyx_float_neg_1_79 __pyx_mstate_global->__pyx_float_neg_1_79
#define __pyx_float_neg_1_96 __pyx_mstate_global->__pyx_float_neg_1_96
#define __pyx_float_neg_2_16 __pyx_mstate_global->__pyx_float_neg_2_16
#define __pyx_float_neg_2_17 __pyx_mstate_global->__pyx_float_neg_2_17
#define __pyx_float_neg_2_35 __pyx_mstate_global->__pyx_float_neg_2_35
#define __pyx_float_neg_2_42 __pyx_mstate_global->__pyx_float_neg_2_42
#define __pyx_float_neg_2_63 __pyx_mstate_global->__pyx_float_neg_2_63
#define __pyx_float_neg_2_82 __pyx_mstate_global->__pyx_float_neg_2_82
#define __pyx_float_neg_21_3 __pyx_mstate_global->__pyx_float_neg_21_3
#define __pyx_float_neg_3_81 __pyx_mstate_global->__pyx_float_neg_3_81
#define __pyx_float_neg_4_04 __pyx_mstate_global->__pyx_float_neg_4_04
#define __pyx_float_neg_4_06 __pyx_mstate_global->__pyx_float_neg_4_06
#define __pyx_float_neg_4_45 __pyx_mstate_global->__pyx_float_neg_4_45
#define __pyx_float_neg_5_18 __pyx_mstate_global->__pyx_float_neg_5_18
#define __pyx_float_neg_5_83 __pyx_mstate_global->__pyx_float_neg_5_83
#define __pyx_float_neg_6_58 __pyx_mstate_global->__pyx_float_neg_6_58
#define __pyx_float_neg_7_28 __pyx_mstate_global->__pyx_float_neg_7_28
#define __pyx_float_neg_7_43 __pyx_mstate_global->__pyx_float_neg_7_43
#define __pyx_float_neg_7_58 __pyx_mstate_global->__pyx_float_neg_7_58
#define __pyx_float_neg_7_69 __pyx_mstate_global->__pyx_float_neg_7_69
#define __pyx_float_neg_8_13 __pyx_mstate_global->__pyx_float_neg_8_13
#define __pyx_float_neg_8_23 __pyx_mstate_global->__pyx_float_neg_8_23
#define __pyx_float_neg_8_27 __pyx_mstate_global->__pyx_float_neg_8_27
#define __pyx_float_neg_8_63 __pyx_mstate_global->__pyx_float_neg_8_63
#define __pyx_float_neg_9_99 __pyx_mstate_global->__pyx_float_neg_9_99
#define __pyx_float_neg_10_63 __pyx_mstate_global->__pyx_float_neg_10_63
#define __pyx_float_neg_104_4 __pyx_mstate_global->__pyx_float_neg_104_4
#define __pyx_float_neg_11_66 __pyx_mstate_global->__pyx_float_neg_11_66
#define __pyx_float_neg_12_42 __pyx_mstate_global->__pyx_float_neg_12_42
#define __pyx_float_neg_12_46 __pyx_mstate_global->__pyx_float_neg_12_46
#define __pyx_float_neg_13_39 __pyx_mstate_global->__pyx_float_neg_13_39
#define __pyx_float_neg_15_62 __pyx_mstate_global->__pyx_float_neg_15_62
#define __pyx_float_neg_16_02 __pyx_mstate_global->__pyx_float_neg_16_02
#define __pyx_float_neg_18_14 __pyx_mstate_global->__pyx_float_neg_18_14
#define __pyx_float_neg_18_25 __pyx_mstate_global->__pyx_float_neg_18_25
#define __pyx_float_neg_18_48 __pyx_mstate_global->__pyx_float_neg_18_48
#define __pyx_float_neg_19_82 __pyx_mstate_global->__pyx_float_neg_19_82
#define __pyx_float_neg_21_32 __pyx_mstate_global->__pyx_float_neg_21_32
#define __pyx_float_neg_21_51 __pyx_mstate_global->__pyx_float_neg_21_51
#define __pyx_float_neg_23_57 __pyx_mstate_global->__pyx_float_neg_23_57
#define __pyx_float_neg_23_59 __pyx_mstate_global->__pyx_float_neg_23_59
#define __pyx_float_neg_24_21 __pyx_mstate_global->__pyx_float_neg_24_21
#define __pyx_float_neg_30_51 __pyx_mstate_global->__pyx_float_neg_30_51
#define __pyx_float_neg_32_25 __pyx_mstate_global->__pyx_float_neg_32_25
#define __pyx_float_neg_39_38 __pyx_mstate_global->__pyx_float_neg_39_38
#define __pyx_float_neg_42_08 __pyx_mstate_global->__pyx_float_neg_42_08
#define __pyx_float_neg_44_38 __pyx_mstate_global->__pyx_float_neg_44_38
#define __pyx_float_neg_57_26 __pyx_mstate_global->__pyx_float_neg_57_26
#define __pyx_float_neg_70_98 __pyx_mstate_global->__pyx_float_neg_70_98
#define __pyx_float_neg_81_94 __pyx_mstate_global->__pyx_float_neg_81_94
#define __pyx_float_neg_84_33 __pyx_mstate_global->__pyx_float_neg_84_33
#define __pyx_float_neg_99_58 __pyx_mstate_global->__pyx_float_neg_99_58
#define __pyx_float_neg_2997454_0 __pyx_mstate_global->__pyx_float_neg_2997454_0
#define __pyx_float_neg_4803766_0 __pyx_mstate_global->__pyx_float_neg_4803766_0
#define __pyx_float_neg_12984032_0 __pyx_mstate_global->__pyx_float_neg_12984032_0
#define __pyx_float_neg_53971303_0 __pyx_mstate_global->__pyx_float_neg_53971303_0
#define __pyx_float_neg_235770368_0 __pyx_mstate_global->__pyx_float_neg_235770368_0
#define __pyx_float_neg_250665728_0 __pyx_mstate_global->__pyx_float_neg_250665728_0
#define __pyx_float_neg_635090960_0 __pyx_mstate_global->__pyx_float_neg_635090960_0
#define __pyx_float_neg_661239776_0 __pyx_mstate_global->__pyx_float_neg_661239776_0
#define __pyx_float_neg_698863952_0 __pyx_mstate_global->__pyx_float_neg_698863952_0
#define __pyx_float_neg_918841824_0 __pyx_mstate_global->__pyx_float_neg_918841824_0
#define __pyx_float_neg_1140853760_0 __pyx_mstate_global->__pyx_float_neg_1140853760_0
#define __pyx_float_neg_1171835776_0 __pyx_mstate_global->__pyx_float_neg_1171835776_0
#define __pyx_float_neg_1468038656_0 __pyx_mstate_global->__pyx_float_neg_1468038656_0
#define __pyx_float_neg_1476325632_0 __pyx_mstate_global->__pyx_float_neg_1476325632_0
#define __pyx_float_neg_1963587072_0 __pyx_mstate_global->__pyx_float_neg_1963587072_0
#define __pyx_float_neg_2227974912_0 __pyx_mstate_global->__pyx_float_neg_2227974912_0
#define __pyx_float_neg_2339542272_0 __pyx_mstate_global->__pyx_float_neg_2339542272_0
#define __pyx_float_neg_2428805376_0 __pyx_mstate_global->__pyx_float_neg_2428805376_0
#define __pyx_float_neg_2440455424_0 __pyx_mstate_global->__pyx_float_neg_2440455424_0
#define __pyx_float_neg_2491724208_0 __pyx_mstate_global->__pyx_float_neg_2491724208_0
#define __pyx_float_neg_2509978624_0 __pyx_mstate_global->__pyx_float_neg_2509978624_0
#define __pyx_float_neg_2539908352_0 __pyx_mstate_global->__pyx_float_neg_2539908352_0
#define __pyx_float_neg_2622219776_0 __pyx_mstate_global->__pyx_float_neg_2622219776_0
#define __pyx_float_neg_4380916480_0 __pyx_mstate_global->__pyx_float_neg_4380916480_0
#define __pyx_float_neg_5655776512_0 __pyx_mstate_global->__pyx_float_neg_5655776512_0
#define __pyx_float_neg_5744585216_0 __pyx_mstate_global->__pyx_float_neg_5744585216_0
#define __pyx_float_neg_6014713856_0 __pyx_mstate_global->__pyx_float_neg_6014713856_0
#define __pyx_float_neg_7491039488_0 __pyx_mstate_global->__pyx_float_neg_7491039488_0
#define __pyx_float_neg_8801696000_0 __pyx_mstate_global->__pyx_float_neg_8801696000_0
#define __pyx_float_neg_8813961984_0 __pyx_mstate_global->__pyx_float_neg_8813961984_0
#define __pyx_float_neg_10169320192_0 __pyx_mstate_global->__pyx_float_neg_10169320192_0
#define __pyx_float_neg_13886649344_0 __pyx_mstate_global->__pyx_float_neg_13886649344_0
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_2 __pyx_mstate_global->__pyx_int_2
#define __pyx_int_4 __pyx_mstate_global->__pyx_int_4
#define __pyx_int_6 __pyx_mstate_global->__pyx_int_6
#define __pyx_int_12 __pyx_mstate_global->__pyx_int_12
#define __pyx_int_15 __pyx_mstate_global->__pyx_int_15
#define __pyx_int_37 __pyx_mstate_global->__pyx_int_37
#define __pyx_int_300 __pyx_mstate_global->__pyx_int_300
#define __pyx_int_167926 __pyx_mstate_global->__pyx_int_167926
#define __pyx_int_571666 __pyx_mstate_global->__pyx_int_571666
#define __pyx_int_2223662 __pyx_mstate_global->__pyx_int_2223662
#define __pyx_int_2419271 __pyx_mstate_global->__pyx_int_2419271
#define __pyx_int_7898580 __pyx_mstate_global->__pyx_int_7898580
#define __pyx_int_8576647 __pyx_mstate_global->__pyx_int_8576647
#define __pyx_int_10592446 __pyx_mstate_global->__pyx_int_10592446
#define __pyx_int_14249490 __pyx_mstate_global->__pyx_int_14249490
#define __pyx_int_16720502 __pyx_mstate_global->__pyx_int_16720502
#define __pyx_int_18144804 __pyx_mstate_global->__pyx_int_18144804
#define __pyx_int_21744403 __pyx_mstate_global->__pyx_int_21744403
#define __pyx_int_25169964 __pyx_mstate_global->__pyx_int_25169964
#define __pyx_int_26315144 __pyx_mstate_global->__pyx_int_26315144
#define __pyx_int_27364120 __pyx_mstate_global->__pyx_int_27364120
#define __pyx_int_32037354 __pyx_mstate_global->__pyx_int_32037354
#define __pyx_int_34126920 __pyx_mstate_global->__pyx_int_34126920
#define __pyx_int_35394350 __pyx_mstate_global->__pyx_int_35394350
#define __pyx_int_36436105 __pyx_mstate_global->__pyx_int_36436105
#define __pyx_int_48122566 __pyx_mstate_global->__pyx_int_48122566
#define __pyx_int_58645358 __pyx_mstate_global->__pyx_int_58645358
#define __pyx_int_59724479 __pyx_mstate_global->__pyx_int_59724479
#define __pyx_int_66238981 __pyx_mstate_global->__pyx_int_66238981
#define __pyx_int_83828686 __pyx_mstate_global->__pyx_int_83828686
#define __pyx_int_88973758 __pyx_mstate_global->__pyx_int_88973758
#define __pyx_int_113527478 __pyx_mstate_global->__pyx_int_113527478
#define __pyx_int_130320202 __pyx_mstate_global->__pyx_int_130320202
#define __pyx_int_131103026 __pyx_mstate_global->__pyx_int_131103026
#define __pyx_int_133117037 __pyx_mstate_global->__pyx_int_133117037
#define __pyx_int_182994245 __pyx_mstate_global->__pyx_int_182994245
#define __pyx_int_199724618 __pyx_mstate_global->__pyx_int_199724618
#define __pyx_int_244630504 __pyx_mstate_global->__pyx_int_244630504
#define __pyx_int_259052823 __pyx_mstate_global->__pyx_int_259052823
#define __pyx_int_316342484 __pyx_mstate_global->__pyx_int_316342484
#define __pyx_int_371100958 __pyx_mstate_global->__pyx_int_371100958
#define __pyx_int_391479032 __pyx_mstate_global->__pyx_int_391479032
#define __pyx_int_392337786 __pyx_mstate_global->__pyx_int_392337786
#define __pyx_int_541037598 __pyx_mstate_global->__pyx_int_541037598
#define __pyx_int_677188186 __pyx_mstate_global->__pyx_int_677188186
#define __pyx_int_8855649026 __pyx_mstate_global->__pyx_int_8855649026
#define __pyx_int_12717649349 __pyx_mstate_global->__pyx_int_12717649349
#define __pyx_int_53136528234 __pyx_mstate_global->__pyx_int_53136528234
#define __pyx_int_53299789831 __pyx_mstate_global->__pyx_int_53299789831
#define __pyx_int_168229436395 __pyx_mstate_global->__pyx_int_168229436395
#define __pyx_int_313032053358 __pyx_mstate_global->__pyx_int_313032053358
#define __pyx_int_515063456666 __pyx_mstate_global->__pyx_int_515063456666
#define __pyx_int_626306385346 __pyx_mstate_global->__pyx_int_626306385346
#define __pyx_int_824243981862 __pyx_mstate_global->__pyx_int_824243981862
#define __pyx_int_0x9507d62c436 __pyx_mstate_global->__pyx_int_0x9507d62c436
#define __pyx_int_0x9660e6b8684 __pyx_mstate_global->__pyx_int_0x9660e6b8684
#define __pyx_int_0x977cef39562 __pyx_mstate_global->__pyx_int_0x977cef39562
#define __pyx_int_0x9c81f15f8f5 __pyx_mstate_global->__pyx_int_0x9c81f15f8f5
#define __pyx_int_0xa5646e4f052 __pyx_mstate_global->__pyx_int_0xa5646e4f052
#define __pyx_int_0xa573354fb9d __pyx_mstate_global->__pyx_int_0xa573354fb9d
#define __pyx_int_0xb294917799f __pyx_mstate_global->__pyx_int_0xb294917799f
#define __pyx_int_0xb38e85961b8 __pyx_mstate_global->__pyx_int_0xb38e85961b8
#define __pyx_int_0xbaef60da2c6 __pyx_mstate_global->__pyx_int_0xbaef60da2c6
#define __pyx_int_0xca8cd5800f9 __pyx_mstate_global->__pyx_int_0xca8cd5800f9
#define __pyx_int_0xe4562e88120 __pyx_mstate_global->__pyx_int_0xe4562e88120
#define __pyx_int_0xfc88ab58e0b __pyx_mstate_global->__pyx_int_0xfc88ab58e0b
#define __pyx_int_1110800675511 __pyx_mstate_global->__pyx_int_1110800675511
#define __pyx_int_1175767851306 __pyx_mstate_global->__pyx_int_1175767851306
#define __pyx_int_1436971721042 __pyx_mstate_global->__pyx_int_1436971721042
#define __pyx_int_1708631550165 __pyx_mstate_global->__pyx_int_1708631550165
#define __pyx_int_1821738041432 __pyx_mstate_global->__pyx_int_1821738041432
#define __pyx_int_1845844064964 __pyx_mstate_global->__pyx_int_1845844064964
#define __pyx_int_2968508455751 __pyx_mstate_global->__pyx_int_2968508455751
#define __pyx_int_3490375050807 __pyx_mstate_global->__pyx_int_3490375050807
#define __pyx_int_3491811426635 __pyx_mstate_global->__pyx_int_3491811426635
#define __pyx_int_4800328458344 __pyx_mstate_global->__pyx_int_4800328458344
#define __pyx_int_4998916135670 __pyx_mstate_global->__pyx_int_4998916135670
#define __pyx_int_5332514997228 __pyx_mstate_global->__pyx_int_5332514997228
#define __pyx_int_5531341956881 __pyx_mstate_global->__pyx_int_5531341956881
#define __pyx_int_5992127393523 __pyx_mstate_global->__pyx_int_5992127393523
#define __pyx_int_6118478847123 __pyx_mstate_global->__pyx_int_6118478847123
#define __pyx_int_6629036171731 __pyx_mstate_global->__pyx_int_6629036171731
#define __pyx_int_6897201046540 __pyx_mstate_global->__pyx_int_6897201046540
#define __pyx_int_7235995254645 __pyx_mstate_global->__pyx_int_7235995254645
#define __pyx_int_7325541012743 __pyx_mstate_global->__pyx_int_7325541012743
#define __pyx_int_7428389236896 __pyx_mstate_global->__pyx_int_7428389236896
#define __pyx_int_7507095323631 __pyx_mstate_global->__pyx_int_7507095323631
#define __pyx_int_7694238899256 __pyx_mstate_global->__pyx_int_7694238899256
#define __pyx_int_7884280772830 __pyx_mstate_global->__pyx_int_7884280772830
#define __pyx_int_8607232746956 __pyx_mstate_global->__pyx_int_8607232746956
#define __pyx_int_9597572050458 __pyx_mstate_global->__pyx_int_9597572050458
#define __pyx_int_9790143307451 __pyx_mstate_global->__pyx_int_9790143307451
#define __pyx_int_9890708337231 __pyx_mstate_global->__pyx_int_9890708337231
#define __pyx_int_0x105293ff5bfe __pyx_mstate_global->__pyx_int_0x105293ff5bfe
#define __pyx_int_0x120f2085deb4 __pyx_mstate_global->__pyx_int_0x120f2085deb4
#define __pyx_int_0x1312c5fef504 __pyx_mstate_global->__pyx_int_0x1312c5fef504
#define __pyx_int_0x157f527fb1d4 __pyx_mstate_global->__pyx_int_0x157f527fb1d4
#define __pyx_int_0x15b1120a25de __pyx_mstate_global->__pyx_int_0x15b1120a25de
#define __pyx_int_0x15bd71393949 __pyx_mstate_global->__pyx_int_0x15bd71393949
#define __pyx_int_0x1839ab81d6a2 __pyx_mstate_global->__pyx_int_0x1839ab81d6a2
#define __pyx_int_0x193c10d5c555 __pyx_mstate_global->__pyx_int_0x193c10d5c555
#define __pyx_int_0x196f90195cb3 __pyx_mstate_global->__pyx_int_0x196f90195cb3
#define __pyx_int_0x19a936e9e6f2 __pyx_mstate_global->__pyx_int_0x19a936e9e6f2
#define __pyx_int_0x19b59fd426fa __pyx_mstate_global->__pyx_int_0x19b59fd426fa
#define __pyx_int_0x22f9a2787068 __pyx_mstate_global->__pyx_int_0x22f9a2787068
#define __pyx_int_0x2528aad29cbb __pyx_mstate_global->__pyx_int_0x2528aad29cbb
#define __pyx_int_0x27eebfaf00e2 __pyx_mstate_global->__pyx_int_0x27eebfaf00e2
#define __pyx_int_0x2b17e83d52a2 __pyx_mstate_global->__pyx_int_0x2b17e83d52a2
#define __pyx_int_0x2c4a1fdb349e __pyx_mstate_global->__pyx_int_0x2c4a1fdb349e
#define __pyx_int_0x2f7ef1b78d0e __pyx_mstate_global->__pyx_int_0x2f7ef1b78d0e
#define __pyx_int_0x3d0738b72996 __pyx_mstate_global->__pyx_int_0x3d0738b72996
#define __pyx_int_0x433f57b789fe __pyx_mstate_global->__pyx_int_0x433f57b789fe
#define __pyx_int_neg_1 __pyx_mstate_global->__pyx_int_neg_1
#define __pyx_int_neg_5 __pyx_mstate_global->__pyx_int_neg_5
#define __pyx_slice__26 __pyx_mstate_global->__pyx_slice__26
#define __pyx_slice__27 __pyx_mstate_global->__pyx_slice__27
#define __pyx_slice__42 __pyx_mstate_global->__pyx_slice__42
#define __pyx_tuple__20 __pyx_mstate_global->__pyx_tuple__20
#define __pyx_tuple__21 __pyx_mstate_global->__pyx_tuple__21
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__24 __pyx_mstate_global->__pyx_tuple__24
#define __pyx_tuple__25 __pyx_mstate_global->__pyx_tuple__25
#define __pyx_tuple__34 __pyx_mstate_global->__pyx_tuple__34
#define __pyx_tuple__35 __pyx_mstate_global->__pyx_tuple__35
#define __pyx_tuple__37 __pyx_mstate_global->__pyx_tuple__37
#define __pyx_tuple__40 __pyx_mstate_global->__pyx_tuple__40
#define __pyx_tuple__41 __pyx_mstate_global->__pyx_tuple__41
#define __pyx_tuple__43 __pyx_mstate_global->__pyx_tuple__43
#define __pyx_tuple__44 __pyx_mstate_global->__pyx_tuple__44
#define __pyx_tuple__46 __pyx_mstate_global->__pyx_tuple__46
#define __pyx_tuple__48 __pyx_mstate_global->__pyx_tuple__48
#define __pyx_tuple__50 __pyx_mstate_global->__pyx_tuple__50
#define __pyx_tuple__52 __pyx_mstate_global->__pyx_tuple__52
#define __pyx_tuple__54 __pyx_mstate_global->__pyx_tuple__54
#define __pyx_tuple__56 __pyx_mstate_global->__pyx_tuple__56
#define __pyx_tuple__58 __pyx_mstate_global->__pyx_tuple__58
#define __pyx_tuple__60 __pyx_mstate_global->__pyx_tuple__60
#define __pyx_tuple__62 __pyx_mstate_global->__pyx_tuple__62
#define __pyx_tuple__64 __pyx_mstate_global->__pyx_tuple__64
#define __pyx_tuple__65 __pyx_mstate_global->__pyx_tuple__65
#define __pyx_tuple__67 __pyx_mstate_global->__pyx_tuple__67
#define __pyx_tuple__69 __pyx_mstate_global->__pyx_tuple__69
#define __pyx_tuple__71 __pyx_mstate_global->__pyx_tuple__71
#define __pyx_tuple__72 __pyx_mstate_global->__pyx_tuple__72
#define __pyx_tuple__74 __pyx_mstate_global->__pyx_tuple__74
#define __pyx_tuple__76 __pyx_mstate_global->__pyx_tuple__76
#define __pyx_tuple__78 __pyx_mstate_global->__pyx_tuple__78
#define __pyx_tuple__80 __pyx_mstate_global->__pyx_tuple__80
#define __pyx_tuple__82 __pyx_mstate_global->__pyx_tuple__82
#define __pyx_tuple__84 __pyx_mstate_global->__pyx_tuple__84
#define __pyx_tuple__86 __pyx_mstate_global->__pyx_tuple__86
#define __pyx_tuple__87 __pyx_mstate_global->__pyx_tuple__87
#define __pyx_tuple__89 __pyx_mstate_global->__pyx_tuple__89
#define __pyx_tuple__90 __pyx_mstate_global->__pyx_tuple__90
#define __pyx_tuple__92 __pyx_mstate_global->__pyx_tuple__92
#define __pyx_tuple__93 __pyx_mstate_global->__pyx_tuple__93
#define __pyx_tuple__95 __pyx_mstate_global->__pyx_tuple__95
#define __pyx_tuple__97 __pyx_mstate_global->__pyx_tuple__97
#define __pyx_tuple__99 __pyx_mstate_global->__pyx_tuple__99
#define __pyx_tuple__101 __pyx_mstate_global->__pyx_tuple__101
#define __pyx_tuple__103 __pyx_mstate_global->__pyx_tuple__103
#define __pyx_tuple__105 __pyx_mstate_global->__pyx_tuple__105
#define __pyx_tuple__107 __pyx_mstate_global->__pyx_tuple__107
#define __pyx_tuple__109 __pyx_mstate_global->__pyx_tuple__109
#define __pyx_codeobj__45 __pyx_mstate_global->__pyx_codeobj__45
#define __pyx_codeobj__47 __pyx_mstate_global->__pyx_codeobj__47
#define __pyx_codeobj__49 __pyx_mstate_global->__pyx_codeobj__49
#define __pyx_codeobj__51 __pyx_mstate_global->__pyx_codeobj__51
#define __pyx_codeobj__53 __pyx_mstate_global->__pyx_codeobj__53
#define __pyx_codeobj__55 __pyx_mstate_global->__pyx_codeobj__55
#define __pyx_codeobj__57 __pyx_mstate_global->__pyx_codeobj__57
#define __pyx_codeobj__59 __pyx_mstate_global->__pyx_codeobj__59
#define __pyx_codeobj__61 __pyx_mstate_global->__pyx_codeobj__61
#define __pyx_codeobj__63 __pyx_mstate_global->__pyx_codeobj__63
#define __pyx_codeobj__66 __pyx_mstate_global->__pyx_codeobj__66
#define __pyx_codeobj__68 __pyx_mstate_global->__pyx_codeobj__68
#define __pyx_codeobj__70 __pyx_mstate_global->__pyx_codeobj__70
#define __pyx_codeobj__73 __pyx_mstate_global->__pyx_codeobj__73
#define __pyx_codeobj__75 __pyx_mstate_global->__pyx_codeobj__75
#define __pyx_codeobj__77 __pyx_mstate_global->__pyx_codeobj__77
#define __pyx_codeobj__79 __pyx_mstate_global->__pyx_codeobj__79
#define __pyx_codeobj__81 __pyx_mstate_global->__pyx_codeobj__81
#define __pyx_codeobj__83 __pyx_mstate_global->__pyx_codeobj__83
#define __pyx_codeobj__85 __pyx_mstate_global->__pyx_codeobj__85
#define __pyx_codeobj__88 __pyx_mstate_global->__pyx_codeobj__88
#define __pyx_codeobj__91 __pyx_mstate_global->__pyx_codeobj__91
#define __pyx_codeobj__94 __pyx_mstate_global->__pyx_codeobj__94
#define __pyx_codeobj__96 __pyx_mstate_global->__pyx_codeobj__96
#define __pyx_codeobj__98 __pyx_mstate_global->__pyx_codeobj__98
#define __pyx_codeobj__100 __pyx_mstate_global->__pyx_codeobj__100
#define __pyx_codeobj__102 __pyx_mstate_global->__pyx_codeobj__102
#define __pyx_codeobj__104 __pyx_mstate_global->__pyx_codeobj__104
#define __pyx_codeobj__106 __pyx_mstate_global->__pyx_codeobj__106
#define __pyx_codeobj__108 __pyx_mstate_global->__pyx_codeobj__108
#define __pyx_codeobj__110 __pyx_mstate_global->__pyx_codeobj__110
/* #### Code section: module_code ### */

/* "tbstock/utils/utils.py":51
 * # print(f"year_list = {year_list}")
 * 
 * def checkCreatePath(directory):             # <<<<<<<<<<<<<<
 *     if not os.path.exists(directory):
 *         # os.makedirs()
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_1checkCreatePath(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_1checkCreatePath = {"checkCreatePath", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_1checkCreatePath, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_1checkCreatePath(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_directory = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkCreatePath (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_directory,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_directory)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 51, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkCreatePath") < 0)) __PYX_ERR(0, 51, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_directory = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkCreatePath", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 51, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.checkCreatePath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_checkCreatePath(__pyx_self, __pyx_v_directory);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_checkCreatePath(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_directory) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_UCS4 __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkCreatePath", 1);

  /* "tbstock/utils/utils.py":52
 * 
 * def checkCreatePath(directory):
 *     if not os.path.exists(directory):             # <<<<<<<<<<<<<<
 *         # os.makedirs()
 *         os.makedirs(directory)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exists); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_directory};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "tbstock/utils/utils.py":54
 *     if not os.path.exists(directory):
 *         # os.makedirs()
 *         os.makedirs(directory)             # <<<<<<<<<<<<<<
 *         print(f" {directory} .")
 *     else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_makedirs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_directory};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 54, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":55
 *         # os.makedirs()
 *         os.makedirs(directory)
 *         print(f" {directory} .")             # <<<<<<<<<<<<<<
 *     else:
 *         print(f" {directory} .")
 */
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = 0;
    __pyx_t_8 = 127;
    __Pyx_INCREF(__pyx_kp_u_);
    __pyx_t_8 = (65535 > __pyx_t_8) ? 65535 : __pyx_t_8;
    __pyx_t_7 += 3;
    __Pyx_GIVEREF(__pyx_kp_u_);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_directory, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u__2);
    __pyx_t_8 = (65535 > __pyx_t_8) ? 65535 : __pyx_t_8;
    __pyx_t_7 += 5;
    __Pyx_GIVEREF(__pyx_kp_u__2);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u__2);
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":52
 * 
 * def checkCreatePath(directory):
 *     if not os.path.exists(directory):             # <<<<<<<<<<<<<<
 *         # os.makedirs()
 *         os.makedirs(directory)
 */
    goto __pyx_L3;
  }

  /* "tbstock/utils/utils.py":57
 *         print(f" {directory} .")
 *     else:
 *         print(f" {directory} .")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = 0;
    __pyx_t_8 = 127;
    __Pyx_INCREF(__pyx_kp_u_);
    __pyx_t_8 = (65535 > __pyx_t_8) ? 65535 : __pyx_t_8;
    __pyx_t_7 += 3;
    __Pyx_GIVEREF(__pyx_kp_u_);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_directory, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u__3);
    __pyx_t_8 = (65535 > __pyx_t_8) ? 65535 : __pyx_t_8;
    __pyx_t_7 += 5;
    __Pyx_GIVEREF(__pyx_kp_u__3);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u__3);
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "tbstock/utils/utils.py":51
 * # print(f"year_list = {year_list}")
 * 
 * def checkCreatePath(directory):             # <<<<<<<<<<<<<<
 *     if not os.path.exists(directory):
 *         # os.makedirs()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("tbstock.utils.utils.checkCreatePath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":70
 * 
 * 
 * def getLatestTradeDay(today_date):             # <<<<<<<<<<<<<<
 *     if not sh_calendar.is_session(today_date):
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_3getLatestTradeDay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_3getLatestTradeDay = {"getLatestTradeDay", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_3getLatestTradeDay, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_3getLatestTradeDay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_today_date = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getLatestTradeDay (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_today_date,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_today_date)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 70, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getLatestTradeDay") < 0)) __PYX_ERR(0, 70, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_today_date = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getLatestTradeDay", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 70, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.getLatestTradeDay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_2getLatestTradeDay(__pyx_self, __pyx_v_today_date);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_2getLatestTradeDay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_today_date) {
  PyObject *__pyx_v_latest_trade_day = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLatestTradeDay", 1);

  /* "tbstock/utils/utils.py":71
 * 
 * def getLatestTradeDay(today_date):
 *     if not sh_calendar.is_session(today_date):             # <<<<<<<<<<<<<<
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')
 *     elif now_datetime.hour < 15:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_is_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_today_date};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "tbstock/utils/utils.py":72
 * def getLatestTradeDay(today_date):
 *     if not sh_calendar.is_session(today_date):
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')             # <<<<<<<<<<<<<<
 *     elif now_datetime.hour < 15:
 *         latest_trade_day = sh_calendar.previous_session(today_date).strftime('%Y%m%d')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date_to_session); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_today_date, __pyx_n_s_previous};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 72, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_strftime); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_s_Y_m_d};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_v_latest_trade_day = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":71
 * 
 * def getLatestTradeDay(today_date):
 *     if not sh_calendar.is_session(today_date):             # <<<<<<<<<<<<<<
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')
 *     elif now_datetime.hour < 15:
 */
    goto __pyx_L3;
  }

  /* "tbstock/utils/utils.py":73
 *     if not sh_calendar.is_session(today_date):
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')
 *     elif now_datetime.hour < 15:             # <<<<<<<<<<<<<<
 *         latest_trade_day = sh_calendar.previous_session(today_date).strftime('%Y%m%d')
 *     else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_now_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_hour); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_7, __pyx_int_15, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "tbstock/utils/utils.py":74
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')
 *     elif now_datetime.hour < 15:
 *         latest_trade_day = sh_calendar.previous_session(today_date).strftime('%Y%m%d')             # <<<<<<<<<<<<<<
 *     else:
 *         latest_trade_day = today_date
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_previous_session); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_today_date};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 74, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strftime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_kp_s_Y_m_d};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 74, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_latest_trade_day = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":73
 *     if not sh_calendar.is_session(today_date):
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')
 *     elif now_datetime.hour < 15:             # <<<<<<<<<<<<<<
 *         latest_trade_day = sh_calendar.previous_session(today_date).strftime('%Y%m%d')
 *     else:
 */
    goto __pyx_L3;
  }

  /* "tbstock/utils/utils.py":76
 *         latest_trade_day = sh_calendar.previous_session(today_date).strftime('%Y%m%d')
 *     else:
 *         latest_trade_day = today_date             # <<<<<<<<<<<<<<
 *     return latest_trade_day
 * 
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_today_date);
    __pyx_v_latest_trade_day = __pyx_v_today_date;
  }
  __pyx_L3:;

  /* "tbstock/utils/utils.py":77
 *     else:
 *         latest_trade_day = today_date
 *     return latest_trade_day             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_latest_trade_day);
  __pyx_r = __pyx_v_latest_trade_day;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":70
 * 
 * 
 * def getLatestTradeDay(today_date):             # <<<<<<<<<<<<<<
 *     if not sh_calendar.is_session(today_date):
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("tbstock.utils.utils.getLatestTradeDay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_latest_trade_day);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":84
 * 
 * 
 * def getIndexCodeName() -> dict:             # <<<<<<<<<<<<<<
 *     str_dict = {"rc": 0, "rt": 6, "svr": 182994245, "lt": 1, "full": 1, "dlmkts": "", "data": {"total": 37, "diff": [
 *         {"f1": 2, "f2": 3051.28, "f3": 0.08, "f4": 2.49, "f5": 316342484, "f6": 318911097485.6, "f7": 1.11, "f8": 0.69, "f9": "-", "f10": 0.99,
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_5getIndexCodeName(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_5getIndexCodeName = {"getIndexCodeName", (PyCFunction)__pyx_pw_7tbstock_5utils_5utils_5getIndexCodeName, METH_NOARGS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_5getIndexCodeName(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getIndexCodeName (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_4getIndexCodeName(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_4getIndexCodeName(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_str_dict = NULL;
  PyObject *__pyx_v_all_data_list = NULL;
  PyObject *__pyx_v_all_index = NULL;
  PyObject *__pyx_v_row = NULL;
  PyObject *__pyx_v_code_ip = NULL;
  PyObject *__pyx_v_index_name = NULL;
  PyObject *__pyx_v_index_code = NULL;
  PyObject *__pyx_v_full_code = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  PyObject *__pyx_t_31 = NULL;
  PyObject *__pyx_t_32 = NULL;
  PyObject *__pyx_t_33 = NULL;
  PyObject *__pyx_t_34 = NULL;
  PyObject *__pyx_t_35 = NULL;
  PyObject *__pyx_t_36 = NULL;
  PyObject *__pyx_t_37 = NULL;
  PyObject *__pyx_t_38 = NULL;
  PyObject *__pyx_t_39 = NULL;
  PyObject *__pyx_t_40 = NULL;
  Py_ssize_t __pyx_t_41;
  PyObject *(*__pyx_t_42)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getIndexCodeName", 1);

  /* "tbstock/utils/utils.py":85
 * 
 * def getIndexCodeName() -> dict:
 *     str_dict = {"rc": 0, "rt": 6, "svr": 182994245, "lt": 1, "full": 1, "dlmkts": "", "data": {"total": 37, "diff": [             # <<<<<<<<<<<<<<
 *         {"f1": 2, "f2": 3051.28, "f3": 0.08, "f4": 2.49, "f5": 316342484, "f6": 318911097485.6, "f7": 1.11, "f8": 0.69, "f9": "-", "f10": 0.99,
 *          "f11": -0.01, "f12": "000001", "f13": 1, "f14": "", "f15": 3065.02, "f16": 3031.04, "f17": 3053.92, "f18": 3048.79,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_rc, __pyx_int_0) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_rt, __pyx_int_6) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_svr, __pyx_int_182994245) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_lt, __pyx_int_1) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_full, __pyx_int_1) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dlmkts, __pyx_kp_s__4) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_total, __pyx_int_37) < 0) __PYX_ERR(0, 85, __pyx_L1_error)

  /* "tbstock/utils/utils.py":86
 * def getIndexCodeName() -> dict:
 *     str_dict = {"rc": 0, "rt": 6, "svr": 182994245, "lt": 1, "full": 1, "dlmkts": "", "data": {"total": 37, "diff": [
 *         {"f1": 2, "f2": 3051.28, "f3": 0.08, "f4": 2.49, "f5": 316342484, "f6": 318911097485.6, "f7": 1.11, "f8": 0.69, "f9": "-", "f10": 0.99,             # <<<<<<<<<<<<<<
 *          "f11": -0.01, "f12": "000001", "f13": 1, "f14": "", "f15": 3065.02, "f16": 3031.04, "f17": 3053.92, "f18": 3048.79,
 *          "f20": 47381680575138, "f21": 43906371616994, "f22": -0.03, "f23": "-", "f24": 0.17, "f25": 2.57, "f26": "-", "f62": -5655776512.0,
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f2, __pyx_float_3051_28) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f3, __pyx_float_0_08) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f4, __pyx_float_2_49) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f5, __pyx_int_316342484) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f6, __pyx_float_318911097485_6) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f7, __pyx_float_1_11) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f8, __pyx_float_0_69) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f10, __pyx_float_0_99) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f11, __pyx_float_neg_0_01) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f12, __pyx_kp_s_000001) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f14, __pyx_kp_s__6) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f15, __pyx_float_3065_02) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f16, __pyx_float_3031_04) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f17, __pyx_float_3053_92) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f18, __pyx_float_3048_79) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f20, __pyx_int_0x2b17e83d52a2) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f21, __pyx_int_0x27eebfaf00e2) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f22, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f24, __pyx_float_0_17) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f25, __pyx_float_2_57) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f62, __pyx_float_neg_5655776512_0) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 86, __pyx_L1_error)

  /* "tbstock/utils/utils.py":90
 *          "f20": 47381680575138, "f21": 43906371616994, "f22": -0.03, "f23": "-", "f24": 0.17, "f25": 2.57, "f26": "-", "f62": -5655776512.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 9255.68, "f3": -0.9, "f4": -84.33, "f5": 392337786, "f6": 397920913934.3657, "f7": 1.97, "f8": 1.69, "f9": "-", "f10": 0.91,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "399001", "f13": 0, "f14": "", "f15": 9366.34, "f16": 9181.89, "f17": 9343.8, "f18": 9340.01,
 *          "f20": 28267861255930, "f21": 23903392577865, "f22": -0.06, "f23": "-", "f24": -1.21, "f25": -2.82, "f26": "-", "f62": -10169320192.0,
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f2, __pyx_float_9255_68) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f3, __pyx_float_neg_0_9) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f4, __pyx_float_neg_84_33) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f5, __pyx_int_392337786) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f6, __pyx_float_397920913934_3657) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f7, __pyx_float_1_97) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f8, __pyx_float_1_69) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f10, __pyx_float_0_91) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f12, __pyx_kp_s_399001) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f14, __pyx_kp_s__7) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f15, __pyx_float_9366_34) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f16, __pyx_float_9181_89) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f17, __pyx_float_9343_8) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f18, __pyx_float_9340_01) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f20, __pyx_int_0x19b59fd426fa) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f21, __pyx_int_0x15bd71393949) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f24, __pyx_float_neg_1_21) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f25, __pyx_float_neg_2_82) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f62, __pyx_float_neg_10169320192_0) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 90, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 90, __pyx_L1_error)

  /* "tbstock/utils/utils.py":94
 *          "f20": 28267861255930, "f21": 23903392577865, "f22": -0.06, "f23": "-", "f24": -1.21, "f25": -2.82, "f26": "-", "f62": -10169320192.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 733.56, "f3": 0.93, "f4": 6.79, "f5": 2419271, "f6": 2377053666.0, "f7": 1.51, "f8": 1.29, "f9": "-", "f10": 0.77,             # <<<<<<<<<<<<<<
 *          "f11": 0.04, "f12": "899050", "f13": 0, "f14": "50", "f15": 739.05, "f16": 728.11, "f17": 729.84, "f18": 726.77, "f20": 313032053358,
 *          "f21": 168229436395, "f22": 0.01, "f23": "-", "f24": -15.62, "f25": -32.25, "f26": "-", "f62": -53971303.0, "f115": "-", "f128": "-",
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f2, __pyx_float_733_56) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f3, __pyx_float_0_93) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f4, __pyx_float_6_79) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f5, __pyx_int_2419271) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f6, __pyx_float_2377053666_0) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f7, __pyx_float_1_51) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f8, __pyx_float_1_29) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f10, __pyx_float_0_77) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f11, __pyx_float_0_04) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f12, __pyx_kp_s_899050) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f14, __pyx_kp_s_50) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f15, __pyx_float_739_05) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f16, __pyx_float_728_11) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f17, __pyx_float_729_84) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f18, __pyx_float_726_77) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f20, __pyx_int_313032053358) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f21, __pyx_int_168229436395) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f22, __pyx_float_0_01) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f24, __pyx_float_neg_15_62) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f25, __pyx_float_neg_32_25) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f62, __pyx_float_neg_53971303_0) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 94, __pyx_L1_error)

  /* "tbstock/utils/utils.py":98
 *          "f21": 168229436395, "f22": 0.01, "f23": "-", "f24": -15.62, "f25": -32.25, "f26": "-", "f62": -53971303.0, "f115": "-", "f128": "-",
 *          "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 1781.07, "f3": -2.16, "f4": -39.38, "f5": 133117037, "f6": 182415895155.26, "f7": 3.07, "f8": 2.7, "f9": "-", "f10": 0.89,             # <<<<<<<<<<<<<<
 *          "f11": -0.04, "f12": "399006", "f13": 0, "f14": "", "f15": 1820.74, "f16": 1764.84, "f17": 1812.46, "f18": 1820.45,
 *          "f20": 9790143307451, "f21": 7325541012743, "f22": -0.07, "f23": "-", "f24": -1.45, "f25": -5.83, "f26": "-", "f62": -5744585216.0,
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f2, __pyx_float_1781_07) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f3, __pyx_float_neg_2_16) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f4, __pyx_float_neg_39_38) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f5, __pyx_int_133117037) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f6, __pyx_float_182415895155_26) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f7, __pyx_float_3_07) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f8, __pyx_float_2_7) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f10, __pyx_float_0_89) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f11, __pyx_float_neg_0_04) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f12, __pyx_kp_s_399006) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f14, __pyx_kp_s__8) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f15, __pyx_float_1820_74) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f16, __pyx_float_1764_84) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f17, __pyx_float_1812_46) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f18, __pyx_float_1820_45) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f20, __pyx_int_9790143307451) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f21, __pyx_int_7325541012743) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f22, __pyx_float_neg_0_07) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f24, __pyx_float_neg_1_45) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f25, __pyx_float_neg_5_83) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f62, __pyx_float_neg_5744585216_0) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 98, __pyx_L1_error)

  /* "tbstock/utils/utils.py":102
 *          "f20": 9790143307451, "f21": 7325541012743, "f22": -0.07, "f23": "-", "f24": -1.45, "f25": -5.83, "f26": "-", "f62": -5744585216.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 737.93, "f3": -0.71, "f4": -5.3, "f5": 16720502, "f6": 45120126315.0, "f7": 2.41, "f8": 1.21, "f9": "-", "f10": 0.84,             # <<<<<<<<<<<<<<
 *          "f11": -0.08, "f12": "000688", "f13": 1, "f14": "50", "f15": 749.42, "f16": 731.52, "f17": 744.39, "f18": 743.23, "f20": 4998916135670,
 *          "f21": 3490375050807, "f22": -0.08, "f23": "-", "f24": -8.13, "f25": -13.39, "f26": "-", "f62": -918841824.0, "f115": "-", "f128": "-",
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f2, __pyx_float_737_93) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f3, __pyx_float_neg_0_71) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f4, __pyx_float_neg_5_3) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f5, __pyx_int_16720502) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f6, __pyx_float_45120126315_0) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f7, __pyx_float_2_41) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f8, __pyx_float_1_21) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f10, __pyx_float_0_84) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f11, __pyx_float_neg_0_08) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f12, __pyx_kp_s_000688) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f14, __pyx_kp_s_50_2) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f15, __pyx_float_749_42) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f16, __pyx_float_731_52) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f17, __pyx_float_744_39) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f18, __pyx_float_743_23) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f20, __pyx_int_4998916135670) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f21, __pyx_int_3490375050807) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f22, __pyx_float_neg_0_08) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f24, __pyx_float_neg_8_13) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f25, __pyx_float_neg_13_39) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f62, __pyx_float_neg_918841824_0) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 102, __pyx_L1_error)

  /* "tbstock/utils/utils.py":106
 *          "f21": 3490375050807, "f22": -0.08, "f23": "-", "f24": -8.13, "f25": -13.39, "f26": "-", "f62": -918841824.0, "f115": "-", "f128": "-",
 *          "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 7899.72, "f3": -0.56, "f4": -44.38, "f5": 25169964, "f6": 42696102285.67, "f7": 1.49, "f8": 0.83, "f9": "-", "f10": 1.0,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "399750", "f13": 0, "f14": "50", "f15": 7957.87, "f16": 7839.59, "f17": 7946.23, "f18": 7944.1,
 *          "f20": 5992127393523, "f21": 5531341956881, "f22": -0.03, "f23": "-", "f24": 0.54, "f25": 2.81, "f26": "-", "f62": -250665728.0, "f115": "-",
 */
  __pyx_t_8 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f2, __pyx_float_7899_72) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f3, __pyx_float_neg_0_56) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f4, __pyx_float_neg_44_38) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f5, __pyx_int_25169964) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f6, __pyx_float_42696102285_67) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f7, __pyx_float_1_49) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f8, __pyx_float_0_83) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f10, __pyx_float_1_0) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f12, __pyx_kp_s_399750) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f14, __pyx_kp_s_50_3) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f15, __pyx_float_7957_87) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f16, __pyx_float_7839_59) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f17, __pyx_float_7946_23) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f18, __pyx_float_7944_1) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f20, __pyx_int_5992127393523) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f21, __pyx_int_5531341956881) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f22, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f24, __pyx_float_0_54) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f25, __pyx_float_2_81) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f62, __pyx_float_neg_250665728_0) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 106, __pyx_L1_error)

  /* "tbstock/utils/utils.py":110
 *          "f20": 5992127393523, "f21": 5531341956881, "f22": -0.03, "f23": "-", "f24": 0.54, "f25": 2.81, "f26": "-", "f62": -250665728.0, "f115": "-",
 *          "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 3574.11, "f3": -0.5, "f4": -18.14, "f5": 131103026, "f6": 213001530097.8, "f7": 1.42, "f8": 0.42, "f9": "-", "f10": 1.05,             # <<<<<<<<<<<<<<
 *          "f11": -0.02, "f12": "000300", "f13": 1, "f14": "300", "f15": 3603.07, "f16": 3552.09, "f17": 3594.63, "f18": 3592.25,
 *          "f20": 40856594848955, "f21": 38455568003176, "f22": -0.05, "f23": "-", "f24": 0.82, "f25": 4.17, "f26": "-", "f62": -6014713856.0,
 */
  __pyx_t_9 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f2, __pyx_float_3574_11) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f3, __pyx_float_neg_0_5) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f4, __pyx_float_neg_18_14) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f5, __pyx_int_131103026) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f6, __pyx_float_213001530097_8) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f7, __pyx_float_1_42) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f8, __pyx_float_0_42) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f10, __pyx_float_1_05) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f11, __pyx_float_neg_0_02) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f12, __pyx_kp_s_000300) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f14, __pyx_kp_s_300) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f15, __pyx_float_3603_07) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f16, __pyx_float_3552_09) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f17, __pyx_float_3594_63) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f18, __pyx_float_3592_25) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f20, __pyx_int_0x2528aad29cbb) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f21, __pyx_int_0x22f9a2787068) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f22, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f24, __pyx_float_0_82) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f25, __pyx_float_4_17) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f62, __pyx_float_neg_6014713856_0) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 110, __pyx_L1_error)

  /* "tbstock/utils/utils.py":114
 *          "f20": 40856594848955, "f21": 38455568003176, "f22": -0.05, "f23": "-", "f24": 0.82, "f25": 4.17, "f26": "-", "f62": -6014713856.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 2457.26, "f3": -0.43, "f4": -10.63, "f5": 36436105, "f6": 58648181396.0, "f7": 1.28, "f8": 0.24, "f9": "-", "f10": 1.14,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "000016", "f13": 1, "f14": "50", "f15": 2476.46, "f16": 2444.93, "f17": 2473.17, "f18": 2467.89,
 *          "f20": 17946856348670, "f21": 17353995030027, "f22": -0.05, "f23": "-", "f24": 1.28, "f25": 5.64, "f26": "-", "f62": -1140853760.0,
 */
  __pyx_t_10 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f2, __pyx_float_2457_26) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f3, __pyx_float_neg_0_43) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f4, __pyx_float_neg_10_63) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f5, __pyx_int_36436105) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f6, __pyx_float_58648181396_0) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f7, __pyx_float_1_28) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f8, __pyx_float_0_24) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f10, __pyx_float_1_14) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f12, __pyx_kp_s_000016) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f14, __pyx_kp_s_50_4) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f15, __pyx_float_2476_46) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f16, __pyx_float_2444_93) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f17, __pyx_float_2473_17) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f18, __pyx_float_2467_89) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f20, __pyx_int_0x105293ff5bfe) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f21, __pyx_int_0xfc88ab58e0b) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f22, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f24, __pyx_float_1_28) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f25, __pyx_float_5_64) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f62, __pyx_float_neg_1140853760_0) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 114, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 114, __pyx_L1_error)

  /* "tbstock/utils/utils.py":118
 *          "f20": 17946856348670, "f21": 17353995030027, "f22": -0.05, "f23": "-", "f24": 1.28, "f25": 5.64, "f26": "-", "f62": -1140853760.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 6557.41, "f3": -1.5, "f4": -99.58, "f5": 21744403, "f6": 61288819659.89, "f7": 2.26, "f8": 0.96, "f9": "-", "f10": 1.0,             # <<<<<<<<<<<<<<
 *          "f11": -0.04, "f12": "399850", "f13": 0, "f14": "50", "f15": 6651.35, "f16": 6500.9, "f17": 6635.4, "f18": 6656.99, "f20": 7235995254645,
 *          "f21": 6629036171731, "f22": -0.06, "f23": "-", "f24": 1.09, "f25": 2.6, "f26": "-", "f62": -1963587072.0, "f115": "-", "f128": "-",
 */
  __pyx_t_11 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f2, __pyx_float_6557_41) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f3, __pyx_float_neg_1_5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f4, __pyx_float_neg_99_58) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f5, __pyx_int_21744403) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f6, __pyx_float_61288819659_89) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f7, __pyx_float_2_26) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f8, __pyx_float_0_96) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f10, __pyx_float_1_0) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f11, __pyx_float_neg_0_04) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f12, __pyx_kp_s_399850) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f14, __pyx_kp_s_50_5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f15, __pyx_float_6651_35) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f16, __pyx_float_6500_9) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f17, __pyx_float_6635_4) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f18, __pyx_float_6656_99) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f20, __pyx_int_7235995254645) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f21, __pyx_int_6629036171731) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f24, __pyx_float_1_09) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f25, __pyx_float_2_6) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f62, __pyx_float_neg_1963587072_0) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 118, __pyx_L1_error)

  /* "tbstock/utils/utils.py":122
 *          "f21": 6629036171731, "f22": -0.06, "f23": "-", "f24": 1.09, "f25": 2.6, "f26": "-", "f62": -1963587072.0, "f115": "-", "f128": "-",
 *          "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 5790.92, "f3": -0.98, "f4": -57.26, "f5": 32037354, "f6": 50489872605.94, "f7": 2.08, "f8": 1.12, "f9": "-", "f10": 1.03,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "399005", "f13": 0, "f14": "100", "f15": 5868.62, "f16": 5747.23, "f17": 5856.89, "f18": 5848.18,
 *          "f20": 5332514997228, "f21": 4800328458344, "f22": -0.06, "f23": "-", "f24": 0.38, "f25": -3.81, "f26": "-", "f62": -1468038656.0,
 */
  __pyx_t_12 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f2, __pyx_float_5790_92) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f3, __pyx_float_neg_0_98) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f4, __pyx_float_neg_57_26) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f5, __pyx_int_32037354) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f6, __pyx_float_50489872605_94) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f7, __pyx_float_2_08) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f8, __pyx_float_1_12) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f10, __pyx_float_1_03) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f12, __pyx_kp_s_399005) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f14, __pyx_kp_s_100) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f15, __pyx_float_5868_62) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f16, __pyx_float_5747_23) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f17, __pyx_float_5856_89) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f18, __pyx_float_5848_18) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f20, __pyx_int_5332514997228) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f21, __pyx_int_4800328458344) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f24, __pyx_float_0_38) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f25, __pyx_float_neg_3_81) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f62, __pyx_float_neg_1468038656_0) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 122, __pyx_L1_error)

  /* "tbstock/utils/utils.py":126
 *          "f20": 5332514997228, "f21": 4800328458344, "f22": -0.06, "f23": "-", "f24": 0.38, "f25": -3.81, "f26": "-", "f62": -1468038656.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 1417.17, "f3": -0.87, "f4": -12.42, "f5": 27364120, "f6": 70813170022.0, "f7": 1.65, "f8": 0.54, "f9": "-", "f10": 1.05,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "930050", "f13": 2, "f14": "A50", "f15": 1432.13, "f16": 1408.48, "f17": 1428.83, "f18": 1429.59,
 *          "f20": 12846080303814, "f21": 12339044245944, "f22": -0.06, "f23": "-", "f24": 1.5, "f25": 4.54, "f26": "-", "f62": "-", "f115": "-",
 */
  __pyx_t_13 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f2, __pyx_float_1417_17) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f3, __pyx_float_neg_0_87) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f4, __pyx_float_neg_12_42) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f5, __pyx_int_27364120) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f6, __pyx_float_70813170022_0) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f7, __pyx_float_1_65) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f8, __pyx_float_0_54) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f10, __pyx_float_1_05) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f12, __pyx_kp_s_930050) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f13, __pyx_int_2) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f14, __pyx_kp_s_A50) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f15, __pyx_float_1432_13) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f16, __pyx_float_1408_48) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f17, __pyx_float_1428_83) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f18, __pyx_float_1429_59) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f20, __pyx_int_0xbaef60da2c6) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f21, __pyx_int_0xb38e85961b8) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f24, __pyx_float_1_5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f25, __pyx_float_4_54) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f62, __pyx_kp_s__5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 126, __pyx_L1_error)

  /* "tbstock/utils/utils.py":130
 *          "f20": 12846080303814, "f21": 12339044245944, "f22": -0.06, "f23": "-", "f24": 1.5, "f25": 4.54, "f26": "-", "f62": "-", "f115": "-",
 *          "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 3411.14, "f3": -0.7, "f4": -24.21, "f5": 59724479, "f6": 115940476191.2, "f7": 1.53, "f8": 0.47, "f9": "-", "f10": 1.03,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "000903", "f13": 1, "f14": "100", "f15": 3442.73, "f16": 3390.29, "f17": 3435.84, "f18": 3435.35,
 *          "f20": 20971352159492, "f21": 19856179453620, "f22": -0.06, "f23": "-", "f24": 1.56, "f25": 4.54, "f26": "-", "f62": -2622219776.0,
 */
  __pyx_t_14 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f2, __pyx_float_3411_14) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f3, __pyx_float_neg_0_7) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f4, __pyx_float_neg_24_21) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f5, __pyx_int_59724479) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f6, __pyx_float_115940476191_2) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f7, __pyx_float_1_53) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f8, __pyx_float_0_47) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f10, __pyx_float_1_03) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f12, __pyx_kp_s_000903) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f14, __pyx_kp_s_100_2) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f15, __pyx_float_3442_73) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f16, __pyx_float_3390_29) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f17, __pyx_float_3435_84) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f18, __pyx_float_3435_35) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f20, __pyx_int_0x1312c5fef504) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f21, __pyx_int_0x120f2085deb4) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f24, __pyx_float_1_56) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f25, __pyx_float_4_54) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f62, __pyx_float_neg_2622219776_0) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 130, __pyx_L1_error)

  /* "tbstock/utils/utils.py":134
 *          "f20": 20971352159492, "f21": 19856179453620, "f22": -0.06, "f23": "-", "f24": 1.56, "f25": 4.54, "f26": "-", "f62": -2622219776.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 4120.29, "f3": -0.19, "f4": -7.69, "f5": 58645358, "f6": 89734052295.0, "f7": 1.39, "f8": 0.66, "f9": "-", "f10": 0.97,             # <<<<<<<<<<<<<<
 *          "f11": -0.02, "f12": "000904", "f13": 1, "f14": "200", "f15": 4149.23, "f16": 4091.72, "f17": 4136.21, "f18": 4127.98,
 *          "f20": 12271947839903, "f21": 11369639639965, "f22": -0.04, "f23": "-", "f24": -1.38, "f25": 0.18, "f26": "-", "f62": -2509978624.0,
 */
  __pyx_t_15 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f2, __pyx_float_4120_29) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f3, __pyx_float_neg_0_19) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f4, __pyx_float_neg_7_69) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f5, __pyx_int_58645358) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f6, __pyx_float_89734052295_0) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f7, __pyx_float_1_39) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f8, __pyx_float_0_66) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f10, __pyx_float_0_97) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f11, __pyx_float_neg_0_02) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f12, __pyx_kp_s_000904) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f14, __pyx_kp_s_200) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f15, __pyx_float_4149_23) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f16, __pyx_float_4091_72) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f17, __pyx_float_4136_21) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f18, __pyx_float_4127_98) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f20, __pyx_int_0xb294917799f) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f21, __pyx_int_0xa573354fb9d) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f22, __pyx_float_neg_0_04) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f24, __pyx_float_neg_1_38) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f25, __pyx_float_0_18) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f62, __pyx_float_neg_2509978624_0) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 134, __pyx_L1_error)

  /* "tbstock/utils/utils.py":138
 *          "f20": 12271947839903, "f21": 11369639639965, "f22": -0.04, "f23": "-", "f24": -1.38, "f25": 0.18, "f26": "-", "f62": -2509978624.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 5208.98, "f3": -0.38, "f4": -19.82, "f5": 113527478, "f6": 118553769519.2, "f7": 1.66, "f8": 0.99, "f9": "-", "f10": 0.98,             # <<<<<<<<<<<<<<
 *          "f11": 0.01, "f12": "000905", "f13": 1, "f14": "500", "f15": 5258.82, "f16": 5172.05, "f17": 5247.15, "f18": 5228.8,
 *          "f20": 11365672874066, "f21": 10241305658422, "f22": -0.05, "f23": "-", "f24": -2.63, "f25": -4.06, "f26": "-", "f62": -1476325632.0,
 */
  __pyx_t_16 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f2, __pyx_float_5208_98) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f3, __pyx_float_neg_0_38) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f4, __pyx_float_neg_19_82) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f5, __pyx_int_113527478) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f6, __pyx_float_118553769519_2) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f7, __pyx_float_1_66) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f8, __pyx_float_0_99) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f10, __pyx_float_0_98) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f11, __pyx_float_0_01) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f12, __pyx_kp_s_000905) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f14, __pyx_kp_s_500) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f15, __pyx_float_5258_82) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f16, __pyx_float_5172_05) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f17, __pyx_float_5247_15) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f18, __pyx_float_5228_8) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f20, __pyx_int_0xa5646e4f052) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f21, __pyx_int_0x9507d62c436) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f22, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f24, __pyx_float_neg_2_63) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f25, __pyx_float_neg_4_06) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f62, __pyx_float_neg_1476325632_0) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 138, __pyx_L1_error)

  /* "tbstock/utils/utils.py":142
 *          "f20": 11365672874066, "f21": 10241305658422, "f22": -0.05, "f23": "-", "f24": -2.63, "f25": -4.06, "f26": "-", "f62": -1476325632.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 3840.42, "f3": -0.47, "f4": -18.25, "f5": 244630504, "f6": 331555299617.0, "f7": 1.48, "f8": 0.57, "f9": "-", "f10": 1.01,             # <<<<<<<<<<<<<<
 *          "f11": -0.01, "f12": "000906", "f13": 1, "f14": "800", "f15": 3872.92, "f16": 3815.88, "f17": 3864.01, "f18": 3858.67,
 *          "f20": 52222267723022, "f21": 48696873661598, "f22": -0.05, "f23": "-", "f24": -0.07, "f25": 1.96, "f26": "-", "f62": -7491039488.0,
 */
  __pyx_t_17 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f2, __pyx_float_3840_42) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f3, __pyx_float_neg_0_47) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f4, __pyx_float_neg_18_25) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f5, __pyx_int_244630504) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f6, __pyx_float_331555299617_0) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f7, __pyx_float_1_48) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f8, __pyx_float_0_57) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f10, __pyx_float_1_01) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f11, __pyx_float_neg_0_01) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f12, __pyx_kp_s_000906) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f14, __pyx_kp_s_800) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f15, __pyx_float_3872_92) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f16, __pyx_float_3815_88) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f17, __pyx_float_3864_01) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f18, __pyx_float_3858_67) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f20, __pyx_int_0x2f7ef1b78d0e) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f21, __pyx_int_0x2c4a1fdb349e) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f22, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f24, __pyx_float_neg_0_07) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f25, __pyx_float_1_96) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f62, __pyx_float_neg_7491039488_0) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 142, __pyx_L1_error)

  /* "tbstock/utils/utils.py":146
 *          "f20": 52222267723022, "f21": 48696873661598, "f22": -0.05, "f23": "-", "f24": -0.07, "f25": 1.96, "f26": "-", "f62": -7491039488.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 5153.59, "f3": 0.44, "f4": 22.72, "f5": 130320202, "f6": 127151511671.8, "f7": 1.83, "f8": 1.34, "f9": "-", "f10": 0.87,             # <<<<<<<<<<<<<<
 *          "f11": -0.05, "f12": "000852", "f13": 1, "f14": "1000", "f15": 5190.0, "f16": 5096.08, "f17": 5159.17, "f18": 5130.87,
 *          "f20": 9890708337231, "f21": 8607232746956, "f22": -0.06, "f23": "-", "f24": -4.04, "f25": -12.46, "f26": "-", "f62": -2539908352.0,
 */
  __pyx_t_18 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f2, __pyx_float_5153_59) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f3, __pyx_float_0_44) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f4, __pyx_float_22_72) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f5, __pyx_int_130320202) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f6, __pyx_float_127151511671_8) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f7, __pyx_float_1_83) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f8, __pyx_float_1_34) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f10, __pyx_float_0_87) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f11, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f12, __pyx_kp_s_000852) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f14, __pyx_kp_s_1000) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f15, __pyx_float_5190_0) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f16, __pyx_float_5096_08) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f17, __pyx_float_5159_17) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f18, __pyx_float_5130_87) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f20, __pyx_int_9890708337231) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f21, __pyx_int_8607232746956) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f24, __pyx_float_neg_4_04) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f25, __pyx_float_neg_12_46) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f62, __pyx_float_neg_2539908352_0) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 146, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 146, __pyx_L1_error)

  /* "tbstock/utils/utils.py":150
 *          "f20": 9890708337231, "f21": 8607232746956, "f22": -0.06, "f23": "-", "f24": -4.04, "f25": -12.46, "f26": "-", "f62": -2539908352.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 1883.29, "f3": 1.83, "f4": 33.8, "f5": 199724618, "f6": 159799015973.0, "f7": 2.01, "f8": 2.28, "f9": "-", "f10": 0.92,             # <<<<<<<<<<<<<<
 *          "f11": 0.03, "f12": "932000", "f13": 2, "f14": "2000", "f15": 1890.25, "f16": 1853.0, "f17": 1865.28, "f18": 1849.49,
 *          "f20": 7507095323631, "f21": 6118478847123, "f22": 0.02, "f23": "-", "f24": -8.27, "f25": -21.51, "f26": "-", "f62": "-", "f115": "-",
 */
  __pyx_t_19 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f2, __pyx_float_1883_29) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f3, __pyx_float_1_83) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f4, __pyx_float_33_8) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f5, __pyx_int_199724618) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f6, __pyx_float_159799015973_0) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f7, __pyx_float_2_01) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f8, __pyx_float_2_28) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f10, __pyx_float_0_92) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f11, __pyx_float_0_03) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f12, __pyx_kp_s_932000) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f13, __pyx_int_2) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f14, __pyx_kp_s_2000) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f15, __pyx_float_1890_25) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f16, __pyx_float_1853_0) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f17, __pyx_float_1865_28) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f18, __pyx_float_1849_49) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f20, __pyx_int_7507095323631) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f21, __pyx_int_6118478847123) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f22, __pyx_float_0_02) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f24, __pyx_float_neg_8_27) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f25, __pyx_float_neg_21_51) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f62, __pyx_kp_s__5) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 150, __pyx_L1_error)

  /* "tbstock/utils/utils.py":154
 *          "f20": 7507095323631, "f21": 6118478847123, "f22": 0.02, "f23": "-", "f24": -8.27, "f25": -21.51, "f26": "-", "f62": "-", "f115": "-",
 *          "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 4192.82, "f3": 0.06, "f4": 2.62, "f5": 677188186, "f6": 691633876518.0, "f7": 1.55, "f8": 1.01, "f9": "-", "f10": 0.95,             # <<<<<<<<<<<<<<
 *          "f11": -0.01, "f12": "000985", "f13": 1, "f14": "", "f15": 4223.36, "f16": 4158.24, "f17": 4203.02, "f18": 4190.2,
 *          "f20": 73939333646846, "f21": 67101225593238, "f22": -0.04, "f23": "-", "f24": -2.17, "f25": -5.18, "f26": "-", "f62": -13886649344.0,
 */
  __pyx_t_20 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f2, __pyx_float_4192_82) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f3, __pyx_float_0_06) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f4, __pyx_float_2_62) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f5, __pyx_int_677188186) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f6, __pyx_float_691633876518_0) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f7, __pyx_float_1_55) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f8, __pyx_float_1_01) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f10, __pyx_float_0_95) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f11, __pyx_float_neg_0_01) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f12, __pyx_kp_s_000985) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f14, __pyx_kp_s__9) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f15, __pyx_float_4223_36) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f16, __pyx_float_4158_24) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f17, __pyx_float_4203_02) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f18, __pyx_float_4190_2) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f20, __pyx_int_0x433f57b789fe) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f21, __pyx_int_0x3d0738b72996) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f22, __pyx_float_neg_0_04) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f24, __pyx_float_neg_2_17) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f25, __pyx_float_neg_5_18) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f62, __pyx_float_neg_13886649344_0) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 154, __pyx_L1_error)

  /* "tbstock/utils/utils.py":158
 *          "f20": 73939333646846, "f21": 67101225593238, "f22": -0.04, "f23": "-", "f24": -2.17, "f25": -5.18, "f26": "-", "f62": -13886649344.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 7860.74, "f3": -0.2, "f4": -16.02, "f5": 88973758, "f6": 127527613173.0, "f7": 1.22, "f8": 0.37, "f9": "-", "f10": 1.08,             # <<<<<<<<<<<<<<
 *          "f11": -0.02, "f12": "000010", "f13": 1, "f14": "180", "f15": 7910.66, "f16": 7814.84, "f17": 7893.4, "f18": 7876.76,
 *          "f20": 27745771177301, "f21": 26635969615522, "f22": -0.04, "f23": "-", "f24": 1.04, "f25": 5.94, "f26": "-", "f62": -2227974912.0,
 */
  __pyx_t_21 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f2, __pyx_float_7860_74) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f3, __pyx_float_neg_0_2) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f4, __pyx_float_neg_16_02) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f5, __pyx_int_88973758) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f6, __pyx_float_127527613173_0) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f7, __pyx_float_1_22) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f8, __pyx_float_0_37) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f10, __pyx_float_1_08) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f11, __pyx_float_neg_0_02) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f12, __pyx_kp_s_000010) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f14, __pyx_kp_s_180) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f15, __pyx_float_7910_66) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f16, __pyx_float_7814_84) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f17, __pyx_float_7893_4) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f18, __pyx_float_7876_76) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f20, __pyx_int_0x193c10d5c555) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f21, __pyx_int_0x1839ab81d6a2) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f22, __pyx_float_neg_0_04) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f24, __pyx_float_1_04) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f25, __pyx_float_5_94) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f62, __pyx_float_neg_2227974912_0) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 158, __pyx_L1_error)

  /* "tbstock/utils/utils.py":162
 *          "f20": 27745771177301, "f21": 26635969615522, "f22": -0.04, "f23": "-", "f24": 1.04, "f25": 5.94, "f26": "-", "f62": -2227974912.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 5192.26, "f3": 0.04, "f4": 2.25, "f5": 48122566, "f6": 61566668750.0, "f7": 1.24, "f8": 0.7, "f9": "-", "f10": 0.93,             # <<<<<<<<<<<<<<
 *          "f11": -0.01, "f12": "000009", "f13": 1, "f14": "380", "f15": 5220.0, "f16": 5155.7, "f17": 5205.05, "f18": 5190.01,
 *          "f20": 7884280772830, "f21": 7428389236896, "f22": -0.04, "f23": "-", "f24": 0.65, "f25": 0.02, "f26": "-", "f62": -1171835776.0,
 */
  __pyx_t_22 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f2, __pyx_float_5192_26) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f3, __pyx_float_0_04) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f4, __pyx_float_2_25) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f5, __pyx_int_48122566) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f6, __pyx_float_61566668750_0) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f7, __pyx_float_1_24) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f8, __pyx_float_0_7) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f10, __pyx_float_0_93) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f11, __pyx_float_neg_0_01) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f12, __pyx_kp_s_000009) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f14, __pyx_kp_s_380) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f15, __pyx_float_5220_0) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f16, __pyx_float_5155_7) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f17, __pyx_float_5205_05) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f18, __pyx_float_5190_01) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f20, __pyx_int_7884280772830) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f21, __pyx_int_7428389236896) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f22, __pyx_float_neg_0_04) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f24, __pyx_float_0_65) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f25, __pyx_float_0_02) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f62, __pyx_float_neg_1171835776_0) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 162, __pyx_L1_error)

  /* "tbstock/utils/utils.py":166
 *          "f20": 7884280772830, "f21": 7428389236896, "f22": -0.04, "f23": "-", "f24": 0.65, "f25": 0.02, "f26": "-", "f62": -1171835776.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 5153.54, "f3": -0.41, "f4": -21.32, "f5": 8576647, "f6": 15092302335.0, "f7": 1.41, "f8": 0.78, "f9": "-", "f10": 0.89,             # <<<<<<<<<<<<<<
 *          "f11": -0.06, "f12": "000132", "f13": 1, "f14": "100", "f15": 5198.9, "f16": 5126.06, "f17": 5187.77, "f18": 5174.86,
 *          "f20": 1821738041432, "f21": 1708631550165, "f22": -0.05, "f23": "-", "f24": -0.71, "f25": -1.33, "f26": "-", "f62": -698863952.0,
 */
  __pyx_t_23 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f2, __pyx_float_5153_54) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f3, __pyx_float_neg_0_41) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f4, __pyx_float_neg_21_32) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f5, __pyx_int_8576647) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f6, __pyx_float_15092302335_0) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f7, __pyx_float_1_41) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f8, __pyx_float_0_78) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f10, __pyx_float_0_89) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f11, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f12, __pyx_kp_s_000132) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f14, __pyx_kp_s_100_3) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f15, __pyx_float_5198_9) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f16, __pyx_float_5126_06) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f17, __pyx_float_5187_77) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f18, __pyx_float_5174_86) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f20, __pyx_int_1821738041432) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f21, __pyx_int_1708631550165) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f22, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f24, __pyx_float_neg_0_71) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f25, __pyx_float_neg_1_33) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f62, __pyx_float_neg_698863952_0) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 166, __pyx_L1_error)

  /* "tbstock/utils/utils.py":170
 *          "f20": 1821738041432, "f21": 1708631550165, "f22": -0.05, "f23": "-", "f24": -0.71, "f25": -1.33, "f26": "-", "f62": -698863952.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 3817.47, "f3": 1.6, "f4": 60.05, "f5": 10592446, "f6": 10894972910.0, "f7": 1.96, "f8": 2.19, "f9": "-", "f10": 0.89,             # <<<<<<<<<<<<<<
 *          "f11": 0.02, "f12": "000133", "f13": 1, "f14": "150", "f15": 3835.07, "f16": 3761.37, "f17": 3784.58, "f18": 3757.42,
 *          "f20": 626306385346, "f21": 515063456666, "f22": 0.0, "f23": "-", "f24": -7.28, "f25": -21.3, "f26": "-", "f62": -12984032.0, "f115": "-",
 */
  __pyx_t_24 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f2, __pyx_float_3817_47) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f3, __pyx_float_1_6) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f4, __pyx_float_60_05) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f5, __pyx_int_10592446) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f6, __pyx_float_10894972910_0) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f7, __pyx_float_1_96) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f8, __pyx_float_2_19) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f10, __pyx_float_0_89) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f11, __pyx_float_0_02) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f12, __pyx_kp_s_000133) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f14, __pyx_kp_s_150) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f15, __pyx_float_3835_07) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f16, __pyx_float_3761_37) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f17, __pyx_float_3784_58) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f18, __pyx_float_3757_42) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f20, __pyx_int_626306385346) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f21, __pyx_int_515063456666) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f22, __pyx_float_0_0) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f24, __pyx_float_neg_7_28) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f25, __pyx_float_neg_21_3) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f62, __pyx_float_neg_12984032_0) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_24, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 170, __pyx_L1_error)

  /* "tbstock/utils/utils.py":174
 *          "f20": 626306385346, "f21": 515063456666, "f22": 0.0, "f23": "-", "f24": -7.28, "f25": -21.3, "f26": "-", "f62": -12984032.0, "f115": "-",
 *          "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 234.61, "f3": 2.77, "f4": 6.33, "f5": 571666, "f6": 140532459.6, "f7": 3.0, "f8": 0.38, "f9": "-", "f10": 0.95, "f11": 0.2,             # <<<<<<<<<<<<<<
 *          "f12": "000003", "f13": 1, "f14": "", "f15": 234.61, "f16": 227.77, "f17": 228.24, "f18": 228.28, "f20": 12717649349,
 *          "f21": 8855649026, "f22": 0.15, "f23": "-", "f24": -11.66, "f25": 1.3, "f26": "-", "f62": 500282.0, "f115": "-", "f128": "-", "f140": "-",
 */
  __pyx_t_25 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f2, __pyx_float_234_61) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f3, __pyx_float_2_77) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f4, __pyx_float_6_33) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f5, __pyx_int_571666) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f6, __pyx_float_140532459_6) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f7, __pyx_float_3_0) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f8, __pyx_float_0_38) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f10, __pyx_float_0_95) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f11, __pyx_float_0_2) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f12, __pyx_kp_s_000003) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f14, __pyx_kp_s__10) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f15, __pyx_float_234_61) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f16, __pyx_float_227_77) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f17, __pyx_float_228_24) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f18, __pyx_float_228_28) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f20, __pyx_int_12717649349) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f21, __pyx_int_8855649026) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f22, __pyx_float_0_15) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f24, __pyx_float_neg_11_66) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f25, __pyx_float_1_3) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f62, __pyx_float_500282_0) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_25, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 174, __pyx_L1_error)

  /* "tbstock/utils/utils.py":178
 *          "f21": 8855649026, "f22": 0.15, "f23": "-", "f24": -11.66, "f25": 1.3, "f26": "-", "f62": 500282.0, "f115": "-", "f128": "-", "f140": "-",
 *          "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 212.94, "f3": 0.0, "f4": 0.01, "f5": 14249490, "f6": 14464539893.0, "f7": 0.03, "f8": "-", "f9": "-", "f10": 0.77, "f11": 0.0,             # <<<<<<<<<<<<<<
 *          "f12": "000012", "f13": 1, "f14": "", "f15": 212.96, "f16": 212.89, "f17": 212.94, "f18": 212.93, "f20": "-", "f21": "-", "f22": 0.0,
 *          "f23": "-", "f24": 1.5, "f25": 3.35, "f26": "-", "f62": 23948464.0, "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-",
 */
  __pyx_t_26 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_26);
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f2, __pyx_float_212_94) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f3, __pyx_float_0_0) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f4, __pyx_float_0_01) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f5, __pyx_int_14249490) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f6, __pyx_float_14464539893_0) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f7, __pyx_float_0_03) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f8, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f10, __pyx_float_0_77) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f11, __pyx_float_0_0) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f12, __pyx_kp_s_000012) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f14, __pyx_kp_s__11) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f15, __pyx_float_212_96) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f16, __pyx_float_212_89) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f17, __pyx_float_212_94) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f18, __pyx_float_212_93) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f20, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f21, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f22, __pyx_float_0_0) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f24, __pyx_float_1_5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f25, __pyx_float_3_35) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f62, __pyx_float_23948464_0) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_26, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 178, __pyx_L1_error)

  /* "tbstock/utils/utils.py":182
 *          "f23": "-", "f24": 1.5, "f25": 3.35, "f26": "-", "f62": 23948464.0, "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-",
 *          "f152": 2},
 *         {"f1": 2, "f2": 286.75, "f3": 0.01, "f4": 0.04, "f5": 2223662, "f6": 2244259683.0, "f7": 0.01, "f8": "-", "f9": "-", "f10": 0.37, "f11": 0.0,             # <<<<<<<<<<<<<<
 *          "f12": "000013", "f13": 1, "f14": "", "f15": 286.75, "f16": 286.73, "f17": 286.73, "f18": 286.71, "f20": "-", "f21": "-", "f22": 0.0,
 *          "f23": "-", "f24": 1.37, "f25": 2.48, "f26": "-", "f62": -2997454.0, "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-",
 */
  __pyx_t_27 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_27);
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f2, __pyx_float_286_75) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f3, __pyx_float_0_01) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f4, __pyx_float_0_04) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f5, __pyx_int_2223662) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f6, __pyx_float_2244259683_0) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f7, __pyx_float_0_01) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f8, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f10, __pyx_float_0_37) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f11, __pyx_float_0_0) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f12, __pyx_kp_s_000013) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f14, __pyx_kp_s__12) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f15, __pyx_float_286_75) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f16, __pyx_float_286_73) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f17, __pyx_float_286_73) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f18, __pyx_float_286_71) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f20, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f21, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f22, __pyx_float_0_0) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f24, __pyx_float_1_37) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f25, __pyx_float_2_48) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f62, __pyx_float_neg_2997454_0) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_27, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 182, __pyx_L1_error)

  /* "tbstock/utils/utils.py":186
 *          "f23": "-", "f24": 1.37, "f25": 2.48, "f26": "-", "f62": -2997454.0, "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-",
 *          "f152": 2},
 *         {"f1": 2, "f2": 5994.52, "f3": -0.39, "f4": -23.59, "f5": 541037598, "f6": 98770455187.0, "f7": 1.31, "f8": 3.83, "f9": "-", "f10": 1.01,             # <<<<<<<<<<<<<<
 *          "f11": 0.01, "f12": "000011", "f13": 1, "f14": "", "f15": 6042.92, "f16": 5964.03, "f17": 6029.51, "f18": 6018.11,
 *          "f20": 1845844064964, "f21": 1845844064964, "f22": -0.01, "f23": "-", "f24": 0.16, "f25": -0.79, "f26": "-", "f62": -2440455424.0,
 */
  __pyx_t_28 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_28);
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f2, __pyx_float_5994_52) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f3, __pyx_float_neg_0_39) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f4, __pyx_float_neg_23_59) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f5, __pyx_int_541037598) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f6, __pyx_float_98770455187_0) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f7, __pyx_float_1_31) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f8, __pyx_float_3_83) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f10, __pyx_float_1_01) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f11, __pyx_float_0_01) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f12, __pyx_kp_s_000011) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f13, __pyx_int_1) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f14, __pyx_kp_s__13) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f15, __pyx_float_6042_92) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f16, __pyx_float_5964_03) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f17, __pyx_float_6029_51) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f18, __pyx_float_6018_11) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f20, __pyx_int_1845844064964) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f21, __pyx_int_1845844064964) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f22, __pyx_float_neg_0_01) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f24, __pyx_float_0_16) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f25, __pyx_float_neg_0_79) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f62, __pyx_float_neg_2440455424_0) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 186, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_28, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 186, __pyx_L1_error)

  /* "tbstock/utils/utils.py":190
 *          "f20": 1845844064964, "f21": 1845844064964, "f22": -0.01, "f23": "-", "f24": 0.16, "f25": -0.79, "f26": "-", "f62": -2440455424.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 12041.42, "f3": -0.86, "f4": -104.4, "f5": 259052823, "f6": 215440232173.34, "f7": 1.98, "f8": 1.12, "f9": "-", "f10": 0.93,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "399002", "f13": 0, "f14": "R", "f15": 12185.37, "f16": 11945.41, "f17": 12156.05, "f18": 12145.82,
 *          "f20": 28214561466098, "f21": 23850256049630, "f22": -0.06, "f23": "-", "f24": -0.33, "f25": -1.96, "f26": "-", "f62": -8813961984.0,
 */
  __pyx_t_29 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_29);
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f2, __pyx_float_12041_42) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f3, __pyx_float_neg_0_86) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f4, __pyx_float_neg_104_4) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f5, __pyx_int_259052823) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f6, __pyx_float_215440232173_34) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f7, __pyx_float_1_98) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f8, __pyx_float_1_12) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f10, __pyx_float_0_93) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f12, __pyx_kp_s_399002) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f14, __pyx_kp_s_R) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f15, __pyx_float_12185_37) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f16, __pyx_float_11945_41) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f17, __pyx_float_12156_05) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f18, __pyx_float_12145_82) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f20, __pyx_int_0x19a936e9e6f2) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f21, __pyx_int_0x15b1120a25de) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f24, __pyx_float_neg_0_33) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f25, __pyx_float_neg_1_96) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f62, __pyx_float_neg_8813961984_0) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_29, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 190, __pyx_L1_error)

  /* "tbstock/utils/utils.py":194
 *          "f20": 28214561466098, "f21": 23850256049630, "f22": -0.06, "f23": "-", "f24": -0.33, "f25": -1.96, "f26": "-", "f62": -8813961984.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 7602.37, "f3": 0.33, "f4": 25.27, "f5": 167926, "f6": 64786605.7657, "f7": 1.31, "f8": 0.14, "f9": "-", "f10": 0.61,             # <<<<<<<<<<<<<<
 *          "f11": 0.34, "f12": "399003", "f13": 0, "f14": "", "f15": 7624.17, "f16": 7525.19, "f17": 7583.68, "f18": 7577.1, "f20": 53299789831,
 *          "f21": 53136528234, "f22": 0.29, "f23": "-", "f24": 6.81, "f25": 3.99, "f26": "-", "f62": -4803766.0, "f115": "-", "f128": "-", "f140": "-",
 */
  __pyx_t_30 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_30);
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f2, __pyx_float_7602_37) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f3, __pyx_float_0_33) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f4, __pyx_float_25_27) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f5, __pyx_int_167926) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f6, __pyx_float_64786605_7657) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f7, __pyx_float_1_31) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f8, __pyx_float_0_14) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f10, __pyx_float_0_61) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f11, __pyx_float_0_34) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f12, __pyx_kp_s_399003) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f14, __pyx_kp_s__14) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f15, __pyx_float_7624_17) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f16, __pyx_float_7525_19) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f17, __pyx_float_7583_68) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f18, __pyx_float_7577_1) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f20, __pyx_int_53299789831) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f21, __pyx_int_53136528234) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f22, __pyx_float_0_29) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f24, __pyx_float_6_81) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f25, __pyx_float_3_99) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f62, __pyx_float_neg_4803766_0) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_30, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 194, __pyx_L1_error)

  /* "tbstock/utils/utils.py":198
 *          "f21": 53136528234, "f22": 0.29, "f23": "-", "f24": 6.81, "f25": 3.99, "f26": "-", "f62": -4803766.0, "f115": "-", "f128": "-", "f140": "-",
 *          "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 1679.31, "f3": 0.1, "f4": 1.63, "f5": 391479032, "f6": 397900984221.1357, "f7": 1.9, "f8": 1.69, "f9": "-", "f10": 0.91,             # <<<<<<<<<<<<<<
 *          "f11": -0.02, "f12": "399106", "f13": 0, "f14": "", "f15": 1693.48, "f16": 1661.57, "f17": 1683.87, "f18": 1677.68,
 *          "f20": 28267861255930, "f21": 23903392577865, "f22": -0.04, "f23": "-", "f24": -2.35, "f25": -8.63, "f26": "-", "f62": -10169320192.0,
 */
  __pyx_t_31 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f2, __pyx_float_1679_31) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f3, __pyx_float_0_1) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f4, __pyx_float_1_63) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f5, __pyx_int_391479032) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f6, __pyx_float_397900984221_1357) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f7, __pyx_float_1_9) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f8, __pyx_float_1_69) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f10, __pyx_float_0_91) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f11, __pyx_float_neg_0_02) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f12, __pyx_kp_s_399106) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f14, __pyx_kp_s__15) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f15, __pyx_float_1693_48) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f16, __pyx_float_1661_57) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f17, __pyx_float_1683_87) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f18, __pyx_float_1677_68) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f20, __pyx_int_0x19b59fd426fa) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f21, __pyx_int_0x15bd71393949) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f22, __pyx_float_neg_0_04) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f24, __pyx_float_neg_2_35) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f25, __pyx_float_neg_8_63) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f62, __pyx_float_neg_10169320192_0) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_31, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 198, __pyx_L1_error)

  /* "tbstock/utils/utils.py":202
 *          "f20": 28267861255930, "f21": 23903392577865, "f22": -0.04, "f23": "-", "f24": -2.35, "f25": -8.63, "f26": "-", "f62": -10169320192.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 5734.42, "f3": -1.22, "f4": -70.98, "f5": 35394350, "f6": 82167390867.05, "f7": 2.07, "f8": 0.8, "f9": "-", "f10": 1.0,             # <<<<<<<<<<<<<<
 *          "f11": -0.04, "f12": "399004", "f13": 0, "f14": "100R", "f15": 5809.3, "f16": 5688.88, "f17": 5793.29, "f18": 5805.4,
 *          "f20": 10755119642869, "f21": 9597572050458, "f22": -0.06, "f23": "-", "f24": 1.1, "f25": 0.8, "f26": "-", "f62": -2428805376.0, "f115": "-",
 */
  __pyx_t_32 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f2, __pyx_float_5734_42) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f3, __pyx_float_neg_1_22) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f4, __pyx_float_neg_70_98) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f5, __pyx_int_35394350) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f6, __pyx_float_82167390867_05) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f7, __pyx_float_2_07) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f8, __pyx_float_0_8) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f10, __pyx_float_1_0) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f11, __pyx_float_neg_0_04) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f12, __pyx_kp_s_399004) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f14, __pyx_kp_s_100R) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f15, __pyx_float_5809_3) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f16, __pyx_float_5688_88) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f17, __pyx_float_5793_29) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f18, __pyx_float_5805_4) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f20, __pyx_int_0x9c81f15f8f5) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f21, __pyx_int_9597572050458) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f24, __pyx_float_1_1) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f25, __pyx_float_0_8) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f62, __pyx_float_neg_2428805376_0) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_32, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 202, __pyx_L1_error)

  /* "tbstock/utils/utils.py":206
 *          "f20": 10755119642869, "f21": 9597572050458, "f22": -0.06, "f23": "-", "f24": 1.1, "f25": 0.8, "f26": "-", "f62": -2428805376.0, "f115": "-",
 *          "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 3937.27, "f3": -1.06, "f4": -42.08, "f5": 83828686, "f6": 146640016315.48, "f7": 2.01, "f8": 0.99, "f9": "-", "f10": 1.01,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "399007", "f13": 0, "f14": "300", "f15": 3987.1, "f16": 3907.11, "f17": 3977.71, "f18": 3979.35,
 *          "f20": 15691174936864, "f21": 13919139135737, "f22": -0.06, "f23": "-", "f24": -0.81, "f25": -1.66, "f26": "-", "f62": -4380916480.0,
 */
  __pyx_t_33 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_33)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_33);
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f2, __pyx_float_3937_27) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f3, __pyx_float_neg_1_06) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f4, __pyx_float_neg_42_08) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f5, __pyx_int_83828686) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f6, __pyx_float_146640016315_48) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f7, __pyx_float_2_01) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f8, __pyx_float_0_99) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f10, __pyx_float_1_01) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f12, __pyx_kp_s_399007) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f14, __pyx_kp_s_300_2) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f15, __pyx_float_3987_1) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f16, __pyx_float_3907_11) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f17, __pyx_float_3977_71) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f18, __pyx_float_3979_35) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f20, __pyx_int_0xe4562e88120) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f21, __pyx_int_0xca8cd5800f9) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f24, __pyx_float_neg_0_81) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f25, __pyx_float_neg_1_66) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f62, __pyx_float_neg_4380916480_0) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_33, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 206, __pyx_L1_error)

  /* "tbstock/utils/utils.py":210
 *          "f20": 15691174936864, "f21": 13919139135737, "f22": -0.06, "f23": "-", "f24": -0.81, "f25": -1.66, "f26": "-", "f62": -4380916480.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 1139.84, "f3": -0.66, "f4": -7.58, "f5": 66238981, "f6": 81258098177.0, "f7": 1.96, "f8": 1.21, "f9": "-", "f10": 0.96,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "399008", "f13": 0, "f14": "300", "f15": 1153.16, "f16": 1130.64, "f17": 1150.35, "f18": 1147.42,
 *          "f20": 7694238899256, "f21": 6897201046540, "f22": -0.06, "f23": "-", "f24": -1.65, "f25": -6.58, "f26": "-", "f62": -2339542272.0,
 */
  __pyx_t_34 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_34)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_34);
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f2, __pyx_float_1139_84) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f3, __pyx_float_neg_0_66) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f4, __pyx_float_neg_7_58) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f5, __pyx_int_66238981) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f6, __pyx_float_81258098177_0) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f7, __pyx_float_1_96) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f8, __pyx_float_1_21) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f10, __pyx_float_0_96) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f12, __pyx_kp_s_399008) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f14, __pyx_kp_s_300_3) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f15, __pyx_float_1153_16) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f16, __pyx_float_1130_64) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f17, __pyx_float_1150_35) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f18, __pyx_float_1147_42) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f20, __pyx_int_7694238899256) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f21, __pyx_int_6897201046540) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f22, __pyx_float_neg_0_06) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f24, __pyx_float_neg_1_65) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f25, __pyx_float_neg_6_58) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f62, __pyx_float_neg_2339542272_0) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_34, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 210, __pyx_L1_error)

  /* "tbstock/utils/utils.py":214
 *          "f20": 7694238899256, "f21": 6897201046540, "f22": -0.06, "f23": "-", "f24": -1.65, "f25": -6.58, "f26": "-", "f62": -2339542272.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 3305.01, "f3": -2.42, "f4": -81.94, "f5": 7898580, "f6": 39340183896.48, "f7": 3.12, "f8": 1.21, "f9": "-", "f10": 1.0,             # <<<<<<<<<<<<<<
 *          "f11": -0.05, "f12": "399293", "f13": 0, "f14": "", "f15": 3382.54, "f16": 3276.87, "f17": 3367.67, "f18": 3386.95,
 *          "f20": 3491811426635, "f21": 2968508455751, "f22": -0.08, "f23": "-", "f24": -1.79, "f25": -4.45, "f26": "-", "f62": -2491724208.0,
 */
  __pyx_t_35 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f2, __pyx_float_3305_01) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f3, __pyx_float_neg_2_42) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f4, __pyx_float_neg_81_94) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f5, __pyx_int_7898580) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f6, __pyx_float_39340183896_48) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f7, __pyx_float_3_12) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f8, __pyx_float_1_21) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f10, __pyx_float_1_0) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f11, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f12, __pyx_kp_s_399293) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f14, __pyx_kp_s__16) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f15, __pyx_float_3382_54) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f16, __pyx_float_3276_87) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f17, __pyx_float_3367_67) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f18, __pyx_float_3386_95) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f20, __pyx_int_3491811426635) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f21, __pyx_int_2968508455751) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f22, __pyx_float_neg_0_08) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f24, __pyx_float_neg_1_79) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f25, __pyx_float_neg_4_45) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f62, __pyx_float_neg_2491724208_0) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_35, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 214, __pyx_L1_error)

  /* "tbstock/utils/utils.py":218
 *          "f20": 3491811426635, "f21": 2968508455751, "f22": -0.08, "f23": "-", "f24": -1.79, "f25": -4.45, "f26": "-", "f62": -2491724208.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 2614.69, "f3": 0.14, "f4": 3.6, "f5": 26315144, "f6": 30233745384.79, "f7": 2.52, "f8": 2.31, "f9": "-", "f10": 0.8,             # <<<<<<<<<<<<<<
 *          "f11": -0.05, "f12": "399019", "f13": 0, "f14": "200", "f15": 2650.98, "f16": 2585.19, "f17": 2631.7, "f18": 2611.09,
 *          "f20": 1436971721042, "f21": 1175767851306, "f22": -0.05, "f23": "-", "f24": -8.23, "f25": -18.48, "f26": "-", "f62": -661239776.0,
 */
  __pyx_t_36 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f2, __pyx_float_2614_69) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f3, __pyx_float_0_14) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f4, __pyx_float_3_6) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f5, __pyx_int_26315144) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f6, __pyx_float_30233745384_79) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f7, __pyx_float_2_52) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f8, __pyx_float_2_31) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f10, __pyx_float_0_8) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f11, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f12, __pyx_kp_s_399019) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f14, __pyx_kp_s_200_2) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f15, __pyx_float_2650_98) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f16, __pyx_float_2585_19) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f17, __pyx_float_2631_7) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f18, __pyx_float_2611_09) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f20, __pyx_int_1436971721042) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f21, __pyx_int_1175767851306) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f22, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f24, __pyx_float_neg_8_23) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f25, __pyx_float_neg_18_48) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f62, __pyx_float_neg_661239776_0) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_36, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 218, __pyx_L1_error)

  /* "tbstock/utils/utils.py":222
 *          "f20": 1436971721042, "f21": 1175767851306, "f22": -0.05, "f23": "-", "f24": -8.23, "f25": -18.48, "f26": "-", "f62": -661239776.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 1022.9, "f3": 1.52, "f4": 15.27, "f5": 34126920, "f6": 34325273049.37, "f7": 2.3, "f8": 3.83, "f9": "-", "f10": 0.91,             # <<<<<<<<<<<<<<
 *          "f11": 0.02, "f12": "399020", "f13": 0, "f14": "", "f15": 1031.8, "f16": 1008.59, "f17": 1018.36, "f18": 1007.63,
 *          "f20": 1110800675511, "f21": 824243981862, "f22": 0.02, "f23": "-", "f24": -9.99, "f25": -23.57, "f26": "-", "f62": -635090960.0,
 */
  __pyx_t_37 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f2, __pyx_float_1022_9) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f3, __pyx_float_1_52) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f4, __pyx_float_15_27) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f5, __pyx_int_34126920) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f6, __pyx_float_34325273049_37) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f7, __pyx_float_2_3) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f8, __pyx_float_3_83) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f10, __pyx_float_0_91) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f11, __pyx_float_0_02) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f12, __pyx_kp_s_399020) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f14, __pyx_kp_s__17) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f15, __pyx_float_1031_8) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f16, __pyx_float_1008_59) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f17, __pyx_float_1018_36) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f18, __pyx_float_1007_63) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f20, __pyx_int_1110800675511) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f21, __pyx_int_824243981862) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f22, __pyx_float_0_02) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f24, __pyx_float_neg_9_99) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f25, __pyx_float_neg_23_57) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f62, __pyx_float_neg_635090960_0) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_37, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 222, __pyx_L1_error)

  /* "tbstock/utils/utils.py":226
 *          "f20": 1110800675511, "f21": 824243981862, "f22": 0.02, "f23": "-", "f24": -9.99, "f25": -23.57, "f26": "-", "f62": -635090960.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 7912.57, "f3": 0.01, "f4": 0.9, "f5": 371100958, "f6": 390925480569.42, "f7": 1.88, "f8": 1.69, "f9": "-", "f10": 0.91,             # <<<<<<<<<<<<<<
 *          "f11": -0.02, "f12": "399100", "f13": 0, "f14": "", "f15": 7980.24, "f16": 7831.78, "f17": 7937.92, "f18": 7911.67,
 *          "f20": 27966949645491, "f21": 23636589130196, "f22": -0.04, "f23": "-", "f24": -1.96, "f25": -7.43, "f26": "-", "f62": -8801696000.0,
 */
  __pyx_t_38 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f2, __pyx_float_7912_57) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f3, __pyx_float_0_01) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f4, __pyx_float_0_9) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f5, __pyx_int_371100958) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f6, __pyx_float_390925480569_42) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f7, __pyx_float_1_88) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f8, __pyx_float_1_69) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f10, __pyx_float_0_91) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f11, __pyx_float_neg_0_02) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f12, __pyx_kp_s_399100) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f14, __pyx_kp_s__18) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f15, __pyx_float_7980_24) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f16, __pyx_float_7831_78) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f17, __pyx_float_7937_92) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f18, __pyx_float_7911_67) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f20, __pyx_int_0x196f90195cb3) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f21, __pyx_int_0x157f527fb1d4) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f22, __pyx_float_neg_0_04) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f24, __pyx_float_neg_1_96) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f25, __pyx_float_neg_7_43) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f62, __pyx_float_neg_8801696000_0) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_38, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 226, __pyx_L1_error)

  /* "tbstock/utils/utils.py":230
 *          "f20": 27966949645491, "f21": 23636589130196, "f22": -0.04, "f23": "-", "f24": -1.96, "f25": -7.43, "f26": "-", "f62": -8801696000.0,
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2},
 *         {"f1": 2, "f2": 6709.81, "f3": -0.45, "f4": -30.51, "f5": 18144804, "f6": 36121085540.7, "f7": 1.3, "f8": 0.25, "f9": "-", "f10": 1.12,             # <<<<<<<<<<<<<<
 *          "f11": -0.03, "f12": "399550", "f13": 0, "f14": "50", "f15": 6765.7, "f16": 6677.79, "f17": 6747.41, "f18": 6740.32,
 *          "f20": 10410177828194, "f21": 10333933241988, "f22": -0.05, "f23": "-", "f24": -0.69, "f25": 3.94, "f26": "-", "f62": -235770368.0,
 */
  __pyx_t_39 = __Pyx_PyDict_NewPresized(32); if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f1, __pyx_int_2) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f2, __pyx_float_6709_81) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f3, __pyx_float_neg_0_45) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f4, __pyx_float_neg_30_51) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f5, __pyx_int_18144804) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f6, __pyx_float_36121085540_7) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f7, __pyx_float_1_3) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f8, __pyx_float_0_25) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f9, __pyx_kp_s__5) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f10, __pyx_float_1_12) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f11, __pyx_float_neg_0_03) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f12, __pyx_kp_s_399550) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f13, __pyx_int_0) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f14, __pyx_kp_s_50_6) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f15, __pyx_float_6765_7) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f16, __pyx_float_6677_79) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f17, __pyx_float_6747_41) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f18, __pyx_float_6740_32) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f20, __pyx_int_0x977cef39562) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f21, __pyx_int_0x9660e6b8684) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f22, __pyx_float_neg_0_05) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f23, __pyx_kp_s__5) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f24, __pyx_float_neg_0_69) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f25, __pyx_float_3_94) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f26, __pyx_kp_s__5) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f62, __pyx_float_neg_235770368_0) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f115, __pyx_kp_s__5) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f128, __pyx_kp_s__5) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f140, __pyx_kp_s__5) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f141, __pyx_kp_s__5) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f136, __pyx_kp_s__5) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_39, __pyx_n_s_f152, __pyx_int_2) < 0) __PYX_ERR(0, 230, __pyx_L1_error)

  /* "tbstock/utils/utils.py":85
 * 
 * def getIndexCodeName() -> dict:
 *     str_dict = {"rc": 0, "rt": 6, "svr": 182994245, "lt": 1, "full": 1, "dlmkts": "", "data": {"total": 37, "diff": [             # <<<<<<<<<<<<<<
 *         {"f1": 2, "f2": 3051.28, "f3": 0.08, "f4": 2.49, "f5": 316342484, "f6": 318911097485.6, "f7": 1.11, "f8": 0.69, "f9": "-", "f10": 0.99,
 *          "f11": -0.01, "f12": "000001", "f13": 1, "f14": "", "f15": 3065.02, "f16": 3031.04, "f17": 3053.92, "f18": 3048.79,
 */
  __pyx_t_40 = PyList_New(37); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 0, __pyx_t_3)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 1, __pyx_t_4)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 2, __pyx_t_5)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 3, __pyx_t_6)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 4, __pyx_t_7)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 5, __pyx_t_8)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 6, __pyx_t_9)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 7, __pyx_t_10)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_11);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 8, __pyx_t_11)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 9, __pyx_t_12)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_13);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 10, __pyx_t_13)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_14);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 11, __pyx_t_14)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_15);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 12, __pyx_t_15)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_16);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 13, __pyx_t_16)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_17);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 14, __pyx_t_17)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_18);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 15, __pyx_t_18)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 16, __pyx_t_19)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_20);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 17, __pyx_t_20)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_21);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 18, __pyx_t_21)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_22);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 19, __pyx_t_22)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_23);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 20, __pyx_t_23)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_24);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 21, __pyx_t_24)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_25);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 22, __pyx_t_25)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_26);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 23, __pyx_t_26)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_27);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 24, __pyx_t_27)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_28);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 25, __pyx_t_28)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_29);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 26, __pyx_t_29)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_30);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 27, __pyx_t_30)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_31);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 28, __pyx_t_31)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_32);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 29, __pyx_t_32)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_33);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 30, __pyx_t_33)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_34);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 31, __pyx_t_34)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_35);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 32, __pyx_t_35)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_36);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 33, __pyx_t_36)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_37);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 34, __pyx_t_37)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_38);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 35, __pyx_t_38)) __PYX_ERR(0, 85, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_39);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_40, 36, __pyx_t_39)) __PYX_ERR(0, 85, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  __pyx_t_10 = 0;
  __pyx_t_11 = 0;
  __pyx_t_12 = 0;
  __pyx_t_13 = 0;
  __pyx_t_14 = 0;
  __pyx_t_15 = 0;
  __pyx_t_16 = 0;
  __pyx_t_17 = 0;
  __pyx_t_18 = 0;
  __pyx_t_19 = 0;
  __pyx_t_20 = 0;
  __pyx_t_21 = 0;
  __pyx_t_22 = 0;
  __pyx_t_23 = 0;
  __pyx_t_24 = 0;
  __pyx_t_25 = 0;
  __pyx_t_26 = 0;
  __pyx_t_27 = 0;
  __pyx_t_28 = 0;
  __pyx_t_29 = 0;
  __pyx_t_30 = 0;
  __pyx_t_31 = 0;
  __pyx_t_32 = 0;
  __pyx_t_33 = 0;
  __pyx_t_34 = 0;
  __pyx_t_35 = 0;
  __pyx_t_36 = 0;
  __pyx_t_37 = 0;
  __pyx_t_38 = 0;
  __pyx_t_39 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_diff, __pyx_t_40) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_data, __pyx_t_2) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_str_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":235
 *          "f115": "-", "f128": "-", "f140": "-", "f141": "-", "f136": "-", "f152": 2}]}}
 * 
 *     all_data_list = str_dict['data']['diff']             # <<<<<<<<<<<<<<
 *     all_index = {}
 *     for row in all_data_list:
 */
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_str_dict, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_diff); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_all_data_list = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":236
 * 
 *     all_data_list = str_dict['data']['diff']
 *     all_index = {}             # <<<<<<<<<<<<<<
 *     for row in all_data_list:
 *         code_ip = row['f13']
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_all_index = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":237
 *     all_data_list = str_dict['data']['diff']
 *     all_index = {}
 *     for row in all_data_list:             # <<<<<<<<<<<<<<
 *         code_ip = row['f13']
 *         index_name = row['f14']
 */
  if (likely(PyList_CheckExact(__pyx_v_all_data_list)) || PyTuple_CheckExact(__pyx_v_all_data_list)) {
    __pyx_t_2 = __pyx_v_all_data_list; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_41 = 0;
    __pyx_t_42 = NULL;
  } else {
    __pyx_t_41 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_all_data_list); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_42 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 237, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_42)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 237, __pyx_L1_error)
          #endif
          if (__pyx_t_41 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_41); __Pyx_INCREF(__pyx_t_1); __pyx_t_41++; if (unlikely((0 < 0))) __PYX_ERR(0, 237, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_41); __pyx_t_41++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 237, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 237, __pyx_L1_error)
          #endif
          if (__pyx_t_41 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_41); __Pyx_INCREF(__pyx_t_1); __pyx_t_41++; if (unlikely((0 < 0))) __PYX_ERR(0, 237, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_41); __pyx_t_41++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 237, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_42(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 237, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_row, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":238
 *     all_index = {}
 *     for row in all_data_list:
 *         code_ip = row['f13']             # <<<<<<<<<<<<<<
 *         index_name = row['f14']
 *         index_code = row['f12']
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_row, __pyx_n_s_f13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_code_ip, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":239
 *     for row in all_data_list:
 *         code_ip = row['f13']
 *         index_name = row['f14']             # <<<<<<<<<<<<<<
 *         index_code = row['f12']
 *         full_code = str(code_ip) + '.' + index_code
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_row, __pyx_n_s_f14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_index_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":240
 *         code_ip = row['f13']
 *         index_name = row['f14']
 *         index_code = row['f12']             # <<<<<<<<<<<<<<
 *         full_code = str(code_ip) + '.' + index_code
 *         all_index[full_code] = index_name
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_row, __pyx_n_s_f12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_index_code, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":241
 *         index_name = row['f14']
 *         index_code = row['f12']
 *         full_code = str(code_ip) + '.' + index_code             # <<<<<<<<<<<<<<
 *         all_index[full_code] = index_name
 *     # for key, value in all_index.items():
 */
    __pyx_t_1 = __Pyx_PyObject_Str(__pyx_v_code_ip); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_40 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__19); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_40);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_40, __pyx_v_index_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;
    __Pyx_XDECREF_SET(__pyx_v_full_code, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":242
 *         index_code = row['f12']
 *         full_code = str(code_ip) + '.' + index_code
 *         all_index[full_code] = index_name             # <<<<<<<<<<<<<<
 *     # for key, value in all_index.items():
 *     #     print(f"{key}:{value}")
 */
    if (unlikely((PyDict_SetItem(__pyx_v_all_index, __pyx_v_full_code, __pyx_v_index_name) < 0))) __PYX_ERR(0, 242, __pyx_L1_error)

    /* "tbstock/utils/utils.py":237
 *     all_data_list = str_dict['data']['diff']
 *     all_index = {}
 *     for row in all_data_list:             # <<<<<<<<<<<<<<
 *         code_ip = row['f13']
 *         index_name = row['f14']
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":245
 *     # for key, value in all_index.items():
 *     #     print(f"{key}:{value}")
 *     return all_index             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_all_index);
  __pyx_r = __pyx_v_all_index;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":84
 * 
 * 
 * def getIndexCodeName() -> dict:             # <<<<<<<<<<<<<<
 *     str_dict = {"rc": 0, "rt": 6, "svr": 182994245, "lt": 1, "full": 1, "dlmkts": "", "data": {"total": 37, "diff": [
 *         {"f1": 2, "f2": 3051.28, "f3": 0.08, "f4": 2.49, "f5": 316342484, "f6": 318911097485.6, "f7": 1.11, "f8": 0.69, "f9": "-", "f10": 0.99,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_XDECREF(__pyx_t_28);
  __Pyx_XDECREF(__pyx_t_29);
  __Pyx_XDECREF(__pyx_t_30);
  __Pyx_XDECREF(__pyx_t_31);
  __Pyx_XDECREF(__pyx_t_32);
  __Pyx_XDECREF(__pyx_t_33);
  __Pyx_XDECREF(__pyx_t_34);
  __Pyx_XDECREF(__pyx_t_35);
  __Pyx_XDECREF(__pyx_t_36);
  __Pyx_XDECREF(__pyx_t_37);
  __Pyx_XDECREF(__pyx_t_38);
  __Pyx_XDECREF(__pyx_t_39);
  __Pyx_XDECREF(__pyx_t_40);
  __Pyx_AddTraceback("tbstock.utils.utils.getIndexCodeName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_str_dict);
  __Pyx_XDECREF(__pyx_v_all_data_list);
  __Pyx_XDECREF(__pyx_v_all_index);
  __Pyx_XDECREF(__pyx_v_row);
  __Pyx_XDECREF(__pyx_v_code_ip);
  __Pyx_XDECREF(__pyx_v_index_name);
  __Pyx_XDECREF(__pyx_v_index_code);
  __Pyx_XDECREF(__pyx_v_full_code);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":248
 * 
 * 
 * def updateLib() -> bool:             # <<<<<<<<<<<<<<
 *     update_lib_succeed = True
 *     out = os.system('pip install akshare --upgrade')
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_7updateLib(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_7updateLib = {"updateLib", (PyCFunction)__pyx_pw_7tbstock_5utils_5utils_7updateLib, METH_NOARGS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_7updateLib(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("updateLib (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_6updateLib(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_6updateLib(CYTHON_UNUSED PyObject *__pyx_self) {
  int __pyx_v_update_lib_succeed;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("updateLib", 1);

  /* "tbstock/utils/utils.py":249
 * 
 * def updateLib() -> bool:
 *     update_lib_succeed = True             # <<<<<<<<<<<<<<
 *     out = os.system('pip install akshare --upgrade')
 *     if out != 0:
 */
  __pyx_v_update_lib_succeed = 1;

  /* "tbstock/utils/utils.py":250
 * def updateLib() -> bool:
 *     update_lib_succeed = True
 *     out = os.system('pip install akshare --upgrade')             # <<<<<<<<<<<<<<
 *     if out != 0:
 *         update_lib_succeed = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_system); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_s_pip_install_akshare_upgrade};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_out = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":251
 *     update_lib_succeed = True
 *     out = os.system('pip install akshare --upgrade')
 *     if out != 0:             # <<<<<<<<<<<<<<
 *         update_lib_succeed = False
 *         print('##############################akshare')
 */
  __pyx_t_5 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_out, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 251, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "tbstock/utils/utils.py":252
 *     out = os.system('pip install akshare --upgrade')
 *     if out != 0:
 *         update_lib_succeed = False             # <<<<<<<<<<<<<<
 *         print('##############################akshare')
 * 
 */
    __pyx_v_update_lib_succeed = 0;

    /* "tbstock/utils/utils.py":253
 *     if out != 0:
 *         update_lib_succeed = False
 *         print('##############################akshare')             # <<<<<<<<<<<<<<
 * 
 *     # out = os.system('pip install adata --upgrade')
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":251
 *     update_lib_succeed = True
 *     out = os.system('pip install akshare --upgrade')
 *     if out != 0:             # <<<<<<<<<<<<<<
 *         update_lib_succeed = False
 *         print('##############################akshare')
 */
  }

  /* "tbstock/utils/utils.py":260
 *     #     print('##############################adata')
 * 
 *     out = os.system('pip install baostock --upgrade')             # <<<<<<<<<<<<<<
 *     if out != 0:
 *         update_lib_succeed = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_system); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_s_pip_install_baostock_upgrade};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":261
 * 
 *     out = os.system('pip install baostock --upgrade')
 *     if out != 0:             # <<<<<<<<<<<<<<
 *         update_lib_succeed = False
 *         print('##############################baostock')
 */
  __pyx_t_5 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_out, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 261, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "tbstock/utils/utils.py":262
 *     out = os.system('pip install baostock --upgrade')
 *     if out != 0:
 *         update_lib_succeed = False             # <<<<<<<<<<<<<<
 *         print('##############################baostock')
 * 
 */
    __pyx_v_update_lib_succeed = 0;

    /* "tbstock/utils/utils.py":263
 *     if out != 0:
 *         update_lib_succeed = False
 *         print('##############################baostock')             # <<<<<<<<<<<<<<
 * 
 *     # out = os.system('pip install yfinance --upgrade --no-cache-dir')
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":261
 * 
 *     out = os.system('pip install baostock --upgrade')
 *     if out != 0:             # <<<<<<<<<<<<<<
 *         update_lib_succeed = False
 *         print('##############################baostock')
 */
  }

  /* "tbstock/utils/utils.py":270
 *     #     print('##############################yfinance')
 * 
 *     return update_lib_succeed             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_update_lib_succeed); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":248
 * 
 * 
 * def updateLib() -> bool:             # <<<<<<<<<<<<<<
 *     update_lib_succeed = True
 *     out = os.system('pip install akshare --upgrade')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("tbstock.utils.utils.updateLib", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":273
 * 
 * 
 * def is_serializable(obj):             # <<<<<<<<<<<<<<
 *     try:
 *         pickle.dumps(obj)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_9is_serializable(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_9is_serializable = {"is_serializable", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_9is_serializable, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_9is_serializable(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_serializable (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 273, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_serializable") < 0)) __PYX_ERR(0, 273, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_obj = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_serializable", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 273, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.is_serializable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_8is_serializable(__pyx_self, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_8is_serializable(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_serializable", 1);

  /* "tbstock/utils/utils.py":274
 * 
 * def is_serializable(obj):
 *     try:             # <<<<<<<<<<<<<<
 *         pickle.dumps(obj)
 *         return True
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "tbstock/utils/utils.py":275
 * def is_serializable(obj):
 *     try:
 *         pickle.dumps(obj)             # <<<<<<<<<<<<<<
 *         return True
 *     except pickle.PicklingError:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pickle); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 275, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_dumps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 275, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_obj};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 275, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "tbstock/utils/utils.py":276
 *     try:
 *         pickle.dumps(obj)
 *         return True             # <<<<<<<<<<<<<<
 *     except pickle.PicklingError:
 *         return False
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      goto __pyx_L7_try_return;

      /* "tbstock/utils/utils.py":274
 * 
 * def is_serializable(obj):
 *     try:             # <<<<<<<<<<<<<<
 *         pickle.dumps(obj)
 *         return True
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "tbstock/utils/utils.py":277
 *         pickle.dumps(obj)
 *         return True
 *     except pickle.PicklingError:             # <<<<<<<<<<<<<<
 *         return False
 *     except TypeError:
 */
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_6, &__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pickle); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 277, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_PicklingError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 277, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_6, __pyx_t_5);
    __pyx_t_4 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0;
    if (__pyx_t_10) {
      __Pyx_AddTraceback("tbstock.utils.utils.is_serializable", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(0, 277, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "tbstock/utils/utils.py":278
 *         return True
 *     except pickle.PicklingError:
 *         return False             # <<<<<<<<<<<<<<
 *     except TypeError:
 *         return False
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }

    /* "tbstock/utils/utils.py":279
 *     except pickle.PicklingError:
 *         return False
 *     except TypeError:             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
    if (__pyx_t_10) {
      __Pyx_AddTraceback("tbstock.utils.utils.is_serializable", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_5) < 0) __PYX_ERR(0, 279, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);

      /* "tbstock/utils/utils.py":280
 *         return False
 *     except TypeError:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "tbstock/utils/utils.py":274
 * 
 * def is_serializable(obj):
 *     try:             # <<<<<<<<<<<<<<
 *         pickle.dumps(obj)
 *         return True
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "tbstock/utils/utils.py":273
 * 
 * 
 * def is_serializable(obj):             # <<<<<<<<<<<<<<
 *     try:
 *         pickle.dumps(obj)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("tbstock.utils.utils.is_serializable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":283
 * 
 * 
 * def check_serializability(obj):             # <<<<<<<<<<<<<<
 *     attributes = obj.__dict__
 *     non_serializable_attrs = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_11check_serializability(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_11check_serializability = {"check_serializability", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_11check_serializability, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_11check_serializability(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_serializability (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 283, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "check_serializability") < 0)) __PYX_ERR(0, 283, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_obj = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("check_serializability", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 283, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.check_serializability", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_10check_serializability(__pyx_self, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_10check_serializability(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_v_attributes = NULL;
  PyObject *__pyx_v_non_serializable_attrs = NULL;
  PyObject *__pyx_v_attr_name = NULL;
  PyObject *__pyx_v_attr_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  unsigned int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_serializability", 1);

  /* "tbstock/utils/utils.py":284
 * 
 * def check_serializability(obj):
 *     attributes = obj.__dict__             # <<<<<<<<<<<<<<
 *     non_serializable_attrs = []
 *     for attr_name, attr_value in attributes.items():
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_attributes = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":285
 * def check_serializability(obj):
 *     attributes = obj.__dict__
 *     non_serializable_attrs = []             # <<<<<<<<<<<<<<
 *     for attr_name, attr_value in attributes.items():
 *         if not is_serializable(attr_value):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_non_serializable_attrs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":286
 *     attributes = obj.__dict__
 *     non_serializable_attrs = []
 *     for attr_name, attr_value in attributes.items():             # <<<<<<<<<<<<<<
 *         if not is_serializable(attr_value):
 *             non_serializable_attrs.append(attr_name)
 */
  __pyx_t_2 = 0;
  if (unlikely(__pyx_v_attributes == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 286, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_attributes, 0, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_attr_name, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_attr_value, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "tbstock/utils/utils.py":287
 *     non_serializable_attrs = []
 *     for attr_name, attr_value in attributes.items():
 *         if not is_serializable(attr_value):             # <<<<<<<<<<<<<<
 *             non_serializable_attrs.append(attr_name)
 *     return non_serializable_attrs
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_is_serializable); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_attr_value};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 287, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 287, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_11 = (!__pyx_t_10);
    if (__pyx_t_11) {

      /* "tbstock/utils/utils.py":288
 *     for attr_name, attr_value in attributes.items():
 *         if not is_serializable(attr_value):
 *             non_serializable_attrs.append(attr_name)             # <<<<<<<<<<<<<<
 *     return non_serializable_attrs
 * 
 */
      __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_non_serializable_attrs, __pyx_v_attr_name); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 288, __pyx_L1_error)

      /* "tbstock/utils/utils.py":287
 *     non_serializable_attrs = []
 *     for attr_name, attr_value in attributes.items():
 *         if not is_serializable(attr_value):             # <<<<<<<<<<<<<<
 *             non_serializable_attrs.append(attr_name)
 *     return non_serializable_attrs
 */
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":289
 *         if not is_serializable(attr_value):
 *             non_serializable_attrs.append(attr_name)
 *     return non_serializable_attrs             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_non_serializable_attrs);
  __pyx_r = __pyx_v_non_serializable_attrs;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":283
 * 
 * 
 * def check_serializability(obj):             # <<<<<<<<<<<<<<
 *     attributes = obj.__dict__
 *     non_serializable_attrs = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("tbstock.utils.utils.check_serializability", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_attributes);
  __Pyx_XDECREF(__pyx_v_non_serializable_attrs);
  __Pyx_XDECREF(__pyx_v_attr_name);
  __Pyx_XDECREF(__pyx_v_attr_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":292
 * 
 * 
 * def testCalendar():             # <<<<<<<<<<<<<<
 *     # date_str = '20190113'
 *     date_str = latest_trade_day
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_13testCalendar(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_13testCalendar = {"testCalendar", (PyCFunction)__pyx_pw_7tbstock_5utils_5utils_13testCalendar, METH_NOARGS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_13testCalendar(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("testCalendar (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_12testCalendar(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_12testCalendar(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_date_str = NULL;
  PyObject *__pyx_v_date = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("testCalendar", 1);

  /* "tbstock/utils/utils.py":294
 * def testCalendar():
 *     # date_str = '20190113'
 *     date_str = latest_trade_day             # <<<<<<<<<<<<<<
 *     date = pd.to_datetime(date_str)
 *     print('type next date = ', type(date))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_latest_trade_day); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_date_str = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":295
 *     # date_str = '20190113'
 *     date_str = latest_trade_day
 *     date = pd.to_datetime(date_str)             # <<<<<<<<<<<<<<
 *     print('type next date = ', type(date))
 *     # print(sh_calendar.schedule.index)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_date_str};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 295, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_date = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":296
 *     date_str = latest_trade_day
 *     date = pd.to_datetime(date_str)
 *     print('type next date = ', type(date))             # <<<<<<<<<<<<<<
 *     # print(sh_calendar.schedule.index)
 *     print(sh_calendar.sessions)
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_kp_s_type_next_date);
  __Pyx_GIVEREF(__pyx_kp_s_type_next_date);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_type_next_date)) __PYX_ERR(0, 296, __pyx_L1_error);
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_date)));
  __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_v_date)));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)Py_TYPE(__pyx_v_date)))) __PYX_ERR(0, 296, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":298
 *     print('type next date = ', type(date))
 *     # print(sh_calendar.schedule.index)
 *     print(sh_calendar.sessions)             # <<<<<<<<<<<<<<
 *     print('date_str: ', date_str)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_sessions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":299
 *     # print(sh_calendar.schedule.index)
 *     print(sh_calendar.sessions)
 *     print('date_str: ', date_str)             # <<<<<<<<<<<<<<
 * 
 *     print('is_session: ', sh_calendar.is_session(date_str))  #
 */
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_kp_s_date_str);
  __Pyx_GIVEREF(__pyx_kp_s_date_str);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_s_date_str)) __PYX_ERR(0, 299, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_date_str);
  __Pyx_GIVEREF(__pyx_v_date_str);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_date_str)) __PYX_ERR(0, 299, __pyx_L1_error);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":301
 *     print('date_str: ', date_str)
 * 
 *     print('is_session: ', sh_calendar.is_session(date_str))  #             # <<<<<<<<<<<<<<
 * 
 *     if not sh_calendar.is_session(date_str):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_is_session); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_date_str};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_kp_s_is_session_2);
  __Pyx_GIVEREF(__pyx_kp_s_is_session_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_s_is_session_2)) __PYX_ERR(0, 301, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1)) __PYX_ERR(0, 301, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":303
 *     print('is_session: ', sh_calendar.is_session(date_str))  #
 * 
 *     if not sh_calendar.is_session(date_str):             # <<<<<<<<<<<<<<
 *         date_str = sh_calendar.date_to_session(date_str, 'previous').strftime('%Y%m%d')
 *         print('new date_str: ', date_str)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_is_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_date_str};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "tbstock/utils/utils.py":304
 * 
 *     if not sh_calendar.is_session(date_str):
 *         date_str = sh_calendar.date_to_session(date_str, 'previous').strftime('%Y%m%d')             # <<<<<<<<<<<<<<
 *         print('new date_str: ', date_str)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date_to_session); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_date_str, __pyx_n_s_previous};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 304, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_strftime); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_s_Y_m_d};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 304, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_date_str, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":305
 *     if not sh_calendar.is_session(date_str):
 *         date_str = sh_calendar.date_to_session(date_str, 'previous').strftime('%Y%m%d')
 *         print('new date_str: ', date_str)             # <<<<<<<<<<<<<<
 * 
 *     print('session_open: ', sh_calendar.session_open(date_str))  #
 */
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_kp_s_new_date_str);
    __Pyx_GIVEREF(__pyx_kp_s_new_date_str);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_new_date_str)) __PYX_ERR(0, 305, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_date_str);
    __Pyx_GIVEREF(__pyx_v_date_str);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_date_str)) __PYX_ERR(0, 305, __pyx_L1_error);
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "tbstock/utils/utils.py":303
 *     print('is_session: ', sh_calendar.is_session(date_str))  #
 * 
 *     if not sh_calendar.is_session(date_str):             # <<<<<<<<<<<<<<
 *         date_str = sh_calendar.date_to_session(date_str, 'previous').strftime('%Y%m%d')
 *         print('new date_str: ', date_str)
 */
  }

  /* "tbstock/utils/utils.py":307
 *         print('new date_str: ', date_str)
 * 
 *     print('session_open: ', sh_calendar.session_open(date_str))  #             # <<<<<<<<<<<<<<
 *     print('session_close: ', sh_calendar.session_close(date_str))  #
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_session_open_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_date_str};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_kp_s_session_open);
  __Pyx_GIVEREF(__pyx_kp_s_session_open);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_s_session_open)) __PYX_ERR(0, 307, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7)) __PYX_ERR(0, 307, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_3, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "tbstock/utils/utils.py":308
 * 
 *     print('session_open: ', sh_calendar.session_open(date_str))  #
 *     print('session_close: ', sh_calendar.session_close(date_str))  #             # <<<<<<<<<<<<<<
 * 
 *     print('next_session: ', sh_calendar.next_session(date_str))  #
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_session_close_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_date_str};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_kp_s_session_close);
  __Pyx_GIVEREF(__pyx_kp_s_session_close);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_session_close)) __PYX_ERR(0, 308, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_7)) __PYX_ERR(0, 308, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "tbstock/utils/utils.py":310
 *     print('session_close: ', sh_calendar.session_close(date_str))  #
 * 
 *     print('next_session: ', sh_calendar.next_session(date_str))  #             # <<<<<<<<<<<<<<
 *     print('previous_session: ', sh_calendar.previous_session(date_str))  #
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_next_session_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_date_str};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_kp_s_next_session);
  __Pyx_GIVEREF(__pyx_kp_s_next_session);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_s_next_session)) __PYX_ERR(0, 310, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7)) __PYX_ERR(0, 310, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_3, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "tbstock/utils/utils.py":311
 * 
 *     print('next_session: ', sh_calendar.next_session(date_str))  #
 *     print('previous_session: ', sh_calendar.previous_session(date_str))  #             # <<<<<<<<<<<<<<
 * 
 *     print('session_offset: ', sh_calendar.session_offset(date_str, -5))  #
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_previous_session); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_date_str};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_kp_s_previous_session_2);
  __Pyx_GIVEREF(__pyx_kp_s_previous_session_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_previous_session_2)) __PYX_ERR(0, 311, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_7)) __PYX_ERR(0, 311, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "tbstock/utils/utils.py":313
 *     print('previous_session: ', sh_calendar.previous_session(date_str))  #
 * 
 *     print('session_offset: ', sh_calendar.session_offset(date_str, -5))  #             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_session_offset_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_date_str, __pyx_int_neg_5};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_kp_s_session_offset);
  __Pyx_GIVEREF(__pyx_kp_s_session_offset);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_s_session_offset)) __PYX_ERR(0, 313, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7)) __PYX_ERR(0, 313, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_3, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "tbstock/utils/utils.py":292
 * 
 * 
 * def testCalendar():             # <<<<<<<<<<<<<<
 *     # date_str = '20190113'
 *     date_str = latest_trade_day
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("tbstock.utils.utils.testCalendar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_date_str);
  __Pyx_XDECREF(__pyx_v_date);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":316
 * 
 * 
 * def extractAdministrativeRegions(text):             # <<<<<<<<<<<<<<
 *     #
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_15extractAdministrativeRegions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_15extractAdministrativeRegions = {"extractAdministrativeRegions", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_15extractAdministrativeRegions, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_15extractAdministrativeRegions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_text = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extractAdministrativeRegions (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_text,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_text)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 316, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "extractAdministrativeRegions") < 0)) __PYX_ERR(0, 316, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_text = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extractAdministrativeRegions", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 316, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.extractAdministrativeRegions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_14extractAdministrativeRegions(__pyx_self, __pyx_v_text);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_14extractAdministrativeRegions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_v_regions = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extractAdministrativeRegions", 1);

  /* "tbstock/utils/utils.py":319
 *     #
 *     #
 *     pattern = r'(|||||||||||||||||||||||||||||||||)'             # <<<<<<<<<<<<<<
 *     # findall
 *     regions = re.findall(pattern, text)
 */
  __Pyx_INCREF(__pyx_kp_s__22);
  __pyx_v_pattern = __pyx_kp_s__22;

  /* "tbstock/utils/utils.py":321
 *     pattern = r'(|||||||||||||||||||||||||||||||||)'
 *     # findall
 *     regions = re.findall(pattern, text)             # <<<<<<<<<<<<<<
 *     return regions
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_findall); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pattern, __pyx_v_text};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_regions = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":322
 *     # findall
 *     regions = re.findall(pattern, text)
 *     return regions             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_regions);
  __pyx_r = __pyx_v_regions;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":316
 * 
 * 
 * def extractAdministrativeRegions(text):             # <<<<<<<<<<<<<<
 *     #
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("tbstock.utils.utils.extractAdministrativeRegions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XDECREF(__pyx_v_regions);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":325
 * 
 * 
 * def startWithDigit(input_str):             # <<<<<<<<<<<<<<
 *     pattern = r'^\d'
 *     if re.match(pattern, input_str):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_17startWithDigit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_17startWithDigit = {"startWithDigit", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_17startWithDigit, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_17startWithDigit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_input_str = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("startWithDigit (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_input_str,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_input_str)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 325, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "startWithDigit") < 0)) __PYX_ERR(0, 325, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_input_str = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("startWithDigit", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 325, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.startWithDigit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_16startWithDigit(__pyx_self, __pyx_v_input_str);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_16startWithDigit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_input_str) {
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("startWithDigit", 1);

  /* "tbstock/utils/utils.py":326
 * 
 * def startWithDigit(input_str):
 *     pattern = r'^\d'             # <<<<<<<<<<<<<<
 *     if re.match(pattern, input_str):
 *         return True
 */
  __Pyx_INCREF(__pyx_kp_s_d);
  __pyx_v_pattern = __pyx_kp_s_d;

  /* "tbstock/utils/utils.py":327
 * def startWithDigit(input_str):
 *     pattern = r'^\d'
 *     if re.match(pattern, input_str):             # <<<<<<<<<<<<<<
 *         return True
 *     else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pattern, __pyx_v_input_str};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "tbstock/utils/utils.py":328
 *     pattern = r'^\d'
 *     if re.match(pattern, input_str):
 *         return True             # <<<<<<<<<<<<<<
 *     else:
 *         return False
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":327
 * def startWithDigit(input_str):
 *     pattern = r'^\d'
 *     if re.match(pattern, input_str):             # <<<<<<<<<<<<<<
 *         return True
 *     else:
 */
  }

  /* "tbstock/utils/utils.py":330
 *         return True
 *     else:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }

  /* "tbstock/utils/utils.py":325
 * 
 * 
 * def startWithDigit(input_str):             # <<<<<<<<<<<<<<
 *     pattern = r'^\d'
 *     if re.match(pattern, input_str):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("tbstock.utils.utils.startWithDigit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":333
 * 
 * 
 * def listIntersection(data_list: Union[List, None] = None, *args) -> list:             # <<<<<<<<<<<<<<
 *     '''
 *     use example:
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_19listIntersection(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_5utils_5utils_18listIntersection, "\n    use example:\n    list1 = ['1', '2', '3']\n    list2 = ['2', '3', '4', '5']\n    list3 = ['2', '5', '7', '10']\n    intersec_list = listIntersection(list1, list2, list3)\n    print(intersec_list)\n    all_list = [list1, list2, list3]\n    intersec_list = listIntersection(all_list)\n    print(intersec_list)\n    :param args:\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_19listIntersection = {"listIntersection", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_19listIntersection, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_5utils_5utils_18listIntersection};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_19listIntersection(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data_list = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("listIntersection (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data_list,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data_list);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 333, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "listIntersection") < 0)) __PYX_ERR(0, 333, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
    }
    __pyx_v_data_list = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("tbstock.utils.utils.listIntersection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_18listIntersection(__pyx_self, __pyx_v_data_list, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_18listIntersection(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data_list, PyObject *__pyx_v_args) {
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_intersection_list = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("listIntersection", 1);

  /* "tbstock/utils/utils.py":347
 *     :return:
 *     '''
 *     if not isinstance(data_list[0], list):             # <<<<<<<<<<<<<<
 *         data = list(args)
 *         data.append(data_list)
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_data_list, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_Check(__pyx_t_1); 
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "tbstock/utils/utils.py":348
 *     '''
 *     if not isinstance(data_list[0], list):
 *         data = list(args)             # <<<<<<<<<<<<<<
 *         data.append(data_list)
 *         # print(data)
 */
    __pyx_t_1 = PySequence_List(__pyx_v_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_data = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":349
 *     if not isinstance(data_list[0], list):
 *         data = list(args)
 *         data.append(data_list)             # <<<<<<<<<<<<<<
 *         # print(data)
 *     else:
 */
    __pyx_t_4 = __Pyx_PyObject_Append(__pyx_v_data, __pyx_v_data_list); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 349, __pyx_L1_error)

    /* "tbstock/utils/utils.py":347
 *     :return:
 *     '''
 *     if not isinstance(data_list[0], list):             # <<<<<<<<<<<<<<
 *         data = list(args)
 *         data.append(data_list)
 */
    goto __pyx_L3;
  }

  /* "tbstock/utils/utils.py":352
 *         # print(data)
 *     else:
 *         data = data_list             # <<<<<<<<<<<<<<
 * 
 *     intersection_list = data[0]
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_data_list);
    __pyx_v_data = __pyx_v_data_list;
  }
  __pyx_L3:;

  /* "tbstock/utils/utils.py":354
 *         data = data_list
 * 
 *     intersection_list = data[0]             # <<<<<<<<<<<<<<
 *     for arg in data:
 *         intersection_list = list(set(intersection_list) & set(arg))
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_data, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_intersection_list = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":355
 * 
 *     intersection_list = data[0]
 *     for arg in data:             # <<<<<<<<<<<<<<
 *         intersection_list = list(set(intersection_list) & set(arg))
 *     return intersection_list
 */
  if (likely(PyList_CheckExact(__pyx_v_data)) || PyTuple_CheckExact(__pyx_v_data)) {
    __pyx_t_1 = __pyx_v_data; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 355, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 355, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 355, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 355, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 355, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 355, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 355, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 355, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 355, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "tbstock/utils/utils.py":356
 *     intersection_list = data[0]
 *     for arg in data:
 *         intersection_list = list(set(intersection_list) & set(arg))             # <<<<<<<<<<<<<<
 *     return intersection_list
 * 
 */
    __pyx_t_7 = PySet_New(__pyx_v_intersection_list); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PySet_New(__pyx_v_arg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = PyNumber_And(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PySequence_List(__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF_SET(__pyx_v_intersection_list, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/utils/utils.py":355
 * 
 *     intersection_list = data[0]
 *     for arg in data:             # <<<<<<<<<<<<<<
 *         intersection_list = list(set(intersection_list) & set(arg))
 *     return intersection_list
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":357
 *     for arg in data:
 *         intersection_list = list(set(intersection_list) & set(arg))
 *     return intersection_list             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(PyList_CheckExact(__pyx_v_intersection_list))||((__pyx_v_intersection_list) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_v_intersection_list))) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_intersection_list);
  __pyx_r = ((PyObject*)__pyx_v_intersection_list);
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":333
 * 
 * 
 * def listIntersection(data_list: Union[List, None] = None, *args) -> list:             # <<<<<<<<<<<<<<
 *     '''
 *     use example:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("tbstock.utils.utils.listIntersection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_intersection_list);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":360
 * 
 * 
 * def listUnion(data_list: Union[List, None] = None, *args) -> list:             # <<<<<<<<<<<<<<
 *     '''
 *     list
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_21listUnion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_5utils_5utils_20listUnion, "\n    list \346\261\202\345\271\266\351\233\206\n    use example:\n    list1 = ['1', '2', '3']\n    list2 = ['2', '3', '4', '5']\n    list3 = ['2', '5', '7', '10']\n    union_list = listUnion(list1, list2, list3)\n    print(union_list)\n    all_list = [list1, list2, list3]\n    union_list = listUnion(all_list)\n    print(union_list)\n    :param args:\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_21listUnion = {"listUnion", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_21listUnion, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_5utils_5utils_20listUnion};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_21listUnion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data_list = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("listUnion (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data_list,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data_list);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 360, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "listUnion") < 0)) __PYX_ERR(0, 360, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
    }
    __pyx_v_data_list = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("tbstock.utils.utils.listUnion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_20listUnion(__pyx_self, __pyx_v_data_list, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_20listUnion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data_list, PyObject *__pyx_v_args) {
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_union_list = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("listUnion", 1);

  /* "tbstock/utils/utils.py":375
 *     :return:
 *     '''
 *     if not isinstance(data_list[0], list):             # <<<<<<<<<<<<<<
 *         data = list(args)
 *         data.append(data_list)
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_data_list, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_Check(__pyx_t_1); 
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "tbstock/utils/utils.py":376
 *     '''
 *     if not isinstance(data_list[0], list):
 *         data = list(args)             # <<<<<<<<<<<<<<
 *         data.append(data_list)
 *     else:
 */
    __pyx_t_1 = PySequence_List(__pyx_v_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 376, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_data = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":377
 *     if not isinstance(data_list[0], list):
 *         data = list(args)
 *         data.append(data_list)             # <<<<<<<<<<<<<<
 *     else:
 *         data = data_list
 */
    __pyx_t_4 = __Pyx_PyObject_Append(__pyx_v_data, __pyx_v_data_list); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 377, __pyx_L1_error)

    /* "tbstock/utils/utils.py":375
 *     :return:
 *     '''
 *     if not isinstance(data_list[0], list):             # <<<<<<<<<<<<<<
 *         data = list(args)
 *         data.append(data_list)
 */
    goto __pyx_L3;
  }

  /* "tbstock/utils/utils.py":379
 *         data.append(data_list)
 *     else:
 *         data = data_list             # <<<<<<<<<<<<<<
 * 
 *     union_list = []
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_data_list);
    __pyx_v_data = __pyx_v_data_list;
  }
  __pyx_L3:;

  /* "tbstock/utils/utils.py":381
 *         data = data_list
 * 
 *     union_list = []             # <<<<<<<<<<<<<<
 *     for arg in data:
 *         union_list = list(set(union_list) | set(arg))
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_union_list = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":382
 * 
 *     union_list = []
 *     for arg in data:             # <<<<<<<<<<<<<<
 *         union_list = list(set(union_list) | set(arg))
 *     return union_list
 */
  if (likely(PyList_CheckExact(__pyx_v_data)) || PyTuple_CheckExact(__pyx_v_data)) {
    __pyx_t_1 = __pyx_v_data; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 382, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 382, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 382, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 382, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 382, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 382, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 382, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 382, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "tbstock/utils/utils.py":383
 *     union_list = []
 *     for arg in data:
 *         union_list = list(set(union_list) | set(arg))             # <<<<<<<<<<<<<<
 *     return union_list
 * 
 */
    __pyx_t_7 = PySet_New(__pyx_v_union_list); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PySet_New(__pyx_v_arg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = PyNumber_Or(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PySequence_List(__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF_SET(__pyx_v_union_list, ((PyObject*)__pyx_t_8));
    __pyx_t_8 = 0;

    /* "tbstock/utils/utils.py":382
 * 
 *     union_list = []
 *     for arg in data:             # <<<<<<<<<<<<<<
 *         union_list = list(set(union_list) | set(arg))
 *     return union_list
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":384
 *     for arg in data:
 *         union_list = list(set(union_list) | set(arg))
 *     return union_list             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_union_list);
  __pyx_r = __pyx_v_union_list;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":360
 * 
 * 
 * def listUnion(data_list: Union[List, None] = None, *args) -> list:             # <<<<<<<<<<<<<<
 *     '''
 *     list
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("tbstock.utils.utils.listUnion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_union_list);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":387
 * 
 * 
 * def strategyCount(data: Union[Dict, None] = None, **kwargs) -> pd.DataFrame():             # <<<<<<<<<<<<<<
 *     '''
 *     use example:
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_23strategyCount(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_5utils_5utils_22strategyCount, "\n    use example:\n    list1 = ['1', '2', '3']\n    list2 = ['2', '3', '4', '5']\n    list3 = ['2', '5', '7', '10']\n    df = strategyCount(a=list1, b=list2, c=list3)\n    print(df)\n    :param kwargs:\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_23strategyCount = {"strategyCount", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_23strategyCount, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_5utils_5utils_22strategyCount};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_23strategyCount(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("strategyCount (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 387, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "strategyCount") < 0)) __PYX_ERR(0, 387, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_data = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("strategyCount", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 387, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("tbstock.utils.utils.strategyCount", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_22strategyCount(__pyx_self, __pyx_v_data, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_22strategyCount(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_all_list = NULL;
  PyObject *__pyx_v_strategy_name = NULL;
  PyObject *__pyx_v_strategy_code_list = NULL;
  PyObject *__pyx_v_count = NULL;
  PyObject *__pyx_v_df = NULL;
  PyObject *__pyx_v_list_2_dict = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_key = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  unsigned int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("strategyCount", 0);
  __Pyx_INCREF(__pyx_v_data);

  /* "tbstock/utils/utils.py":398
 *     :return:
 *     '''
 *     if data is None:             # <<<<<<<<<<<<<<
 *         data = kwargs
 *     elif not isinstance(data, dict):
 */
  __pyx_t_1 = (__pyx_v_data == Py_None);
  if (__pyx_t_1) {

    /* "tbstock/utils/utils.py":399
 *     '''
 *     if data is None:
 *         data = kwargs             # <<<<<<<<<<<<<<
 *     elif not isinstance(data, dict):
 *         raise ValueError("data must be a dictionary")
 */
    __Pyx_INCREF(__pyx_v_kwargs);
    __Pyx_DECREF_SET(__pyx_v_data, __pyx_v_kwargs);

    /* "tbstock/utils/utils.py":398
 *     :return:
 *     '''
 *     if data is None:             # <<<<<<<<<<<<<<
 *         data = kwargs
 *     elif not isinstance(data, dict):
 */
    goto __pyx_L3;
  }

  /* "tbstock/utils/utils.py":400
 *     if data is None:
 *         data = kwargs
 *     elif not isinstance(data, dict):             # <<<<<<<<<<<<<<
 *         raise ValueError("data must be a dictionary")
 * 
 */
  __pyx_t_1 = PyDict_Check(__pyx_v_data); 
  __pyx_t_2 = (!__pyx_t_1);
  if (unlikely(__pyx_t_2)) {

    /* "tbstock/utils/utils.py":401
 *         data = kwargs
 *     elif not isinstance(data, dict):
 *         raise ValueError("data must be a dictionary")             # <<<<<<<<<<<<<<
 * 
 *     all_list = []
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 401, __pyx_L1_error)

    /* "tbstock/utils/utils.py":400
 *     if data is None:
 *         data = kwargs
 *     elif not isinstance(data, dict):             # <<<<<<<<<<<<<<
 *         raise ValueError("data must be a dictionary")
 * 
 */
  }
  __pyx_L3:;

  /* "tbstock/utils/utils.py":403
 *         raise ValueError("data must be a dictionary")
 * 
 *     all_list = []             # <<<<<<<<<<<<<<
 *     for strategy_name, strategy_code_list in data.items():
 *         all_list = all_list + strategy_code_list
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_all_list = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":404
 * 
 *     all_list = []
 *     for strategy_name, strategy_code_list in data.items():             # <<<<<<<<<<<<<<
 *         all_list = all_list + strategy_code_list
 * 
 */
  __pyx_t_4 = 0;
  if (unlikely(__pyx_v_data == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 404, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_dict_iterator(__pyx_v_data, 0, __pyx_n_s_items, (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_3);
  __pyx_t_3 = __pyx_t_7;
  __pyx_t_7 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_3, __pyx_t_5, &__pyx_t_4, &__pyx_t_7, &__pyx_t_8, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_strategy_name, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_strategy_code_list, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/utils/utils.py":405
 *     all_list = []
 *     for strategy_name, strategy_code_list in data.items():
 *         all_list = all_list + strategy_code_list             # <<<<<<<<<<<<<<
 * 
 *     count = Counter(all_list)
 */
    __pyx_t_8 = PyNumber_Add(__pyx_v_all_list, __pyx_v_strategy_code_list); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF_SET(__pyx_v_all_list, __pyx_t_8);
    __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":407
 *         all_list = all_list + strategy_code_list
 * 
 *     count = Counter(all_list)             # <<<<<<<<<<<<<<
 *     df = pd.DataFrame(index=list(count.keys()))
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_Counter); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_all_list};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_v_count = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":408
 * 
 *     count = Counter(all_list)
 *     df = pd.DataFrame(index=list(count.keys()))             # <<<<<<<<<<<<<<
 * 
 *     for strategy_name, strategy_code_list in data.items():
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_count, __pyx_n_s_keys); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_12, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  __pyx_t_11 = __Pyx_PySequence_ListKeepNew(__pyx_t_7); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_index, __pyx_t_11) < 0) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_df = __pyx_t_11;
  __pyx_t_11 = 0;

  /* "tbstock/utils/utils.py":410
 *     df = pd.DataFrame(index=list(count.keys()))
 * 
 *     for strategy_name, strategy_code_list in data.items():             # <<<<<<<<<<<<<<
 *         list_2_dict = {key: 1 for key in strategy_code_list}
 *         df[strategy_name] = df.index.map(list_2_dict)
 */
  __pyx_t_5 = 0;
  if (unlikely(__pyx_v_data == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 410, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_data, 0, __pyx_n_s_items, (&__pyx_t_4), (&__pyx_t_6)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_11);
  __pyx_t_11 = __pyx_t_3;
  __pyx_t_3 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_11, __pyx_t_4, &__pyx_t_5, &__pyx_t_3, &__pyx_t_8, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_strategy_name, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_strategy_code_list, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/utils/utils.py":411
 * 
 *     for strategy_name, strategy_code_list in data.items():
 *         list_2_dict = {key: 1 for key in strategy_code_list}             # <<<<<<<<<<<<<<
 *         df[strategy_name] = df.index.map(list_2_dict)
 *     df['sum'] = df.index.map(count)
 */
    { /* enter inner scope */
      __pyx_t_8 = PyDict_New(); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 411, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (likely(PyList_CheckExact(__pyx_v_strategy_code_list)) || PyTuple_CheckExact(__pyx_v_strategy_code_list)) {
        __pyx_t_3 = __pyx_v_strategy_code_list; __Pyx_INCREF(__pyx_t_3);
        __pyx_t_13 = 0;
        __pyx_t_14 = NULL;
      } else {
        __pyx_t_13 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_strategy_code_list); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 411, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 411, __pyx_L10_error)
      }
      for (;;) {
        if (likely(!__pyx_t_14)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 411, __pyx_L10_error)
              #endif
              if (__pyx_t_13 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_7 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_13); __Pyx_INCREF(__pyx_t_7); __pyx_t_13++; if (unlikely((0 < 0))) __PYX_ERR(0, 411, __pyx_L10_error)
            #else
            __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 411, __pyx_L10_error)
            __Pyx_GOTREF(__pyx_t_7);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 411, __pyx_L10_error)
              #endif
              if (__pyx_t_13 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_13); __Pyx_INCREF(__pyx_t_7); __pyx_t_13++; if (unlikely((0 < 0))) __PYX_ERR(0, 411, __pyx_L10_error)
            #else
            __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 411, __pyx_L10_error)
            __Pyx_GOTREF(__pyx_t_7);
            #endif
          }
        } else {
          __pyx_t_7 = __pyx_t_14(__pyx_t_3);
          if (unlikely(!__pyx_t_7)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 411, __pyx_L10_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_key, __pyx_t_7);
        __pyx_t_7 = 0;
        if (unlikely(PyDict_SetItem(__pyx_t_8, (PyObject*)__pyx_8genexpr1__pyx_v_key, (PyObject*)__pyx_int_1))) __PYX_ERR(0, 411, __pyx_L10_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key); __pyx_8genexpr1__pyx_v_key = 0;
      goto __pyx_L14_exit_scope;
      __pyx_L10_error:;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key); __pyx_8genexpr1__pyx_v_key = 0;
      goto __pyx_L1_error;
      __pyx_L14_exit_scope:;
    } /* exit inner scope */
    __Pyx_XDECREF_SET(__pyx_v_list_2_dict, ((PyObject*)__pyx_t_8));
    __pyx_t_8 = 0;

    /* "tbstock/utils/utils.py":412
 *     for strategy_name, strategy_code_list in data.items():
 *         list_2_dict = {key: 1 for key in strategy_code_list}
 *         df[strategy_name] = df.index.map(list_2_dict)             # <<<<<<<<<<<<<<
 *     df['sum'] = df.index.map(count)
 *     df.fillna(0, inplace=True)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_map); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_list_2_dict};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 412, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_v_df, __pyx_v_strategy_name, __pyx_t_8) < 0))) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "tbstock/utils/utils.py":413
 *         list_2_dict = {key: 1 for key in strategy_code_list}
 *         df[strategy_name] = df.index.map(list_2_dict)
 *     df['sum'] = df.index.map(count)             # <<<<<<<<<<<<<<
 *     df.fillna(0, inplace=True)
 *     df.sort_values('sum', ascending=False, inplace=True)
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_index); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_map); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_count};
    __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  if (unlikely((PyObject_SetItem(__pyx_v_df, __pyx_n_s_sum, __pyx_t_11) < 0))) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "tbstock/utils/utils.py":414
 *         df[strategy_name] = df.index.map(list_2_dict)
 *     df['sum'] = df.index.map(count)
 *     df.fillna(0, inplace=True)             # <<<<<<<<<<<<<<
 *     df.sort_values('sum', ascending=False, inplace=True)
 *     return df
 */
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_fillna); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_inplace, Py_True) < 0) __PYX_ERR(0, 414, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__24, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "tbstock/utils/utils.py":415
 *     df['sum'] = df.index.map(count)
 *     df.fillna(0, inplace=True)
 *     df.sort_values('sum', ascending=False, inplace=True)             # <<<<<<<<<<<<<<
 *     return df
 * 
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_sort_values); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ascending, Py_False) < 0) __PYX_ERR(0, 415, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_inplace, Py_True) < 0) __PYX_ERR(0, 415, __pyx_L1_error)
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__25, __pyx_t_7); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "tbstock/utils/utils.py":416
 *     df.fillna(0, inplace=True)
 *     df.sort_values('sum', ascending=False, inplace=True)
 *     return df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_df);
  __pyx_r = __pyx_v_df;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":387
 * 
 * 
 * def strategyCount(data: Union[Dict, None] = None, **kwargs) -> pd.DataFrame():             # <<<<<<<<<<<<<<
 *     '''
 *     use example:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("tbstock.utils.utils.strategyCount", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_all_list);
  __Pyx_XDECREF(__pyx_v_strategy_name);
  __Pyx_XDECREF(__pyx_v_strategy_code_list);
  __Pyx_XDECREF(__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_df);
  __Pyx_XDECREF(__pyx_v_list_2_dict);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":419
 * 
 * 
 * def getFullStockCode(stock_code, mode='xx') -> str:             # <<<<<<<<<<<<<<
 *     '''
 *     # A 600 601 603 688 : 6068
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_25getFullStockCode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_5utils_5utils_24getFullStockCode, "\n    # \346\262\252\345\270\202A\350\202\241 600 601 603 688 \345\274\200\345\244\264: \344\270\273\346\235\277\344\273\24560\345\274\200\345\244\264\357\274\214\347\247\221\345\210\233\346\235\277\344\273\24568\345\274\200\345\244\264\n    # \346\267\261\345\270\202A\350\202\241 000 001 002 003 300 \345\274\200\345\244\264: \346\267\261\345\270\202\344\270\273\346\235\277\350\202\241\347\245\250\344\273\243\347\240\201\344\273\2450\345\274\200\345\244\264\357\274\214\345\210\233\344\270\232\346\235\277\350\202\241\347\245\250\344\273\243\347\240\201\344\273\2453\345\274\200\345\244\264\n    # \345\214\227\345\270\202A\350\202\241 8 \345\274\200\345\244\264: \345\214\227\344\272\244\346\211\200\344\270\212\345\270\202\345\205\254\345\217\270\357\274\214\350\202\241\347\245\250\344\273\243\347\240\201\344\273\2454\346\210\2268\345\274\200\345\244\264\n    mode = 'xx' : sz300416\n    mode = 'xx.' : sz.300416\n    mode = '.XX' : 300416.SZ\n    :param stock_code:\n    :param mode:\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_25getFullStockCode = {"getFullStockCode", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_25getFullStockCode, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_5utils_5utils_24getFullStockCode};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_25getFullStockCode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_stock_code = 0;
  PyObject *__pyx_v_mode = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getFullStockCode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_stock_code,&__pyx_n_s_mode,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_xx)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_stock_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 419, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 419, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getFullStockCode") < 0)) __PYX_ERR(0, 419, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_stock_code = values[0];
    __pyx_v_mode = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getFullStockCode", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 419, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.getFullStockCode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_24getFullStockCode(__pyx_self, __pyx_v_stock_code, __pyx_v_mode);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_24getFullStockCode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_stock_code, PyObject *__pyx_v_mode) {
  PyObject *__pyx_v_full_stock_code = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFullStockCode", 1);

  /* "tbstock/utils/utils.py":431
 *     :return:
 *     '''
 *     full_stock_code = ""             # <<<<<<<<<<<<<<
 *     if stock_code[0:2] in ["60", "68"]:
 *         full_stock_code = 'sh' + stock_code
 */
  __Pyx_INCREF(__pyx_kp_s__4);
  __pyx_v_full_stock_code = __pyx_kp_s__4;

  /* "tbstock/utils/utils.py":432
 *     '''
 *     full_stock_code = ""
 *     if stock_code[0:2] in ["60", "68"]:             # <<<<<<<<<<<<<<
 *         full_stock_code = 'sh' + stock_code
 *     elif stock_code[0:2] in ["00", "30"]:
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_stock_code, 0, 2, NULL, NULL, &__pyx_slice__26, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_60, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 432, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_68, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 432, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_2;
  if (__pyx_t_3) {

    /* "tbstock/utils/utils.py":433
 *     full_stock_code = ""
 *     if stock_code[0:2] in ["60", "68"]:
 *         full_stock_code = 'sh' + stock_code             # <<<<<<<<<<<<<<
 *     elif stock_code[0:2] in ["00", "30"]:
 *         full_stock_code = 'sz' + stock_code
 */
    __pyx_t_1 = PyNumber_Add(__pyx_n_s_sh, __pyx_v_stock_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_full_stock_code, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":432
 *     '''
 *     full_stock_code = ""
 *     if stock_code[0:2] in ["60", "68"]:             # <<<<<<<<<<<<<<
 *         full_stock_code = 'sh' + stock_code
 *     elif stock_code[0:2] in ["00", "30"]:
 */
    goto __pyx_L3;
  }

  /* "tbstock/utils/utils.py":434
 *     if stock_code[0:2] in ["60", "68"]:
 *         full_stock_code = 'sh' + stock_code
 *     elif stock_code[0:2] in ["00", "30"]:             # <<<<<<<<<<<<<<
 *         full_stock_code = 'sz' + stock_code
 *     elif stock_code[0] in ["4", "8"]:
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_stock_code, 0, 2, NULL, NULL, &__pyx_slice__26, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_00, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 434, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_3 = __pyx_t_2;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_30, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 434, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  if (__pyx_t_2) {

    /* "tbstock/utils/utils.py":435
 *         full_stock_code = 'sh' + stock_code
 *     elif stock_code[0:2] in ["00", "30"]:
 *         full_stock_code = 'sz' + stock_code             # <<<<<<<<<<<<<<
 *     elif stock_code[0] in ["4", "8"]:
 *         full_stock_code = 'bj' + stock_code
 */
    __pyx_t_1 = PyNumber_Add(__pyx_n_s_sz, __pyx_v_stock_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 435, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_full_stock_code, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":434
 *     if stock_code[0:2] in ["60", "68"]:
 *         full_stock_code = 'sh' + stock_code
 *     elif stock_code[0:2] in ["00", "30"]:             # <<<<<<<<<<<<<<
 *         full_stock_code = 'sz' + stock_code
 *     elif stock_code[0] in ["4", "8"]:
 */
    goto __pyx_L3;
  }

  /* "tbstock/utils/utils.py":436
 *     elif stock_code[0:2] in ["00", "30"]:
 *         full_stock_code = 'sz' + stock_code
 *     elif stock_code[0] in ["4", "8"]:             # <<<<<<<<<<<<<<
 *         full_stock_code = 'bj' + stock_code
 * 
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_stock_code, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_4, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 436, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_8, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 436, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L8_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_2;
  if (__pyx_t_3) {

    /* "tbstock/utils/utils.py":437
 *         full_stock_code = 'sz' + stock_code
 *     elif stock_code[0] in ["4", "8"]:
 *         full_stock_code = 'bj' + stock_code             # <<<<<<<<<<<<<<
 * 
 *     if mode == 'xx':
 */
    __pyx_t_1 = PyNumber_Add(__pyx_n_s_bj, __pyx_v_stock_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_full_stock_code, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":436
 *     elif stock_code[0:2] in ["00", "30"]:
 *         full_stock_code = 'sz' + stock_code
 *     elif stock_code[0] in ["4", "8"]:             # <<<<<<<<<<<<<<
 *         full_stock_code = 'bj' + stock_code
 * 
 */
  }
  __pyx_L3:;

  /* "tbstock/utils/utils.py":439
 *         full_stock_code = 'bj' + stock_code
 * 
 *     if mode == 'xx':             # <<<<<<<<<<<<<<
 *         pass
 *     elif mode == 'xx.':
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_xx, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 439, __pyx_L1_error)
  if (__pyx_t_3) {
    goto __pyx_L10;
  }

  /* "tbstock/utils/utils.py":441
 *     if mode == 'xx':
 *         pass
 *     elif mode == 'xx.':             # <<<<<<<<<<<<<<
 *         full_stock_code = full_stock_code[0:2] + '.' + full_stock_code[2:]
 *     elif mode == '.XX':
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_kp_s_xx_2, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 441, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "tbstock/utils/utils.py":442
 *         pass
 *     elif mode == 'xx.':
 *         full_stock_code = full_stock_code[0:2] + '.' + full_stock_code[2:]             # <<<<<<<<<<<<<<
 *     elif mode == '.XX':
 *         full_stock_code = full_stock_code[2:] + '.' + full_stock_code[0:2].upper()
 */
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_full_stock_code, 0, 2, NULL, NULL, &__pyx_slice__26, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__19); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_full_stock_code, 2, 0, NULL, NULL, &__pyx_slice__27, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_full_stock_code, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "tbstock/utils/utils.py":441
 *     if mode == 'xx':
 *         pass
 *     elif mode == 'xx.':             # <<<<<<<<<<<<<<
 *         full_stock_code = full_stock_code[0:2] + '.' + full_stock_code[2:]
 *     elif mode == '.XX':
 */
    goto __pyx_L10;
  }

  /* "tbstock/utils/utils.py":443
 *     elif mode == 'xx.':
 *         full_stock_code = full_stock_code[0:2] + '.' + full_stock_code[2:]
 *     elif mode == '.XX':             # <<<<<<<<<<<<<<
 *         full_stock_code = full_stock_code[2:] + '.' + full_stock_code[0:2].upper()
 * 
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_kp_s_XX, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 443, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "tbstock/utils/utils.py":444
 *         full_stock_code = full_stock_code[0:2] + '.' + full_stock_code[2:]
 *     elif mode == '.XX':
 *         full_stock_code = full_stock_code[2:] + '.' + full_stock_code[0:2].upper()             # <<<<<<<<<<<<<<
 * 
 *     return full_stock_code
 */
    __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_full_stock_code, 2, 0, NULL, NULL, &__pyx_slice__27, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyNumber_Add(__pyx_t_5, __pyx_kp_s__19); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_full_stock_code, 0, 2, NULL, NULL, &__pyx_slice__26, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_upper); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_full_stock_code, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "tbstock/utils/utils.py":443
 *     elif mode == 'xx.':
 *         full_stock_code = full_stock_code[0:2] + '.' + full_stock_code[2:]
 *     elif mode == '.XX':             # <<<<<<<<<<<<<<
 *         full_stock_code = full_stock_code[2:] + '.' + full_stock_code[0:2].upper()
 * 
 */
  }
  __pyx_L10:;

  /* "tbstock/utils/utils.py":446
 *         full_stock_code = full_stock_code[2:] + '.' + full_stock_code[0:2].upper()
 * 
 *     return full_stock_code             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(PyString_CheckExact(__pyx_v_full_stock_code))||((__pyx_v_full_stock_code) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_v_full_stock_code))) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_full_stock_code);
  __pyx_r = ((PyObject*)__pyx_v_full_stock_code);
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":419
 * 
 * 
 * def getFullStockCode(stock_code, mode='xx') -> str:             # <<<<<<<<<<<<<<
 *     '''
 *     # A 600 601 603 688 : 6068
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("tbstock.utils.utils.getFullStockCode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_full_stock_code);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":449
 * 
 * 
 * def isAPrimaryBoardStock(stock_code):             # <<<<<<<<<<<<<<
 *     if stock_code[0:2] in ["00", "30", "60", "68"] or stock_code[0] in ["4", "8"]:
 *         return True
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_27isAPrimaryBoardStock(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_27isAPrimaryBoardStock = {"isAPrimaryBoardStock", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_27isAPrimaryBoardStock, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_27isAPrimaryBoardStock(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_stock_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isAPrimaryBoardStock (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_stock_code,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_stock_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 449, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "isAPrimaryBoardStock") < 0)) __PYX_ERR(0, 449, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_stock_code = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("isAPrimaryBoardStock", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 449, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.isAPrimaryBoardStock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_26isAPrimaryBoardStock(__pyx_self, __pyx_v_stock_code);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_26isAPrimaryBoardStock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_stock_code) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAPrimaryBoardStock", 1);

  /* "tbstock/utils/utils.py":450
 * 
 * def isAPrimaryBoardStock(stock_code):
 *     if stock_code[0:2] in ["00", "30", "60", "68"] or stock_code[0] in ["4", "8"]:             # <<<<<<<<<<<<<<
 *         return True
 *     else:
 */
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_stock_code, 0, 2, NULL, NULL, &__pyx_slice__26, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s_00, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 450, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s_30, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 450, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s_60, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 450, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s_68, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 450, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L6_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __pyx_t_3;
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_stock_code, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s_4, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 450, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s_8, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 450, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_3;
  __pyx_L10_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "tbstock/utils/utils.py":451
 * def isAPrimaryBoardStock(stock_code):
 *     if stock_code[0:2] in ["00", "30", "60", "68"] or stock_code[0] in ["4", "8"]:
 *         return True             # <<<<<<<<<<<<<<
 *     else:
 *         return False
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":450
 * 
 * def isAPrimaryBoardStock(stock_code):
 *     if stock_code[0:2] in ["00", "30", "60", "68"] or stock_code[0] in ["4", "8"]:             # <<<<<<<<<<<<<<
 *         return True
 *     else:
 */
  }

  /* "tbstock/utils/utils.py":453
 *         return True
 *     else:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }

  /* "tbstock/utils/utils.py":449
 * 
 * 
 * def isAPrimaryBoardStock(stock_code):             # <<<<<<<<<<<<<<
 *     if stock_code[0:2] in ["00", "30", "60", "68"] or stock_code[0] in ["4", "8"]:
 *         return True
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("tbstock.utils.utils.isAPrimaryBoardStock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":456
 * 
 * 
 * def getStockLimitUp(stock_code, stock_name):             # <<<<<<<<<<<<<<
 *     '''
 *     # 15610 %
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_29getStockLimitUp(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_5utils_5utils_28getStockLimitUp, "\n    # 1\343\200\201\344\270\273\346\235\277\357\274\232\346\226\260\350\202\241\344\270\212\345\270\202\345\220\216\347\232\204\345\211\2155\344\270\252\344\272\244\346\230\223\346\227\245\344\270\215\350\256\276\344\273\267\346\240\274\346\266\250\350\267\214\345\271\205\351\231\220\345\210\266\357\274\214\347\254\2546\344\270\252\344\272\244\346\230\223\346\227\245\350\265\267\357\274\214\346\266\250\350\267\214\345\271\205\351\231\220\345\210\266\344\270\27210 %\343\200\202\n    # 2\343\200\201\345\210\233\344\270\232\346\235\277\357\274\232\346\226\260\350\202\241\344\270\212\345\270\202\345\220\216\347\232\204\345\211\2155\344\270\252\344\272\244\346\230\223\346\227\245\346\262\241\346\234\211\344\273\267\346\240\274\346\266\250\350\267\214\345\271\205\351\231\220\345\210\266\357\274\214\347\254\2546\344\270\252\344\272\244\346\230\223\346\227\245\350\265\267\357\274\214\346\266\250\350\267\214\345\271\205\351\231\220\345\210\266\344\270\27220 %\343\200\202\n    # 3\343\200\201\347\247\221\345\210\233\346\235\277\357\274\232\346\226\260\350\202\241\344\270\212\345\270\202\345\220\216\347\232\204\345\211\2155\344\270\252\344\272\244\346\230\223\346\227\245\346\262\241\346\234\211\344\273\267\346\240\274\346\266\250\350\267\214\345\271\205\351\231\220\345\210\266\357\274\214\347\254\2546\344\270\252\344\272\244\346\230\223\346\227\245\350\265\267\357\274\214\346\266\250\350\267\214\345\271\205\351\231\220\345\210\266\344\270\27220 %\343\200\202\n    # 4\343\200\201\345\214\227\344\272\244\346\211\200\357\274\232\346\226\260\350\202\241\344\270\212\345\270\202\351\246\226\346\227\245\344\270\215\350\256\276\346\266\250\350\267\214\345\271\205\351\231\220\345\210\266\357\274\214\351\246\226\346\227\245\344\271\213\345\220\216\346\266\250\350\267\214\345\271\205\351\231\220\345\210\26630 %\n    # 5\343\200\201ST\350\202\241\347\245\250\344\270\273\346\235\277\346\266\250\350\267\214\345\271\2055 %\357\274\214\347\247\221\345\210\233\346\235\277\345\210\233\344""\270\232\346\235\27720 %\n    :param stock_code:\n    :param stock_name:\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_29getStockLimitUp = {"getStockLimitUp", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_29getStockLimitUp, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_5utils_5utils_28getStockLimitUp};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_29getStockLimitUp(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_stock_code = 0;
  PyObject *__pyx_v_stock_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getStockLimitUp (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_stock_code,&__pyx_n_s_stock_name,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_stock_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 456, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_stock_name)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 456, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("getStockLimitUp", 1, 2, 2, 1); __PYX_ERR(0, 456, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getStockLimitUp") < 0)) __PYX_ERR(0, 456, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_stock_code = values[0];
    __pyx_v_stock_name = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getStockLimitUp", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 456, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.getStockLimitUp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_28getStockLimitUp(__pyx_self, __pyx_v_stock_code, __pyx_v_stock_name);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_28getStockLimitUp(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_stock_code, PyObject *__pyx_v_stock_name) {
  double __pyx_v_limit_up;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getStockLimitUp", 1);

  /* "tbstock/utils/utils.py":467
 *     :return:
 *     '''
 *     if 'ST' in stock_name and stock_code[0:2] not in ["30", "68"]:             # <<<<<<<<<<<<<<
 *         return 0.05
 * 
 */
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_ST, __pyx_v_stock_name, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 467, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_stock_code, 0, 2, NULL, NULL, &__pyx_slice__26, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s_30, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 467, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s_68, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 467, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L6_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __pyx_t_2;
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "tbstock/utils/utils.py":468
 *     '''
 *     if 'ST' in stock_name and stock_code[0:2] not in ["30", "68"]:
 *         return 0.05             # <<<<<<<<<<<<<<
 * 
 *     limit_up = 0.1
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_float_0_05);
    __pyx_r = __pyx_float_0_05;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":467
 *     :return:
 *     '''
 *     if 'ST' in stock_name and stock_code[0:2] not in ["30", "68"]:             # <<<<<<<<<<<<<<
 *         return 0.05
 * 
 */
  }

  /* "tbstock/utils/utils.py":470
 *         return 0.05
 * 
 *     limit_up = 0.1             # <<<<<<<<<<<<<<
 *     if stock_code[0:2] in ["60", "00"]:
 *         limit_up = 0.1
 */
  __pyx_v_limit_up = 0.1;

  /* "tbstock/utils/utils.py":471
 * 
 *     limit_up = 0.1
 *     if stock_code[0:2] in ["60", "00"]:             # <<<<<<<<<<<<<<
 *         limit_up = 0.1
 *     elif stock_code[0:2] in ["68", "30"]:
 */
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_stock_code, 0, 2, NULL, NULL, &__pyx_slice__26, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s_60, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 471, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s_00, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 471, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_4;
  __pyx_L9_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __pyx_t_1;
  if (__pyx_t_4) {

    /* "tbstock/utils/utils.py":472
 *     limit_up = 0.1
 *     if stock_code[0:2] in ["60", "00"]:
 *         limit_up = 0.1             # <<<<<<<<<<<<<<
 *     elif stock_code[0:2] in ["68", "30"]:
 *         limit_up = 0.2
 */
    __pyx_v_limit_up = 0.1;

    /* "tbstock/utils/utils.py":471
 * 
 *     limit_up = 0.1
 *     if stock_code[0:2] in ["60", "00"]:             # <<<<<<<<<<<<<<
 *         limit_up = 0.1
 *     elif stock_code[0:2] in ["68", "30"]:
 */
    goto __pyx_L8;
  }

  /* "tbstock/utils/utils.py":473
 *     if stock_code[0:2] in ["60", "00"]:
 *         limit_up = 0.1
 *     elif stock_code[0:2] in ["68", "30"]:             # <<<<<<<<<<<<<<
 *         limit_up = 0.2
 *     elif stock_code[0] in ["4", "8"]:
 */
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_stock_code, 0, 2, NULL, NULL, &__pyx_slice__26, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s_68, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 473, __pyx_L1_error)
  if (!__pyx_t_1) {
  } else {
    __pyx_t_4 = __pyx_t_1;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s_30, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 473, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_1;
  __pyx_L11_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_4;
  if (__pyx_t_1) {

    /* "tbstock/utils/utils.py":474
 *         limit_up = 0.1
 *     elif stock_code[0:2] in ["68", "30"]:
 *         limit_up = 0.2             # <<<<<<<<<<<<<<
 *     elif stock_code[0] in ["4", "8"]:
 *         limit_up = 0.3
 */
    __pyx_v_limit_up = 0.2;

    /* "tbstock/utils/utils.py":473
 *     if stock_code[0:2] in ["60", "00"]:
 *         limit_up = 0.1
 *     elif stock_code[0:2] in ["68", "30"]:             # <<<<<<<<<<<<<<
 *         limit_up = 0.2
 *     elif stock_code[0] in ["4", "8"]:
 */
    goto __pyx_L8;
  }

  /* "tbstock/utils/utils.py":475
 *     elif stock_code[0:2] in ["68", "30"]:
 *         limit_up = 0.2
 *     elif stock_code[0] in ["4", "8"]:             # <<<<<<<<<<<<<<
 *         limit_up = 0.3
 * 
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_stock_code, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s_4, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 475, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s_8, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 475, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_4;
  __pyx_L13_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __pyx_t_1;
  if (__pyx_t_4) {

    /* "tbstock/utils/utils.py":476
 *         limit_up = 0.2
 *     elif stock_code[0] in ["4", "8"]:
 *         limit_up = 0.3             # <<<<<<<<<<<<<<
 * 
 *     return limit_up
 */
    __pyx_v_limit_up = 0.3;

    /* "tbstock/utils/utils.py":475
 *     elif stock_code[0:2] in ["68", "30"]:
 *         limit_up = 0.2
 *     elif stock_code[0] in ["4", "8"]:             # <<<<<<<<<<<<<<
 *         limit_up = 0.3
 * 
 */
  }
  __pyx_L8:;

  /* "tbstock/utils/utils.py":478
 *         limit_up = 0.3
 * 
 *     return limit_up             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_limit_up); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":456
 * 
 * 
 * def getStockLimitUp(stock_code, stock_name):             # <<<<<<<<<<<<<<
 *     '''
 *     # 15610 %
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("tbstock.utils.utils.getStockLimitUp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":481
 * 
 * 
 * def splitDataframeByYear(data_in) -> dict:             # <<<<<<<<<<<<<<
 *     result = {}
 *     date_type = data_in['date'].dtype
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_31splitDataframeByYear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_31splitDataframeByYear = {"splitDataframeByYear", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_31splitDataframeByYear, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_31splitDataframeByYear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data_in = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("splitDataframeByYear (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data_in,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data_in)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 481, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "splitDataframeByYear") < 0)) __PYX_ERR(0, 481, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_data_in = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("splitDataframeByYear", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 481, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.splitDataframeByYear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_30splitDataframeByYear(__pyx_self, __pyx_v_data_in);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_30splitDataframeByYear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data_in) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_date_type = NULL;
  PyObject *__pyx_v_year = NULL;
  PyObject *__pyx_v_group = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("splitDataframeByYear", 1);

  /* "tbstock/utils/utils.py":482
 * 
 * def splitDataframeByYear(data_in) -> dict:
 *     result = {}             # <<<<<<<<<<<<<<
 *     date_type = data_in['date'].dtype
 *     if date_type != 'datetime64[ns]':
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":483
 * def splitDataframeByYear(data_in) -> dict:
 *     result = {}
 *     date_type = data_in['date'].dtype             # <<<<<<<<<<<<<<
 *     if date_type != 'datetime64[ns]':
 *         data_in["date"] = pd.to_datetime(data_in["date"], errors="coerce")
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_in, __pyx_n_s_date); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_date_type = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":484
 *     result = {}
 *     date_type = data_in['date'].dtype
 *     if date_type != 'datetime64[ns]':             # <<<<<<<<<<<<<<
 *         data_in["date"] = pd.to_datetime(data_in["date"], errors="coerce")
 *     for year, group in data_in.groupby(data_in['date'].dt.year):
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_date_type, __pyx_kp_s_datetime64_ns, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 484, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "tbstock/utils/utils.py":485
 *     date_type = data_in['date'].dtype
 *     if date_type != 'datetime64[ns]':
 *         data_in["date"] = pd.to_datetime(data_in["date"], errors="coerce")             # <<<<<<<<<<<<<<
 *     for year, group in data_in.groupby(data_in['date'].dt.year):
 *         result[year] = group
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_in, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 485, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 485, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely((PyObject_SetItem(__pyx_v_data_in, __pyx_n_s_date, __pyx_t_5) < 0))) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "tbstock/utils/utils.py":484
 *     result = {}
 *     date_type = data_in['date'].dtype
 *     if date_type != 'datetime64[ns]':             # <<<<<<<<<<<<<<
 *         data_in["date"] = pd.to_datetime(data_in["date"], errors="coerce")
 *     for year, group in data_in.groupby(data_in['date'].dt.year):
 */
  }

  /* "tbstock/utils/utils.py":486
 *     if date_type != 'datetime64[ns]':
 *         data_in["date"] = pd.to_datetime(data_in["date"], errors="coerce")
 *     for year, group in data_in.groupby(data_in['date'].dt.year):             # <<<<<<<<<<<<<<
 *         result[year] = group
 *     return result
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_data_in, __pyx_n_s_groupby); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_in, __pyx_n_s_date); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_dt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_year); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_4};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
    __pyx_t_2 = __pyx_t_5; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 486, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 486, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_5); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 486, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 486, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 486, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_5); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 486, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 486, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_8(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 486, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
      PyObject* sequence = __pyx_t_5;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 486, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #endif
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_9 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
      index = 0; __pyx_t_4 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_4)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_1 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_1)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 2) < 0) __PYX_ERR(0, 486, __pyx_L1_error)
      __pyx_t_10 = NULL;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_10 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 486, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_year, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_group, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":487
 *         data_in["date"] = pd.to_datetime(data_in["date"], errors="coerce")
 *     for year, group in data_in.groupby(data_in['date'].dt.year):
 *         result[year] = group             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
    if (unlikely((PyDict_SetItem(__pyx_v_result, __pyx_v_year, __pyx_v_group) < 0))) __PYX_ERR(0, 487, __pyx_L1_error)

    /* "tbstock/utils/utils.py":486
 *     if date_type != 'datetime64[ns]':
 *         data_in["date"] = pd.to_datetime(data_in["date"], errors="coerce")
 *     for year, group in data_in.groupby(data_in['date'].dt.year):             # <<<<<<<<<<<<<<
 *         result[year] = group
 *     return result
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":488
 *     for year, group in data_in.groupby(data_in['date'].dt.year):
 *         result[year] = group
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":481
 * 
 * 
 * def splitDataframeByYear(data_in) -> dict:             # <<<<<<<<<<<<<<
 *     result = {}
 *     date_type = data_in['date'].dtype
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("tbstock.utils.utils.splitDataframeByYear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_date_type);
  __Pyx_XDECREF(__pyx_v_year);
  __Pyx_XDECREF(__pyx_v_group);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":492
 * 
 * class MyEncoder(json.JSONEncoder):
 *     def default(self, obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, datetime):
 *             return obj.isoformat()
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_9MyEncoder_1default(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_9MyEncoder_1default = {"default", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_9MyEncoder_1default, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_9MyEncoder_1default(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("default (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 492, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 492, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("default", 1, 2, 2, 1); __PYX_ERR(0, 492, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "default") < 0)) __PYX_ERR(0, 492, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_obj = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("default", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 492, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.MyEncoder.default", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_9MyEncoder_default(__pyx_self, __pyx_v_self, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_9MyEncoder_default(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("default", 1);

  /* "tbstock/utils/utils.py":493
 * class MyEncoder(json.JSONEncoder):
 *     def default(self, obj):
 *         if isinstance(obj, datetime):             # <<<<<<<<<<<<<<
 *             return obj.isoformat()
 *         return super().default(obj)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "tbstock/utils/utils.py":494
 *     def default(self, obj):
 *         if isinstance(obj, datetime):
 *             return obj.isoformat()             # <<<<<<<<<<<<<<
 *         return super().default(obj)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_isoformat); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 494, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":493
 * class MyEncoder(json.JSONEncoder):
 *     def default(self, obj):
 *         if isinstance(obj, datetime):             # <<<<<<<<<<<<<<
 *             return obj.isoformat()
 *         return super().default(obj)
 */
  }

  /* "tbstock/utils/utils.py":495
 *         if isinstance(obj, datetime):
 *             return obj.isoformat()
 *         return super().default(obj)             # <<<<<<<<<<<<<<
 * 
 *     def insert_newlines(self, text, interval):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_CyFunction_GetClassObj(__pyx_self);
  if (!__pyx_t_3) { PyErr_SetString(PyExc_SystemError, "super(): empty __class__ cell"); __PYX_ERR(0, 495, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(0, 495, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self)) __PYX_ERR(0, 495, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_default); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_obj};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 495, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":492
 * 
 * class MyEncoder(json.JSONEncoder):
 *     def default(self, obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, datetime):
 *             return obj.isoformat()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("tbstock.utils.utils.MyEncoder.default", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":497
 *         return super().default(obj)
 * 
 *     def insert_newlines(self, text, interval):             # <<<<<<<<<<<<<<
 *         """
 *         intervaltext
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_9MyEncoder_3insert_newlines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_5utils_5utils_9MyEncoder_2insert_newlines, "\n        \346\257\217\351\232\224interval\344\270\252\345\255\227\347\254\246\345\234\250text\345\255\227\347\254\246\344\270\262\344\270\255\346\217\222\345\205\245\346\215\242\350\241\214\347\254\246\343\200\202\n        ");
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_9MyEncoder_3insert_newlines = {"insert_newlines", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_9MyEncoder_3insert_newlines, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_5utils_5utils_9MyEncoder_2insert_newlines};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_9MyEncoder_3insert_newlines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_interval = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("insert_newlines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_text,&__pyx_n_s_interval,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 497, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_text)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 497, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("insert_newlines", 1, 3, 3, 1); __PYX_ERR(0, 497, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_interval)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 497, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("insert_newlines", 1, 3, 3, 2); __PYX_ERR(0, 497, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "insert_newlines") < 0)) __PYX_ERR(0, 497, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_text = values[1];
    __pyx_v_interval = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("insert_newlines", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 497, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.MyEncoder.insert_newlines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_9MyEncoder_2insert_newlines(__pyx_self, __pyx_v_self, __pyx_v_text, __pyx_v_interval);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_9MyEncoder_2insert_newlines(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_interval) {
  PyObject *__pyx_v_comma_index = NULL;
  PyObject *__pyx_v_wrapped_text = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_text_tail = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("insert_newlines", 1);

  /* "tbstock/utils/utils.py":501
 *         intervaltext
 *         """
 *         if len(text) <= interval:             # <<<<<<<<<<<<<<
 *             return text  #
 * 
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_text); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 501, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_v_interval, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "tbstock/utils/utils.py":502
 *         """
 *         if len(text) <= interval:
 *             return text  #             # <<<<<<<<<<<<<<
 * 
 *         # interval
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_text);
    __pyx_r = __pyx_v_text;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":501
 *         intervaltext
 *         """
 *         if len(text) <= interval:             # <<<<<<<<<<<<<<
 *             return text  #
 * 
 */
  }

  /* "tbstock/utils/utils.py":505
 * 
 *         # interval
 *         comma_index = text.find(',', interval)             # <<<<<<<<<<<<<<
 *         if comma_index != -1 and comma_index != len(text) - 1:
 *             comma_index += 1
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_text, __pyx_n_s_find); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_kp_s__28, __pyx_v_interval};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_comma_index = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":506
 *         # interval
 *         comma_index = text.find(',', interval)
 *         if comma_index != -1 and comma_index != len(text) - 1:             # <<<<<<<<<<<<<<
 *             comma_index += 1
 *         else:
 */
  __pyx_t_7 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_comma_index, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 506, __pyx_L1_error)
  if (__pyx_t_7) {
  } else {
    __pyx_t_4 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_1 = PyObject_Length(__pyx_v_text); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 506, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t((__pyx_t_1 - 1)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_comma_index, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __pyx_t_7;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_4) {

    /* "tbstock/utils/utils.py":507
 *         comma_index = text.find(',', interval)
 *         if comma_index != -1 and comma_index != len(text) - 1:
 *             comma_index += 1             # <<<<<<<<<<<<<<
 *         else:
 *             return text
 */
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_comma_index, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_comma_index, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "tbstock/utils/utils.py":506
 *         # interval
 *         comma_index = text.find(',', interval)
 *         if comma_index != -1 and comma_index != len(text) - 1:             # <<<<<<<<<<<<<<
 *             comma_index += 1
 *         else:
 */
    goto __pyx_L4;
  }

  /* "tbstock/utils/utils.py":509
 *             comma_index += 1
 *         else:
 *             return text             # <<<<<<<<<<<<<<
 * 
 *         wrapped_text = text[:comma_index]
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_text);
    __pyx_r = __pyx_v_text;
    goto __pyx_L0;
  }
  __pyx_L4:;

  /* "tbstock/utils/utils.py":511
 *             return text
 * 
 *         wrapped_text = text[:comma_index]             # <<<<<<<<<<<<<<
 * 
 *         # indexinterval
 */
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_text, 0, 0, NULL, &__pyx_v_comma_index, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_wrapped_text = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":514
 * 
 *         # indexinterval
 *         index = comma_index             # <<<<<<<<<<<<<<
 *         while index < len(text):
 *             #
 */
  __Pyx_INCREF(__pyx_v_comma_index);
  __pyx_v_index = __pyx_v_comma_index;

  /* "tbstock/utils/utils.py":515
 *         # indexinterval
 *         index = comma_index
 *         while index < len(text):             # <<<<<<<<<<<<<<
 *             #
 *             text_tail = text[index:]
 */
  while (1) {
    __pyx_t_1 = PyObject_Length(__pyx_v_text); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 515, __pyx_L1_error)
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 515, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_index, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 515, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 515, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_4) break;

    /* "tbstock/utils/utils.py":517
 *         while index < len(text):
 *             #
 *             text_tail = text[index:]             # <<<<<<<<<<<<<<
 *             comma_index = text_tail.find(',', interval)
 *             if comma_index != -1 and comma_index != len(text_tail) - 1:
 */
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_text, 0, 0, &__pyx_v_index, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_text_tail, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "tbstock/utils/utils.py":518
 *             #
 *             text_tail = text[index:]
 *             comma_index = text_tail.find(',', interval)             # <<<<<<<<<<<<<<
 *             if comma_index != -1 and comma_index != len(text_tail) - 1:
 *                 comma_index += 1
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_text_tail, __pyx_n_s_find); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_kp_s__28, __pyx_v_interval};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 518, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_comma_index, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "tbstock/utils/utils.py":519
 *             text_tail = text[index:]
 *             comma_index = text_tail.find(',', interval)
 *             if comma_index != -1 and comma_index != len(text_tail) - 1:             # <<<<<<<<<<<<<<
 *                 comma_index += 1
 *             else:
 */
    __pyx_t_7 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_comma_index, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 519, __pyx_L1_error)
    if (__pyx_t_7) {
    } else {
      __pyx_t_4 = __pyx_t_7;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_1 = PyObject_Length(__pyx_v_text_tail); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 519, __pyx_L1_error)
    __pyx_t_3 = PyInt_FromSsize_t((__pyx_t_1 - 1)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_comma_index, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 519, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 519, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __pyx_t_7;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_4) {

      /* "tbstock/utils/utils.py":520
 *             comma_index = text_tail.find(',', interval)
 *             if comma_index != -1 and comma_index != len(text_tail) - 1:
 *                 comma_index += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 wrapped_text += '\n' + ' ' * 24 + text_tail
 */
      __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_comma_index, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 520, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_comma_index, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "tbstock/utils/utils.py":519
 *             text_tail = text[index:]
 *             comma_index = text_tail.find(',', interval)
 *             if comma_index != -1 and comma_index != len(text_tail) - 1:             # <<<<<<<<<<<<<<
 *                 comma_index += 1
 *             else:
 */
      goto __pyx_L9;
    }

    /* "tbstock/utils/utils.py":522
 *                 comma_index += 1
 *             else:
 *                 wrapped_text += '\n' + ' ' * 24 + text_tail             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_PyStr_Concat(__pyx_kp_s__29, __pyx_kp_s__30); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_text_tail); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_wrapped_text, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_wrapped_text, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "tbstock/utils/utils.py":523
 *             else:
 *                 wrapped_text += '\n' + ' ' * 24 + text_tail
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             wrapped_text += '\n' + ' ' * 24 + text_tail[:comma_index]
 */
      goto __pyx_L8_break;
    }
    __pyx_L9:;

    /* "tbstock/utils/utils.py":525
 *                 break
 * 
 *             wrapped_text += '\n' + ' ' * 24 + text_tail[:comma_index]             # <<<<<<<<<<<<<<
 *             index += comma_index
 * 
 */
    __pyx_t_2 = __Pyx_PyStr_Concat(__pyx_kp_s__29, __pyx_kp_s__30); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_text_tail, 0, 0, NULL, &__pyx_v_comma_index, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_wrapped_text, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_wrapped_text, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "tbstock/utils/utils.py":526
 * 
 *             wrapped_text += '\n' + ' ' * 24 + text_tail[:comma_index]
 *             index += comma_index             # <<<<<<<<<<<<<<
 * 
 *         return wrapped_text
 */
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_index, __pyx_v_comma_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 526, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L8_break:;

  /* "tbstock/utils/utils.py":528
 *             index += comma_index
 * 
 *         return wrapped_text             # <<<<<<<<<<<<<<
 * 
 *     def encode(self, obj):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrapped_text);
  __pyx_r = __pyx_v_wrapped_text;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":497
 *         return super().default(obj)
 * 
 *     def insert_newlines(self, text, interval):             # <<<<<<<<<<<<<<
 *         """
 *         intervaltext
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("tbstock.utils.utils.MyEncoder.insert_newlines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_comma_index);
  __Pyx_XDECREF(__pyx_v_wrapped_text);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_text_tail);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":530
 *         return wrapped_text
 * 
 *     def encode(self, obj):             # <<<<<<<<<<<<<<
 *         chunks = self.iterencode(obj, _one_shot=True)
 *         # print('chunks = ', chunks)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_9MyEncoder_5encode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_9MyEncoder_5encode = {"encode", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_9MyEncoder_5encode, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_9MyEncoder_5encode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("encode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 530, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 530, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("encode", 1, 2, 2, 1); __PYX_ERR(0, 530, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "encode") < 0)) __PYX_ERR(0, 530, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_obj = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("encode", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 530, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.MyEncoder.encode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_9MyEncoder_4encode(__pyx_self, __pyx_v_self, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_9MyEncoder_4encode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_v_chunks = NULL;
  PyObject *__pyx_v_json_str = NULL;
  PyObject *__pyx_v_list_start_idxs = NULL;
  PyObject *__pyx_v_list_end_idxs = NULL;
  PyObject *__pyx_v_num = NULL;
  PyObject *__pyx_v_list_start_idx = NULL;
  PyObject *__pyx_v_list_end_idx = NULL;
  PyObject *__pyx_v_list_str = NULL;
  PyObject *__pyx_v_cleaned_list_str = NULL;
  Py_ssize_t __pyx_8genexpr2__pyx_v_i;
  Py_ssize_t __pyx_8genexpr3__pyx_v_i;
  Py_ssize_t __pyx_8genexpr4__pyx_v_i;
  Py_ssize_t __pyx_8genexpr5__pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  unsigned int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("encode", 1);

  /* "tbstock/utils/utils.py":531
 * 
 *     def encode(self, obj):
 *         chunks = self.iterencode(obj, _one_shot=True)             # <<<<<<<<<<<<<<
 *         # print('chunks = ', chunks)
 *         if not isinstance(chunks, (list, tuple)):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_iterencode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_obj);
  __Pyx_GIVEREF(__pyx_v_obj);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_obj)) __PYX_ERR(0, 531, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_one_shot, Py_True) < 0) __PYX_ERR(0, 531, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_chunks = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "tbstock/utils/utils.py":533
 *         chunks = self.iterencode(obj, _one_shot=True)
 *         # print('chunks = ', chunks)
 *         if not isinstance(chunks, (list, tuple)):             # <<<<<<<<<<<<<<
 *             chunks = list(chunks)
 *             # print('chunks = ', chunks)
 */
  __pyx_t_6 = PyList_Check(__pyx_v_chunks); 
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = PyTuple_Check(__pyx_v_chunks); 
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "tbstock/utils/utils.py":534
 *         # print('chunks = ', chunks)
 *         if not isinstance(chunks, (list, tuple)):
 *             chunks = list(chunks)             # <<<<<<<<<<<<<<
 *             # print('chunks = ', chunks)
 * 
 */
    __pyx_t_4 = PySequence_List(__pyx_v_chunks); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_chunks, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "tbstock/utils/utils.py":533
 *         chunks = self.iterencode(obj, _one_shot=True)
 *         # print('chunks = ', chunks)
 *         if not isinstance(chunks, (list, tuple)):             # <<<<<<<<<<<<<<
 *             chunks = list(chunks)
 *             # print('chunks = ', chunks)
 */
  }

  /* "tbstock/utils/utils.py":537
 *             # print('chunks = ', chunks)
 * 
 *         json_str = ''.join(chunks)             # <<<<<<<<<<<<<<
 * 
 *         #
 */
  __pyx_t_4 = __Pyx_PyString_Join(__pyx_kp_s__4, __pyx_v_chunks); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_json_str = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "tbstock/utils/utils.py":540
 * 
 *         #
 *         list_start_idxs = [i for i in range(len(json_str)) if json_str[i] == '[']             # <<<<<<<<<<<<<<
 *         list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']
 * 
 */
  { /* enter inner scope */
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyObject_Length(__pyx_v_json_str); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 540, __pyx_L1_error)
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_8genexpr2__pyx_v_i = __pyx_t_9;
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_json_str, __pyx_8genexpr2__pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s__31, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 540, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_8genexpr2__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 540, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_4, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 540, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
    }
  } /* exit inner scope */
  __pyx_v_list_start_idxs = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "tbstock/utils/utils.py":541
 *         #
 *         list_start_idxs = [i for i in range(len(json_str)) if json_str[i] == '[']
 *         list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']             # <<<<<<<<<<<<<<
 * 
 *         if not list_start_idxs or not list_start_idxs:
 */
  { /* enter inner scope */
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 541, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyObject_Length(__pyx_v_json_str); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 541, __pyx_L1_error)
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_8genexpr3__pyx_v_i = __pyx_t_9;
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_json_str, __pyx_8genexpr3__pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 541, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s__32, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 541, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_8genexpr3__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 541, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_4, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 541, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
    }
  } /* exit inner scope */
  __pyx_v_list_end_idxs = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "tbstock/utils/utils.py":543
 *         list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']
 * 
 *         if not list_start_idxs or not list_start_idxs:             # <<<<<<<<<<<<<<
 *             return json_str
 * 
 */
  __pyx_t_5 = (PyList_GET_SIZE(__pyx_v_list_start_idxs) != 0);
  __pyx_t_10 = (!__pyx_t_5);
  if (!__pyx_t_10) {
  } else {
    __pyx_t_6 = __pyx_t_10;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_10 = (PyList_GET_SIZE(__pyx_v_list_start_idxs) != 0);
  __pyx_t_5 = (!__pyx_t_10);
  __pyx_t_6 = __pyx_t_5;
  __pyx_L13_bool_binop_done:;
  if (__pyx_t_6) {

    /* "tbstock/utils/utils.py":544
 * 
 *         if not list_start_idxs or not list_start_idxs:
 *             return json_str             # <<<<<<<<<<<<<<
 * 
 *         #
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_json_str);
    __pyx_r = __pyx_v_json_str;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":543
 *         list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']
 * 
 *         if not list_start_idxs or not list_start_idxs:             # <<<<<<<<<<<<<<
 *             return json_str
 * 
 */
  }

  /* "tbstock/utils/utils.py":547
 * 
 *         #
 *         num = 0             # <<<<<<<<<<<<<<
 *         list_start_idx = list_start_idxs[num]
 *         list_end_idx = list_end_idxs[num]
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_num = __pyx_int_0;

  /* "tbstock/utils/utils.py":548
 *         #
 *         num = 0
 *         list_start_idx = list_start_idxs[num]             # <<<<<<<<<<<<<<
 *         list_end_idx = list_end_idxs[num]
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_list_start_idxs, __pyx_v_num); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_list_start_idx = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "tbstock/utils/utils.py":549
 *         num = 0
 *         list_start_idx = list_start_idxs[num]
 *         list_end_idx = list_end_idxs[num]             # <<<<<<<<<<<<<<
 * 
 *         while list_start_idx != -1 and list_end_idx != -1:
 */
  __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_list_end_idxs, __pyx_v_num); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_list_end_idx = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "tbstock/utils/utils.py":551
 *         list_end_idx = list_end_idxs[num]
 * 
 *         while list_start_idx != -1 and list_end_idx != -1:             # <<<<<<<<<<<<<<
 *             # print('list_start_idx = ', list_start_idx)
 *             # print('list_end_idx = ', list_end_idx)
 */
  while (1) {
    __pyx_t_5 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_list_start_idx, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 551, __pyx_L1_error)
    if (__pyx_t_5) {
    } else {
      __pyx_t_6 = __pyx_t_5;
      goto __pyx_L17_bool_binop_done;
    }
    __pyx_t_5 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_list_end_idx, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 551, __pyx_L1_error)
    __pyx_t_6 = __pyx_t_5;
    __pyx_L17_bool_binop_done:;
    if (!__pyx_t_6) break;

    /* "tbstock/utils/utils.py":555
 *             # print('list_end_idx = ', list_end_idx)
 *             #
 *             list_str = json_str[list_start_idx:list_end_idx + 1]             # <<<<<<<<<<<<<<
 *             # print('list_str = ', repr(list_str))
 * 
 */
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_list_end_idx, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_json_str, 0, 0, &__pyx_v_list_start_idx, &__pyx_t_4, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_list_str, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "tbstock/utils/utils.py":559
 * 
 *             # '\n'
 *             cleaned_list_str = list_str.replace(',\n', ',').replace('\n', '')             # <<<<<<<<<<<<<<
 *             cleaned_list_str = re.sub(r'\s+', ' ', cleaned_list_str)
 *             cleaned_list_str = self.insert_newlines(cleaned_list_str, 300)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_list_str, __pyx_n_s_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__35, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_cleaned_list_str, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "tbstock/utils/utils.py":560
 *             # '\n'
 *             cleaned_list_str = list_str.replace(',\n', ',').replace('\n', '')
 *             cleaned_list_str = re.sub(r'\s+', ' ', cleaned_list_str)             # <<<<<<<<<<<<<<
 *             cleaned_list_str = self.insert_newlines(cleaned_list_str, 300)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 560, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_sub); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 560, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_11 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_11 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_kp_s_s, __pyx_kp_s__36, __pyx_v_cleaned_list_str};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_11, 3+__pyx_t_11);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_cleaned_list_str, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "tbstock/utils/utils.py":561
 *             cleaned_list_str = list_str.replace(',\n', ',').replace('\n', '')
 *             cleaned_list_str = re.sub(r'\s+', ' ', cleaned_list_str)
 *             cleaned_list_str = self.insert_newlines(cleaned_list_str, 300)             # <<<<<<<<<<<<<<
 * 
 *             #
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_insert_newlines); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_11 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_11 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_cleaned_list_str, __pyx_int_300};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_11, 2+__pyx_t_11);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_cleaned_list_str, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "tbstock/utils/utils.py":565
 *             #
 *             json_str = (
 *                     json_str[:list_start_idx] + cleaned_list_str + json_str[list_end_idx + 1:]             # <<<<<<<<<<<<<<
 *             )
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_json_str, 0, 0, NULL, &__pyx_v_list_start_idx, NULL, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_v_cleaned_list_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_list_end_idx, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_json_str, 0, 0, &__pyx_t_4, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_json_str, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "tbstock/utils/utils.py":569
 * 
 *             #
 *             num += 1             # <<<<<<<<<<<<<<
 *             list_start_idxs = [i for i in range(len(json_str)) if json_str[i] == '[']
 *             list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']
 */
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_num, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_num, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "tbstock/utils/utils.py":570
 *             #
 *             num += 1
 *             list_start_idxs = [i for i in range(len(json_str)) if json_str[i] == '[']             # <<<<<<<<<<<<<<
 *             list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']
 *             if num >= len(list_end_idxs) or num >= len(list_start_idxs):
 */
    { /* enter inner scope */
      __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = PyObject_Length(__pyx_v_json_str); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 570, __pyx_L1_error)
      __pyx_t_8 = __pyx_t_7;
      for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
        __pyx_8genexpr4__pyx_v_i = __pyx_t_9;
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_json_str, __pyx_8genexpr4__pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 570, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s__31, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 570, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_6) {
          __pyx_t_3 = PyInt_FromSsize_t(__pyx_8genexpr4__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 570, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_4, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 570, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
      }
    } /* exit inner scope */
    __Pyx_DECREF_SET(__pyx_v_list_start_idxs, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "tbstock/utils/utils.py":571
 *             num += 1
 *             list_start_idxs = [i for i in range(len(json_str)) if json_str[i] == '[']
 *             list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']             # <<<<<<<<<<<<<<
 *             if num >= len(list_end_idxs) or num >= len(list_start_idxs):
 *                 break
 */
    { /* enter inner scope */
      __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = PyObject_Length(__pyx_v_json_str); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 571, __pyx_L1_error)
      __pyx_t_8 = __pyx_t_7;
      for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
        __pyx_8genexpr5__pyx_v_i = __pyx_t_9;
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_json_str, __pyx_8genexpr5__pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 571, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_kp_s__32, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 571, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_6) {
          __pyx_t_3 = PyInt_FromSsize_t(__pyx_8genexpr5__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 571, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_4, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 571, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
      }
    } /* exit inner scope */
    __Pyx_DECREF_SET(__pyx_v_list_end_idxs, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "tbstock/utils/utils.py":572
 *             list_start_idxs = [i for i in range(len(json_str)) if json_str[i] == '[']
 *             list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']
 *             if num >= len(list_end_idxs) or num >= len(list_start_idxs):             # <<<<<<<<<<<<<<
 *                 break
 *             else:
 */
    __pyx_t_7 = __Pyx_PyList_GET_SIZE(__pyx_v_list_end_idxs); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 572, __pyx_L1_error)
    __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_num, __pyx_t_4, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_5) {
    } else {
      __pyx_t_6 = __pyx_t_5;
      goto __pyx_L26_bool_binop_done;
    }
    __pyx_t_7 = __Pyx_PyList_GET_SIZE(__pyx_v_list_start_idxs); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 572, __pyx_L1_error)
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_num, __pyx_t_3, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = __pyx_t_5;
    __pyx_L26_bool_binop_done:;
    if (__pyx_t_6) {

      /* "tbstock/utils/utils.py":573
 *             list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']
 *             if num >= len(list_end_idxs) or num >= len(list_start_idxs):
 *                 break             # <<<<<<<<<<<<<<
 *             else:
 *                 list_start_idx = list_start_idxs[num]
 */
      goto __pyx_L16_break;

      /* "tbstock/utils/utils.py":572
 *             list_start_idxs = [i for i in range(len(json_str)) if json_str[i] == '[']
 *             list_end_idxs = [i for i in range(len(json_str)) if json_str[i] == ']']
 *             if num >= len(list_end_idxs) or num >= len(list_start_idxs):             # <<<<<<<<<<<<<<
 *                 break
 *             else:
 */
    }

    /* "tbstock/utils/utils.py":575
 *                 break
 *             else:
 *                 list_start_idx = list_start_idxs[num]             # <<<<<<<<<<<<<<
 *                 list_end_idx = list_end_idxs[num]
 *         return json_str
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_list_start_idxs, __pyx_v_num); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 575, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_list_start_idx, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "tbstock/utils/utils.py":576
 *             else:
 *                 list_start_idx = list_start_idxs[num]
 *                 list_end_idx = list_end_idxs[num]             # <<<<<<<<<<<<<<
 *         return json_str
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_list_end_idxs, __pyx_v_num); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 576, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_list_end_idx, __pyx_t_4);
      __pyx_t_4 = 0;
    }
  }
  __pyx_L16_break:;

  /* "tbstock/utils/utils.py":577
 *                 list_start_idx = list_start_idxs[num]
 *                 list_end_idx = list_end_idxs[num]
 *         return json_str             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_json_str);
  __pyx_r = __pyx_v_json_str;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":530
 *         return wrapped_text
 * 
 *     def encode(self, obj):             # <<<<<<<<<<<<<<
 *         chunks = self.iterencode(obj, _one_shot=True)
 *         # print('chunks = ', chunks)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("tbstock.utils.utils.MyEncoder.encode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_chunks);
  __Pyx_XDECREF(__pyx_v_json_str);
  __Pyx_XDECREF(__pyx_v_list_start_idxs);
  __Pyx_XDECREF(__pyx_v_list_end_idxs);
  __Pyx_XDECREF(__pyx_v_num);
  __Pyx_XDECREF(__pyx_v_list_start_idx);
  __Pyx_XDECREF(__pyx_v_list_end_idx);
  __Pyx_XDECREF(__pyx_v_list_str);
  __Pyx_XDECREF(__pyx_v_cleaned_list_str);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":580
 * 
 * 
 * def loadJsonData(load_json_file, json_file_name=''):             # <<<<<<<<<<<<<<
 *     update_json = {}
 *     try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_33loadJsonData(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_33loadJsonData = {"loadJsonData", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_33loadJsonData, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_33loadJsonData(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_load_json_file = 0;
  PyObject *__pyx_v_json_file_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("loadJsonData (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_load_json_file,&__pyx_n_s_json_file_name,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_s__4)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_load_json_file)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 580, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_json_file_name);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 580, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "loadJsonData") < 0)) __PYX_ERR(0, 580, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_load_json_file = values[0];
    __pyx_v_json_file_name = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("loadJsonData", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 580, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.loadJsonData", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_32loadJsonData(__pyx_self, __pyx_v_load_json_file, __pyx_v_json_file_name);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_32loadJsonData(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_load_json_file, PyObject *__pyx_v_json_file_name) {
  PyObject *__pyx_v_update_json = NULL;
  PyObject *__pyx_v_file = NULL;
  int __pyx_v_has_update_file;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  Py_UCS4 __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("loadJsonData", 1);

  /* "tbstock/utils/utils.py":581
 * 
 * def loadJsonData(load_json_file, json_file_name=''):
 *     update_json = {}             # <<<<<<<<<<<<<<
 *     try:
 *         file = open(load_json_file, 'r', encoding='utf-8')
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_update_json = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":582
 * def loadJsonData(load_json_file, json_file_name=''):
 *     update_json = {}
 *     try:             # <<<<<<<<<<<<<<
 *         file = open(load_json_file, 'r', encoding='utf-8')
 *         update_json = json.load(file)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "tbstock/utils/utils.py":583
 *     update_json = {}
 *     try:
 *         file = open(load_json_file, 'r', encoding='utf-8')             # <<<<<<<<<<<<<<
 *         update_json = json.load(file)
 *         has_update_file = True
 */
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 583, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_load_json_file);
      __Pyx_GIVEREF(__pyx_v_load_json_file);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_load_json_file)) __PYX_ERR(0, 583, __pyx_L3_error);
      __Pyx_INCREF(__pyx_n_s_r);
      __Pyx_GIVEREF(__pyx_n_s_r);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_r)) __PYX_ERR(0, 583, __pyx_L3_error);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 583, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_encoding, __pyx_kp_s_utf_8) < 0) __PYX_ERR(0, 583, __pyx_L3_error)
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_open, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 583, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_file = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "tbstock/utils/utils.py":584
 *     try:
 *         file = open(load_json_file, 'r', encoding='utf-8')
 *         update_json = json.load(file)             # <<<<<<<<<<<<<<
 *         has_update_file = True
 *     except IOError:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 584, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_load); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_file};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 584, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_update_json, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "tbstock/utils/utils.py":585
 *         file = open(load_json_file, 'r', encoding='utf-8')
 *         update_json = json.load(file)
 *         has_update_file = True             # <<<<<<<<<<<<<<
 *     except IOError:
 *         logger.error(f'Json file {json_file_name} not found.')
 */
      __pyx_v_has_update_file = 1;

      /* "tbstock/utils/utils.py":582
 * def loadJsonData(load_json_file, json_file_name=''):
 *     update_json = {}
 *     try:             # <<<<<<<<<<<<<<
 *         file = open(load_json_file, 'r', encoding='utf-8')
 *         update_json = json.load(file)
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "tbstock/utils/utils.py":586
 *         update_json = json.load(file)
 *         has_update_file = True
 *     except IOError:             # <<<<<<<<<<<<<<
 *         logger.error(f'Json file {json_file_name} not found.')
 *         has_update_file = False
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IOError);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("tbstock.utils.utils.loadJsonData", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_5) < 0) __PYX_ERR(0, 586, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_5);

      /* "tbstock/utils/utils.py":587
 *         has_update_file = True
 *     except IOError:
 *         logger.error(f'Json file {json_file_name} not found.')             # <<<<<<<<<<<<<<
 *         has_update_file = False
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_logger); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 587, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_error); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 587, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 587, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_12 = 0;
      __pyx_t_13 = 127;
      __Pyx_INCREF(__pyx_kp_u_Json_file);
      __pyx_t_12 += 10;
      __Pyx_GIVEREF(__pyx_kp_u_Json_file);
      PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_kp_u_Json_file);
      __pyx_t_14 = __Pyx_PyObject_FormatSimple(__pyx_v_json_file_name, __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 587, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_13;
      __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u_not_found);
      __pyx_t_12 += 11;
      __Pyx_GIVEREF(__pyx_kp_u_not_found);
      PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_kp_u_not_found);
      __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_10, 3, __pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 587, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_14};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 587, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "tbstock/utils/utils.py":588
 *     except IOError:
 *         logger.error(f'Json file {json_file_name} not found.')
 *         has_update_file = False             # <<<<<<<<<<<<<<
 * 
 *     return has_update_file, update_json
 */
      __pyx_v_has_update_file = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "tbstock/utils/utils.py":582
 * def loadJsonData(load_json_file, json_file_name=''):
 *     update_json = {}
 *     try:             # <<<<<<<<<<<<<<
 *         file = open(load_json_file, 'r', encoding='utf-8')
 *         update_json = json.load(file)
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_L8_try_end:;
  }

  /* "tbstock/utils/utils.py":590
 *         has_update_file = False
 * 
 *     return has_update_file, update_json             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_has_update_file); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5)) __PYX_ERR(0, 590, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_update_json);
  __Pyx_GIVEREF(__pyx_v_update_json);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_update_json)) __PYX_ERR(0, 590, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":580
 * 
 * 
 * def loadJsonData(load_json_file, json_file_name=''):             # <<<<<<<<<<<<<<
 *     update_json = {}
 *     try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("tbstock.utils.utils.loadJsonData", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_update_json);
  __Pyx_XDECREF(__pyx_v_file);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":593
 * 
 * 
 * def dumpJsonToFile(load_json_file, update_json, json_file_name='', use_cls=True):             # <<<<<<<<<<<<<<
 *     #  JSON
 *     try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_35dumpJsonToFile(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_35dumpJsonToFile = {"dumpJsonToFile", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_35dumpJsonToFile, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_35dumpJsonToFile(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_load_json_file = 0;
  PyObject *__pyx_v_update_json = 0;
  PyObject *__pyx_v_json_file_name = 0;
  PyObject *__pyx_v_use_cls = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dumpJsonToFile (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_load_json_file,&__pyx_n_s_update_json,&__pyx_n_s_json_file_name,&__pyx_n_s_use_cls,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_s__4)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_load_json_file)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 593, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_update_json)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 593, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("dumpJsonToFile", 0, 2, 4, 1); __PYX_ERR(0, 593, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_json_file_name);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 593, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_cls);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 593, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dumpJsonToFile") < 0)) __PYX_ERR(0, 593, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_load_json_file = values[0];
    __pyx_v_update_json = values[1];
    __pyx_v_json_file_name = values[2];
    __pyx_v_use_cls = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dumpJsonToFile", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 593, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.dumpJsonToFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_34dumpJsonToFile(__pyx_self, __pyx_v_load_json_file, __pyx_v_update_json, __pyx_v_json_file_name, __pyx_v_use_cls);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_34dumpJsonToFile(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_load_json_file, PyObject *__pyx_v_update_json, PyObject *__pyx_v_json_file_name, PyObject *__pyx_v_use_cls) {
  PyObject *__pyx_v_json_string = NULL;
  PyObject *__pyx_v_write_f = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  unsigned int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  int __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  Py_ssize_t __pyx_t_19;
  Py_UCS4 __pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dumpJsonToFile", 1);

  /* "tbstock/utils/utils.py":595
 * def dumpJsonToFile(load_json_file, update_json, json_file_name='', use_cls=True):
 *     #  JSON
 *     try:             # <<<<<<<<<<<<<<
 *         # with open(load_json_file, 'w', encoding='utf-8') as file:
 *         #     json.dump(update_json, file, ensure_ascii=False)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "tbstock/utils/utils.py":598
 *         # with open(load_json_file, 'w', encoding='utf-8') as file:
 *         #     json.dump(update_json, file, ensure_ascii=False)
 *         if use_cls:             # <<<<<<<<<<<<<<
 *             json_string = json.dumps(update_json, cls=MyEncoder, indent=4, ensure_ascii=False)
 *         else:
 */
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_use_cls); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 598, __pyx_L3_error)
      if (__pyx_t_4) {

        /* "tbstock/utils/utils.py":599
 *         #     json.dump(update_json, file, ensure_ascii=False)
 *         if use_cls:
 *             json_string = json.dumps(update_json, cls=MyEncoder, indent=4, ensure_ascii=False)             # <<<<<<<<<<<<<<
 *         else:
 *             json_string = json.dumps(update_json, indent=4, ensure_ascii=False)
 */
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 599, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_dumps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 599, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 599, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_update_json);
        __Pyx_GIVEREF(__pyx_v_update_json);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_update_json)) __PYX_ERR(0, 599, __pyx_L3_error);
        __pyx_t_7 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 599, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_MyEncoder); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 599, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_cls, __pyx_t_8) < 0) __PYX_ERR(0, 599, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_indent, __pyx_int_4) < 0) __PYX_ERR(0, 599, __pyx_L3_error)
        if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ensure_ascii, Py_False) < 0) __PYX_ERR(0, 599, __pyx_L3_error)
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 599, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_v_json_string = __pyx_t_8;
        __pyx_t_8 = 0;

        /* "tbstock/utils/utils.py":598
 *         # with open(load_json_file, 'w', encoding='utf-8') as file:
 *         #     json.dump(update_json, file, ensure_ascii=False)
 *         if use_cls:             # <<<<<<<<<<<<<<
 *             json_string = json.dumps(update_json, cls=MyEncoder, indent=4, ensure_ascii=False)
 *         else:
 */
        goto __pyx_L9;
      }

      /* "tbstock/utils/utils.py":601
 *             json_string = json.dumps(update_json, cls=MyEncoder, indent=4, ensure_ascii=False)
 *         else:
 *             json_string = json.dumps(update_json, indent=4, ensure_ascii=False)             # <<<<<<<<<<<<<<
 *         with open(load_json_file, 'w', encoding='utf-8') as write_f:
 *             write_f.write(json_string)
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_json); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 601, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_dumps); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 601, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 601, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_update_json);
        __Pyx_GIVEREF(__pyx_v_update_json);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_update_json)) __PYX_ERR(0, 601, __pyx_L3_error);
        __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 601, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_indent, __pyx_int_4) < 0) __PYX_ERR(0, 601, __pyx_L3_error)
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_ensure_ascii, Py_False) < 0) __PYX_ERR(0, 601, __pyx_L3_error)
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 601, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_v_json_string = __pyx_t_6;
        __pyx_t_6 = 0;
      }
      __pyx_L9:;

      /* "tbstock/utils/utils.py":602
 *         else:
 *             json_string = json.dumps(update_json, indent=4, ensure_ascii=False)
 *         with open(load_json_file, 'w', encoding='utf-8') as write_f:             # <<<<<<<<<<<<<<
 *             write_f.write(json_string)
 * 
 */
      /*with:*/ {
        __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 602, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_v_load_json_file);
        __Pyx_GIVEREF(__pyx_v_load_json_file);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_load_json_file)) __PYX_ERR(0, 602, __pyx_L3_error);
        __Pyx_INCREF(__pyx_n_s_w);
        __Pyx_GIVEREF(__pyx_n_s_w);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_n_s_w)) __PYX_ERR(0, 602, __pyx_L3_error);
        __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 602, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_encoding, __pyx_kp_s_utf_8) < 0) __PYX_ERR(0, 602, __pyx_L3_error)
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_open, __pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 602, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_9 = __Pyx_PyObject_LookupSpecial(__pyx_t_8, __pyx_n_s_exit); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 602, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_8, __pyx_n_s_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 602, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 602, __pyx_L10_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __pyx_t_6 = __pyx_t_5;
        __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        /*try:*/ {
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_11);
            __Pyx_XGOTREF(__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_13);
            /*try:*/ {
              __pyx_v_write_f = __pyx_t_6;
              __pyx_t_6 = 0;

              /* "tbstock/utils/utils.py":603
 *             json_string = json.dumps(update_json, indent=4, ensure_ascii=False)
 *         with open(load_json_file, 'w', encoding='utf-8') as write_f:
 *             write_f.write(json_string)             # <<<<<<<<<<<<<<
 * 
 *     except IOError:
 */
              __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_write_f, __pyx_n_s_write); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 603, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_8);
              __pyx_t_5 = NULL;
              __pyx_t_10 = 0;
              #if CYTHON_UNPACK_METHODS
              if (likely(PyMethod_Check(__pyx_t_8))) {
                __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
                if (likely(__pyx_t_5)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                  __Pyx_INCREF(__pyx_t_5);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_8, function);
                  __pyx_t_10 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_json_string};
                __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 603, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_6);
                __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              }
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

              /* "tbstock/utils/utils.py":602
 *         else:
 *             json_string = json.dumps(update_json, indent=4, ensure_ascii=False)
 *         with open(load_json_file, 'w', encoding='utf-8') as write_f:             # <<<<<<<<<<<<<<
 *             write_f.write(json_string)
 * 
 */
            }
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            goto __pyx_L19_try_end;
            __pyx_L14_error:;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            /*except:*/ {
              __Pyx_AddTraceback("tbstock.utils.utils.dumpJsonToFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 602, __pyx_L16_except_error)
              __Pyx_XGOTREF(__pyx_t_6);
              __Pyx_XGOTREF(__pyx_t_8);
              __Pyx_XGOTREF(__pyx_t_5);
              __pyx_t_7 = PyTuple_Pack(3, __pyx_t_6, __pyx_t_8, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 602, __pyx_L16_except_error)
              __Pyx_GOTREF(__pyx_t_7);
              __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_7, NULL);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 602, __pyx_L16_except_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (__pyx_t_4 < 0) __PYX_ERR(0, 602, __pyx_L16_except_error)
              __pyx_t_15 = (!__pyx_t_4);
              if (unlikely(__pyx_t_15)) {
                __Pyx_GIVEREF(__pyx_t_6);
                __Pyx_GIVEREF(__pyx_t_8);
                __Pyx_XGIVEREF(__pyx_t_5);
                __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_8, __pyx_t_5);
                __pyx_t_6 = 0; __pyx_t_8 = 0; __pyx_t_5 = 0; 
                __PYX_ERR(0, 602, __pyx_L16_except_error)
              }
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              goto __pyx_L15_exception_handled;
            }
            __pyx_L16_except_error:;
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
            goto __pyx_L3_error;
            __pyx_L15_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
            __pyx_L19_try_end:;
          }
        }
        /*finally:*/ {
          /*normal exit:*/{
            if (__pyx_t_9) {
              __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__37, NULL);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 602, __pyx_L3_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
            goto __pyx_L13;
          }
          __pyx_L13:;
        }
        goto __pyx_L23;
        __pyx_L10_error:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L3_error;
        __pyx_L23:;
      }

      /* "tbstock/utils/utils.py":595
 * def dumpJsonToFile(load_json_file, update_json, json_file_name='', use_cls=True):
 *     #  JSON
 *     try:             # <<<<<<<<<<<<<<
 *         # with open(load_json_file, 'w', encoding='utf-8') as file:
 *         #     json.dump(update_json, file, ensure_ascii=False)
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "tbstock/utils/utils.py":605
 *             write_f.write(json_string)
 * 
 *     except IOError:             # <<<<<<<<<<<<<<
 *         logger.error(f'Open json file {json_file_name} failed.')
 * 
 */
    __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IOError);
    if (__pyx_t_16) {
      __Pyx_AddTraceback("tbstock.utils.utils.dumpJsonToFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_8, &__pyx_t_6) < 0) __PYX_ERR(0, 605, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "tbstock/utils/utils.py":606
 * 
 *     except IOError:
 *         logger.error(f'Open json file {json_file_name} failed.')             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_logger); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 606, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_error); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 606, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_18);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = PyTuple_New(3); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 606, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_19 = 0;
      __pyx_t_20 = 127;
      __Pyx_INCREF(__pyx_kp_u_Open_json_file);
      __pyx_t_19 += 15;
      __Pyx_GIVEREF(__pyx_kp_u_Open_json_file);
      PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_kp_u_Open_json_file);
      __pyx_t_21 = __Pyx_PyObject_FormatSimple(__pyx_v_json_file_name, __pyx_empty_unicode); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 606, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_21);
      __pyx_t_20 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_21) > __pyx_t_20) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_21) : __pyx_t_20;
      __pyx_t_19 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_21);
      __Pyx_GIVEREF(__pyx_t_21);
      PyTuple_SET_ITEM(__pyx_t_17, 1, __pyx_t_21);
      __pyx_t_21 = 0;
      __Pyx_INCREF(__pyx_kp_u_failed);
      __pyx_t_19 += 8;
      __Pyx_GIVEREF(__pyx_kp_u_failed);
      PyTuple_SET_ITEM(__pyx_t_17, 2, __pyx_kp_u_failed);
      __pyx_t_21 = __Pyx_PyUnicode_Join(__pyx_t_17, 3, __pyx_t_19, __pyx_t_20); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 606, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_18))) {
        __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_18);
        if (likely(__pyx_t_17)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_18, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_17, __pyx_t_21};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_18, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 606, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "tbstock/utils/utils.py":595
 * def dumpJsonToFile(load_json_file, update_json, json_file_name='', use_cls=True):
 *     #  JSON
 *     try:             # <<<<<<<<<<<<<<
 *         # with open(load_json_file, 'w', encoding='utf-8') as file:
 *         #     json.dump(update_json, file, ensure_ascii=False)
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "tbstock/utils/utils.py":593
 * 
 * 
 * def dumpJsonToFile(load_json_file, update_json, json_file_name='', use_cls=True):             # <<<<<<<<<<<<<<
 *     #  JSON
 *     try:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_AddTraceback("tbstock.utils.utils.dumpJsonToFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_json_string);
  __Pyx_XDECREF(__pyx_v_write_f);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":609
 * 
 * 
 * def getYearStartEndDate(year_str: str, mode='trade'):             # <<<<<<<<<<<<<<
 *     '''
 *     mode = 'trade'
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_37getYearStartEndDate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_5utils_5utils_36getYearStartEndDate, "\n    mode = 'trade'\357\274\232\350\277\224\345\233\236\344\270\200\345\271\264\347\232\204\345\274\200\345\247\213\345\222\214\347\273\223\346\235\237\346\227\245\346\234\237\n    mode = ''\357\274\232\350\277\224\345\233\236\344\270\200\345\271\264\347\232\204\345\274\200\345\247\213\345\222\214\347\273\223\346\235\237\346\227\245\346\234\237\n    ");
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_37getYearStartEndDate = {"getYearStartEndDate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_37getYearStartEndDate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_5utils_5utils_36getYearStartEndDate};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_37getYearStartEndDate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_year_str = 0;
  PyObject *__pyx_v_mode = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getYearStartEndDate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_year_str,&__pyx_n_s_mode,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_trade)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_year_str)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 609, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 609, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getYearStartEndDate") < 0)) __PYX_ERR(0, 609, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_year_str = ((PyObject*)values[0]);
    __pyx_v_mode = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getYearStartEndDate", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 609, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.getYearStartEndDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_year_str), (&PyString_Type), 0, "year_str", 1))) __PYX_ERR(0, 609, __pyx_L1_error)
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_36getYearStartEndDate(__pyx_self, __pyx_v_year_str, __pyx_v_mode);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_36getYearStartEndDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_year_str, PyObject *__pyx_v_mode) {
  PyObject *__pyx_v_year_start = NULL;
  PyObject *__pyx_v_year_int = NULL;
  PyObject *__pyx_v_year_end = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getYearStartEndDate", 1);

  /* "tbstock/utils/utils.py":614
 *     mode = ''
 *     '''
 *     year_start = year_str + '0101'             # <<<<<<<<<<<<<<
 *     year_start = datetime.strptime(year_start, '%Y%m%d')
 *     year_int = int(year_str)
 */
  __pyx_t_1 = __Pyx_PyStr_Concat(__pyx_v_year_str, __pyx_kp_s_0101); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_year_start = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":615
 *     '''
 *     year_start = year_str + '0101'
 *     year_start = datetime.strptime(year_start, '%Y%m%d')             # <<<<<<<<<<<<<<
 *     year_int = int(year_str)
 *     year_end = datetime(year_int, 12, calendar.monthrange(year_int, 12)[1])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strptime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_year_start, __pyx_kp_s_Y_m_d};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_year_start, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":616
 *     year_start = year_str + '0101'
 *     year_start = datetime.strptime(year_start, '%Y%m%d')
 *     year_int = int(year_str)             # <<<<<<<<<<<<<<
 *     year_end = datetime(year_int, 12, calendar.monthrange(year_int, 12)[1])
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_year_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_year_int = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":617
 *     year_start = datetime.strptime(year_start, '%Y%m%d')
 *     year_int = int(year_str)
 *     year_end = datetime(year_int, 12, calendar.monthrange(year_int, 12)[1])             # <<<<<<<<<<<<<<
 * 
 *     if mode == 'trade':
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_datetime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_calendar); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_monthrange); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_year_int, __pyx_int_12};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 617, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_2, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_year_int, __pyx_int_12, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 617, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_year_end = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":619
 *     year_end = datetime(year_int, 12, calendar.monthrange(year_int, 12)[1])
 * 
 *     if mode == 'trade':             # <<<<<<<<<<<<<<
 *         if not sh_calendar.is_session(year_start):  #
 *             year_start = sh_calendar.date_to_session(year_start, 'next')
 */
  __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_trade, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 619, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "tbstock/utils/utils.py":620
 * 
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(year_start):  #             # <<<<<<<<<<<<<<
 *             year_start = sh_calendar.date_to_session(year_start, 'next')
 *         if not sh_calendar.is_session(year_end):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_is_session); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_year_start};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 620, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = (!__pyx_t_7);
    if (__pyx_t_8) {

      /* "tbstock/utils/utils.py":621
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(year_start):  #
 *             year_start = sh_calendar.date_to_session(year_start, 'next')             # <<<<<<<<<<<<<<
 *         if not sh_calendar.is_session(year_end):
 *             year_end = sh_calendar.date_to_session(year_end, 'previous')
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 621, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_date_to_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 621, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_year_start, __pyx_n_s_next};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_year_start, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "tbstock/utils/utils.py":620
 * 
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(year_start):  #             # <<<<<<<<<<<<<<
 *             year_start = sh_calendar.date_to_session(year_start, 'next')
 *         if not sh_calendar.is_session(year_end):
 */
    }

    /* "tbstock/utils/utils.py":622
 *         if not sh_calendar.is_session(year_start):  #
 *             year_start = sh_calendar.date_to_session(year_start, 'next')
 *         if not sh_calendar.is_session(year_end):             # <<<<<<<<<<<<<<
 *             year_end = sh_calendar.date_to_session(year_end, 'previous')
 *     return year_start, year_end
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_is_session); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_year_end};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 622, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 622, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = (!__pyx_t_8);
    if (__pyx_t_7) {

      /* "tbstock/utils/utils.py":623
 *             year_start = sh_calendar.date_to_session(year_start, 'next')
 *         if not sh_calendar.is_session(year_end):
 *             year_end = sh_calendar.date_to_session(year_end, 'previous')             # <<<<<<<<<<<<<<
 *     return year_start, year_end
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_date_to_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_year_end, __pyx_n_s_previous};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_year_end, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "tbstock/utils/utils.py":622
 *         if not sh_calendar.is_session(year_start):  #
 *             year_start = sh_calendar.date_to_session(year_start, 'next')
 *         if not sh_calendar.is_session(year_end):             # <<<<<<<<<<<<<<
 *             year_end = sh_calendar.date_to_session(year_end, 'previous')
 *     return year_start, year_end
 */
    }

    /* "tbstock/utils/utils.py":619
 *     year_end = datetime(year_int, 12, calendar.monthrange(year_int, 12)[1])
 * 
 *     if mode == 'trade':             # <<<<<<<<<<<<<<
 *         if not sh_calendar.is_session(year_start):  #
 *             year_start = sh_calendar.date_to_session(year_start, 'next')
 */
  }

  /* "tbstock/utils/utils.py":624
 *         if not sh_calendar.is_session(year_end):
 *             year_end = sh_calendar.date_to_session(year_end, 'previous')
 *     return year_start, year_end             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_year_start);
  __Pyx_GIVEREF(__pyx_v_year_start);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_year_start)) __PYX_ERR(0, 624, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_year_end);
  __Pyx_GIVEREF(__pyx_v_year_end);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_year_end)) __PYX_ERR(0, 624, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":609
 * 
 * 
 * def getYearStartEndDate(year_str: str, mode='trade'):             # <<<<<<<<<<<<<<
 *     '''
 *     mode = 'trade'
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("tbstock.utils.utils.getYearStartEndDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_year_start);
  __Pyx_XDECREF(__pyx_v_year_int);
  __Pyx_XDECREF(__pyx_v_year_end);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":627
 * 
 * 
 * def getDateDistribution(start_date: datetime, end_date: datetime):             # <<<<<<<<<<<<<<
 *     result = {}
 *     current_date = start_date
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_39getDateDistribution(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_39getDateDistribution = {"getDateDistribution", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_39getDateDistribution, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_39getDateDistribution(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_start_date = 0;
  PyObject *__pyx_v_end_date = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDateDistribution (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_start_date,&__pyx_n_s_end_date,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_start_date)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 627, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_end_date)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 627, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("getDateDistribution", 1, 2, 2, 1); __PYX_ERR(0, 627, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getDateDistribution") < 0)) __PYX_ERR(0, 627, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_start_date = values[0];
    __pyx_v_end_date = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getDateDistribution", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 627, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.getDateDistribution", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_38getDateDistribution(__pyx_self, __pyx_v_start_date, __pyx_v_end_date);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_38getDateDistribution(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_start_date, PyObject *__pyx_v_end_date) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_current_date = NULL;
  PyObject *__pyx_v_year = NULL;
  PyObject *__pyx_v_month12_days = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDateDistribution", 1);

  /* "tbstock/utils/utils.py":628
 * 
 * def getDateDistribution(start_date: datetime, end_date: datetime):
 *     result = {}             # <<<<<<<<<<<<<<
 *     current_date = start_date
 *     while current_date <= end_date:
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":629
 * def getDateDistribution(start_date: datetime, end_date: datetime):
 *     result = {}
 *     current_date = start_date             # <<<<<<<<<<<<<<
 *     while current_date <= end_date:
 *         year = current_date.year
 */
  __Pyx_INCREF(__pyx_v_start_date);
  __pyx_v_current_date = __pyx_v_start_date;

  /* "tbstock/utils/utils.py":630
 *     result = {}
 *     current_date = start_date
 *     while current_date <= end_date:             # <<<<<<<<<<<<<<
 *         year = current_date.year
 *         if year not in result:
 */
  while (1) {
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_current_date, __pyx_v_end_date, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 630, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 630, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_2) break;

    /* "tbstock/utils/utils.py":631
 *     current_date = start_date
 *     while current_date <= end_date:
 *         year = current_date.year             # <<<<<<<<<<<<<<
 *         if year not in result:
 *             result[year] = [current_date]
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_current_date, __pyx_n_s_year); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_year, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "tbstock/utils/utils.py":632
 *     while current_date <= end_date:
 *         year = current_date.year
 *         if year not in result:             # <<<<<<<<<<<<<<
 *             result[year] = [current_date]
 *         month12_days = calendar.monthrange(year, 12)[1]
 */
    __pyx_t_2 = (__Pyx_PyDict_ContainsTF(__pyx_v_year, __pyx_v_result, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 632, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "tbstock/utils/utils.py":633
 *         year = current_date.year
 *         if year not in result:
 *             result[year] = [current_date]             # <<<<<<<<<<<<<<
 *         month12_days = calendar.monthrange(year, 12)[1]
 *         result[year].append(min(current_date.replace(year=year, month=12, day=month12_days), end_date))
 */
      __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_current_date);
      __Pyx_GIVEREF(__pyx_v_current_date);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_current_date)) __PYX_ERR(0, 633, __pyx_L1_error);
      if (unlikely((PyDict_SetItem(__pyx_v_result, __pyx_v_year, __pyx_t_1) < 0))) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "tbstock/utils/utils.py":632
 *     while current_date <= end_date:
 *         year = current_date.year
 *         if year not in result:             # <<<<<<<<<<<<<<
 *             result[year] = [current_date]
 *         month12_days = calendar.monthrange(year, 12)[1]
 */
    }

    /* "tbstock/utils/utils.py":634
 *         if year not in result:
 *             result[year] = [current_date]
 *         month12_days = calendar.monthrange(year, 12)[1]             # <<<<<<<<<<<<<<
 *         result[year].append(min(current_date.replace(year=year, month=12, day=month12_days), end_date))
 *         current_date = current_date.replace(year=current_date.year + 1, month=1, day=1)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_monthrange); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_year, __pyx_int_12};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 634, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_month12_days, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "tbstock/utils/utils.py":635
 *             result[year] = [current_date]
 *         month12_days = calendar.monthrange(year, 12)[1]
 *         result[year].append(min(current_date.replace(year=year, month=12, day=month12_days), end_date))             # <<<<<<<<<<<<<<
 *         current_date = current_date.replace(year=current_date.year + 1, month=1, day=1)
 *     return result
 */
    __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_result, __pyx_v_year); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_end_date);
    __pyx_t_1 = __pyx_v_end_date;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_current_date, __pyx_n_s_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_year, __pyx_v_year) < 0) __PYX_ERR(0, 635, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_month, __pyx_int_12) < 0) __PYX_ERR(0, 635, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_day, __pyx_v_month12_days) < 0) __PYX_ERR(0, 635, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_7, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 635, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_6 = __pyx_t_1;
    } else {
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_6 = __pyx_t_7;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = __Pyx_PyObject_Append(__pyx_t_4, __pyx_t_6); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "tbstock/utils/utils.py":636
 *         month12_days = calendar.monthrange(year, 12)[1]
 *         result[year].append(min(current_date.replace(year=year, month=12, day=month12_days), end_date))
 *         current_date = current_date.replace(year=current_date.year + 1, month=1, day=1)             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_current_date, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_current_date, __pyx_n_s_year); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_year, __pyx_t_7) < 0) __PYX_ERR(0, 636, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_month, __pyx_int_1) < 0) __PYX_ERR(0, 636, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_day, __pyx_int_1) < 0) __PYX_ERR(0, 636, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_current_date, __pyx_t_7);
    __pyx_t_7 = 0;
  }

  /* "tbstock/utils/utils.py":637
 *         result[year].append(min(current_date.replace(year=year, month=12, day=month12_days), end_date))
 *         current_date = current_date.replace(year=current_date.year + 1, month=1, day=1)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":627
 * 
 * 
 * def getDateDistribution(start_date: datetime, end_date: datetime):             # <<<<<<<<<<<<<<
 *     result = {}
 *     current_date = start_date
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("tbstock.utils.utils.getDateDistribution", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_current_date);
  __Pyx_XDECREF(__pyx_v_year);
  __Pyx_XDECREF(__pyx_v_month12_days);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":640
 * 
 * 
 * def getMonthStartEndDate(year_str: str, month_str: str, mode='trade'):             # <<<<<<<<<<<<<<
 *     # calendar.monthrange
 *     year = int(year_str)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_41getMonthStartEndDate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_41getMonthStartEndDate = {"getMonthStartEndDate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_41getMonthStartEndDate, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_41getMonthStartEndDate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_year_str = 0;
  PyObject *__pyx_v_month_str = 0;
  PyObject *__pyx_v_mode = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getMonthStartEndDate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_year_str,&__pyx_n_s_month_str,&__pyx_n_s_mode,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_trade)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_year_str)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_month_str)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("getMonthStartEndDate", 0, 2, 3, 1); __PYX_ERR(0, 640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getMonthStartEndDate") < 0)) __PYX_ERR(0, 640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_year_str = ((PyObject*)values[0]);
    __pyx_v_month_str = ((PyObject*)values[1]);
    __pyx_v_mode = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getMonthStartEndDate", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.getMonthStartEndDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_year_str), (&PyString_Type), 0, "year_str", 1))) __PYX_ERR(0, 640, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_month_str), (&PyString_Type), 0, "month_str", 1))) __PYX_ERR(0, 640, __pyx_L1_error)
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_40getMonthStartEndDate(__pyx_self, __pyx_v_year_str, __pyx_v_month_str, __pyx_v_mode);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_40getMonthStartEndDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_year_str, PyObject *__pyx_v_month_str, PyObject *__pyx_v_mode) {
  PyObject *__pyx_v_year = NULL;
  PyObject *__pyx_v_month = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_first_weekday = NULL;
  PyObject *__pyx_v_number_of_days = NULL;
  PyObject *__pyx_v_start_date = NULL;
  PyObject *__pyx_v_end_date = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  Py_ssize_t __pyx_t_7;
  Py_UCS4 __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getMonthStartEndDate", 1);

  /* "tbstock/utils/utils.py":642
 * def getMonthStartEndDate(year_str: str, month_str: str, mode='trade'):
 *     # calendar.monthrange
 *     year = int(year_str)             # <<<<<<<<<<<<<<
 *     month = int(month_str)
 *     first_weekday, number_of_days = calendar.monthrange(year, month)
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_year_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_year = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":643
 *     # calendar.monthrange
 *     year = int(year_str)
 *     month = int(month_str)             # <<<<<<<<<<<<<<
 *     first_weekday, number_of_days = calendar.monthrange(year, month)
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_month_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_month = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":644
 *     year = int(year_str)
 *     month = int(month_str)
 *     first_weekday, number_of_days = calendar.monthrange(year, month)             # <<<<<<<<<<<<<<
 * 
 *     #
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_monthrange); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_year, __pyx_v_month};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 644, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 644, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 644, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_first_weekday = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_number_of_days = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":647
 * 
 *     #
 *     start_date = f"{year}{month:02d}01"             # <<<<<<<<<<<<<<
 *     start_date = datetime.strptime(start_date, '%Y%m%d')
 *     end_date = f"{year}{month:02d}{number_of_days:02d}"
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = 0;
  __pyx_t_8 = 127;
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_year, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_8;
  __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Format(__pyx_v_month, __pyx_kp_u_02d); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_8;
  __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_kp_u_01);
  __pyx_t_7 += 2;
  __Pyx_GIVEREF(__pyx_kp_u_01);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_01);
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_start_date = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":648
 *     #
 *     start_date = f"{year}{month:02d}01"
 *     start_date = datetime.strptime(start_date, '%Y%m%d')             # <<<<<<<<<<<<<<
 *     end_date = f"{year}{month:02d}{number_of_days:02d}"
 *     end_date = datetime.strptime(end_date, '%Y%m%d')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_strptime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_start_date, __pyx_kp_s_Y_m_d};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_start_date, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":649
 *     start_date = f"{year}{month:02d}01"
 *     start_date = datetime.strptime(start_date, '%Y%m%d')
 *     end_date = f"{year}{month:02d}{number_of_days:02d}"             # <<<<<<<<<<<<<<
 *     end_date = datetime.strptime(end_date, '%Y%m%d')
 * 
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = 0;
  __pyx_t_8 = 127;
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_year, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_8;
  __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Format(__pyx_v_month, __pyx_kp_u_02d); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_8;
  __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Format(__pyx_v_number_of_days, __pyx_kp_u_02d); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_8;
  __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_end_date = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":650
 *     start_date = datetime.strptime(start_date, '%Y%m%d')
 *     end_date = f"{year}{month:02d}{number_of_days:02d}"
 *     end_date = datetime.strptime(end_date, '%Y%m%d')             # <<<<<<<<<<<<<<
 * 
 *     if mode == 'trade':
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strptime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_end_date, __pyx_kp_s_Y_m_d};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 650, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_end_date, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":652
 *     end_date = datetime.strptime(end_date, '%Y%m%d')
 * 
 *     if mode == 'trade':             # <<<<<<<<<<<<<<
 *         if not sh_calendar.is_session(start_date):  #
 *             start_date = sh_calendar.date_to_session(start_date, 'next')
 */
  __pyx_t_9 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_trade, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 652, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "tbstock/utils/utils.py":653
 * 
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(start_date):  #             # <<<<<<<<<<<<<<
 *             start_date = sh_calendar.date_to_session(start_date, 'next')
 *         if not sh_calendar.is_session(end_date):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_is_session); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_start_date};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 653, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_10 = (!__pyx_t_9);
    if (__pyx_t_10) {

      /* "tbstock/utils/utils.py":654
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(start_date):  #
 *             start_date = sh_calendar.date_to_session(start_date, 'next')             # <<<<<<<<<<<<<<
 *         if not sh_calendar.is_session(end_date):
 *             end_date = sh_calendar.date_to_session(end_date, 'previous')
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date_to_session); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_start_date, __pyx_n_s_next};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 654, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_start_date, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "tbstock/utils/utils.py":653
 * 
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(start_date):  #             # <<<<<<<<<<<<<<
 *             start_date = sh_calendar.date_to_session(start_date, 'next')
 *         if not sh_calendar.is_session(end_date):
 */
    }

    /* "tbstock/utils/utils.py":655
 *         if not sh_calendar.is_session(start_date):  #
 *             start_date = sh_calendar.date_to_session(start_date, 'next')
 *         if not sh_calendar.is_session(end_date):             # <<<<<<<<<<<<<<
 *             end_date = sh_calendar.date_to_session(end_date, 'previous')
 *     return start_date, end_date
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_is_session); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_end_date};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 655, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = (!__pyx_t_10);
    if (__pyx_t_9) {

      /* "tbstock/utils/utils.py":656
 *             start_date = sh_calendar.date_to_session(start_date, 'next')
 *         if not sh_calendar.is_session(end_date):
 *             end_date = sh_calendar.date_to_session(end_date, 'previous')             # <<<<<<<<<<<<<<
 *     return start_date, end_date
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date_to_session); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_end_date, __pyx_n_s_previous};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 656, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_end_date, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "tbstock/utils/utils.py":655
 *         if not sh_calendar.is_session(start_date):  #
 *             start_date = sh_calendar.date_to_session(start_date, 'next')
 *         if not sh_calendar.is_session(end_date):             # <<<<<<<<<<<<<<
 *             end_date = sh_calendar.date_to_session(end_date, 'previous')
 *     return start_date, end_date
 */
    }

    /* "tbstock/utils/utils.py":652
 *     end_date = datetime.strptime(end_date, '%Y%m%d')
 * 
 *     if mode == 'trade':             # <<<<<<<<<<<<<<
 *         if not sh_calendar.is_session(start_date):  #
 *             start_date = sh_calendar.date_to_session(start_date, 'next')
 */
  }

  /* "tbstock/utils/utils.py":657
 *         if not sh_calendar.is_session(end_date):
 *             end_date = sh_calendar.date_to_session(end_date, 'previous')
 *     return start_date, end_date             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_start_date);
  __Pyx_GIVEREF(__pyx_v_start_date);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_start_date)) __PYX_ERR(0, 657, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_end_date);
  __Pyx_GIVEREF(__pyx_v_end_date);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_end_date)) __PYX_ERR(0, 657, __pyx_L1_error);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":640
 * 
 * 
 * def getMonthStartEndDate(year_str: str, month_str: str, mode='trade'):             # <<<<<<<<<<<<<<
 *     # calendar.monthrange
 *     year = int(year_str)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("tbstock.utils.utils.getMonthStartEndDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_year);
  __Pyx_XDECREF(__pyx_v_month);
  __Pyx_XDECREF(__pyx_v_first_weekday);
  __Pyx_XDECREF(__pyx_v_number_of_days);
  __Pyx_XDECREF(__pyx_v_start_date);
  __Pyx_XDECREF(__pyx_v_end_date);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":660
 * 
 * 
 * def getSuspendedStocks() -> list:             # <<<<<<<<<<<<<<
 *     stock_tfp_em_df = ak.stock_tfp_em(date=latest_trade_day)
 *     suspended_stock_list = list(stock_tfp_em_df[''])
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_43getSuspendedStocks(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_43getSuspendedStocks = {"getSuspendedStocks", (PyCFunction)__pyx_pw_7tbstock_5utils_5utils_43getSuspendedStocks, METH_NOARGS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_43getSuspendedStocks(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSuspendedStocks (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_42getSuspendedStocks(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_42getSuspendedStocks(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_stock_tfp_em_df = NULL;
  PyObject *__pyx_v_suspended_stock_list = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSuspendedStocks", 1);

  /* "tbstock/utils/utils.py":661
 * 
 * def getSuspendedStocks() -> list:
 *     stock_tfp_em_df = ak.stock_tfp_em(date=latest_trade_day)             # <<<<<<<<<<<<<<
 *     suspended_stock_list = list(stock_tfp_em_df[''])
 *     return suspended_stock_list
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ak); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_stock_tfp_em); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_latest_trade_day); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_date, __pyx_t_3) < 0) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_stock_tfp_em_df = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":662
 * def getSuspendedStocks() -> list:
 *     stock_tfp_em_df = ak.stock_tfp_em(date=latest_trade_day)
 *     suspended_stock_list = list(stock_tfp_em_df[''])             # <<<<<<<<<<<<<<
 *     return suspended_stock_list
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_stock_tfp_em_df, __pyx_kp_s__38); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PySequence_ListKeepNew(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_suspended_stock_list = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":663
 *     stock_tfp_em_df = ak.stock_tfp_em(date=latest_trade_day)
 *     suspended_stock_list = list(stock_tfp_em_df[''])
 *     return suspended_stock_list             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_suspended_stock_list);
  __pyx_r = __pyx_v_suspended_stock_list;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":660
 * 
 * 
 * def getSuspendedStocks() -> list:             # <<<<<<<<<<<<<<
 *     stock_tfp_em_df = ak.stock_tfp_em(date=latest_trade_day)
 *     suspended_stock_list = list(stock_tfp_em_df[''])
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("tbstock.utils.utils.getSuspendedStocks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_stock_tfp_em_df);
  __Pyx_XDECREF(__pyx_v_suspended_stock_list);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":666
 * 
 * 
 * def getWeekStartEndByDate(given_date: datetime, mode='trade'):             # <<<<<<<<<<<<<<
 *     # 06
 *     weekday = given_date.weekday()
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_45getWeekStartEndByDate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_45getWeekStartEndByDate = {"getWeekStartEndByDate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_45getWeekStartEndByDate, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_45getWeekStartEndByDate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_given_date = 0;
  PyObject *__pyx_v_mode = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getWeekStartEndByDate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_given_date,&__pyx_n_s_mode,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_trade)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_given_date)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 666, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 666, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getWeekStartEndByDate") < 0)) __PYX_ERR(0, 666, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_given_date = values[0];
    __pyx_v_mode = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getWeekStartEndByDate", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 666, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.getWeekStartEndByDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_44getWeekStartEndByDate(__pyx_self, __pyx_v_given_date, __pyx_v_mode);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_44getWeekStartEndByDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_given_date, PyObject *__pyx_v_mode) {
  PyObject *__pyx_v_weekday = NULL;
  PyObject *__pyx_v_start_of_week = NULL;
  PyObject *__pyx_v_end_of_week = NULL;
  PyObject *__pyx_v_week_number = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_UCS4 __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWeekStartEndByDate", 1);

  /* "tbstock/utils/utils.py":668
 * def getWeekStartEndByDate(given_date: datetime, mode='trade'):
 *     # 06
 *     weekday = given_date.weekday()             # <<<<<<<<<<<<<<
 *     #
 *     start_of_week = given_date - timedelta(days=weekday)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_given_date, __pyx_n_s_weekday); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_weekday = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":670
 *     weekday = given_date.weekday()
 *     #
 *     start_of_week = given_date - timedelta(days=weekday)             # <<<<<<<<<<<<<<
 *     #
 *     end_of_week = start_of_week + timedelta(days=6)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_timedelta); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_days, __pyx_v_weekday) < 0) __PYX_ERR(0, 670, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_v_given_date, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_start_of_week = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":672
 *     start_of_week = given_date - timedelta(days=weekday)
 *     #
 *     end_of_week = start_of_week + timedelta(days=6)             # <<<<<<<<<<<<<<
 *     # ISO-860114
 *     week_number = given_date.isocalendar()[1]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_timedelta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_days, __pyx_int_6) < 0) __PYX_ERR(0, 672, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_v_start_of_week, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_end_of_week = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":674
 *     end_of_week = start_of_week + timedelta(days=6)
 *     # ISO-860114
 *     week_number = given_date.isocalendar()[1]             # <<<<<<<<<<<<<<
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(start_of_week):  #
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_given_date, __pyx_n_s_isocalendar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_week_number = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":675
 *     # ISO-860114
 *     week_number = given_date.isocalendar()[1]
 *     if mode == 'trade':             # <<<<<<<<<<<<<<
 *         if not sh_calendar.is_session(start_of_week):  #
 *             start_of_week = sh_calendar.date_to_session(start_of_week, 'next')
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_trade, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 675, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "tbstock/utils/utils.py":676
 *     week_number = given_date.isocalendar()[1]
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(start_of_week):  #             # <<<<<<<<<<<<<<
 *             start_of_week = sh_calendar.date_to_session(start_of_week, 'next')
 *         if not sh_calendar.is_session(end_of_week):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_is_session); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_start_of_week};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 676, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 676, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = (!__pyx_t_5);
    if (__pyx_t_6) {

      /* "tbstock/utils/utils.py":677
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(start_of_week):  #
 *             start_of_week = sh_calendar.date_to_session(start_of_week, 'next')             # <<<<<<<<<<<<<<
 *         if not sh_calendar.is_session(end_of_week):
 *             end_of_week = sh_calendar.date_to_session(end_of_week, 'previous')
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 677, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date_to_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 677, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_start_of_week, __pyx_n_s_next};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 677, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_start_of_week, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "tbstock/utils/utils.py":676
 *     week_number = given_date.isocalendar()[1]
 *     if mode == 'trade':
 *         if not sh_calendar.is_session(start_of_week):  #             # <<<<<<<<<<<<<<
 *             start_of_week = sh_calendar.date_to_session(start_of_week, 'next')
 *         if not sh_calendar.is_session(end_of_week):
 */
    }

    /* "tbstock/utils/utils.py":678
 *         if not sh_calendar.is_session(start_of_week):  #
 *             start_of_week = sh_calendar.date_to_session(start_of_week, 'next')
 *         if not sh_calendar.is_session(end_of_week):             # <<<<<<<<<<<<<<
 *             end_of_week = sh_calendar.date_to_session(end_of_week, 'previous')
 *         if start_of_week > end_of_week:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_is_session); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_end_of_week};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 678, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 678, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (!__pyx_t_6);
    if (__pyx_t_5) {

      /* "tbstock/utils/utils.py":679
 *             start_of_week = sh_calendar.date_to_session(start_of_week, 'next')
 *         if not sh_calendar.is_session(end_of_week):
 *             end_of_week = sh_calendar.date_to_session(end_of_week, 'previous')             # <<<<<<<<<<<<<<
 *         if start_of_week > end_of_week:
 *             week_number = 0
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sh_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 679, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date_to_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 679, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_end_of_week, __pyx_n_s_previous};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_end_of_week, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "tbstock/utils/utils.py":678
 *         if not sh_calendar.is_session(start_of_week):  #
 *             start_of_week = sh_calendar.date_to_session(start_of_week, 'next')
 *         if not sh_calendar.is_session(end_of_week):             # <<<<<<<<<<<<<<
 *             end_of_week = sh_calendar.date_to_session(end_of_week, 'previous')
 *         if start_of_week > end_of_week:
 */
    }

    /* "tbstock/utils/utils.py":680
 *         if not sh_calendar.is_session(end_of_week):
 *             end_of_week = sh_calendar.date_to_session(end_of_week, 'previous')
 *         if start_of_week > end_of_week:             # <<<<<<<<<<<<<<
 *             week_number = 0
 *             start_of_week = 0
 */
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_start_of_week, __pyx_v_end_of_week, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 680, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 680, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "tbstock/utils/utils.py":681
 *             end_of_week = sh_calendar.date_to_session(end_of_week, 'previous')
 *         if start_of_week > end_of_week:
 *             week_number = 0             # <<<<<<<<<<<<<<
 *             start_of_week = 0
 *             end_of_week = 0
 */
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_DECREF_SET(__pyx_v_week_number, __pyx_int_0);

      /* "tbstock/utils/utils.py":682
 *         if start_of_week > end_of_week:
 *             week_number = 0
 *             start_of_week = 0             # <<<<<<<<<<<<<<
 *             end_of_week = 0
 *             logger.warning(f"All days in the week of this {given_date} are non-trading days")
 */
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_DECREF_SET(__pyx_v_start_of_week, __pyx_int_0);

      /* "tbstock/utils/utils.py":683
 *             week_number = 0
 *             start_of_week = 0
 *             end_of_week = 0             # <<<<<<<<<<<<<<
 *             logger.warning(f"All days in the week of this {given_date} are non-trading days")
 *     return week_number, start_of_week, end_of_week
 */
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_DECREF_SET(__pyx_v_end_of_week, __pyx_int_0);

      /* "tbstock/utils/utils.py":684
 *             start_of_week = 0
 *             end_of_week = 0
 *             logger.warning(f"All days in the week of this {given_date} are non-trading days")             # <<<<<<<<<<<<<<
 *     return week_number, start_of_week, end_of_week
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_logger); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 684, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_warning); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 684, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 684, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = 0;
      __pyx_t_8 = 127;
      __Pyx_INCREF(__pyx_kp_u_All_days_in_the_week_of_this);
      __pyx_t_7 += 29;
      __Pyx_GIVEREF(__pyx_kp_u_All_days_in_the_week_of_this);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_All_days_in_the_week_of_this);
      __pyx_t_9 = __Pyx_PyObject_FormatSimple(__pyx_v_given_date, __pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 684, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) : __pyx_t_8;
      __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_9);
      __pyx_t_9 = 0;
      __Pyx_INCREF(__pyx_kp_u_are_non_trading_days);
      __pyx_t_7 += 21;
      __Pyx_GIVEREF(__pyx_kp_u_are_non_trading_days);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_are_non_trading_days);
      __pyx_t_9 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 684, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_9};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 684, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "tbstock/utils/utils.py":680
 *         if not sh_calendar.is_session(end_of_week):
 *             end_of_week = sh_calendar.date_to_session(end_of_week, 'previous')
 *         if start_of_week > end_of_week:             # <<<<<<<<<<<<<<
 *             week_number = 0
 *             start_of_week = 0
 */
    }

    /* "tbstock/utils/utils.py":675
 *     # ISO-860114
 *     week_number = given_date.isocalendar()[1]
 *     if mode == 'trade':             # <<<<<<<<<<<<<<
 *         if not sh_calendar.is_session(start_of_week):  #
 *             start_of_week = sh_calendar.date_to_session(start_of_week, 'next')
 */
  }

  /* "tbstock/utils/utils.py":685
 *             end_of_week = 0
 *             logger.warning(f"All days in the week of this {given_date} are non-trading days")
 *     return week_number, start_of_week, end_of_week             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_week_number);
  __Pyx_GIVEREF(__pyx_v_week_number);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_week_number)) __PYX_ERR(0, 685, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_start_of_week);
  __Pyx_GIVEREF(__pyx_v_start_of_week);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_start_of_week)) __PYX_ERR(0, 685, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_end_of_week);
  __Pyx_GIVEREF(__pyx_v_end_of_week);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_end_of_week)) __PYX_ERR(0, 685, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "tbstock/utils/utils.py":666
 * 
 * 
 * def getWeekStartEndByDate(given_date: datetime, mode='trade'):             # <<<<<<<<<<<<<<
 *     # 06
 *     weekday = given_date.weekday()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("tbstock.utils.utils.getWeekStartEndByDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_weekday);
  __Pyx_XDECREF(__pyx_v_start_of_week);
  __Pyx_XDECREF(__pyx_v_end_of_week);
  __Pyx_XDECREF(__pyx_v_week_number);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":688
 * 
 * 
 * def isStockDataSaveToMysql():             # <<<<<<<<<<<<<<
 *     json_file_name = latest_trade_day + '_updatelog.json'
 *     load_json_file = update_db_logs_dir + json_file_name
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_47isStockDataSaveToMysql(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_47isStockDataSaveToMysql = {"isStockDataSaveToMysql", (PyCFunction)__pyx_pw_7tbstock_5utils_5utils_47isStockDataSaveToMysql, METH_NOARGS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_47isStockDataSaveToMysql(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isStockDataSaveToMysql (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_46isStockDataSaveToMysql(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_46isStockDataSaveToMysql(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_json_file_name = NULL;
  PyObject *__pyx_v_load_json_file = NULL;
  PyObject *__pyx_v_has_update_file = NULL;
  PyObject *__pyx_v_update_json = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isStockDataSaveToMysql", 1);

  /* "tbstock/utils/utils.py":689
 * 
 * def isStockDataSaveToMysql():
 *     json_file_name = latest_trade_day + '_updatelog.json'             # <<<<<<<<<<<<<<
 *     load_json_file = update_db_logs_dir + json_file_name
 *     has_update_file, update_json = loadJsonData(load_json_file, json_file_name)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_latest_trade_day); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s_updatelog_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_json_file_name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":690
 * def isStockDataSaveToMysql():
 *     json_file_name = latest_trade_day + '_updatelog.json'
 *     load_json_file = update_db_logs_dir + json_file_name             # <<<<<<<<<<<<<<
 *     has_update_file, update_json = loadJsonData(load_json_file, json_file_name)
 *     if has_update_file and update_json['updated']:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_update_db_logs_dir); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_json_file_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_load_json_file = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":691
 *     json_file_name = latest_trade_day + '_updatelog.json'
 *     load_json_file = update_db_logs_dir + json_file_name
 *     has_update_file, update_json = loadJsonData(load_json_file, json_file_name)             # <<<<<<<<<<<<<<
 *     if has_update_file and update_json['updated']:
 *         return True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_loadJsonData); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_load_json_file, __pyx_v_json_file_name};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 691, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 691, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 691, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 691, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 691, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 691, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 691, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_has_update_file = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_update_json = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":692
 *     load_json_file = update_db_logs_dir + json_file_name
 *     has_update_file, update_json = loadJsonData(load_json_file, json_file_name)
 *     if has_update_file and update_json['updated']:             # <<<<<<<<<<<<<<
 *         return True
 *     else:
 */
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_has_update_file); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 692, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_update_json, __pyx_n_s_updated); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __pyx_t_8;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_7) {

    /* "tbstock/utils/utils.py":693
 *     has_update_file, update_json = loadJsonData(load_json_file, json_file_name)
 *     if has_update_file and update_json['updated']:
 *         return True             # <<<<<<<<<<<<<<
 *     else:
 *         return False
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":692
 *     load_json_file = update_db_logs_dir + json_file_name
 *     has_update_file, update_json = loadJsonData(load_json_file, json_file_name)
 *     if has_update_file and update_json['updated']:             # <<<<<<<<<<<<<<
 *         return True
 *     else:
 */
  }

  /* "tbstock/utils/utils.py":695
 *         return True
 *     else:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }

  /* "tbstock/utils/utils.py":688
 * 
 * 
 * def isStockDataSaveToMysql():             # <<<<<<<<<<<<<<
 *     json_file_name = latest_trade_day + '_updatelog.json'
 *     load_json_file = update_db_logs_dir + json_file_name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("tbstock.utils.utils.isStockDataSaveToMysql", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_json_file_name);
  __Pyx_XDECREF(__pyx_v_load_json_file);
  __Pyx_XDECREF(__pyx_v_has_update_file);
  __Pyx_XDECREF(__pyx_v_update_json);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":698
 * 
 * 
 * def isWeekLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     week, start_date, end_date = getWeekStartEndByDate(trade_date)
 *     if week == start_date and week == end_date:
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_49isWeekLastTradeDay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_49isWeekLastTradeDay = {"isWeekLastTradeDay", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_49isWeekLastTradeDay, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_49isWeekLastTradeDay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_trade_date = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isWeekLastTradeDay (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_trade_date,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_trade_date)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 698, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "isWeekLastTradeDay") < 0)) __PYX_ERR(0, 698, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_trade_date = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("isWeekLastTradeDay", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 698, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.isWeekLastTradeDay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_48isWeekLastTradeDay(__pyx_self, __pyx_v_trade_date);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_48isWeekLastTradeDay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date) {
  PyObject *__pyx_v_week = NULL;
  PyObject *__pyx_v_start_date = NULL;
  PyObject *__pyx_v_end_date = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isWeekLastTradeDay", 1);

  /* "tbstock/utils/utils.py":699
 * 
 * def isWeekLastTradeDay(trade_date: datetime):
 *     week, start_date, end_date = getWeekStartEndByDate(trade_date)             # <<<<<<<<<<<<<<
 *     if week == start_date and week == end_date:
 *         return False, start_date, end_date
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_getWeekStartEndByDate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_trade_date};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 699, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 2); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
    index = 0; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 2; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 3) < 0) __PYX_ERR(0, 699, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 699, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_week = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_start_date = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_end_date = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":700
 * def isWeekLastTradeDay(trade_date: datetime):
 *     week, start_date, end_date = getWeekStartEndByDate(trade_date)
 *     if week == start_date and week == end_date:             # <<<<<<<<<<<<<<
 *         return False, start_date, end_date
 *     if trade_date == end_date:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_week, __pyx_v_start_date, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 700, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_week, __pyx_v_end_date, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 700, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_8) {

    /* "tbstock/utils/utils.py":701
 *     week, start_date, end_date = getWeekStartEndByDate(trade_date)
 *     if week == start_date and week == end_date:
 *         return False, start_date, end_date             # <<<<<<<<<<<<<<
 *     if trade_date == end_date:
 *         return True, start_date, end_date
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, Py_False)) __PYX_ERR(0, 701, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_start_date);
    __Pyx_GIVEREF(__pyx_v_start_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_start_date)) __PYX_ERR(0, 701, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_end_date);
    __Pyx_GIVEREF(__pyx_v_end_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_end_date)) __PYX_ERR(0, 701, __pyx_L1_error);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":700
 * def isWeekLastTradeDay(trade_date: datetime):
 *     week, start_date, end_date = getWeekStartEndByDate(trade_date)
 *     if week == start_date and week == end_date:             # <<<<<<<<<<<<<<
 *         return False, start_date, end_date
 *     if trade_date == end_date:
 */
  }

  /* "tbstock/utils/utils.py":702
 *     if week == start_date and week == end_date:
 *         return False, start_date, end_date
 *     if trade_date == end_date:             # <<<<<<<<<<<<<<
 *         return True, start_date, end_date
 *     else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_trade_date, __pyx_v_end_date, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 702, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_8) {

    /* "tbstock/utils/utils.py":703
 *         return False, start_date, end_date
 *     if trade_date == end_date:
 *         return True, start_date, end_date             # <<<<<<<<<<<<<<
 *     else:
 *         return False, start_date, end_date
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, Py_True)) __PYX_ERR(0, 703, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_start_date);
    __Pyx_GIVEREF(__pyx_v_start_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_start_date)) __PYX_ERR(0, 703, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_end_date);
    __Pyx_GIVEREF(__pyx_v_end_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_end_date)) __PYX_ERR(0, 703, __pyx_L1_error);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":702
 *     if week == start_date and week == end_date:
 *         return False, start_date, end_date
 *     if trade_date == end_date:             # <<<<<<<<<<<<<<
 *         return True, start_date, end_date
 *     else:
 */
  }

  /* "tbstock/utils/utils.py":705
 *         return True, start_date, end_date
 *     else:
 *         return False, start_date, end_date             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, Py_False)) __PYX_ERR(0, 705, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_start_date);
    __Pyx_GIVEREF(__pyx_v_start_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_start_date)) __PYX_ERR(0, 705, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_end_date);
    __Pyx_GIVEREF(__pyx_v_end_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_end_date)) __PYX_ERR(0, 705, __pyx_L1_error);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "tbstock/utils/utils.py":698
 * 
 * 
 * def isWeekLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     week, start_date, end_date = getWeekStartEndByDate(trade_date)
 *     if week == start_date and week == end_date:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("tbstock.utils.utils.isWeekLastTradeDay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_week);
  __Pyx_XDECREF(__pyx_v_start_date);
  __Pyx_XDECREF(__pyx_v_end_date);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":708
 * 
 * 
 * def isMonthLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     trade_year = str(trade_date.year)
 *     trade_month = str(trade_date.month)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_51isMonthLastTradeDay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_51isMonthLastTradeDay = {"isMonthLastTradeDay", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_51isMonthLastTradeDay, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_51isMonthLastTradeDay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_trade_date = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isMonthLastTradeDay (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_trade_date,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_trade_date)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 708, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "isMonthLastTradeDay") < 0)) __PYX_ERR(0, 708, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_trade_date = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("isMonthLastTradeDay", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 708, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.isMonthLastTradeDay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_50isMonthLastTradeDay(__pyx_self, __pyx_v_trade_date);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_50isMonthLastTradeDay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date) {
  PyObject *__pyx_v_trade_year = NULL;
  PyObject *__pyx_v_trade_month = NULL;
  PyObject *__pyx_v_start_date = NULL;
  PyObject *__pyx_v_end_date = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isMonthLastTradeDay", 1);

  /* "tbstock/utils/utils.py":709
 * 
 * def isMonthLastTradeDay(trade_date: datetime):
 *     trade_year = str(trade_date.year)             # <<<<<<<<<<<<<<
 *     trade_month = str(trade_date.month)
 *     start_date, end_date = getMonthStartEndDate(trade_year, trade_month)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_trade_date, __pyx_n_s_year); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Str(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_trade_year = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":710
 * def isMonthLastTradeDay(trade_date: datetime):
 *     trade_year = str(trade_date.year)
 *     trade_month = str(trade_date.month)             # <<<<<<<<<<<<<<
 *     start_date, end_date = getMonthStartEndDate(trade_year, trade_month)
 *     if trade_date == end_date:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_trade_date, __pyx_n_s_month); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_Str(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_trade_month = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":711
 *     trade_year = str(trade_date.year)
 *     trade_month = str(trade_date.month)
 *     start_date, end_date = getMonthStartEndDate(trade_year, trade_month)             # <<<<<<<<<<<<<<
 *     if trade_date == end_date:
 *         return True, start_date, end_date
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_getMonthStartEndDate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_trade_year, __pyx_v_trade_month};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 711, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 711, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 711, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_start_date = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_end_date = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":712
 *     trade_month = str(trade_date.month)
 *     start_date, end_date = getMonthStartEndDate(trade_year, trade_month)
 *     if trade_date == end_date:             # <<<<<<<<<<<<<<
 *         return True, start_date, end_date
 *     else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_trade_date, __pyx_v_end_date, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 712, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 712, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "tbstock/utils/utils.py":713
 *     start_date, end_date = getMonthStartEndDate(trade_year, trade_month)
 *     if trade_date == end_date:
 *         return True, start_date, end_date             # <<<<<<<<<<<<<<
 *     else:
 *         return False, start_date, end_date
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, Py_True)) __PYX_ERR(0, 713, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_start_date);
    __Pyx_GIVEREF(__pyx_v_start_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_start_date)) __PYX_ERR(0, 713, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_end_date);
    __Pyx_GIVEREF(__pyx_v_end_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_end_date)) __PYX_ERR(0, 713, __pyx_L1_error);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":712
 *     trade_month = str(trade_date.month)
 *     start_date, end_date = getMonthStartEndDate(trade_year, trade_month)
 *     if trade_date == end_date:             # <<<<<<<<<<<<<<
 *         return True, start_date, end_date
 *     else:
 */
  }

  /* "tbstock/utils/utils.py":715
 *         return True, start_date, end_date
 *     else:
 *         return False, start_date, end_date             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, Py_False)) __PYX_ERR(0, 715, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_start_date);
    __Pyx_GIVEREF(__pyx_v_start_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_start_date)) __PYX_ERR(0, 715, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_end_date);
    __Pyx_GIVEREF(__pyx_v_end_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_end_date)) __PYX_ERR(0, 715, __pyx_L1_error);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "tbstock/utils/utils.py":708
 * 
 * 
 * def isMonthLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     trade_year = str(trade_date.year)
 *     trade_month = str(trade_date.month)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("tbstock.utils.utils.isMonthLastTradeDay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_trade_year);
  __Pyx_XDECREF(__pyx_v_trade_month);
  __Pyx_XDECREF(__pyx_v_start_date);
  __Pyx_XDECREF(__pyx_v_end_date);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":718
 * 
 * 
 * def isYearLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     trade_year = str(trade_date.year)
 *     start_date, end_date = getYearStartEndDate(trade_year)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_53isYearLastTradeDay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_53isYearLastTradeDay = {"isYearLastTradeDay", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_5utils_5utils_53isYearLastTradeDay, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_53isYearLastTradeDay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_trade_date = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isYearLastTradeDay (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_trade_date,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_trade_date)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 718, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "isYearLastTradeDay") < 0)) __PYX_ERR(0, 718, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_trade_date = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("isYearLastTradeDay", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 718, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.utils.utils.isYearLastTradeDay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_52isYearLastTradeDay(__pyx_self, __pyx_v_trade_date);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_52isYearLastTradeDay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date) {
  PyObject *__pyx_v_trade_year = NULL;
  PyObject *__pyx_v_start_date = NULL;
  PyObject *__pyx_v_end_date = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isYearLastTradeDay", 1);

  /* "tbstock/utils/utils.py":719
 * 
 * def isYearLastTradeDay(trade_date: datetime):
 *     trade_year = str(trade_date.year)             # <<<<<<<<<<<<<<
 *     start_date, end_date = getYearStartEndDate(trade_year)
 *     if trade_date == end_date:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_trade_date, __pyx_n_s_year); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Str(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_trade_year = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":720
 * def isYearLastTradeDay(trade_date: datetime):
 *     trade_year = str(trade_date.year)
 *     start_date, end_date = getYearStartEndDate(trade_year)             # <<<<<<<<<<<<<<
 *     if trade_date == end_date:
 *         return True, start_date, end_date
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_getYearStartEndDate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_trade_year};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 720, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_1 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 720, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 720, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_start_date = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_end_date = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":721
 *     trade_year = str(trade_date.year)
 *     start_date, end_date = getYearStartEndDate(trade_year)
 *     if trade_date == end_date:             # <<<<<<<<<<<<<<
 *         return True, start_date, end_date
 *     else:
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_trade_date, __pyx_v_end_date, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 721, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "tbstock/utils/utils.py":722
 *     start_date, end_date = getYearStartEndDate(trade_year)
 *     if trade_date == end_date:
 *         return True, start_date, end_date             # <<<<<<<<<<<<<<
 *     else:
 *         return False, start_date, end_date
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 722, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, Py_True)) __PYX_ERR(0, 722, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_start_date);
    __Pyx_GIVEREF(__pyx_v_start_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_start_date)) __PYX_ERR(0, 722, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_end_date);
    __Pyx_GIVEREF(__pyx_v_end_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_end_date)) __PYX_ERR(0, 722, __pyx_L1_error);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "tbstock/utils/utils.py":721
 *     trade_year = str(trade_date.year)
 *     start_date, end_date = getYearStartEndDate(trade_year)
 *     if trade_date == end_date:             # <<<<<<<<<<<<<<
 *         return True, start_date, end_date
 *     else:
 */
  }

  /* "tbstock/utils/utils.py":724
 *         return True, start_date, end_date
 *     else:
 *         return False, start_date, end_date             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 724, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, Py_False)) __PYX_ERR(0, 724, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_start_date);
    __Pyx_GIVEREF(__pyx_v_start_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_start_date)) __PYX_ERR(0, 724, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_end_date);
    __Pyx_GIVEREF(__pyx_v_end_date);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_end_date)) __PYX_ERR(0, 724, __pyx_L1_error);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "tbstock/utils/utils.py":718
 * 
 * 
 * def isYearLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     trade_year = str(trade_date.year)
 *     start_date, end_date = getYearStartEndDate(trade_year)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("tbstock.utils.utils.isYearLastTradeDay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_trade_year);
  __Pyx_XDECREF(__pyx_v_start_date);
  __Pyx_XDECREF(__pyx_v_end_date);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/utils/utils.py":727
 * 
 * 
 * def test():             # <<<<<<<<<<<<<<
 *     # year = '2019'
 *     # start_date, end_date = getYearStartEndDate(year)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_5utils_5utils_55test(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_5utils_5utils_55test = {"test", (PyCFunction)__pyx_pw_7tbstock_5utils_5utils_55test, METH_NOARGS, 0};
static PyObject *__pyx_pw_7tbstock_5utils_5utils_55test(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_5utils_5utils_54test(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_5utils_5utils_54test(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_list1 = NULL;
  PyObject *__pyx_v_list2 = NULL;
  PyObject *__pyx_v_list3 = NULL;
  PyObject *__pyx_v_intersec_list = NULL;
  PyObject *__pyx_v_all_list = NULL;
  PyObject *__pyx_v_union_list = NULL;
  PyObject *__pyx_v_Counter = NULL;
  PyObject *__pyx_v_combined_list = NULL;
  PyObject *__pyx_v_count = NULL;
  PyObject *__pyx_v_df = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test", 1);

  /* "tbstock/utils/utils.py":737
 *     # testCalendar()
 * 
 *     list1 = ['1', '2', '3']             # <<<<<<<<<<<<<<
 *     list2 = ['2', '3', '4', '5']
 *     list3 = ['2', '5', '7', '10']
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_kp_s_1);
  __Pyx_GIVEREF(__pyx_kp_s_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_1)) __PYX_ERR(0, 737, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_2);
  __Pyx_GIVEREF(__pyx_kp_s_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_kp_s_2)) __PYX_ERR(0, 737, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_3);
  __Pyx_GIVEREF(__pyx_kp_s_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_kp_s_3)) __PYX_ERR(0, 737, __pyx_L1_error);
  __pyx_v_list1 = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":738
 * 
 *     list1 = ['1', '2', '3']
 *     list2 = ['2', '3', '4', '5']             # <<<<<<<<<<<<<<
 *     list3 = ['2', '5', '7', '10']
 *     intersec_list = listIntersection(list1, list2, list3)
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_kp_s_2);
  __Pyx_GIVEREF(__pyx_kp_s_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_2)) __PYX_ERR(0, 738, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_3);
  __Pyx_GIVEREF(__pyx_kp_s_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_kp_s_3)) __PYX_ERR(0, 738, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_4);
  __Pyx_GIVEREF(__pyx_kp_s_4);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_kp_s_4)) __PYX_ERR(0, 738, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_5);
  __Pyx_GIVEREF(__pyx_kp_s_5);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 3, __pyx_kp_s_5)) __PYX_ERR(0, 738, __pyx_L1_error);
  __pyx_v_list2 = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":739
 *     list1 = ['1', '2', '3']
 *     list2 = ['2', '3', '4', '5']
 *     list3 = ['2', '5', '7', '10']             # <<<<<<<<<<<<<<
 *     intersec_list = listIntersection(list1, list2, list3)
 *     print(intersec_list)
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_kp_s_2);
  __Pyx_GIVEREF(__pyx_kp_s_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_2)) __PYX_ERR(0, 739, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_5);
  __Pyx_GIVEREF(__pyx_kp_s_5);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_kp_s_5)) __PYX_ERR(0, 739, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_7);
  __Pyx_GIVEREF(__pyx_kp_s_7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_kp_s_7)) __PYX_ERR(0, 739, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_10);
  __Pyx_GIVEREF(__pyx_kp_s_10);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 3, __pyx_kp_s_10)) __PYX_ERR(0, 739, __pyx_L1_error);
  __pyx_v_list3 = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":740
 *     list2 = ['2', '3', '4', '5']
 *     list3 = ['2', '5', '7', '10']
 *     intersec_list = listIntersection(list1, list2, list3)             # <<<<<<<<<<<<<<
 *     print(intersec_list)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_listIntersection); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_list1, __pyx_v_list2, __pyx_v_list3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 740, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_intersec_list = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":741
 *     list3 = ['2', '5', '7', '10']
 *     intersec_list = listIntersection(list1, list2, list3)
 *     print(intersec_list)             # <<<<<<<<<<<<<<
 * 
 *     all_list = [list1, list2, list3]
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_intersec_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":743
 *     print(intersec_list)
 * 
 *     all_list = [list1, list2, list3]             # <<<<<<<<<<<<<<
 *     intersec_list = listIntersection(all_list)
 *     print(intersec_list)
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_list1);
  __Pyx_GIVEREF(__pyx_v_list1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_list1)) __PYX_ERR(0, 743, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_list2);
  __Pyx_GIVEREF(__pyx_v_list2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_list2)) __PYX_ERR(0, 743, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_list3);
  __Pyx_GIVEREF(__pyx_v_list3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_v_list3)) __PYX_ERR(0, 743, __pyx_L1_error);
  __pyx_v_all_list = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":744
 * 
 *     all_list = [list1, list2, list3]
 *     intersec_list = listIntersection(all_list)             # <<<<<<<<<<<<<<
 *     print(intersec_list)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_listIntersection); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_all_list};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_intersec_list, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":745
 *     all_list = [list1, list2, list3]
 *     intersec_list = listIntersection(all_list)
 *     print(intersec_list)             # <<<<<<<<<<<<<<
 * 
 *     union_list = listUnion(list1, list2, list3)
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_intersec_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":747
 *     print(intersec_list)
 * 
 *     union_list = listUnion(list1, list2, list3)             # <<<<<<<<<<<<<<
 *     print(union_list)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_listUnion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_list1, __pyx_v_list2, __pyx_v_list3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_union_list = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":748
 * 
 *     union_list = listUnion(list1, list2, list3)
 *     print(union_list)             # <<<<<<<<<<<<<<
 * 
 *     union_list = listUnion(all_list)
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_union_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":750
 *     print(union_list)
 * 
 *     union_list = listUnion(all_list)             # <<<<<<<<<<<<<<
 *     print(union_list)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_listUnion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_all_list};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_union_list, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":751
 * 
 *     union_list = listUnion(all_list)
 *     print(union_list)             # <<<<<<<<<<<<<<
 * 
 *     from collections import Counter
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_union_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":753
 *     print(union_list)
 * 
 *     from collections import Counter             # <<<<<<<<<<<<<<
 *     combined_list = list1 + list2 + list3
 *     count = Counter(combined_list)
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_Counter);
  __Pyx_GIVEREF(__pyx_n_s_Counter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_Counter)) __PYX_ERR(0, 753, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Counter); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_Counter = __pyx_t_1;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":754
 * 
 *     from collections import Counter
 *     combined_list = list1 + list2 + list3             # <<<<<<<<<<<<<<
 *     count = Counter(combined_list)
 *     print(count)
 */
  __pyx_t_2 = PyNumber_Add(__pyx_v_list1, __pyx_v_list2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_list3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_combined_list = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":755
 *     from collections import Counter
 *     combined_list = list1 + list2 + list3
 *     count = Counter(combined_list)             # <<<<<<<<<<<<<<
 *     print(count)
 * 
 */
  __Pyx_INCREF(__pyx_v_Counter);
  __pyx_t_2 = __pyx_v_Counter; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_combined_list};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_count = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":756
 *     combined_list = list1 + list2 + list3
 *     count = Counter(combined_list)
 *     print(count)             # <<<<<<<<<<<<<<
 * 
 *     # temp = {'a': list1, 'b': list2, 'c': list3}
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_count); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/utils/utils.py":760
 *     # temp = {'a': list1, 'b': list2, 'c': list3}
 *     # df = strategyCount(temp)
 *     df = strategyCount(a=list1, b=list2, c=list3)             # <<<<<<<<<<<<<<
 *     print(df)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_strategyCount); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_a, __pyx_v_list1) < 0) __PYX_ERR(0, 760, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_b, __pyx_v_list2) < 0) __PYX_ERR(0, 760, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_c, __pyx_v_list3) < 0) __PYX_ERR(0, 760, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_df = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":761
 *     # df = strategyCount(temp)
 *     df = strategyCount(a=list1, b=list2, c=list3)
 *     print(df)             # <<<<<<<<<<<<<<
 * 
 *     # text = '1855;'
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_df); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":727
 * 
 * 
 * def test():             # <<<<<<<<<<<<<<
 *     # year = '2019'
 *     # start_date, end_date = getYearStartEndDate(year)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("tbstock.utils.utils.test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_list1);
  __Pyx_XDECREF(__pyx_v_list2);
  __Pyx_XDECREF(__pyx_v_list3);
  __Pyx_XDECREF(__pyx_v_intersec_list);
  __Pyx_XDECREF(__pyx_v_all_list);
  __Pyx_XDECREF(__pyx_v_union_list);
  __Pyx_XDECREF(__pyx_v_Counter);
  __Pyx_XDECREF(__pyx_v_combined_list);
  __Pyx_XDECREF(__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_df);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
    {&__pyx_kp_s_00, __pyx_k_00, sizeof(__pyx_k_00), 0, 0, 1, 0},
    {&__pyx_kp_s_000001, __pyx_k_000001, sizeof(__pyx_k_000001), 0, 0, 1, 0},
    {&__pyx_kp_s_000003, __pyx_k_000003, sizeof(__pyx_k_000003), 0, 0, 1, 0},
    {&__pyx_kp_s_000009, __pyx_k_000009, sizeof(__pyx_k_000009), 0, 0, 1, 0},
    {&__pyx_kp_s_000010, __pyx_k_000010, sizeof(__pyx_k_000010), 0, 0, 1, 0},
    {&__pyx_kp_s_000011, __pyx_k_000011, sizeof(__pyx_k_000011), 0, 0, 1, 0},
    {&__pyx_kp_s_000012, __pyx_k_000012, sizeof(__pyx_k_000012), 0, 0, 1, 0},
    {&__pyx_kp_s_000013, __pyx_k_000013, sizeof(__pyx_k_000013), 0, 0, 1, 0},
    {&__pyx_kp_s_000016, __pyx_k_000016, sizeof(__pyx_k_000016), 0, 0, 1, 0},
    {&__pyx_kp_s_000132, __pyx_k_000132, sizeof(__pyx_k_000132), 0, 0, 1, 0},
    {&__pyx_kp_s_000133, __pyx_k_000133, sizeof(__pyx_k_000133), 0, 0, 1, 0},
    {&__pyx_kp_s_000300, __pyx_k_000300, sizeof(__pyx_k_000300), 0, 0, 1, 0},
    {&__pyx_kp_s_000688, __pyx_k_000688, sizeof(__pyx_k_000688), 0, 0, 1, 0},
    {&__pyx_kp_s_000852, __pyx_k_000852, sizeof(__pyx_k_000852), 0, 0, 1, 0},
    {&__pyx_kp_s_000903, __pyx_k_000903, sizeof(__pyx_k_000903), 0, 0, 1, 0},
    {&__pyx_kp_s_000904, __pyx_k_000904, sizeof(__pyx_k_000904), 0, 0, 1, 0},
    {&__pyx_kp_s_000905, __pyx_k_000905, sizeof(__pyx_k_000905), 0, 0, 1, 0},
    {&__pyx_kp_s_000906, __pyx_k_000906, sizeof(__pyx_k_000906), 0, 0, 1, 0},
    {&__pyx_kp_s_000985, __pyx_k_000985, sizeof(__pyx_k_000985), 0, 0, 1, 0},
    {&__pyx_kp_u_01, __pyx_k_01, sizeof(__pyx_k_01), 0, 1, 0, 0},
    {&__pyx_kp_s_0101, __pyx_k_0101, sizeof(__pyx_k_0101), 0, 0, 1, 0},
    {&__pyx_kp_u_02d, __pyx_k_02d, sizeof(__pyx_k_02d), 0, 1, 0, 0},
    {&__pyx_kp_s_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 0, 1, 0},
    {&__pyx_kp_s_10, __pyx_k_10, sizeof(__pyx_k_10), 0, 0, 1, 0},
    {&__pyx_kp_s_100, __pyx_k_100, sizeof(__pyx_k_100), 0, 0, 1, 0},
    {&__pyx_kp_s_1000, __pyx_k_1000, sizeof(__pyx_k_1000), 0, 0, 1, 0},
    {&__pyx_kp_s_100R, __pyx_k_100R, sizeof(__pyx_k_100R), 0, 0, 1, 0},
    {&__pyx_kp_s_100_2, __pyx_k_100_2, sizeof(__pyx_k_100_2), 0, 0, 1, 0},
    {&__pyx_kp_s_100_3, __pyx_k_100_3, sizeof(__pyx_k_100_3), 0, 0, 1, 0},
    {&__pyx_kp_s_14_days, __pyx_k_14_days, sizeof(__pyx_k_14_days), 0, 0, 1, 0},
    {&__pyx_kp_s_150, __pyx_k_150, sizeof(__pyx_k_150), 0, 0, 1, 0},
    {&__pyx_kp_s_180, __pyx_k_180, sizeof(__pyx_k_180), 0, 0, 1, 0},
    {&__pyx_kp_s_2, __pyx_k_2, sizeof(__pyx_k_2), 0, 0, 1, 0},
    {&__pyx_kp_s_200, __pyx_k_200, sizeof(__pyx_k_200), 0, 0, 1, 0},
    {&__pyx_kp_s_2000, __pyx_k_2000, sizeof(__pyx_k_2000), 0, 0, 1, 0},
    {&__pyx_kp_s_200_2, __pyx_k_200_2, sizeof(__pyx_k_200_2), 0, 0, 1, 0},
    {&__pyx_kp_s_20180101, __pyx_k_20180101, sizeof(__pyx_k_20180101), 0, 0, 1, 0},
    {&__pyx_kp_s_3, __pyx_k_3, sizeof(__pyx_k_3), 0, 0, 1, 0},
    {&__pyx_kp_s_30, __pyx_k_30, sizeof(__pyx_k_30), 0, 0, 1, 0},
    {&__pyx_kp_s_300, __pyx_k_300, sizeof(__pyx_k_300), 0, 0, 1, 0},
    {&__pyx_kp_s_300_2, __pyx_k_300_2, sizeof(__pyx_k_300_2), 0, 0, 1, 0},
    {&__pyx_kp_s_300_3, __pyx_k_300_3, sizeof(__pyx_k_300_3), 0, 0, 1, 0},
    {&__pyx_kp_s_380, __pyx_k_380, sizeof(__pyx_k_380), 0, 0, 1, 0},
    {&__pyx_kp_s_399001, __pyx_k_399001, sizeof(__pyx_k_399001), 0, 0, 1, 0},
    {&__pyx_kp_s_399002, __pyx_k_399002, sizeof(__pyx_k_399002), 0, 0, 1, 0},
    {&__pyx_kp_s_399003, __pyx_k_399003, sizeof(__pyx_k_399003), 0, 0, 1, 0},
    {&__pyx_kp_s_399004, __pyx_k_399004, sizeof(__pyx_k_399004), 0, 0, 1, 0},
    {&__pyx_kp_s_399005, __pyx_k_399005, sizeof(__pyx_k_399005), 0, 0, 1, 0},
    {&__pyx_kp_s_399006, __pyx_k_399006, sizeof(__pyx_k_399006), 0, 0, 1, 0},
    {&__pyx_kp_s_399007, __pyx_k_399007, sizeof(__pyx_k_399007), 0, 0, 1, 0},
    {&__pyx_kp_s_399008, __pyx_k_399008, sizeof(__pyx_k_399008), 0, 0, 1, 0},
    {&__pyx_kp_s_399019, __pyx_k_399019, sizeof(__pyx_k_399019), 0, 0, 1, 0},
    {&__pyx_kp_s_399020, __pyx_k_399020, sizeof(__pyx_k_399020), 0, 0, 1, 0},
    {&__pyx_kp_s_399100, __pyx_k_399100, sizeof(__pyx_k_399100), 0, 0, 1, 0},
    {&__pyx_kp_s_399106, __pyx_k_399106, sizeof(__pyx_k_399106), 0, 0, 1, 0},
    {&__pyx_kp_s_399293, __pyx_k_399293, sizeof(__pyx_k_399293), 0, 0, 1, 0},
    {&__pyx_kp_s_399550, __pyx_k_399550, sizeof(__pyx_k_399550), 0, 0, 1, 0},
    {&__pyx_kp_s_399750, __pyx_k_399750, sizeof(__pyx_k_399750), 0, 0, 1, 0},
    {&__pyx_kp_s_399850, __pyx_k_399850, sizeof(__pyx_k_399850), 0, 0, 1, 0},
    {&__pyx_kp_s_4, __pyx_k_4, sizeof(__pyx_k_4), 0, 0, 1, 0},
    {&__pyx_kp_s_5, __pyx_k_5, sizeof(__pyx_k_5), 0, 0, 1, 0},
    {&__pyx_kp_s_50, __pyx_k_50, sizeof(__pyx_k_50), 0, 0, 1, 0},
    {&__pyx_kp_s_500, __pyx_k_500, sizeof(__pyx_k_500), 0, 0, 1, 0},
    {&__pyx_kp_s_50MB, __pyx_k_50MB, sizeof(__pyx_k_50MB), 0, 0, 1, 0},
    {&__pyx_kp_s_50_2, __pyx_k_50_2, sizeof(__pyx_k_50_2), 0, 0, 1, 0},
    {&__pyx_kp_s_50_3, __pyx_k_50_3, sizeof(__pyx_k_50_3), 0, 0, 1, 0},
    {&__pyx_kp_s_50_4, __pyx_k_50_4, sizeof(__pyx_k_50_4), 0, 0, 1, 0},
    {&__pyx_kp_s_50_5, __pyx_k_50_5, sizeof(__pyx_k_50_5), 0, 0, 1, 0},
    {&__pyx_kp_s_50_6, __pyx_k_50_6, sizeof(__pyx_k_50_6), 0, 0, 1, 0},
    {&__pyx_kp_s_60, __pyx_k_60, sizeof(__pyx_k_60), 0, 0, 1, 0},
    {&__pyx_kp_s_68, __pyx_k_68, sizeof(__pyx_k_68), 0, 0, 1, 0},
    {&__pyx_kp_s_7, __pyx_k_7, sizeof(__pyx_k_7), 0, 0, 1, 0},
    {&__pyx_kp_s_8, __pyx_k_8, sizeof(__pyx_k_8), 0, 0, 1, 0},
    {&__pyx_kp_s_800, __pyx_k_800, sizeof(__pyx_k_800), 0, 0, 1, 0},
    {&__pyx_kp_s_899050, __pyx_k_899050, sizeof(__pyx_k_899050), 0, 0, 1, 0},
    {&__pyx_kp_s_930050, __pyx_k_930050, sizeof(__pyx_k_930050), 0, 0, 1, 0},
    {&__pyx_kp_s_932000, __pyx_k_932000, sizeof(__pyx_k_932000), 0, 0, 1, 0},
    {&__pyx_kp_s_A50, __pyx_k_A50, sizeof(__pyx_k_A50), 0, 0, 1, 0},
    {&__pyx_kp_u_All_days_in_the_week_of_this, __pyx_k_All_days_in_the_week_of_this, sizeof(__pyx_k_All_days_in_the_week_of_this), 0, 1, 0, 0},
    {&__pyx_n_s_Counter, __pyx_k_Counter, sizeof(__pyx_k_Counter), 0, 0, 1, 1},
    {&__pyx_n_s_DataFrame, __pyx_k_DataFrame, sizeof(__pyx_k_DataFrame), 0, 0, 1, 1},
    {&__pyx_n_s_Dict, __pyx_k_Dict, sizeof(__pyx_k_Dict), 0, 0, 1, 1},
    {&__pyx_n_s_INFO, __pyx_k_INFO, sizeof(__pyx_k_INFO), 0, 0, 1, 1},
    {&__pyx_n_s_IOError, __pyx_k_IOError, sizeof(__pyx_k_IOError), 0, 0, 1, 1},
    {&__pyx_n_s_JSONEncoder, __pyx_k_JSONEncoder, sizeof(__pyx_k_JSONEncoder), 0, 0, 1, 1},
    {&__pyx_kp_u_Json_file, __pyx_k_Json_file, sizeof(__pyx_k_Json_file), 0, 1, 0, 0},
    {&__pyx_n_s_List, __pyx_k_List, sizeof(__pyx_k_List), 0, 0, 1, 1},
    {&__pyx_n_s_MyEncoder, __pyx_k_MyEncoder, sizeof(__pyx_k_MyEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_MyEncoder_default, __pyx_k_MyEncoder_default, sizeof(__pyx_k_MyEncoder_default), 0, 0, 1, 1},
    {&__pyx_n_s_MyEncoder_encode, __pyx_k_MyEncoder_encode, sizeof(__pyx_k_MyEncoder_encode), 0, 0, 1, 1},
    {&__pyx_n_s_MyEncoder_insert_newlines, __pyx_k_MyEncoder_insert_newlines, sizeof(__pyx_k_MyEncoder_insert_newlines), 0, 0, 1, 1},
    {&__pyx_kp_u_Open_json_file, __pyx_k_Open_json_file, sizeof(__pyx_k_Open_json_file), 0, 1, 0, 0},
    {&__pyx_n_s_PicklingError, __pyx_k_PicklingError, sizeof(__pyx_k_PicklingError), 0, 0, 1, 1},
    {&__pyx_kp_s_R, __pyx_k_R, sizeof(__pyx_k_R), 0, 0, 1, 0},
    {&__pyx_n_s_ST, __pyx_k_ST, sizeof(__pyx_k_ST), 0, 0, 1, 1},
    {&__pyx_kp_s_Start_this_log_record, __pyx_k_Start_this_log_record, sizeof(__pyx_k_Start_this_log_record), 0, 0, 1, 0},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_n_s_Union, __pyx_k_Union, sizeof(__pyx_k_Union), 0, 0, 1, 1},
    {&__pyx_kp_s_Union_Dict_None, __pyx_k_Union_Dict_None, sizeof(__pyx_k_Union_Dict_None), 0, 0, 1, 0},
    {&__pyx_kp_s_Union_List_None, __pyx_k_Union_List_None, sizeof(__pyx_k_Union_List_None), 0, 0, 1, 0},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_n_s_XSHG, __pyx_k_XSHG, sizeof(__pyx_k_XSHG), 0, 0, 1, 1},
    {&__pyx_kp_s_XX, __pyx_k_XX, sizeof(__pyx_k_XX), 0, 0, 1, 0},
    {&__pyx_kp_s_Y_m_d, __pyx_k_Y_m_d, sizeof(__pyx_k_Y_m_d), 0, 0, 1, 0},
    {&__pyx_kp_s__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 0, 1, 0},
    {&__pyx_kp_s__11, __pyx_k__11, sizeof(__pyx_k__11), 0, 0, 1, 0},
    {&__pyx_n_s__111, __pyx_k__111, sizeof(__pyx_k__111), 0, 0, 1, 1},
    {&__pyx_kp_s__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 0, 1, 0},
    {&__pyx_kp_s__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 0, 1, 0},
    {&__pyx_kp_s__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 0, 1, 0},
    {&__pyx_kp_s__15, __pyx_k__15, sizeof(__pyx_k__15), 0, 0, 1, 0},
    {&__pyx_kp_s__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 0, 1, 0},
    {&__pyx_kp_s__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 0, 1, 0},
    {&__pyx_kp_s__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 0, 1, 0},
    {&__pyx_kp_s__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 0, 1, 0},
    {&__pyx_kp_u__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 1, 0, 0},
    {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
    {&__pyx_kp_s__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 0, 1, 0},
    {&__pyx_kp_s__28, __pyx_k__28, sizeof(__pyx_k__28), 0, 0, 1, 0},
    {&__pyx_kp_s__29, __pyx_k__29, sizeof(__pyx_k__29), 0, 0, 1, 0},
    {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
    {&__pyx_kp_s__30, __pyx_k__30, sizeof(__pyx_k__30), 0, 0, 1, 0},
    {&__pyx_kp_s__31, __pyx_k__31, sizeof(__pyx_k__31), 0, 0, 1, 0},
    {&__pyx_kp_s__32, __pyx_k__32, sizeof(__pyx_k__32), 0, 0, 1, 0},
    {&__pyx_kp_s__33, __pyx_k__33, sizeof(__pyx_k__33), 0, 0, 1, 0},
    {&__pyx_kp_s__36, __pyx_k__36, sizeof(__pyx_k__36), 0, 0, 1, 0},
    {&__pyx_kp_s__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 0, 1, 0},
    {&__pyx_n_s__39, __pyx_k__39, sizeof(__pyx_k__39), 0, 0, 1, 1},
    {&__pyx_kp_s__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 0, 1, 0},
    {&__pyx_kp_s__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 0, 1, 0},
    {&__pyx_kp_s__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 0, 1, 0},
    {&__pyx_kp_s__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 0, 1, 0},
    {&__pyx_kp_s__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 0, 1, 0},
    {&__pyx_kp_s__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 0, 1, 0},
    {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
    {&__pyx_n_s_add, __pyx_k_add, sizeof(__pyx_k_add), 0, 0, 1, 1},
    {&__pyx_n_s_ak, __pyx_k_ak, sizeof(__pyx_k_ak), 0, 0, 1, 1},
    {&__pyx_kp_s_akshare, __pyx_k_akshare, sizeof(__pyx_k_akshare), 0, 0, 1, 0},
    {&__pyx_n_s_akshare_2, __pyx_k_akshare_2, sizeof(__pyx_k_akshare_2), 0, 0, 1, 1},
    {&__pyx_n_s_all_data_list, __pyx_k_all_data_list, sizeof(__pyx_k_all_data_list), 0, 0, 1, 1},
    {&__pyx_n_s_all_index, __pyx_k_all_index, sizeof(__pyx_k_all_index), 0, 0, 1, 1},
    {&__pyx_n_s_all_list, __pyx_k_all_list, sizeof(__pyx_k_all_list), 0, 0, 1, 1},
    {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
    {&__pyx_kp_u_are_non_trading_days, __pyx_k_are_non_trading_days, sizeof(__pyx_k_are_non_trading_days), 0, 1, 0, 0},
    {&__pyx_n_s_arg, __pyx_k_arg, sizeof(__pyx_k_arg), 0, 0, 1, 1},
    {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
    {&__pyx_n_s_ascending, __pyx_k_ascending, sizeof(__pyx_k_ascending), 0, 0, 1, 1},
    {&__pyx_kp_s_assets_audios, __pyx_k_assets_audios, sizeof(__pyx_k_assets_audios), 0, 0, 1, 0},
    {&__pyx_kp_s_assets_cookies, __pyx_k_assets_cookies, sizeof(__pyx_k_assets_cookies), 0, 0, 1, 0},
    {&__pyx_kp_s_assets_cover_img, __pyx_k_assets_cover_img, sizeof(__pyx_k_assets_cover_img), 0, 0, 1, 0},
    {&__pyx_kp_s_assets_imgs, __pyx_k_assets_imgs, sizeof(__pyx_k_assets_imgs), 0, 0, 1, 0},
    {&__pyx_kp_s_assets_logs, __pyx_k_assets_logs, sizeof(__pyx_k_assets_logs), 0, 0, 1, 0},
    {&__pyx_kp_s_assets_update_db_logs, __pyx_k_assets_update_db_logs, sizeof(__pyx_k_assets_update_db_logs), 0, 0, 1, 0},
    {&__pyx_kp_s_assets_update_strategy_logs, __pyx_k_assets_update_strategy_logs, sizeof(__pyx_k_assets_update_strategy_logs), 0, 0, 1, 0},
    {&__pyx_kp_s_assets_videos, __pyx_k_assets_videos, sizeof(__pyx_k_assets_videos), 0, 0, 1, 0},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_attr_name, __pyx_k_attr_name, sizeof(__pyx_k_attr_name), 0, 0, 1, 1},
    {&__pyx_n_s_attr_value, __pyx_k_attr_value, sizeof(__pyx_k_attr_value), 0, 0, 1, 1},
    {&__pyx_n_s_attributes, __pyx_k_attributes, sizeof(__pyx_k_attributes), 0, 0, 1, 1},
    {&__pyx_n_s_audio_dir, __pyx_k_audio_dir, sizeof(__pyx_k_audio_dir), 0, 0, 1, 1},
    {&__pyx_n_s_b, __pyx_k_b, sizeof(__pyx_k_b), 0, 0, 1, 1},
    {&__pyx_kp_s_baostock, __pyx_k_baostock, sizeof(__pyx_k_baostock), 0, 0, 1, 0},
    {&__pyx_n_s_bj, __pyx_k_bj, sizeof(__pyx_k_bj), 0, 0, 1, 1},
    {&__pyx_n_s_bool, __pyx_k_bool, sizeof(__pyx_k_bool), 0, 0, 1, 1},
    {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
    {&__pyx_n_s_calendar, __pyx_k_calendar, sizeof(__pyx_k_calendar), 0, 0, 1, 1},
    {&__pyx_n_s_checkCreatePath, __pyx_k_checkCreatePath, sizeof(__pyx_k_checkCreatePath), 0, 0, 1, 1},
    {&__pyx_n_s_check_serializability, __pyx_k_check_serializability, sizeof(__pyx_k_check_serializability), 0, 0, 1, 1},
    {&__pyx_n_s_chunks, __pyx_k_chunks, sizeof(__pyx_k_chunks), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_cleaned_list_str, __pyx_k_cleaned_list_str, sizeof(__pyx_k_cleaned_list_str), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
    {&__pyx_n_s_code_ip, __pyx_k_code_ip, sizeof(__pyx_k_code_ip), 0, 0, 1, 1},
    {&__pyx_n_s_coerce, __pyx_k_coerce, sizeof(__pyx_k_coerce), 0, 0, 1, 1},
    {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
    {&__pyx_n_s_combined_list, __pyx_k_combined_list, sizeof(__pyx_k_combined_list), 0, 0, 1, 1},
    {&__pyx_n_s_comma_index, __pyx_k_comma_index, sizeof(__pyx_k_comma_index), 0, 0, 1, 1},
    {&__pyx_n_s_cookies_dir, __pyx_k_cookies_dir, sizeof(__pyx_k_cookies_dir), 0, 0, 1, 1},
    {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
    {&__pyx_n_s_cover_img_dir, __pyx_k_cover_img_dir, sizeof(__pyx_k_cover_img_dir), 0, 0, 1, 1},
    {&__pyx_n_s_current_date, __pyx_k_current_date, sizeof(__pyx_k_current_date), 0, 0, 1, 1},
    {&__pyx_n_s_current_directory, __pyx_k_current_directory, sizeof(__pyx_k_current_directory), 0, 0, 1, 1},
    {&__pyx_kp_s_current_directory_2, __pyx_k_current_directory_2, sizeof(__pyx_k_current_directory_2), 0, 0, 1, 0},
    {&__pyx_kp_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 0},
    {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
    {&__pyx_n_s_data_in, __pyx_k_data_in, sizeof(__pyx_k_data_in), 0, 0, 1, 1},
    {&__pyx_n_s_data_list, __pyx_k_data_list, sizeof(__pyx_k_data_list), 0, 0, 1, 1},
    {&__pyx_kp_s_data_must_be_a_dictionary, __pyx_k_data_must_be_a_dictionary, sizeof(__pyx_k_data_must_be_a_dictionary), 0, 0, 1, 0},
    {&__pyx_n_s_date, __pyx_k_date, sizeof(__pyx_k_date), 0, 0, 1, 1},
    {&__pyx_kp_s_date_str, __pyx_k_date_str, sizeof(__pyx_k_date_str), 0, 0, 1, 0},
    {&__pyx_n_s_date_str_2, __pyx_k_date_str_2, sizeof(__pyx_k_date_str_2), 0, 0, 1, 1},
    {&__pyx_n_s_date_to_session, __pyx_k_date_to_session, sizeof(__pyx_k_date_to_session), 0, 0, 1, 1},
    {&__pyx_n_s_date_type, __pyx_k_date_type, sizeof(__pyx_k_date_type), 0, 0, 1, 1},
    {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
    {&__pyx_kp_s_datetime64_ns, __pyx_k_datetime64_ns, sizeof(__pyx_k_datetime64_ns), 0, 0, 1, 0},
    {&__pyx_n_s_day, __pyx_k_day, sizeof(__pyx_k_day), 0, 0, 1, 1},
    {&__pyx_n_s_days, __pyx_k_days, sizeof(__pyx_k_days), 0, 0, 1, 1},
    {&__pyx_n_s_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 0, 1, 1},
    {&__pyx_n_s_df, __pyx_k_df, sizeof(__pyx_k_df), 0, 0, 1, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_n_s_dict_2, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
    {&__pyx_n_s_diff, __pyx_k_diff, sizeof(__pyx_k_diff), 0, 0, 1, 1},
    {&__pyx_n_s_directory, __pyx_k_directory, sizeof(__pyx_k_directory), 0, 0, 1, 1},
    {&__pyx_n_s_dirname, __pyx_k_dirname, sizeof(__pyx_k_dirname), 0, 0, 1, 1},
    {&__pyx_n_s_dlmkts, __pyx_k_dlmkts, sizeof(__pyx_k_dlmkts), 0, 0, 1, 1},
    {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
    {&__pyx_n_s_dt, __pyx_k_dt, sizeof(__pyx_k_dt), 0, 0, 1, 1},
    {&__pyx_n_s_dtype, __pyx_k_dtype, sizeof(__pyx_k_dtype), 0, 0, 1, 1},
    {&__pyx_n_s_dumpJsonToFile, __pyx_k_dumpJsonToFile, sizeof(__pyx_k_dumpJsonToFile), 0, 0, 1, 1},
    {&__pyx_n_s_dumps, __pyx_k_dumps, sizeof(__pyx_k_dumps), 0, 0, 1, 1},
    {&__pyx_n_s_edge_driver_path, __pyx_k_edge_driver_path, sizeof(__pyx_k_edge_driver_path), 0, 0, 1, 1},
    {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
    {&__pyx_n_s_encoding, __pyx_k_encoding, sizeof(__pyx_k_encoding), 0, 0, 1, 1},
    {&__pyx_n_s_end_date, __pyx_k_end_date, sizeof(__pyx_k_end_date), 0, 0, 1, 1},
    {&__pyx_n_s_end_of_week, __pyx_k_end_of_week, sizeof(__pyx_k_end_of_week), 0, 0, 1, 1},
    {&__pyx_n_s_enqueue, __pyx_k_enqueue, sizeof(__pyx_k_enqueue), 0, 0, 1, 1},
    {&__pyx_n_s_ensure_ascii, __pyx_k_ensure_ascii, sizeof(__pyx_k_ensure_ascii), 0, 0, 1, 1},
    {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
    {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
    {&__pyx_n_s_errors, __pyx_k_errors, sizeof(__pyx_k_errors), 0, 0, 1, 1},
    {&__pyx_n_s_exchange_calendars, __pyx_k_exchange_calendars, sizeof(__pyx_k_exchange_calendars), 0, 0, 1, 1},
    {&__pyx_n_s_exists, __pyx_k_exists, sizeof(__pyx_k_exists), 0, 0, 1, 1},
    {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
    {&__pyx_n_s_extractAdministrativeRegions, __pyx_k_extractAdministrativeRegions, sizeof(__pyx_k_extractAdministrativeRegions), 0, 0, 1, 1},
    {&__pyx_n_s_f1, __pyx_k_f1, sizeof(__pyx_k_f1), 0, 0, 1, 1},
    {&__pyx_n_s_f10, __pyx_k_f10, sizeof(__pyx_k_f10), 0, 0, 1, 1},
    {&__pyx_n_s_f11, __pyx_k_f11, sizeof(__pyx_k_f11), 0, 0, 1, 1},
    {&__pyx_n_s_f115, __pyx_k_f115, sizeof(__pyx_k_f115), 0, 0, 1, 1},
    {&__pyx_n_s_f12, __pyx_k_f12, sizeof(__pyx_k_f12), 0, 0, 1, 1},
    {&__pyx_n_s_f128, __pyx_k_f128, sizeof(__pyx_k_f128), 0, 0, 1, 1},
    {&__pyx_n_s_f13, __pyx_k_f13, sizeof(__pyx_k_f13), 0, 0, 1, 1},
    {&__pyx_n_s_f136, __pyx_k_f136, sizeof(__pyx_k_f136), 0, 0, 1, 1},
    {&__pyx_n_s_f14, __pyx_k_f14, sizeof(__pyx_k_f14), 0, 0, 1, 1},
    {&__pyx_n_s_f140, __pyx_k_f140, sizeof(__pyx_k_f140), 0, 0, 1, 1},
    {&__pyx_n_s_f141, __pyx_k_f141, sizeof(__pyx_k_f141), 0, 0, 1, 1},
    {&__pyx_n_s_f15, __pyx_k_f15, sizeof(__pyx_k_f15), 0, 0, 1, 1},
    {&__pyx_n_s_f152, __pyx_k_f152, sizeof(__pyx_k_f152), 0, 0, 1, 1},
    {&__pyx_n_s_f16, __pyx_k_f16, sizeof(__pyx_k_f16), 0, 0, 1, 1},
    {&__pyx_n_s_f17, __pyx_k_f17, sizeof(__pyx_k_f17), 0, 0, 1, 1},
    {&__pyx_n_s_f18, __pyx_k_f18, sizeof(__pyx_k_f18), 0, 0, 1, 1},
    {&__pyx_n_s_f2, __pyx_k_f2, sizeof(__pyx_k_f2), 0, 0, 1, 1},
    {&__pyx_n_s_f20, __pyx_k_f20, sizeof(__pyx_k_f20), 0, 0, 1, 1},
    {&__pyx_n_s_f21, __pyx_k_f21, sizeof(__pyx_k_f21), 0, 0, 1, 1},
    {&__pyx_n_s_f22, __pyx_k_f22, sizeof(__pyx_k_f22), 0, 0, 1, 1},
    {&__pyx_n_s_f23, __pyx_k_f23, sizeof(__pyx_k_f23), 0, 0, 1, 1},
    {&__pyx_n_s_f24, __pyx_k_f24, sizeof(__pyx_k_f24), 0, 0, 1, 1},
    {&__pyx_n_s_f25, __pyx_k_f25, sizeof(__pyx_k_f25), 0, 0, 1, 1},
    {&__pyx_n_s_f26, __pyx_k_f26, sizeof(__pyx_k_f26), 0, 0, 1, 1},
    {&__pyx_n_s_f3, __pyx_k_f3, sizeof(__pyx_k_f3), 0, 0, 1, 1},
    {&__pyx_n_s_f4, __pyx_k_f4, sizeof(__pyx_k_f4), 0, 0, 1, 1},
    {&__pyx_n_s_f5, __pyx_k_f5, sizeof(__pyx_k_f5), 0, 0, 1, 1},
    {&__pyx_n_s_f6, __pyx_k_f6, sizeof(__pyx_k_f6), 0, 0, 1, 1},
    {&__pyx_n_s_f62, __pyx_k_f62, sizeof(__pyx_k_f62), 0, 0, 1, 1},
    {&__pyx_n_s_f7, __pyx_k_f7, sizeof(__pyx_k_f7), 0, 0, 1, 1},
    {&__pyx_n_s_f8, __pyx_k_f8, sizeof(__pyx_k_f8), 0, 0, 1, 1},
    {&__pyx_n_s_f9, __pyx_k_f9, sizeof(__pyx_k_f9), 0, 0, 1, 1},
    {&__pyx_kp_u_failed, __pyx_k_failed, sizeof(__pyx_k_failed), 0, 1, 0, 0},
    {&__pyx_n_s_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 0, 1, 1},
    {&__pyx_n_s_fillna, __pyx_k_fillna, sizeof(__pyx_k_fillna), 0, 0, 1, 1},
    {&__pyx_n_s_find, __pyx_k_find, sizeof(__pyx_k_find), 0, 0, 1, 1},
    {&__pyx_n_s_findall, __pyx_k_findall, sizeof(__pyx_k_findall), 0, 0, 1, 1},
    {&__pyx_n_s_first_weekday, __pyx_k_first_weekday, sizeof(__pyx_k_first_weekday), 0, 0, 1, 1},
    {&__pyx_n_s_full, __pyx_k_full, sizeof(__pyx_k_full), 0, 0, 1, 1},
    {&__pyx_n_s_full_code, __pyx_k_full_code, sizeof(__pyx_k_full_code), 0, 0, 1, 1},
    {&__pyx_n_s_full_stock_code, __pyx_k_full_stock_code, sizeof(__pyx_k_full_stock_code), 0, 0, 1, 1},
    {&__pyx_n_s_getDateDistribution, __pyx_k_getDateDistribution, sizeof(__pyx_k_getDateDistribution), 0, 0, 1, 1},
    {&__pyx_n_s_getFullStockCode, __pyx_k_getFullStockCode, sizeof(__pyx_k_getFullStockCode), 0, 0, 1, 1},
    {&__pyx_n_s_getIndexCodeName, __pyx_k_getIndexCodeName, sizeof(__pyx_k_getIndexCodeName), 0, 0, 1, 1},
    {&__pyx_n_s_getLatestTradeDay, __pyx_k_getLatestTradeDay, sizeof(__pyx_k_getLatestTradeDay), 0, 0, 1, 1},
    {&__pyx_n_s_getMonthStartEndDate, __pyx_k_getMonthStartEndDate, sizeof(__pyx_k_getMonthStartEndDate), 0, 0, 1, 1},
    {&__pyx_n_s_getStockLimitUp, __pyx_k_getStockLimitUp, sizeof(__pyx_k_getStockLimitUp), 0, 0, 1, 1},
    {&__pyx_n_s_getSuspendedStocks, __pyx_k_getSuspendedStocks, sizeof(__pyx_k_getSuspendedStocks), 0, 0, 1, 1},
    {&__pyx_n_s_getWeekStartEndByDate, __pyx_k_getWeekStartEndByDate, sizeof(__pyx_k_getWeekStartEndByDate), 0, 0, 1, 1},
    {&__pyx_n_s_getYearStartEndDate, __pyx_k_getYearStartEndDate, sizeof(__pyx_k_getYearStartEndDate), 0, 0, 1, 1},
    {&__pyx_n_s_get_calendar, __pyx_k_get_calendar, sizeof(__pyx_k_get_calendar), 0, 0, 1, 1},
    {&__pyx_n_s_getcwd, __pyx_k_getcwd, sizeof(__pyx_k_getcwd), 0, 0, 1, 1},
    {&__pyx_n_s_given_date, __pyx_k_given_date, sizeof(__pyx_k_given_date), 0, 0, 1, 1},
    {&__pyx_n_s_group, __pyx_k_group, sizeof(__pyx_k_group), 0, 0, 1, 1},
    {&__pyx_n_s_groupby, __pyx_k_groupby, sizeof(__pyx_k_groupby), 0, 0, 1, 1},
    {&__pyx_n_s_has_update_file, __pyx_k_has_update_file, sizeof(__pyx_k_has_update_file), 0, 0, 1, 1},
    {&__pyx_kp_s_home_paco_norm_envs_softwares_e, __pyx_k_home_paco_norm_envs_softwares_e, sizeof(__pyx_k_home_paco_norm_envs_softwares_e), 0, 0, 1, 0},
    {&__pyx_n_s_hour, __pyx_k_hour, sizeof(__pyx_k_hour), 0, 0, 1, 1},
    {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
    {&__pyx_n_s_img_save_path_root, __pyx_k_img_save_path_root, sizeof(__pyx_k_img_save_path_root), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_indent, __pyx_k_indent, sizeof(__pyx_k_indent), 0, 0, 1, 1},
    {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
    {&__pyx_n_s_index_code, __pyx_k_index_code, sizeof(__pyx_k_index_code), 0, 0, 1, 1},
    {&__pyx_n_s_index_name, __pyx_k_index_name, sizeof(__pyx_k_index_name), 0, 0, 1, 1},
    {&__pyx_n_s_inf, __pyx_k_inf, sizeof(__pyx_k_inf), 0, 0, 1, 1},
    {&__pyx_kp_s_inf_2, __pyx_k_inf_2, sizeof(__pyx_k_inf_2), 0, 0, 1, 0},
    {&__pyx_n_s_info, __pyx_k_info, sizeof(__pyx_k_info), 0, 0, 1, 1},
    {&__pyx_n_s_init_subclass, __pyx_k_init_subclass, sizeof(__pyx_k_init_subclass), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_inplace, __pyx_k_inplace, sizeof(__pyx_k_inplace), 0, 0, 1, 1},
    {&__pyx_n_s_input_str, __pyx_k_input_str, sizeof(__pyx_k_input_str), 0, 0, 1, 1},
    {&__pyx_n_s_insert_newlines, __pyx_k_insert_newlines, sizeof(__pyx_k_insert_newlines), 0, 0, 1, 1},
    {&__pyx_n_s_intersec_list, __pyx_k_intersec_list, sizeof(__pyx_k_intersec_list), 0, 0, 1, 1},
    {&__pyx_n_s_intersection_list, __pyx_k_intersection_list, sizeof(__pyx_k_intersection_list), 0, 0, 1, 1},
    {&__pyx_n_s_interval, __pyx_k_interval, sizeof(__pyx_k_interval), 0, 0, 1, 1},
    {&__pyx_n_s_isAPrimaryBoardStock, __pyx_k_isAPrimaryBoardStock, sizeof(__pyx_k_isAPrimaryBoardStock), 0, 0, 1, 1},
    {&__pyx_n_s_isMonthLastTradeDay, __pyx_k_isMonthLastTradeDay, sizeof(__pyx_k_isMonthLastTradeDay), 0, 0, 1, 1},
    {&__pyx_n_s_isStockDataSaveToMysql, __pyx_k_isStockDataSaveToMysql, sizeof(__pyx_k_isStockDataSaveToMysql), 0, 0, 1, 1},
    {&__pyx_n_s_isWeekLastTradeDay, __pyx_k_isWeekLastTradeDay, sizeof(__pyx_k_isWeekLastTradeDay), 0, 0, 1, 1},
    {&__pyx_n_s_isYearLastTradeDay, __pyx_k_isYearLastTradeDay, sizeof(__pyx_k_isYearLastTradeDay), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_n_s_is_serializable, __pyx_k_is_serializable, sizeof(__pyx_k_is_serializable), 0, 0, 1, 1},
    {&__pyx_n_s_is_session, __pyx_k_is_session, sizeof(__pyx_k_is_session), 0, 0, 1, 1},
    {&__pyx_kp_s_is_session_2, __pyx_k_is_session_2, sizeof(__pyx_k_is_session_2), 0, 0, 1, 0},
    {&__pyx_n_s_isocalendar, __pyx_k_isocalendar, sizeof(__pyx_k_isocalendar), 0, 0, 1, 1},
    {&__pyx_n_s_isoformat, __pyx_k_isoformat, sizeof(__pyx_k_isoformat), 0, 0, 1, 1},
    {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
    {&__pyx_n_s_iterencode, __pyx_k_iterencode, sizeof(__pyx_k_iterencode), 0, 0, 1, 1},
    {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
    {&__pyx_n_s_json, __pyx_k_json, sizeof(__pyx_k_json), 0, 0, 1, 1},
    {&__pyx_n_s_json_file_name, __pyx_k_json_file_name, sizeof(__pyx_k_json_file_name), 0, 0, 1, 1},
    {&__pyx_n_s_json_str, __pyx_k_json_str, sizeof(__pyx_k_json_str), 0, 0, 1, 1},
    {&__pyx_n_s_json_string, __pyx_k_json_string, sizeof(__pyx_k_json_string), 0, 0, 1, 1},
    {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
    {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
    {&__pyx_n_s_kwargs, __pyx_k_kwargs, sizeof(__pyx_k_kwargs), 0, 0, 1, 1},
    {&__pyx_n_s_latest_trade_day, __pyx_k_latest_trade_day, sizeof(__pyx_k_latest_trade_day), 0, 0, 1, 1},
    {&__pyx_kp_u_latest_trade_day_2, __pyx_k_latest_trade_day_2, sizeof(__pyx_k_latest_trade_day_2), 0, 1, 0, 0},
    {&__pyx_n_s_level, __pyx_k_level, sizeof(__pyx_k_level), 0, 0, 1, 1},
    {&__pyx_n_s_limit_up, __pyx_k_limit_up, sizeof(__pyx_k_limit_up), 0, 0, 1, 1},
    {&__pyx_n_s_list, __pyx_k_list, sizeof(__pyx_k_list), 0, 0, 1, 1},
    {&__pyx_n_s_list1, __pyx_k_list1, sizeof(__pyx_k_list1), 0, 0, 1, 1},
    {&__pyx_n_s_list2, __pyx_k_list2, sizeof(__pyx_k_list2), 0, 0, 1, 1},
    {&__pyx_n_s_list3, __pyx_k_list3, sizeof(__pyx_k_list3), 0, 0, 1, 1},
    {&__pyx_n_s_listIntersection, __pyx_k_listIntersection, sizeof(__pyx_k_listIntersection), 0, 0, 1, 1},
    {&__pyx_n_s_listUnion, __pyx_k_listUnion, sizeof(__pyx_k_listUnion), 0, 0, 1, 1},
    {&__pyx_n_s_list_2_dict, __pyx_k_list_2_dict, sizeof(__pyx_k_list_2_dict), 0, 0, 1, 1},
    {&__pyx_n_s_list_end_idx, __pyx_k_list_end_idx, sizeof(__pyx_k_list_end_idx), 0, 0, 1, 1},
    {&__pyx_n_s_list_end_idxs, __pyx_k_list_end_idxs, sizeof(__pyx_k_list_end_idxs), 0, 0, 1, 1},
    {&__pyx_n_s_list_start_idx, __pyx_k_list_start_idx, sizeof(__pyx_k_list_start_idx), 0, 0, 1, 1},
    {&__pyx_n_s_list_start_idxs, __pyx_k_list_start_idxs, sizeof(__pyx_k_list_start_idxs), 0, 0, 1, 1},
    {&__pyx_n_s_list_str, __pyx_k_list_str, sizeof(__pyx_k_list_str), 0, 0, 1, 1},
    {&__pyx_n_s_load, __pyx_k_load, sizeof(__pyx_k_load), 0, 0, 1, 1},
    {&__pyx_n_s_loadJsonData, __pyx_k_loadJsonData, sizeof(__pyx_k_loadJsonData), 0, 0, 1, 1},
    {&__pyx_n_s_load_json_file, __pyx_k_load_json_file, sizeof(__pyx_k_load_json_file), 0, 0, 1, 1},
    {&__pyx_n_s_log_trace, __pyx_k_log_trace, sizeof(__pyx_k_log_trace), 0, 0, 1, 1},
    {&__pyx_n_s_logger, __pyx_k_logger, sizeof(__pyx_k_logger), 0, 0, 1, 1},
    {&__pyx_n_s_logs_dir, __pyx_k_logs_dir, sizeof(__pyx_k_logs_dir), 0, 0, 1, 1},
    {&__pyx_n_s_loguru, __pyx_k_loguru, sizeof(__pyx_k_loguru), 0, 0, 1, 1},
    {&__pyx_n_s_lt, __pyx_k_lt, sizeof(__pyx_k_lt), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_makedirs, __pyx_k_makedirs, sizeof(__pyx_k_makedirs), 0, 0, 1, 1},
    {&__pyx_n_s_map, __pyx_k_map, sizeof(__pyx_k_map), 0, 0, 1, 1},
    {&__pyx_n_s_match, __pyx_k_match, sizeof(__pyx_k_match), 0, 0, 1, 1},
    {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
    {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
    {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
    {&__pyx_n_s_month, __pyx_k_month, sizeof(__pyx_k_month), 0, 0, 1, 1},
    {&__pyx_n_s_month12_days, __pyx_k_month12_days, sizeof(__pyx_k_month12_days), 0, 0, 1, 1},
    {&__pyx_n_s_month_str, __pyx_k_month_str, sizeof(__pyx_k_month_str), 0, 0, 1, 1},
    {&__pyx_n_s_monthrange, __pyx_k_monthrange, sizeof(__pyx_k_monthrange), 0, 0, 1, 1},
    {&__pyx_n_s_mro_entries, __pyx_k_mro_entries, sizeof(__pyx_k_mro_entries), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_negative_infinity, __pyx_k_negative_infinity, sizeof(__pyx_k_negative_infinity), 0, 0, 1, 1},
    {&__pyx_kp_s_new_date_str, __pyx_k_new_date_str, sizeof(__pyx_k_new_date_str), 0, 0, 1, 0},
    {&__pyx_n_s_next, __pyx_k_next, sizeof(__pyx_k_next), 0, 0, 1, 1},
    {&__pyx_kp_s_next_session, __pyx_k_next_session, sizeof(__pyx_k_next_session), 0, 0, 1, 0},
    {&__pyx_n_s_next_session_2, __pyx_k_next_session_2, sizeof(__pyx_k_next_session_2), 0, 0, 1, 1},
    {&__pyx_n_s_non_serializable_attrs, __pyx_k_non_serializable_attrs, sizeof(__pyx_k_non_serializable_attrs), 0, 0, 1, 1},
    {&__pyx_kp_u_not_found, __pyx_k_not_found, sizeof(__pyx_k_not_found), 0, 1, 0, 0},
    {&__pyx_n_s_now_datetime, __pyx_k_now_datetime, sizeof(__pyx_k_now_datetime), 0, 0, 1, 1},
    {&__pyx_n_s_num, __pyx_k_num, sizeof(__pyx_k_num), 0, 0, 1, 1},
    {&__pyx_n_s_number_of_days, __pyx_k_number_of_days, sizeof(__pyx_k_number_of_days), 0, 0, 1, 1},
    {&__pyx_n_s_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 0, 1, 1},
    {&__pyx_n_s_one_shot, __pyx_k_one_shot, sizeof(__pyx_k_one_shot), 0, 0, 1, 1},
    {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
    {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
    {&__pyx_n_s_out, __pyx_k_out, sizeof(__pyx_k_out), 0, 0, 1, 1},
    {&__pyx_n_s_pandas, __pyx_k_pandas, sizeof(__pyx_k_pandas), 0, 0, 1, 1},
    {&__pyx_n_s_path, __pyx_k_path, sizeof(__pyx_k_path), 0, 0, 1, 1},
    {&__pyx_n_s_pattern, __pyx_k_pattern, sizeof(__pyx_k_pattern), 0, 0, 1, 1},
    {&__pyx_n_s_pd, __pyx_k_pd, sizeof(__pyx_k_pd), 0, 0, 1, 1},
    {&__pyx_kp_s_pd_DataFrame, __pyx_k_pd_DataFrame, sizeof(__pyx_k_pd_DataFrame), 0, 0, 1, 0},
    {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
    {&__pyx_kp_s_pip_install_akshare_upgrade, __pyx_k_pip_install_akshare_upgrade, sizeof(__pyx_k_pip_install_akshare_upgrade), 0, 0, 1, 0},
    {&__pyx_kp_s_pip_install_baostock_upgrade, __pyx_k_pip_install_baostock_upgrade, sizeof(__pyx_k_pip_install_baostock_upgrade), 0, 0, 1, 0},
    {&__pyx_n_s_positive_infinity, __pyx_k_positive_infinity, sizeof(__pyx_k_positive_infinity), 0, 0, 1, 1},
    {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
    {&__pyx_n_s_previous, __pyx_k_previous, sizeof(__pyx_k_previous), 0, 0, 1, 1},
    {&__pyx_n_s_previous_session, __pyx_k_previous_session, sizeof(__pyx_k_previous_session), 0, 0, 1, 1},
    {&__pyx_kp_s_previous_session_2, __pyx_k_previous_session_2, sizeof(__pyx_k_previous_session_2), 0, 0, 1, 0},
    {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
    {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
    {&__pyx_n_s_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 0, 1, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_rc, __pyx_k_rc, sizeof(__pyx_k_rc), 0, 0, 1, 1},
    {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
    {&__pyx_n_s_regions, __pyx_k_regions, sizeof(__pyx_k_regions), 0, 0, 1, 1},
    {&__pyx_n_s_replace, __pyx_k_replace, sizeof(__pyx_k_replace), 0, 0, 1, 1},
    {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
    {&__pyx_n_s_retention, __pyx_k_retention, sizeof(__pyx_k_retention), 0, 0, 1, 1},
    {&__pyx_n_s_return, __pyx_k_return, sizeof(__pyx_k_return), 0, 0, 1, 1},
    {&__pyx_n_s_rotation, __pyx_k_rotation, sizeof(__pyx_k_rotation), 0, 0, 1, 1},
    {&__pyx_n_s_row, __pyx_k_row, sizeof(__pyx_k_row), 0, 0, 1, 1},
    {&__pyx_n_s_rt, __pyx_k_rt, sizeof(__pyx_k_rt), 0, 0, 1, 1},
    {&__pyx_kp_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 0},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_kp_s_session_close, __pyx_k_session_close, sizeof(__pyx_k_session_close), 0, 0, 1, 0},
    {&__pyx_n_s_session_close_2, __pyx_k_session_close_2, sizeof(__pyx_k_session_close_2), 0, 0, 1, 1},
    {&__pyx_kp_s_session_offset, __pyx_k_session_offset, sizeof(__pyx_k_session_offset), 0, 0, 1, 0},
    {&__pyx_n_s_session_offset_2, __pyx_k_session_offset_2, sizeof(__pyx_k_session_offset_2), 0, 0, 1, 1},
    {&__pyx_kp_s_session_open, __pyx_k_session_open, sizeof(__pyx_k_session_open), 0, 0, 1, 0},
    {&__pyx_n_s_session_open_2, __pyx_k_session_open_2, sizeof(__pyx_k_session_open_2), 0, 0, 1, 1},
    {&__pyx_n_s_sessions, __pyx_k_sessions, sizeof(__pyx_k_sessions), 0, 0, 1, 1},
    {&__pyx_n_s_set_name, __pyx_k_set_name, sizeof(__pyx_k_set_name), 0, 0, 1, 1},
    {&__pyx_n_s_sh, __pyx_k_sh, sizeof(__pyx_k_sh), 0, 0, 1, 1},
    {&__pyx_n_s_sh_calendar, __pyx_k_sh_calendar, sizeof(__pyx_k_sh_calendar), 0, 0, 1, 1},
    {&__pyx_n_s_sort_values, __pyx_k_sort_values, sizeof(__pyx_k_sort_values), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_splitDataframeByYear, __pyx_k_splitDataframeByYear, sizeof(__pyx_k_splitDataframeByYear), 0, 0, 1, 1},
    {&__pyx_n_s_startWithDigit, __pyx_k_startWithDigit, sizeof(__pyx_k_startWithDigit), 0, 0, 1, 1},
    {&__pyx_n_s_start_date, __pyx_k_start_date, sizeof(__pyx_k_start_date), 0, 0, 1, 1},
    {&__pyx_n_s_start_of_week, __pyx_k_start_of_week, sizeof(__pyx_k_start_of_week), 0, 0, 1, 1},
    {&__pyx_n_s_stock_code, __pyx_k_stock_code, sizeof(__pyx_k_stock_code), 0, 0, 1, 1},
    {&__pyx_kp_s_stock_log, __pyx_k_stock_log, sizeof(__pyx_k_stock_log), 0, 0, 1, 0},
    {&__pyx_n_s_stock_name, __pyx_k_stock_name, sizeof(__pyx_k_stock_name), 0, 0, 1, 1},
    {&__pyx_n_s_stock_tfp_em, __pyx_k_stock_tfp_em, sizeof(__pyx_k_stock_tfp_em), 0, 0, 1, 1},
    {&__pyx_n_s_stock_tfp_em_df, __pyx_k_stock_tfp_em_df, sizeof(__pyx_k_stock_tfp_em_df), 0, 0, 1, 1},
    {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
    {&__pyx_n_s_str_dict, __pyx_k_str_dict, sizeof(__pyx_k_str_dict), 0, 0, 1, 1},
    {&__pyx_n_s_strategyCount, __pyx_k_strategyCount, sizeof(__pyx_k_strategyCount), 0, 0, 1, 1},
    {&__pyx_n_s_strategy_code_list, __pyx_k_strategy_code_list, sizeof(__pyx_k_strategy_code_list), 0, 0, 1, 1},
    {&__pyx_n_s_strategy_name, __pyx_k_strategy_name, sizeof(__pyx_k_strategy_name), 0, 0, 1, 1},
    {&__pyx_n_s_strftime, __pyx_k_strftime, sizeof(__pyx_k_strftime), 0, 0, 1, 1},
    {&__pyx_n_s_strptime, __pyx_k_strptime, sizeof(__pyx_k_strptime), 0, 0, 1, 1},
    {&__pyx_n_s_sub, __pyx_k_sub, sizeof(__pyx_k_sub), 0, 0, 1, 1},
    {&__pyx_n_s_sum, __pyx_k_sum, sizeof(__pyx_k_sum), 0, 0, 1, 1},
    {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
    {&__pyx_n_s_suspended_stock_list, __pyx_k_suspended_stock_list, sizeof(__pyx_k_suspended_stock_list), 0, 0, 1, 1},
    {&__pyx_n_s_svr, __pyx_k_svr, sizeof(__pyx_k_svr), 0, 0, 1, 1},
    {&__pyx_n_s_system, __pyx_k_system, sizeof(__pyx_k_system), 0, 0, 1, 1},
    {&__pyx_n_s_sz, __pyx_k_sz, sizeof(__pyx_k_sz), 0, 0, 1, 1},
    {&__pyx_n_s_tbstock_utils_utils, __pyx_k_tbstock_utils_utils, sizeof(__pyx_k_tbstock_utils_utils), 0, 0, 1, 1},
    {&__pyx_kp_s_tbstock_utils_utils_py, __pyx_k_tbstock_utils_utils_py, sizeof(__pyx_k_tbstock_utils_utils_py), 0, 0, 1, 0},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_testCalendar, __pyx_k_testCalendar, sizeof(__pyx_k_testCalendar), 0, 0, 1, 1},
    {&__pyx_n_s_test_2, __pyx_k_test_2, sizeof(__pyx_k_test_2), 0, 0, 1, 1},
    {&__pyx_n_s_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 0, 1, 1},
    {&__pyx_n_s_text_tail, __pyx_k_text_tail, sizeof(__pyx_k_text_tail), 0, 0, 1, 1},
    {&__pyx_n_s_timedelta, __pyx_k_timedelta, sizeof(__pyx_k_timedelta), 0, 0, 1, 1},
    {&__pyx_n_s_to_datetime, __pyx_k_to_datetime, sizeof(__pyx_k_to_datetime), 0, 0, 1, 1},
    {&__pyx_n_s_today, __pyx_k_today, sizeof(__pyx_k_today), 0, 0, 1, 1},
    {&__pyx_n_s_today_date, __pyx_k_today_date, sizeof(__pyx_k_today_date), 0, 0, 1, 1},
    {&__pyx_n_s_total, __pyx_k_total, sizeof(__pyx_k_total), 0, 0, 1, 1},
    {&__pyx_n_s_trade, __pyx_k_trade, sizeof(__pyx_k_trade), 0, 0, 1, 1},
    {&__pyx_n_s_trade_date, __pyx_k_trade_date, sizeof(__pyx_k_trade_date), 0, 0, 1, 1},
    {&__pyx_n_s_trade_month, __pyx_k_trade_month, sizeof(__pyx_k_trade_month), 0, 0, 1, 1},
    {&__pyx_n_s_trade_year, __pyx_k_trade_year, sizeof(__pyx_k_trade_year), 0, 0, 1, 1},
    {&__pyx_kp_s_type_next_date, __pyx_k_type_next_date, sizeof(__pyx_k_type_next_date), 0, 0, 1, 0},
    {&__pyx_n_s_typing, __pyx_k_typing, sizeof(__pyx_k_typing), 0, 0, 1, 1},
    {&__pyx_n_s_union_list, __pyx_k_union_list, sizeof(__pyx_k_union_list), 0, 0, 1, 1},
    {&__pyx_n_s_updateLib, __pyx_k_updateLib, sizeof(__pyx_k_updateLib), 0, 0, 1, 1},
    {&__pyx_n_s_update_db_logs_dir, __pyx_k_update_db_logs_dir, sizeof(__pyx_k_update_db_logs_dir), 0, 0, 1, 1},
    {&__pyx_n_s_update_json, __pyx_k_update_json, sizeof(__pyx_k_update_json), 0, 0, 1, 1},
    {&__pyx_n_s_update_lib_succeed, __pyx_k_update_lib_succeed, sizeof(__pyx_k_update_lib_succeed), 0, 0, 1, 1},
    {&__pyx_n_s_update_strategy_logs_dir, __pyx_k_update_strategy_logs_dir, sizeof(__pyx_k_update_strategy_logs_dir), 0, 0, 1, 1},
    {&__pyx_n_s_updated, __pyx_k_updated, sizeof(__pyx_k_updated), 0, 0, 1, 1},
    {&__pyx_kp_s_updatelog_json, __pyx_k_updatelog_json, sizeof(__pyx_k_updatelog_json), 0, 0, 1, 0},
    {&__pyx_n_s_upper, __pyx_k_upper, sizeof(__pyx_k_upper), 0, 0, 1, 1},
    {&__pyx_n_s_use_cls, __pyx_k_use_cls, sizeof(__pyx_k_use_cls), 0, 0, 1, 1},
    {&__pyx_kp_s_utf_8, __pyx_k_utf_8, sizeof(__pyx_k_utf_8), 0, 0, 1, 0},
    {&__pyx_n_s_video_save_path_root, __pyx_k_video_save_path_root, sizeof(__pyx_k_video_save_path_root), 0, 0, 1, 1},
    {&__pyx_n_s_w, __pyx_k_w, sizeof(__pyx_k_w), 0, 0, 1, 1},
    {&__pyx_n_s_warning, __pyx_k_warning, sizeof(__pyx_k_warning), 0, 0, 1, 1},
    {&__pyx_n_s_week, __pyx_k_week, sizeof(__pyx_k_week), 0, 0, 1, 1},
    {&__pyx_n_s_week_number, __pyx_k_week_number, sizeof(__pyx_k_week_number), 0, 0, 1, 1},
    {&__pyx_n_s_weekday, __pyx_k_weekday, sizeof(__pyx_k_weekday), 0, 0, 1, 1},
    {&__pyx_n_s_wrapped_text, __pyx_k_wrapped_text, sizeof(__pyx_k_wrapped_text), 0, 0, 1, 1},
    {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
    {&__pyx_n_s_write_f, __pyx_k_write_f, sizeof(__pyx_k_write_f), 0, 0, 1, 1},
    {&__pyx_n_s_xx, __pyx_k_xx, sizeof(__pyx_k_xx), 0, 0, 1, 1},
    {&__pyx_kp_s_xx_2, __pyx_k_xx_2, sizeof(__pyx_k_xx_2), 0, 0, 1, 0},
    {&__pyx_n_s_year, __pyx_k_year, sizeof(__pyx_k_year), 0, 0, 1, 1},
    {&__pyx_n_s_year_end, __pyx_k_year_end, sizeof(__pyx_k_year_end), 0, 0, 1, 1},
    {&__pyx_n_s_year_int, __pyx_k_year_int, sizeof(__pyx_k_year_int), 0, 0, 1, 1},
    {&__pyx_n_s_year_list, __pyx_k_year_list, sizeof(__pyx_k_year_list), 0, 0, 1, 1},
    {&__pyx_n_s_year_start, __pyx_k_year_start, sizeof(__pyx_k_year_start), 0, 0, 1, 1},
    {&__pyx_n_s_year_str, __pyx_k_year_str, sizeof(__pyx_k_year_str), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 15, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 42, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 279, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 401, __pyx_L1_error)
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_n_s_super); if (!__pyx_builtin_super) __PYX_ERR(0, 495, __pyx_L1_error)
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_n_s_open); if (!__pyx_builtin_open) __PYX_ERR(0, 583, __pyx_L1_error)
  __pyx_builtin_IOError = __Pyx_GetBuiltinName(__pyx_n_s_IOError); if (!__pyx_builtin_IOError) __PYX_ERR(0, 586, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "tbstock/utils/utils.py":253
 *     if out != 0:
 *         update_lib_succeed = False
 *         print('##############################akshare')             # <<<<<<<<<<<<<<
 * 
 *     # out = os.system('pip install adata --upgrade')
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_s_akshare); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "tbstock/utils/utils.py":263
 *     if out != 0:
 *         update_lib_succeed = False
 *         print('##############################baostock')             # <<<<<<<<<<<<<<
 * 
 *     # out = os.system('pip install yfinance --upgrade --no-cache-dir')
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_kp_s_baostock); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "tbstock/utils/utils.py":401
 *         data = kwargs
 *     elif not isinstance(data, dict):
 *         raise ValueError("data must be a dictionary")             # <<<<<<<<<<<<<<
 * 
 *     all_list = []
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_s_data_must_be_a_dictionary); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "tbstock/utils/utils.py":414
 *         df[strategy_name] = df.index.map(list_2_dict)
 *     df['sum'] = df.index.map(count)
 *     df.fillna(0, inplace=True)             # <<<<<<<<<<<<<<
 *     df.sort_values('sum', ascending=False, inplace=True)
 *     return df
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_int_0); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "tbstock/utils/utils.py":415
 *     df['sum'] = df.index.map(count)
 *     df.fillna(0, inplace=True)
 *     df.sort_values('sum', ascending=False, inplace=True)             # <<<<<<<<<<<<<<
 *     return df
 * 
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_n_s_sum); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "tbstock/utils/utils.py":432
 *     '''
 *     full_stock_code = ""
 *     if stock_code[0:2] in ["60", "68"]:             # <<<<<<<<<<<<<<
 *         full_stock_code = 'sh' + stock_code
 *     elif stock_code[0:2] in ["00", "30"]:
 */
  __pyx_slice__26 = PySlice_New(__pyx_int_0, __pyx_int_2, Py_None); if (unlikely(!__pyx_slice__26)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__26);
  __Pyx_GIVEREF(__pyx_slice__26);

  /* "tbstock/utils/utils.py":442
 *         pass
 *     elif mode == 'xx.':
 *         full_stock_code = full_stock_code[0:2] + '.' + full_stock_code[2:]             # <<<<<<<<<<<<<<
 *     elif mode == '.XX':
 *         full_stock_code = full_stock_code[2:] + '.' + full_stock_code[0:2].upper()
 */
  __pyx_slice__27 = PySlice_New(__pyx_int_2, Py_None, Py_None); if (unlikely(!__pyx_slice__27)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__27);
  __Pyx_GIVEREF(__pyx_slice__27);

  /* "tbstock/utils/utils.py":559
 * 
 *             # '\n'
 *             cleaned_list_str = list_str.replace(',\n', ',').replace('\n', '')             # <<<<<<<<<<<<<<
 *             cleaned_list_str = re.sub(r'\s+', ' ', cleaned_list_str)
 *             cleaned_list_str = self.insert_newlines(cleaned_list_str, 300)
 */
  __pyx_tuple__34 = PyTuple_Pack(2, __pyx_kp_s__33, __pyx_kp_s__28); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);
  __pyx_tuple__35 = PyTuple_Pack(2, __pyx_kp_s__29, __pyx_kp_s__4); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "tbstock/utils/utils.py":602
 *         else:
 *             json_string = json.dumps(update_json, indent=4, ensure_ascii=False)
 *         with open(load_json_file, 'w', encoding='utf-8') as write_f:             # <<<<<<<<<<<<<<
 *             write_f.write(json_string)
 * 
 */
  __pyx_tuple__37 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "tbstock/utils/utils.py":35
 *                        enqueue=True,
 *                        retention="14 days")
 * logger.info("Start this log record.\n")             # <<<<<<<<<<<<<<
 * 
 * start_date = '20180101'
 */
  __pyx_tuple__40 = PyTuple_Pack(1, __pyx_kp_s_Start_this_log_record); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);

  /* "tbstock/utils/utils.py":40
 * now_datetime = datetime.today()
 * # now_datetime = datetime(2024, 8, 29, 16, 25, 15)
 * today_date = now_datetime.strftime('%Y%m%d')             # <<<<<<<<<<<<<<
 * 
 * year_list = [str(i) for i in range(int(start_date[0:4]), int(today_date[0:4]) + 1)]
 */
  __pyx_tuple__41 = PyTuple_Pack(1, __pyx_kp_s_Y_m_d); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "tbstock/utils/utils.py":42
 * today_date = now_datetime.strftime('%Y%m%d')
 * 
 * year_list = [str(i) for i in range(int(start_date[0:4]), int(today_date[0:4]) + 1)]             # <<<<<<<<<<<<<<
 * sh_calendar = trade_date.get_calendar("XSHG")
 * 
 */
  __pyx_slice__42 = PySlice_New(__pyx_int_0, __pyx_int_4, Py_None); if (unlikely(!__pyx_slice__42)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__42);
  __Pyx_GIVEREF(__pyx_slice__42);

  /* "tbstock/utils/utils.py":43
 * 
 * year_list = [str(i) for i in range(int(start_date[0:4]), int(today_date[0:4]) + 1)]
 * sh_calendar = trade_date.get_calendar("XSHG")             # <<<<<<<<<<<<<<
 * 
 * positive_infinity = float('inf')
 */
  __pyx_tuple__43 = PyTuple_Pack(1, __pyx_n_s_XSHG); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "tbstock/utils/utils.py":51
 * # print(f"year_list = {year_list}")
 * 
 * def checkCreatePath(directory):             # <<<<<<<<<<<<<<
 *     if not os.path.exists(directory):
 *         # os.makedirs()
 */
  __pyx_tuple__44 = PyTuple_Pack(1, __pyx_n_s_directory); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__44, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_checkCreatePath, 51, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) __PYX_ERR(0, 51, __pyx_L1_error)

  /* "tbstock/utils/utils.py":70
 * 
 * 
 * def getLatestTradeDay(today_date):             # <<<<<<<<<<<<<<
 *     if not sh_calendar.is_session(today_date):
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')
 */
  __pyx_tuple__46 = PyTuple_Pack(2, __pyx_n_s_today_date, __pyx_n_s_latest_trade_day); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);
  __pyx_codeobj__47 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__46, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_getLatestTradeDay, 70, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__47)) __PYX_ERR(0, 70, __pyx_L1_error)

  /* "tbstock/utils/utils.py":84
 * 
 * 
 * def getIndexCodeName() -> dict:             # <<<<<<<<<<<<<<
 *     str_dict = {"rc": 0, "rt": 6, "svr": 182994245, "lt": 1, "full": 1, "dlmkts": "", "data": {"total": 37, "diff": [
 *         {"f1": 2, "f2": 3051.28, "f3": 0.08, "f4": 2.49, "f5": 316342484, "f6": 318911097485.6, "f7": 1.11, "f8": 0.69, "f9": "-", "f10": 0.99,
 */
  __pyx_tuple__48 = PyTuple_Pack(8, __pyx_n_s_str_dict, __pyx_n_s_all_data_list, __pyx_n_s_all_index, __pyx_n_s_row, __pyx_n_s_code_ip, __pyx_n_s_index_name, __pyx_n_s_index_code, __pyx_n_s_full_code); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__48, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_getIndexCodeName, 84, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(0, 84, __pyx_L1_error)

  /* "tbstock/utils/utils.py":248
 * 
 * 
 * def updateLib() -> bool:             # <<<<<<<<<<<<<<
 *     update_lib_succeed = True
 *     out = os.system('pip install akshare --upgrade')
 */
  __pyx_tuple__50 = PyTuple_Pack(2, __pyx_n_s_update_lib_succeed, __pyx_n_s_out); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__50, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_updateLib, 248, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) __PYX_ERR(0, 248, __pyx_L1_error)

  /* "tbstock/utils/utils.py":273
 * 
 * 
 * def is_serializable(obj):             # <<<<<<<<<<<<<<
 *     try:
 *         pickle.dumps(obj)
 */
  __pyx_tuple__52 = PyTuple_Pack(1, __pyx_n_s_obj); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);
  __pyx_codeobj__53 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__52, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_is_serializable, 273, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__53)) __PYX_ERR(0, 273, __pyx_L1_error)

  /* "tbstock/utils/utils.py":283
 * 
 * 
 * def check_serializability(obj):             # <<<<<<<<<<<<<<
 *     attributes = obj.__dict__
 *     non_serializable_attrs = []
 */
  __pyx_tuple__54 = PyTuple_Pack(5, __pyx_n_s_obj, __pyx_n_s_attributes, __pyx_n_s_non_serializable_attrs, __pyx_n_s_attr_name, __pyx_n_s_attr_value); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);
  __pyx_codeobj__55 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__54, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_check_serializability, 283, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__55)) __PYX_ERR(0, 283, __pyx_L1_error)

  /* "tbstock/utils/utils.py":292
 * 
 * 
 * def testCalendar():             # <<<<<<<<<<<<<<
 *     # date_str = '20190113'
 *     date_str = latest_trade_day
 */
  __pyx_tuple__56 = PyTuple_Pack(2, __pyx_n_s_date_str_2, __pyx_n_s_date); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);
  __pyx_codeobj__57 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__56, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_testCalendar, 292, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__57)) __PYX_ERR(0, 292, __pyx_L1_error)

  /* "tbstock/utils/utils.py":316
 * 
 * 
 * def extractAdministrativeRegions(text):             # <<<<<<<<<<<<<<
 *     #
 *     #
 */
  __pyx_tuple__58 = PyTuple_Pack(3, __pyx_n_s_text, __pyx_n_s_pattern, __pyx_n_s_regions); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);
  __pyx_codeobj__59 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__58, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_extractAdministrativeRegions, 316, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__59)) __PYX_ERR(0, 316, __pyx_L1_error)

  /* "tbstock/utils/utils.py":325
 * 
 * 
 * def startWithDigit(input_str):             # <<<<<<<<<<<<<<
 *     pattern = r'^\d'
 *     if re.match(pattern, input_str):
 */
  __pyx_tuple__60 = PyTuple_Pack(2, __pyx_n_s_input_str, __pyx_n_s_pattern); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);
  __pyx_codeobj__61 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__60, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_startWithDigit, 325, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__61)) __PYX_ERR(0, 325, __pyx_L1_error)

  /* "tbstock/utils/utils.py":333
 * 
 * 
 * def listIntersection(data_list: Union[List, None] = None, *args) -> list:             # <<<<<<<<<<<<<<
 *     '''
 *     use example:
 */
  __pyx_tuple__62 = PyTuple_Pack(5, __pyx_n_s_data_list, __pyx_n_s_args, __pyx_n_s_data, __pyx_n_s_intersection_list, __pyx_n_s_arg); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__62, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_listIntersection, 333, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) __PYX_ERR(0, 333, __pyx_L1_error)
  __pyx_tuple__64 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "tbstock/utils/utils.py":360
 * 
 * 
 * def listUnion(data_list: Union[List, None] = None, *args) -> list:             # <<<<<<<<<<<<<<
 *     '''
 *     list
 */
  __pyx_tuple__65 = PyTuple_Pack(5, __pyx_n_s_data_list, __pyx_n_s_args, __pyx_n_s_data, __pyx_n_s_union_list, __pyx_n_s_arg); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);
  __pyx_codeobj__66 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__65, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_listUnion, 360, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__66)) __PYX_ERR(0, 360, __pyx_L1_error)

  /* "tbstock/utils/utils.py":387
 * 
 * 
 * def strategyCount(data: Union[Dict, None] = None, **kwargs) -> pd.DataFrame():             # <<<<<<<<<<<<<<
 *     '''
 *     use example:
 */
  __pyx_tuple__67 = PyTuple_Pack(9, __pyx_n_s_data, __pyx_n_s_kwargs, __pyx_n_s_all_list, __pyx_n_s_strategy_name, __pyx_n_s_strategy_code_list, __pyx_n_s_count, __pyx_n_s_df, __pyx_n_s_list_2_dict, __pyx_n_s_key); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);
  __pyx_codeobj__68 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__67, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_strategyCount, 387, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__68)) __PYX_ERR(0, 387, __pyx_L1_error)

  /* "tbstock/utils/utils.py":419
 * 
 * 
 * def getFullStockCode(stock_code, mode='xx') -> str:             # <<<<<<<<<<<<<<
 *     '''
 *     # A 600 601 603 688 : 6068
 */
  __pyx_tuple__69 = PyTuple_Pack(3, __pyx_n_s_stock_code, __pyx_n_s_mode, __pyx_n_s_full_stock_code); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__69, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_getFullStockCode, 419, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(0, 419, __pyx_L1_error)
  __pyx_tuple__71 = PyTuple_Pack(1, ((PyObject*)__pyx_n_s_xx)); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);

  /* "tbstock/utils/utils.py":449
 * 
 * 
 * def isAPrimaryBoardStock(stock_code):             # <<<<<<<<<<<<<<
 *     if stock_code[0:2] in ["00", "30", "60", "68"] or stock_code[0] in ["4", "8"]:
 *         return True
 */
  __pyx_tuple__72 = PyTuple_Pack(1, __pyx_n_s_stock_code); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);
  __pyx_codeobj__73 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__72, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_isAPrimaryBoardStock, 449, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__73)) __PYX_ERR(0, 449, __pyx_L1_error)

  /* "tbstock/utils/utils.py":456
 * 
 * 
 * def getStockLimitUp(stock_code, stock_name):             # <<<<<<<<<<<<<<
 *     '''
 *     # 15610 %
 */
  __pyx_tuple__74 = PyTuple_Pack(3, __pyx_n_s_stock_code, __pyx_n_s_stock_name, __pyx_n_s_limit_up); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);
  __pyx_codeobj__75 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__74, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_getStockLimitUp, 456, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__75)) __PYX_ERR(0, 456, __pyx_L1_error)

  /* "tbstock/utils/utils.py":481
 * 
 * 
 * def splitDataframeByYear(data_in) -> dict:             # <<<<<<<<<<<<<<
 *     result = {}
 *     date_type = data_in['date'].dtype
 */
  __pyx_tuple__76 = PyTuple_Pack(5, __pyx_n_s_data_in, __pyx_n_s_result, __pyx_n_s_date_type, __pyx_n_s_year, __pyx_n_s_group); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);
  __pyx_codeobj__77 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__76, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_splitDataframeByYear, 481, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__77)) __PYX_ERR(0, 481, __pyx_L1_error)

  /* "tbstock/utils/utils.py":492
 * 
 * class MyEncoder(json.JSONEncoder):
 *     def default(self, obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, datetime):
 *             return obj.isoformat()
 */
  __pyx_tuple__78 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_obj); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);
  __pyx_codeobj__79 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_default, 492, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__79)) __PYX_ERR(0, 492, __pyx_L1_error)

  /* "tbstock/utils/utils.py":497
 *         return super().default(obj)
 * 
 *     def insert_newlines(self, text, interval):             # <<<<<<<<<<<<<<
 *         """
 *         intervaltext
 */
  __pyx_tuple__80 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_text, __pyx_n_s_interval, __pyx_n_s_comma_index, __pyx_n_s_wrapped_text, __pyx_n_s_index, __pyx_n_s_text_tail); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);
  __pyx_codeobj__81 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__80, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_insert_newlines, 497, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__81)) __PYX_ERR(0, 497, __pyx_L1_error)

  /* "tbstock/utils/utils.py":530
 *         return wrapped_text
 * 
 *     def encode(self, obj):             # <<<<<<<<<<<<<<
 *         chunks = self.iterencode(obj, _one_shot=True)
 *         # print('chunks = ', chunks)
 */
  __pyx_tuple__82 = PyTuple_Pack(15, __pyx_n_s_self, __pyx_n_s_obj, __pyx_n_s_chunks, __pyx_n_s_json_str, __pyx_n_s_list_start_idxs, __pyx_n_s_list_end_idxs, __pyx_n_s_num, __pyx_n_s_list_start_idx, __pyx_n_s_list_end_idx, __pyx_n_s_list_str, __pyx_n_s_cleaned_list_str, __pyx_n_s_i, __pyx_n_s_i, __pyx_n_s_i, __pyx_n_s_i); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 15, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__82, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_encode, 530, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(0, 530, __pyx_L1_error)

  /* "tbstock/utils/utils.py":580
 * 
 * 
 * def loadJsonData(load_json_file, json_file_name=''):             # <<<<<<<<<<<<<<
 *     update_json = {}
 *     try:
 */
  __pyx_tuple__84 = PyTuple_Pack(5, __pyx_n_s_load_json_file, __pyx_n_s_json_file_name, __pyx_n_s_update_json, __pyx_n_s_file, __pyx_n_s_has_update_file); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);
  __pyx_codeobj__85 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__84, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_loadJsonData, 580, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__85)) __PYX_ERR(0, 580, __pyx_L1_error)
  __pyx_tuple__86 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_s__4)); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);

  /* "tbstock/utils/utils.py":593
 * 
 * 
 * def dumpJsonToFile(load_json_file, update_json, json_file_name='', use_cls=True):             # <<<<<<<<<<<<<<
 *     #  JSON
 *     try:
 */
  __pyx_tuple__87 = PyTuple_Pack(6, __pyx_n_s_load_json_file, __pyx_n_s_update_json, __pyx_n_s_json_file_name, __pyx_n_s_use_cls, __pyx_n_s_json_string, __pyx_n_s_write_f); if (unlikely(!__pyx_tuple__87)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);
  __pyx_codeobj__88 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__87, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_dumpJsonToFile, 593, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__88)) __PYX_ERR(0, 593, __pyx_L1_error)
  __pyx_tuple__89 = PyTuple_Pack(2, ((PyObject*)__pyx_kp_s__4), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__89)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);

  /* "tbstock/utils/utils.py":609
 * 
 * 
 * def getYearStartEndDate(year_str: str, mode='trade'):             # <<<<<<<<<<<<<<
 *     '''
 *     mode = 'trade'
 */
  __pyx_tuple__90 = PyTuple_Pack(5, __pyx_n_s_year_str, __pyx_n_s_mode, __pyx_n_s_year_start, __pyx_n_s_year_int, __pyx_n_s_year_end); if (unlikely(!__pyx_tuple__90)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__90);
  __Pyx_GIVEREF(__pyx_tuple__90);
  __pyx_codeobj__91 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__90, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_getYearStartEndDate, 609, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__91)) __PYX_ERR(0, 609, __pyx_L1_error)
  __pyx_tuple__92 = PyTuple_Pack(1, ((PyObject*)__pyx_n_s_trade)); if (unlikely(!__pyx_tuple__92)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);

  /* "tbstock/utils/utils.py":627
 * 
 * 
 * def getDateDistribution(start_date: datetime, end_date: datetime):             # <<<<<<<<<<<<<<
 *     result = {}
 *     current_date = start_date
 */
  __pyx_tuple__93 = PyTuple_Pack(6, __pyx_n_s_start_date, __pyx_n_s_end_date, __pyx_n_s_result, __pyx_n_s_current_date, __pyx_n_s_year, __pyx_n_s_month12_days); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);
  __pyx_codeobj__94 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_getDateDistribution, 627, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__94)) __PYX_ERR(0, 627, __pyx_L1_error)

  /* "tbstock/utils/utils.py":640
 * 
 * 
 * def getMonthStartEndDate(year_str: str, month_str: str, mode='trade'):             # <<<<<<<<<<<<<<
 *     # calendar.monthrange
 *     year = int(year_str)
 */
  __pyx_tuple__95 = PyTuple_Pack(9, __pyx_n_s_year_str, __pyx_n_s_month_str, __pyx_n_s_mode, __pyx_n_s_year, __pyx_n_s_month, __pyx_n_s_first_weekday, __pyx_n_s_number_of_days, __pyx_n_s_start_date, __pyx_n_s_end_date); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);
  __pyx_codeobj__96 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__95, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_getMonthStartEndDate, 640, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__96)) __PYX_ERR(0, 640, __pyx_L1_error)

  /* "tbstock/utils/utils.py":660
 * 
 * 
 * def getSuspendedStocks() -> list:             # <<<<<<<<<<<<<<
 *     stock_tfp_em_df = ak.stock_tfp_em(date=latest_trade_day)
 *     suspended_stock_list = list(stock_tfp_em_df[''])
 */
  __pyx_tuple__97 = PyTuple_Pack(2, __pyx_n_s_stock_tfp_em_df, __pyx_n_s_suspended_stock_list); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);
  __pyx_codeobj__98 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_getSuspendedStocks, 660, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__98)) __PYX_ERR(0, 660, __pyx_L1_error)

  /* "tbstock/utils/utils.py":666
 * 
 * 
 * def getWeekStartEndByDate(given_date: datetime, mode='trade'):             # <<<<<<<<<<<<<<
 *     # 06
 *     weekday = given_date.weekday()
 */
  __pyx_tuple__99 = PyTuple_Pack(6, __pyx_n_s_given_date, __pyx_n_s_mode, __pyx_n_s_weekday, __pyx_n_s_start_of_week, __pyx_n_s_end_of_week, __pyx_n_s_week_number); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);
  __pyx_codeobj__100 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__99, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_getWeekStartEndByDate, 666, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__100)) __PYX_ERR(0, 666, __pyx_L1_error)

  /* "tbstock/utils/utils.py":688
 * 
 * 
 * def isStockDataSaveToMysql():             # <<<<<<<<<<<<<<
 *     json_file_name = latest_trade_day + '_updatelog.json'
 *     load_json_file = update_db_logs_dir + json_file_name
 */
  __pyx_tuple__101 = PyTuple_Pack(4, __pyx_n_s_json_file_name, __pyx_n_s_load_json_file, __pyx_n_s_has_update_file, __pyx_n_s_update_json); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);
  __pyx_codeobj__102 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__101, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_isStockDataSaveToMysql, 688, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__102)) __PYX_ERR(0, 688, __pyx_L1_error)

  /* "tbstock/utils/utils.py":698
 * 
 * 
 * def isWeekLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     week, start_date, end_date = getWeekStartEndByDate(trade_date)
 *     if week == start_date and week == end_date:
 */
  __pyx_tuple__103 = PyTuple_Pack(4, __pyx_n_s_trade_date, __pyx_n_s_week, __pyx_n_s_start_date, __pyx_n_s_end_date); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);
  __pyx_codeobj__104 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__103, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_isWeekLastTradeDay, 698, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__104)) __PYX_ERR(0, 698, __pyx_L1_error)

  /* "tbstock/utils/utils.py":708
 * 
 * 
 * def isMonthLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     trade_year = str(trade_date.year)
 *     trade_month = str(trade_date.month)
 */
  __pyx_tuple__105 = PyTuple_Pack(5, __pyx_n_s_trade_date, __pyx_n_s_trade_year, __pyx_n_s_trade_month, __pyx_n_s_start_date, __pyx_n_s_end_date); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(0, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);
  __pyx_codeobj__106 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__105, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_isMonthLastTradeDay, 708, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__106)) __PYX_ERR(0, 708, __pyx_L1_error)

  /* "tbstock/utils/utils.py":718
 * 
 * 
 * def isYearLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     trade_year = str(trade_date.year)
 *     start_date, end_date = getYearStartEndDate(trade_year)
 */
  __pyx_tuple__107 = PyTuple_Pack(4, __pyx_n_s_trade_date, __pyx_n_s_trade_year, __pyx_n_s_start_date, __pyx_n_s_end_date); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);
  __pyx_codeobj__108 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__107, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_isYearLastTradeDay, 718, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__108)) __PYX_ERR(0, 718, __pyx_L1_error)

  /* "tbstock/utils/utils.py":727
 * 
 * 
 * def test():             # <<<<<<<<<<<<<<
 *     # year = '2019'
 *     # start_date, end_date = getYearStartEndDate(year)
 */
  __pyx_tuple__109 = PyTuple_Pack(10, __pyx_n_s_list1, __pyx_n_s_list2, __pyx_n_s_list3, __pyx_n_s_intersec_list, __pyx_n_s_all_list, __pyx_n_s_union_list, __pyx_n_s_Counter, __pyx_n_s_combined_list, __pyx_n_s_count, __pyx_n_s_df); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);
  __pyx_codeobj__110 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__109, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_utils_utils_py, __pyx_n_s_test, 727, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__110)) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_float_0_0 = PyFloat_FromDouble(0.0); if (unlikely(!__pyx_float_0_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_1 = PyFloat_FromDouble(0.1); if (unlikely(!__pyx_float_0_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_2 = PyFloat_FromDouble(0.2); if (unlikely(!__pyx_float_0_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_7 = PyFloat_FromDouble(0.7); if (unlikely(!__pyx_float_0_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_8 = PyFloat_FromDouble(0.8); if (unlikely(!__pyx_float_0_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_9 = PyFloat_FromDouble(0.9); if (unlikely(!__pyx_float_0_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_0 = PyFloat_FromDouble(1.0); if (unlikely(!__pyx_float_1_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_1 = PyFloat_FromDouble(1.1); if (unlikely(!__pyx_float_1_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_3 = PyFloat_FromDouble(1.3); if (unlikely(!__pyx_float_1_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_5 = PyFloat_FromDouble(1.5); if (unlikely(!__pyx_float_1_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_6 = PyFloat_FromDouble(1.6); if (unlikely(!__pyx_float_1_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_9 = PyFloat_FromDouble(1.9); if (unlikely(!__pyx_float_1_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_3 = PyFloat_FromDouble(2.3); if (unlikely(!__pyx_float_2_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_6 = PyFloat_FromDouble(2.6); if (unlikely(!__pyx_float_2_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_7 = PyFloat_FromDouble(2.7); if (unlikely(!__pyx_float_2_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_0 = PyFloat_FromDouble(3.0); if (unlikely(!__pyx_float_3_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_6 = PyFloat_FromDouble(3.6); if (unlikely(!__pyx_float_3_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_01 = PyFloat_FromDouble(0.01); if (unlikely(!__pyx_float_0_01)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_02 = PyFloat_FromDouble(0.02); if (unlikely(!__pyx_float_0_02)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_03 = PyFloat_FromDouble(0.03); if (unlikely(!__pyx_float_0_03)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_04 = PyFloat_FromDouble(0.04); if (unlikely(!__pyx_float_0_04)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_05 = PyFloat_FromDouble(0.05); if (unlikely(!__pyx_float_0_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_06 = PyFloat_FromDouble(0.06); if (unlikely(!__pyx_float_0_06)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_08 = PyFloat_FromDouble(0.08); if (unlikely(!__pyx_float_0_08)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_14 = PyFloat_FromDouble(0.14); if (unlikely(!__pyx_float_0_14)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_15 = PyFloat_FromDouble(0.15); if (unlikely(!__pyx_float_0_15)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_16 = PyFloat_FromDouble(0.16); if (unlikely(!__pyx_float_0_16)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_17 = PyFloat_FromDouble(0.17); if (unlikely(!__pyx_float_0_17)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_18 = PyFloat_FromDouble(0.18); if (unlikely(!__pyx_float_0_18)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_24 = PyFloat_FromDouble(0.24); if (unlikely(!__pyx_float_0_24)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_25 = PyFloat_FromDouble(0.25); if (unlikely(!__pyx_float_0_25)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_29 = PyFloat_FromDouble(0.29); if (unlikely(!__pyx_float_0_29)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_33 = PyFloat_FromDouble(0.33); if (unlikely(!__pyx_float_0_33)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_34 = PyFloat_FromDouble(0.34); if (unlikely(!__pyx_float_0_34)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_37 = PyFloat_FromDouble(0.37); if (unlikely(!__pyx_float_0_37)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_38 = PyFloat_FromDouble(0.38); if (unlikely(!__pyx_float_0_38)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_42 = PyFloat_FromDouble(0.42); if (unlikely(!__pyx_float_0_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_44 = PyFloat_FromDouble(0.44); if (unlikely(!__pyx_float_0_44)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_47 = PyFloat_FromDouble(0.47); if (unlikely(!__pyx_float_0_47)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_54 = PyFloat_FromDouble(0.54); if (unlikely(!__pyx_float_0_54)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_57 = PyFloat_FromDouble(0.57); if (unlikely(!__pyx_float_0_57)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_61 = PyFloat_FromDouble(0.61); if (unlikely(!__pyx_float_0_61)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_65 = PyFloat_FromDouble(0.65); if (unlikely(!__pyx_float_0_65)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_66 = PyFloat_FromDouble(0.66); if (unlikely(!__pyx_float_0_66)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_69 = PyFloat_FromDouble(0.69); if (unlikely(!__pyx_float_0_69)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_77 = PyFloat_FromDouble(0.77); if (unlikely(!__pyx_float_0_77)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_78 = PyFloat_FromDouble(0.78); if (unlikely(!__pyx_float_0_78)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_82 = PyFloat_FromDouble(0.82); if (unlikely(!__pyx_float_0_82)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_83 = PyFloat_FromDouble(0.83); if (unlikely(!__pyx_float_0_83)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_84 = PyFloat_FromDouble(0.84); if (unlikely(!__pyx_float_0_84)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_87 = PyFloat_FromDouble(0.87); if (unlikely(!__pyx_float_0_87)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_89 = PyFloat_FromDouble(0.89); if (unlikely(!__pyx_float_0_89)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_91 = PyFloat_FromDouble(0.91); if (unlikely(!__pyx_float_0_91)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_92 = PyFloat_FromDouble(0.92); if (unlikely(!__pyx_float_0_92)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_93 = PyFloat_FromDouble(0.93); if (unlikely(!__pyx_float_0_93)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_95 = PyFloat_FromDouble(0.95); if (unlikely(!__pyx_float_0_95)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_96 = PyFloat_FromDouble(0.96); if (unlikely(!__pyx_float_0_96)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_97 = PyFloat_FromDouble(0.97); if (unlikely(!__pyx_float_0_97)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_98 = PyFloat_FromDouble(0.98); if (unlikely(!__pyx_float_0_98)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_99 = PyFloat_FromDouble(0.99); if (unlikely(!__pyx_float_0_99)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_01 = PyFloat_FromDouble(1.01); if (unlikely(!__pyx_float_1_01)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_03 = PyFloat_FromDouble(1.03); if (unlikely(!__pyx_float_1_03)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_04 = PyFloat_FromDouble(1.04); if (unlikely(!__pyx_float_1_04)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_05 = PyFloat_FromDouble(1.05); if (unlikely(!__pyx_float_1_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_08 = PyFloat_FromDouble(1.08); if (unlikely(!__pyx_float_1_08)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_09 = PyFloat_FromDouble(1.09); if (unlikely(!__pyx_float_1_09)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_11 = PyFloat_FromDouble(1.11); if (unlikely(!__pyx_float_1_11)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_12 = PyFloat_FromDouble(1.12); if (unlikely(!__pyx_float_1_12)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_14 = PyFloat_FromDouble(1.14); if (unlikely(!__pyx_float_1_14)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_21 = PyFloat_FromDouble(1.21); if (unlikely(!__pyx_float_1_21)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_22 = PyFloat_FromDouble(1.22); if (unlikely(!__pyx_float_1_22)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_24 = PyFloat_FromDouble(1.24); if (unlikely(!__pyx_float_1_24)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_28 = PyFloat_FromDouble(1.28); if (unlikely(!__pyx_float_1_28)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_29 = PyFloat_FromDouble(1.29); if (unlikely(!__pyx_float_1_29)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_31 = PyFloat_FromDouble(1.31); if (unlikely(!__pyx_float_1_31)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_34 = PyFloat_FromDouble(1.34); if (unlikely(!__pyx_float_1_34)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_37 = PyFloat_FromDouble(1.37); if (unlikely(!__pyx_float_1_37)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_39 = PyFloat_FromDouble(1.39); if (unlikely(!__pyx_float_1_39)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_41 = PyFloat_FromDouble(1.41); if (unlikely(!__pyx_float_1_41)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_42 = PyFloat_FromDouble(1.42); if (unlikely(!__pyx_float_1_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_48 = PyFloat_FromDouble(1.48); if (unlikely(!__pyx_float_1_48)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_49 = PyFloat_FromDouble(1.49); if (unlikely(!__pyx_float_1_49)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_51 = PyFloat_FromDouble(1.51); if (unlikely(!__pyx_float_1_51)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_52 = PyFloat_FromDouble(1.52); if (unlikely(!__pyx_float_1_52)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_53 = PyFloat_FromDouble(1.53); if (unlikely(!__pyx_float_1_53)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_55 = PyFloat_FromDouble(1.55); if (unlikely(!__pyx_float_1_55)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_56 = PyFloat_FromDouble(1.56); if (unlikely(!__pyx_float_1_56)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_63 = PyFloat_FromDouble(1.63); if (unlikely(!__pyx_float_1_63)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_65 = PyFloat_FromDouble(1.65); if (unlikely(!__pyx_float_1_65)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_66 = PyFloat_FromDouble(1.66); if (unlikely(!__pyx_float_1_66)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_69 = PyFloat_FromDouble(1.69); if (unlikely(!__pyx_float_1_69)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_83 = PyFloat_FromDouble(1.83); if (unlikely(!__pyx_float_1_83)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_88 = PyFloat_FromDouble(1.88); if (unlikely(!__pyx_float_1_88)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_96 = PyFloat_FromDouble(1.96); if (unlikely(!__pyx_float_1_96)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_97 = PyFloat_FromDouble(1.97); if (unlikely(!__pyx_float_1_97)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_98 = PyFloat_FromDouble(1.98); if (unlikely(!__pyx_float_1_98)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_01 = PyFloat_FromDouble(2.01); if (unlikely(!__pyx_float_2_01)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_07 = PyFloat_FromDouble(2.07); if (unlikely(!__pyx_float_2_07)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_08 = PyFloat_FromDouble(2.08); if (unlikely(!__pyx_float_2_08)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_19 = PyFloat_FromDouble(2.19); if (unlikely(!__pyx_float_2_19)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_25 = PyFloat_FromDouble(2.25); if (unlikely(!__pyx_float_2_25)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_26 = PyFloat_FromDouble(2.26); if (unlikely(!__pyx_float_2_26)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_28 = PyFloat_FromDouble(2.28); if (unlikely(!__pyx_float_2_28)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_31 = PyFloat_FromDouble(2.31); if (unlikely(!__pyx_float_2_31)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_41 = PyFloat_FromDouble(2.41); if (unlikely(!__pyx_float_2_41)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_48 = PyFloat_FromDouble(2.48); if (unlikely(!__pyx_float_2_48)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_49 = PyFloat_FromDouble(2.49); if (unlikely(!__pyx_float_2_49)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_52 = PyFloat_FromDouble(2.52); if (unlikely(!__pyx_float_2_52)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_57 = PyFloat_FromDouble(2.57); if (unlikely(!__pyx_float_2_57)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_62 = PyFloat_FromDouble(2.62); if (unlikely(!__pyx_float_2_62)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_77 = PyFloat_FromDouble(2.77); if (unlikely(!__pyx_float_2_77)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_81 = PyFloat_FromDouble(2.81); if (unlikely(!__pyx_float_2_81)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_07 = PyFloat_FromDouble(3.07); if (unlikely(!__pyx_float_3_07)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_12 = PyFloat_FromDouble(3.12); if (unlikely(!__pyx_float_3_12)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_35 = PyFloat_FromDouble(3.35); if (unlikely(!__pyx_float_3_35)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_83 = PyFloat_FromDouble(3.83); if (unlikely(!__pyx_float_3_83)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_94 = PyFloat_FromDouble(3.94); if (unlikely(!__pyx_float_3_94)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_99 = PyFloat_FromDouble(3.99); if (unlikely(!__pyx_float_3_99)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_33_8 = PyFloat_FromDouble(33.8); if (unlikely(!__pyx_float_33_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4_17 = PyFloat_FromDouble(4.17); if (unlikely(!__pyx_float_4_17)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4_54 = PyFloat_FromDouble(4.54); if (unlikely(!__pyx_float_4_54)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5_64 = PyFloat_FromDouble(5.64); if (unlikely(!__pyx_float_5_64)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5_94 = PyFloat_FromDouble(5.94); if (unlikely(!__pyx_float_5_94)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6_33 = PyFloat_FromDouble(6.33); if (unlikely(!__pyx_float_6_33)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6_79 = PyFloat_FromDouble(6.79); if (unlikely(!__pyx_float_6_79)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6_81 = PyFloat_FromDouble(6.81); if (unlikely(!__pyx_float_6_81)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_15_27 = PyFloat_FromDouble(15.27); if (unlikely(!__pyx_float_15_27)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_22_72 = PyFloat_FromDouble(22.72); if (unlikely(!__pyx_float_22_72)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_25_27 = PyFloat_FromDouble(25.27); if (unlikely(!__pyx_float_25_27)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_60_05 = PyFloat_FromDouble(60.05); if (unlikely(!__pyx_float_60_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1022_9 = PyFloat_FromDouble(1022.9); if (unlikely(!__pyx_float_1022_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1031_8 = PyFloat_FromDouble(1031.8); if (unlikely(!__pyx_float_1031_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1853_0 = PyFloat_FromDouble(1853.0); if (unlikely(!__pyx_float_1853_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_212_89 = PyFloat_FromDouble(212.89); if (unlikely(!__pyx_float_212_89)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_212_93 = PyFloat_FromDouble(212.93); if (unlikely(!__pyx_float_212_93)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_212_94 = PyFloat_FromDouble(212.94); if (unlikely(!__pyx_float_212_94)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_212_96 = PyFloat_FromDouble(212.96); if (unlikely(!__pyx_float_212_96)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_227_77 = PyFloat_FromDouble(227.77); if (unlikely(!__pyx_float_227_77)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_228_24 = PyFloat_FromDouble(228.24); if (unlikely(!__pyx_float_228_24)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_228_28 = PyFloat_FromDouble(228.28); if (unlikely(!__pyx_float_228_28)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_234_61 = PyFloat_FromDouble(234.61); if (unlikely(!__pyx_float_234_61)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2631_7 = PyFloat_FromDouble(2631.7); if (unlikely(!__pyx_float_2631_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_286_71 = PyFloat_FromDouble(286.71); if (unlikely(!__pyx_float_286_71)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_286_73 = PyFloat_FromDouble(286.73); if (unlikely(!__pyx_float_286_73)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_286_75 = PyFloat_FromDouble(286.75); if (unlikely(!__pyx_float_286_75)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3987_1 = PyFloat_FromDouble(3987.1); if (unlikely(!__pyx_float_3987_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4190_2 = PyFloat_FromDouble(4190.2); if (unlikely(!__pyx_float_4190_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5155_7 = PyFloat_FromDouble(5155.7); if (unlikely(!__pyx_float_5155_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5190_0 = PyFloat_FromDouble(5190.0); if (unlikely(!__pyx_float_5190_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5198_9 = PyFloat_FromDouble(5198.9); if (unlikely(!__pyx_float_5198_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5220_0 = PyFloat_FromDouble(5220.0); if (unlikely(!__pyx_float_5220_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5228_8 = PyFloat_FromDouble(5228.8); if (unlikely(!__pyx_float_5228_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5805_4 = PyFloat_FromDouble(5805.4); if (unlikely(!__pyx_float_5805_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5809_3 = PyFloat_FromDouble(5809.3); if (unlikely(!__pyx_float_5809_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6500_9 = PyFloat_FromDouble(6500.9); if (unlikely(!__pyx_float_6500_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6635_4 = PyFloat_FromDouble(6635.4); if (unlikely(!__pyx_float_6635_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6765_7 = PyFloat_FromDouble(6765.7); if (unlikely(!__pyx_float_6765_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_726_77 = PyFloat_FromDouble(726.77); if (unlikely(!__pyx_float_726_77)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_728_11 = PyFloat_FromDouble(728.11); if (unlikely(!__pyx_float_728_11)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_729_84 = PyFloat_FromDouble(729.84); if (unlikely(!__pyx_float_729_84)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_731_52 = PyFloat_FromDouble(731.52); if (unlikely(!__pyx_float_731_52)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_733_56 = PyFloat_FromDouble(733.56); if (unlikely(!__pyx_float_733_56)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_737_93 = PyFloat_FromDouble(737.93); if (unlikely(!__pyx_float_737_93)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_739_05 = PyFloat_FromDouble(739.05); if (unlikely(!__pyx_float_739_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_743_23 = PyFloat_FromDouble(743.23); if (unlikely(!__pyx_float_743_23)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_744_39 = PyFloat_FromDouble(744.39); if (unlikely(!__pyx_float_744_39)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_749_42 = PyFloat_FromDouble(749.42); if (unlikely(!__pyx_float_749_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7577_1 = PyFloat_FromDouble(7577.1); if (unlikely(!__pyx_float_7577_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7893_4 = PyFloat_FromDouble(7893.4); if (unlikely(!__pyx_float_7893_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7944_1 = PyFloat_FromDouble(7944.1); if (unlikely(!__pyx_float_7944_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_9343_8 = PyFloat_FromDouble(9343.8); if (unlikely(!__pyx_float_9343_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1007_63 = PyFloat_FromDouble(1007.63); if (unlikely(!__pyx_float_1007_63)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1008_59 = PyFloat_FromDouble(1008.59); if (unlikely(!__pyx_float_1008_59)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1018_36 = PyFloat_FromDouble(1018.36); if (unlikely(!__pyx_float_1018_36)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1130_64 = PyFloat_FromDouble(1130.64); if (unlikely(!__pyx_float_1130_64)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1139_84 = PyFloat_FromDouble(1139.84); if (unlikely(!__pyx_float_1139_84)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1147_42 = PyFloat_FromDouble(1147.42); if (unlikely(!__pyx_float_1147_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1150_35 = PyFloat_FromDouble(1150.35); if (unlikely(!__pyx_float_1150_35)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1153_16 = PyFloat_FromDouble(1153.16); if (unlikely(!__pyx_float_1153_16)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1408_48 = PyFloat_FromDouble(1408.48); if (unlikely(!__pyx_float_1408_48)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1417_17 = PyFloat_FromDouble(1417.17); if (unlikely(!__pyx_float_1417_17)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1428_83 = PyFloat_FromDouble(1428.83); if (unlikely(!__pyx_float_1428_83)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1429_59 = PyFloat_FromDouble(1429.59); if (unlikely(!__pyx_float_1429_59)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1432_13 = PyFloat_FromDouble(1432.13); if (unlikely(!__pyx_float_1432_13)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1661_57 = PyFloat_FromDouble(1661.57); if (unlikely(!__pyx_float_1661_57)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1677_68 = PyFloat_FromDouble(1677.68); if (unlikely(!__pyx_float_1677_68)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1679_31 = PyFloat_FromDouble(1679.31); if (unlikely(!__pyx_float_1679_31)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1683_87 = PyFloat_FromDouble(1683.87); if (unlikely(!__pyx_float_1683_87)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1693_48 = PyFloat_FromDouble(1693.48); if (unlikely(!__pyx_float_1693_48)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1764_84 = PyFloat_FromDouble(1764.84); if (unlikely(!__pyx_float_1764_84)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1781_07 = PyFloat_FromDouble(1781.07); if (unlikely(!__pyx_float_1781_07)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1812_46 = PyFloat_FromDouble(1812.46); if (unlikely(!__pyx_float_1812_46)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1820_45 = PyFloat_FromDouble(1820.45); if (unlikely(!__pyx_float_1820_45)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1820_74 = PyFloat_FromDouble(1820.74); if (unlikely(!__pyx_float_1820_74)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1849_49 = PyFloat_FromDouble(1849.49); if (unlikely(!__pyx_float_1849_49)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1865_28 = PyFloat_FromDouble(1865.28); if (unlikely(!__pyx_float_1865_28)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1883_29 = PyFloat_FromDouble(1883.29); if (unlikely(!__pyx_float_1883_29)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1890_25 = PyFloat_FromDouble(1890.25); if (unlikely(!__pyx_float_1890_25)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2444_93 = PyFloat_FromDouble(2444.93); if (unlikely(!__pyx_float_2444_93)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2457_26 = PyFloat_FromDouble(2457.26); if (unlikely(!__pyx_float_2457_26)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2467_89 = PyFloat_FromDouble(2467.89); if (unlikely(!__pyx_float_2467_89)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2473_17 = PyFloat_FromDouble(2473.17); if (unlikely(!__pyx_float_2473_17)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2476_46 = PyFloat_FromDouble(2476.46); if (unlikely(!__pyx_float_2476_46)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2585_19 = PyFloat_FromDouble(2585.19); if (unlikely(!__pyx_float_2585_19)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2611_09 = PyFloat_FromDouble(2611.09); if (unlikely(!__pyx_float_2611_09)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2614_69 = PyFloat_FromDouble(2614.69); if (unlikely(!__pyx_float_2614_69)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2650_98 = PyFloat_FromDouble(2650.98); if (unlikely(!__pyx_float_2650_98)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3031_04 = PyFloat_FromDouble(3031.04); if (unlikely(!__pyx_float_3031_04)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3048_79 = PyFloat_FromDouble(3048.79); if (unlikely(!__pyx_float_3048_79)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3051_28 = PyFloat_FromDouble(3051.28); if (unlikely(!__pyx_float_3051_28)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3053_92 = PyFloat_FromDouble(3053.92); if (unlikely(!__pyx_float_3053_92)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3065_02 = PyFloat_FromDouble(3065.02); if (unlikely(!__pyx_float_3065_02)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3276_87 = PyFloat_FromDouble(3276.87); if (unlikely(!__pyx_float_3276_87)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3305_01 = PyFloat_FromDouble(3305.01); if (unlikely(!__pyx_float_3305_01)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3367_67 = PyFloat_FromDouble(3367.67); if (unlikely(!__pyx_float_3367_67)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3382_54 = PyFloat_FromDouble(3382.54); if (unlikely(!__pyx_float_3382_54)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3386_95 = PyFloat_FromDouble(3386.95); if (unlikely(!__pyx_float_3386_95)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3390_29 = PyFloat_FromDouble(3390.29); if (unlikely(!__pyx_float_3390_29)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3411_14 = PyFloat_FromDouble(3411.14); if (unlikely(!__pyx_float_3411_14)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3435_35 = PyFloat_FromDouble(3435.35); if (unlikely(!__pyx_float_3435_35)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3435_84 = PyFloat_FromDouble(3435.84); if (unlikely(!__pyx_float_3435_84)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3442_73 = PyFloat_FromDouble(3442.73); if (unlikely(!__pyx_float_3442_73)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3552_09 = PyFloat_FromDouble(3552.09); if (unlikely(!__pyx_float_3552_09)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3574_11 = PyFloat_FromDouble(3574.11); if (unlikely(!__pyx_float_3574_11)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3592_25 = PyFloat_FromDouble(3592.25); if (unlikely(!__pyx_float_3592_25)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3594_63 = PyFloat_FromDouble(3594.63); if (unlikely(!__pyx_float_3594_63)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3603_07 = PyFloat_FromDouble(3603.07); if (unlikely(!__pyx_float_3603_07)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3757_42 = PyFloat_FromDouble(3757.42); if (unlikely(!__pyx_float_3757_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3761_37 = PyFloat_FromDouble(3761.37); if (unlikely(!__pyx_float_3761_37)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3784_58 = PyFloat_FromDouble(3784.58); if (unlikely(!__pyx_float_3784_58)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3815_88 = PyFloat_FromDouble(3815.88); if (unlikely(!__pyx_float_3815_88)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3817_47 = PyFloat_FromDouble(3817.47); if (unlikely(!__pyx_float_3817_47)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3835_07 = PyFloat_FromDouble(3835.07); if (unlikely(!__pyx_float_3835_07)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3840_42 = PyFloat_FromDouble(3840.42); if (unlikely(!__pyx_float_3840_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3858_67 = PyFloat_FromDouble(3858.67); if (unlikely(!__pyx_float_3858_67)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3864_01 = PyFloat_FromDouble(3864.01); if (unlikely(!__pyx_float_3864_01)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3872_92 = PyFloat_FromDouble(3872.92); if (unlikely(!__pyx_float_3872_92)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3907_11 = PyFloat_FromDouble(3907.11); if (unlikely(!__pyx_float_3907_11)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3937_27 = PyFloat_FromDouble(3937.27); if (unlikely(!__pyx_float_3937_27)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3977_71 = PyFloat_FromDouble(3977.71); if (unlikely(!__pyx_float_3977_71)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3979_35 = PyFloat_FromDouble(3979.35); if (unlikely(!__pyx_float_3979_35)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4091_72 = PyFloat_FromDouble(4091.72); if (unlikely(!__pyx_float_4091_72)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4120_29 = PyFloat_FromDouble(4120.29); if (unlikely(!__pyx_float_4120_29)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4127_98 = PyFloat_FromDouble(4127.98); if (unlikely(!__pyx_float_4127_98)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4136_21 = PyFloat_FromDouble(4136.21); if (unlikely(!__pyx_float_4136_21)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4149_23 = PyFloat_FromDouble(4149.23); if (unlikely(!__pyx_float_4149_23)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4158_24 = PyFloat_FromDouble(4158.24); if (unlikely(!__pyx_float_4158_24)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4192_82 = PyFloat_FromDouble(4192.82); if (unlikely(!__pyx_float_4192_82)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4203_02 = PyFloat_FromDouble(4203.02); if (unlikely(!__pyx_float_4203_02)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4223_36 = PyFloat_FromDouble(4223.36); if (unlikely(!__pyx_float_4223_36)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5096_08 = PyFloat_FromDouble(5096.08); if (unlikely(!__pyx_float_5096_08)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5126_06 = PyFloat_FromDouble(5126.06); if (unlikely(!__pyx_float_5126_06)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5130_87 = PyFloat_FromDouble(5130.87); if (unlikely(!__pyx_float_5130_87)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5153_54 = PyFloat_FromDouble(5153.54); if (unlikely(!__pyx_float_5153_54)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5153_59 = PyFloat_FromDouble(5153.59); if (unlikely(!__pyx_float_5153_59)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5159_17 = PyFloat_FromDouble(5159.17); if (unlikely(!__pyx_float_5159_17)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5172_05 = PyFloat_FromDouble(5172.05); if (unlikely(!__pyx_float_5172_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5174_86 = PyFloat_FromDouble(5174.86); if (unlikely(!__pyx_float_5174_86)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5187_77 = PyFloat_FromDouble(5187.77); if (unlikely(!__pyx_float_5187_77)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5190_01 = PyFloat_FromDouble(5190.01); if (unlikely(!__pyx_float_5190_01)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5192_26 = PyFloat_FromDouble(5192.26); if (unlikely(!__pyx_float_5192_26)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5205_05 = PyFloat_FromDouble(5205.05); if (unlikely(!__pyx_float_5205_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5208_98 = PyFloat_FromDouble(5208.98); if (unlikely(!__pyx_float_5208_98)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5247_15 = PyFloat_FromDouble(5247.15); if (unlikely(!__pyx_float_5247_15)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5258_82 = PyFloat_FromDouble(5258.82); if (unlikely(!__pyx_float_5258_82)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5688_88 = PyFloat_FromDouble(5688.88); if (unlikely(!__pyx_float_5688_88)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5734_42 = PyFloat_FromDouble(5734.42); if (unlikely(!__pyx_float_5734_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5747_23 = PyFloat_FromDouble(5747.23); if (unlikely(!__pyx_float_5747_23)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5790_92 = PyFloat_FromDouble(5790.92); if (unlikely(!__pyx_float_5790_92)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5793_29 = PyFloat_FromDouble(5793.29); if (unlikely(!__pyx_float_5793_29)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5848_18 = PyFloat_FromDouble(5848.18); if (unlikely(!__pyx_float_5848_18)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5856_89 = PyFloat_FromDouble(5856.89); if (unlikely(!__pyx_float_5856_89)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5868_62 = PyFloat_FromDouble(5868.62); if (unlikely(!__pyx_float_5868_62)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5964_03 = PyFloat_FromDouble(5964.03); if (unlikely(!__pyx_float_5964_03)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5994_52 = PyFloat_FromDouble(5994.52); if (unlikely(!__pyx_float_5994_52)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6018_11 = PyFloat_FromDouble(6018.11); if (unlikely(!__pyx_float_6018_11)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6029_51 = PyFloat_FromDouble(6029.51); if (unlikely(!__pyx_float_6029_51)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6042_92 = PyFloat_FromDouble(6042.92); if (unlikely(!__pyx_float_6042_92)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6557_41 = PyFloat_FromDouble(6557.41); if (unlikely(!__pyx_float_6557_41)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6651_35 = PyFloat_FromDouble(6651.35); if (unlikely(!__pyx_float_6651_35)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6656_99 = PyFloat_FromDouble(6656.99); if (unlikely(!__pyx_float_6656_99)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6677_79 = PyFloat_FromDouble(6677.79); if (unlikely(!__pyx_float_6677_79)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6709_81 = PyFloat_FromDouble(6709.81); if (unlikely(!__pyx_float_6709_81)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6740_32 = PyFloat_FromDouble(6740.32); if (unlikely(!__pyx_float_6740_32)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_6747_41 = PyFloat_FromDouble(6747.41); if (unlikely(!__pyx_float_6747_41)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7525_19 = PyFloat_FromDouble(7525.19); if (unlikely(!__pyx_float_7525_19)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7583_68 = PyFloat_FromDouble(7583.68); if (unlikely(!__pyx_float_7583_68)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7602_37 = PyFloat_FromDouble(7602.37); if (unlikely(!__pyx_float_7602_37)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7624_17 = PyFloat_FromDouble(7624.17); if (unlikely(!__pyx_float_7624_17)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7814_84 = PyFloat_FromDouble(7814.84); if (unlikely(!__pyx_float_7814_84)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7831_78 = PyFloat_FromDouble(7831.78); if (unlikely(!__pyx_float_7831_78)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7839_59 = PyFloat_FromDouble(7839.59); if (unlikely(!__pyx_float_7839_59)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7860_74 = PyFloat_FromDouble(7860.74); if (unlikely(!__pyx_float_7860_74)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7876_76 = PyFloat_FromDouble(7876.76); if (unlikely(!__pyx_float_7876_76)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7899_72 = PyFloat_FromDouble(7899.72); if (unlikely(!__pyx_float_7899_72)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7910_66 = PyFloat_FromDouble(7910.66); if (unlikely(!__pyx_float_7910_66)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7911_67 = PyFloat_FromDouble(7911.67); if (unlikely(!__pyx_float_7911_67)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7912_57 = PyFloat_FromDouble(7912.57); if (unlikely(!__pyx_float_7912_57)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7937_92 = PyFloat_FromDouble(7937.92); if (unlikely(!__pyx_float_7937_92)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7946_23 = PyFloat_FromDouble(7946.23); if (unlikely(!__pyx_float_7946_23)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7957_87 = PyFloat_FromDouble(7957.87); if (unlikely(!__pyx_float_7957_87)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_7980_24 = PyFloat_FromDouble(7980.24); if (unlikely(!__pyx_float_7980_24)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_9181_89 = PyFloat_FromDouble(9181.89); if (unlikely(!__pyx_float_9181_89)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_9255_68 = PyFloat_FromDouble(9255.68); if (unlikely(!__pyx_float_9255_68)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_9340_01 = PyFloat_FromDouble(9340.01); if (unlikely(!__pyx_float_9340_01)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_9366_34 = PyFloat_FromDouble(9366.34); if (unlikely(!__pyx_float_9366_34)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_11945_41 = PyFloat_FromDouble(11945.41); if (unlikely(!__pyx_float_11945_41)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_12041_42 = PyFloat_FromDouble(12041.42); if (unlikely(!__pyx_float_12041_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_12145_82 = PyFloat_FromDouble(12145.82); if (unlikely(!__pyx_float_12145_82)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_12156_05 = PyFloat_FromDouble(12156.05); if (unlikely(!__pyx_float_12156_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_12185_37 = PyFloat_FromDouble(12185.37); if (unlikely(!__pyx_float_12185_37)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_500282_0 = PyFloat_FromDouble(500282.0); if (unlikely(!__pyx_float_500282_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_23948464_0 = PyFloat_FromDouble(23948464.0); if (unlikely(!__pyx_float_23948464_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_140532459_6 = PyFloat_FromDouble(140532459.6); if (unlikely(!__pyx_float_140532459_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2244259683_0 = PyFloat_FromDouble(2244259683.0); if (unlikely(!__pyx_float_2244259683_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2377053666_0 = PyFloat_FromDouble(2377053666.0); if (unlikely(!__pyx_float_2377053666_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_10894972910_0 = PyFloat_FromDouble(10894972910.0); if (unlikely(!__pyx_float_10894972910_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_14464539893_0 = PyFloat_FromDouble(14464539893.0); if (unlikely(!__pyx_float_14464539893_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_15092302335_0 = PyFloat_FromDouble(15092302335.0); if (unlikely(!__pyx_float_15092302335_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_36121085540_7 = PyFloat_FromDouble(36121085540.7); if (unlikely(!__pyx_float_36121085540_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_45120126315_0 = PyFloat_FromDouble(45120126315.0); if (unlikely(!__pyx_float_45120126315_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_58648181396_0 = PyFloat_FromDouble(58648181396.0); if (unlikely(!__pyx_float_58648181396_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_61566668750_0 = PyFloat_FromDouble(61566668750.0); if (unlikely(!__pyx_float_61566668750_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_64786605_7657 = PyFloat_FromDouble(64786605.7657); if (unlikely(!__pyx_float_64786605_7657)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_70813170022_0 = PyFloat_FromDouble(70813170022.0); if (unlikely(!__pyx_float_70813170022_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_81258098177_0 = PyFloat_FromDouble(81258098177.0); if (unlikely(!__pyx_float_81258098177_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_89734052295_0 = PyFloat_FromDouble(89734052295.0); if (unlikely(!__pyx_float_89734052295_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_98770455187_0 = PyFloat_FromDouble(98770455187.0); if (unlikely(!__pyx_float_98770455187_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_115940476191_2 = PyFloat_FromDouble(115940476191.2); if (unlikely(!__pyx_float_115940476191_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_118553769519_2 = PyFloat_FromDouble(118553769519.2); if (unlikely(!__pyx_float_118553769519_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_127151511671_8 = PyFloat_FromDouble(127151511671.8); if (unlikely(!__pyx_float_127151511671_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_127527613173_0 = PyFloat_FromDouble(127527613173.0); if (unlikely(!__pyx_float_127527613173_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_159799015973_0 = PyFloat_FromDouble(159799015973.0); if (unlikely(!__pyx_float_159799015973_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_213001530097_8 = PyFloat_FromDouble(213001530097.8); if (unlikely(!__pyx_float_213001530097_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_30233745384_79 = PyFloat_FromDouble(30233745384.79); if (unlikely(!__pyx_float_30233745384_79)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_318911097485_6 = PyFloat_FromDouble(318911097485.6); if (unlikely(!__pyx_float_318911097485_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_331555299617_0 = PyFloat_FromDouble(331555299617.0); if (unlikely(!__pyx_float_331555299617_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_34325273049_37 = PyFloat_FromDouble(34325273049.37); if (unlikely(!__pyx_float_34325273049_37)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_39340183896_48 = PyFloat_FromDouble(39340183896.48); if (unlikely(!__pyx_float_39340183896_48)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_42696102285_67 = PyFloat_FromDouble(42696102285.67); if (unlikely(!__pyx_float_42696102285_67)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_50489872605_94 = PyFloat_FromDouble(50489872605.94); if (unlikely(!__pyx_float_50489872605_94)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_61288819659_89 = PyFloat_FromDouble(61288819659.89); if (unlikely(!__pyx_float_61288819659_89)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_691633876518_0 = PyFloat_FromDouble(691633876518.0); if (unlikely(!__pyx_float_691633876518_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_82167390867_05 = PyFloat_FromDouble(82167390867.05); if (unlikely(!__pyx_float_82167390867_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_146640016315_48 = PyFloat_FromDouble(146640016315.48); if (unlikely(!__pyx_float_146640016315_48)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_182415895155_26 = PyFloat_FromDouble(182415895155.26); if (unlikely(!__pyx_float_182415895155_26)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_215440232173_34 = PyFloat_FromDouble(215440232173.34); if (unlikely(!__pyx_float_215440232173_34)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_390925480569_42 = PyFloat_FromDouble(390925480569.42); if (unlikely(!__pyx_float_390925480569_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_397900984221_1357 = PyFloat_FromDouble(397900984221.1357); if (unlikely(!__pyx_float_397900984221_1357)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_397920913934_3657 = PyFloat_FromDouble(397920913934.3657); if (unlikely(!__pyx_float_397920913934_3657)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_2 = PyFloat_FromDouble(-0.2); if (unlikely(!__pyx_float_neg_0_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_5 = PyFloat_FromDouble(-0.5); if (unlikely(!__pyx_float_neg_0_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_7 = PyFloat_FromDouble(-0.7); if (unlikely(!__pyx_float_neg_0_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_9 = PyFloat_FromDouble(-0.9); if (unlikely(!__pyx_float_neg_0_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_5 = PyFloat_FromDouble(-1.5); if (unlikely(!__pyx_float_neg_1_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_5_3 = PyFloat_FromDouble(-5.3); if (unlikely(!__pyx_float_neg_5_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_01 = PyFloat_FromDouble(-0.01); if (unlikely(!__pyx_float_neg_0_01)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_02 = PyFloat_FromDouble(-0.02); if (unlikely(!__pyx_float_neg_0_02)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_03 = PyFloat_FromDouble(-0.03); if (unlikely(!__pyx_float_neg_0_03)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_04 = PyFloat_FromDouble(-0.04); if (unlikely(!__pyx_float_neg_0_04)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_05 = PyFloat_FromDouble(-0.05); if (unlikely(!__pyx_float_neg_0_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_06 = PyFloat_FromDouble(-0.06); if (unlikely(!__pyx_float_neg_0_06)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_07 = PyFloat_FromDouble(-0.07); if (unlikely(!__pyx_float_neg_0_07)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_08 = PyFloat_FromDouble(-0.08); if (unlikely(!__pyx_float_neg_0_08)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_19 = PyFloat_FromDouble(-0.19); if (unlikely(!__pyx_float_neg_0_19)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_33 = PyFloat_FromDouble(-0.33); if (unlikely(!__pyx_float_neg_0_33)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_38 = PyFloat_FromDouble(-0.38); if (unlikely(!__pyx_float_neg_0_38)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_39 = PyFloat_FromDouble(-0.39); if (unlikely(!__pyx_float_neg_0_39)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_41 = PyFloat_FromDouble(-0.41); if (unlikely(!__pyx_float_neg_0_41)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_43 = PyFloat_FromDouble(-0.43); if (unlikely(!__pyx_float_neg_0_43)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_45 = PyFloat_FromDouble(-0.45); if (unlikely(!__pyx_float_neg_0_45)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_47 = PyFloat_FromDouble(-0.47); if (unlikely(!__pyx_float_neg_0_47)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_56 = PyFloat_FromDouble(-0.56); if (unlikely(!__pyx_float_neg_0_56)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_66 = PyFloat_FromDouble(-0.66); if (unlikely(!__pyx_float_neg_0_66)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_69 = PyFloat_FromDouble(-0.69); if (unlikely(!__pyx_float_neg_0_69)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_71 = PyFloat_FromDouble(-0.71); if (unlikely(!__pyx_float_neg_0_71)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_79 = PyFloat_FromDouble(-0.79); if (unlikely(!__pyx_float_neg_0_79)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_81 = PyFloat_FromDouble(-0.81); if (unlikely(!__pyx_float_neg_0_81)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_86 = PyFloat_FromDouble(-0.86); if (unlikely(!__pyx_float_neg_0_86)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_87 = PyFloat_FromDouble(-0.87); if (unlikely(!__pyx_float_neg_0_87)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_98 = PyFloat_FromDouble(-0.98); if (unlikely(!__pyx_float_neg_0_98)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_06 = PyFloat_FromDouble(-1.06); if (unlikely(!__pyx_float_neg_1_06)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_21 = PyFloat_FromDouble(-1.21); if (unlikely(!__pyx_float_neg_1_21)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_22 = PyFloat_FromDouble(-1.22); if (unlikely(!__pyx_float_neg_1_22)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_33 = PyFloat_FromDouble(-1.33); if (unlikely(!__pyx_float_neg_1_33)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_38 = PyFloat_FromDouble(-1.38); if (unlikely(!__pyx_float_neg_1_38)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_45 = PyFloat_FromDouble(-1.45); if (unlikely(!__pyx_float_neg_1_45)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_65 = PyFloat_FromDouble(-1.65); if (unlikely(!__pyx_float_neg_1_65)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_66 = PyFloat_FromDouble(-1.66); if (unlikely(!__pyx_float_neg_1_66)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_79 = PyFloat_FromDouble(-1.79); if (unlikely(!__pyx_float_neg_1_79)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_96 = PyFloat_FromDouble(-1.96); if (unlikely(!__pyx_float_neg_1_96)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2_16 = PyFloat_FromDouble(-2.16); if (unlikely(!__pyx_float_neg_2_16)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2_17 = PyFloat_FromDouble(-2.17); if (unlikely(!__pyx_float_neg_2_17)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2_35 = PyFloat_FromDouble(-2.35); if (unlikely(!__pyx_float_neg_2_35)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2_42 = PyFloat_FromDouble(-2.42); if (unlikely(!__pyx_float_neg_2_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2_63 = PyFloat_FromDouble(-2.63); if (unlikely(!__pyx_float_neg_2_63)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2_82 = PyFloat_FromDouble(-2.82); if (unlikely(!__pyx_float_neg_2_82)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_21_3 = PyFloat_FromDouble(-21.3); if (unlikely(!__pyx_float_neg_21_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_3_81 = PyFloat_FromDouble(-3.81); if (unlikely(!__pyx_float_neg_3_81)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_4_04 = PyFloat_FromDouble(-4.04); if (unlikely(!__pyx_float_neg_4_04)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_4_06 = PyFloat_FromDouble(-4.06); if (unlikely(!__pyx_float_neg_4_06)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_4_45 = PyFloat_FromDouble(-4.45); if (unlikely(!__pyx_float_neg_4_45)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_5_18 = PyFloat_FromDouble(-5.18); if (unlikely(!__pyx_float_neg_5_18)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_5_83 = PyFloat_FromDouble(-5.83); if (unlikely(!__pyx_float_neg_5_83)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_6_58 = PyFloat_FromDouble(-6.58); if (unlikely(!__pyx_float_neg_6_58)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_7_28 = PyFloat_FromDouble(-7.28); if (unlikely(!__pyx_float_neg_7_28)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_7_43 = PyFloat_FromDouble(-7.43); if (unlikely(!__pyx_float_neg_7_43)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_7_58 = PyFloat_FromDouble(-7.58); if (unlikely(!__pyx_float_neg_7_58)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_7_69 = PyFloat_FromDouble(-7.69); if (unlikely(!__pyx_float_neg_7_69)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_8_13 = PyFloat_FromDouble(-8.13); if (unlikely(!__pyx_float_neg_8_13)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_8_23 = PyFloat_FromDouble(-8.23); if (unlikely(!__pyx_float_neg_8_23)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_8_27 = PyFloat_FromDouble(-8.27); if (unlikely(!__pyx_float_neg_8_27)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_8_63 = PyFloat_FromDouble(-8.63); if (unlikely(!__pyx_float_neg_8_63)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_9_99 = PyFloat_FromDouble(-9.99); if (unlikely(!__pyx_float_neg_9_99)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_10_63 = PyFloat_FromDouble(-10.63); if (unlikely(!__pyx_float_neg_10_63)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_104_4 = PyFloat_FromDouble(-104.4); if (unlikely(!__pyx_float_neg_104_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_11_66 = PyFloat_FromDouble(-11.66); if (unlikely(!__pyx_float_neg_11_66)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_12_42 = PyFloat_FromDouble(-12.42); if (unlikely(!__pyx_float_neg_12_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_12_46 = PyFloat_FromDouble(-12.46); if (unlikely(!__pyx_float_neg_12_46)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_13_39 = PyFloat_FromDouble(-13.39); if (unlikely(!__pyx_float_neg_13_39)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_15_62 = PyFloat_FromDouble(-15.62); if (unlikely(!__pyx_float_neg_15_62)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_16_02 = PyFloat_FromDouble(-16.02); if (unlikely(!__pyx_float_neg_16_02)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_18_14 = PyFloat_FromDouble(-18.14); if (unlikely(!__pyx_float_neg_18_14)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_18_25 = PyFloat_FromDouble(-18.25); if (unlikely(!__pyx_float_neg_18_25)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_18_48 = PyFloat_FromDouble(-18.48); if (unlikely(!__pyx_float_neg_18_48)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_19_82 = PyFloat_FromDouble(-19.82); if (unlikely(!__pyx_float_neg_19_82)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_21_32 = PyFloat_FromDouble(-21.32); if (unlikely(!__pyx_float_neg_21_32)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_21_51 = PyFloat_FromDouble(-21.51); if (unlikely(!__pyx_float_neg_21_51)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_23_57 = PyFloat_FromDouble(-23.57); if (unlikely(!__pyx_float_neg_23_57)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_23_59 = PyFloat_FromDouble(-23.59); if (unlikely(!__pyx_float_neg_23_59)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_24_21 = PyFloat_FromDouble(-24.21); if (unlikely(!__pyx_float_neg_24_21)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_30_51 = PyFloat_FromDouble(-30.51); if (unlikely(!__pyx_float_neg_30_51)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_32_25 = PyFloat_FromDouble(-32.25); if (unlikely(!__pyx_float_neg_32_25)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_39_38 = PyFloat_FromDouble(-39.38); if (unlikely(!__pyx_float_neg_39_38)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_42_08 = PyFloat_FromDouble(-42.08); if (unlikely(!__pyx_float_neg_42_08)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_44_38 = PyFloat_FromDouble(-44.38); if (unlikely(!__pyx_float_neg_44_38)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_57_26 = PyFloat_FromDouble(-57.26); if (unlikely(!__pyx_float_neg_57_26)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_70_98 = PyFloat_FromDouble(-70.98); if (unlikely(!__pyx_float_neg_70_98)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_81_94 = PyFloat_FromDouble(-81.94); if (unlikely(!__pyx_float_neg_81_94)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_84_33 = PyFloat_FromDouble(-84.33); if (unlikely(!__pyx_float_neg_84_33)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_99_58 = PyFloat_FromDouble(-99.58); if (unlikely(!__pyx_float_neg_99_58)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2997454_0 = PyFloat_FromDouble(-2997454.0); if (unlikely(!__pyx_float_neg_2997454_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_4803766_0 = PyFloat_FromDouble(-4803766.0); if (unlikely(!__pyx_float_neg_4803766_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_12984032_0 = PyFloat_FromDouble(-12984032.0); if (unlikely(!__pyx_float_neg_12984032_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_53971303_0 = PyFloat_FromDouble(-53971303.0); if (unlikely(!__pyx_float_neg_53971303_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_235770368_0 = PyFloat_FromDouble(-235770368.0); if (unlikely(!__pyx_float_neg_235770368_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_250665728_0 = PyFloat_FromDouble(-250665728.0); if (unlikely(!__pyx_float_neg_250665728_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_635090960_0 = PyFloat_FromDouble(-635090960.0); if (unlikely(!__pyx_float_neg_635090960_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_661239776_0 = PyFloat_FromDouble(-661239776.0); if (unlikely(!__pyx_float_neg_661239776_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_698863952_0 = PyFloat_FromDouble(-698863952.0); if (unlikely(!__pyx_float_neg_698863952_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_918841824_0 = PyFloat_FromDouble(-918841824.0); if (unlikely(!__pyx_float_neg_918841824_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1140853760_0 = PyFloat_FromDouble(-1140853760.0); if (unlikely(!__pyx_float_neg_1140853760_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1171835776_0 = PyFloat_FromDouble(-1171835776.0); if (unlikely(!__pyx_float_neg_1171835776_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1468038656_0 = PyFloat_FromDouble(-1468038656.0); if (unlikely(!__pyx_float_neg_1468038656_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1476325632_0 = PyFloat_FromDouble(-1476325632.0); if (unlikely(!__pyx_float_neg_1476325632_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1963587072_0 = PyFloat_FromDouble(-1963587072.0); if (unlikely(!__pyx_float_neg_1963587072_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2227974912_0 = PyFloat_FromDouble(-2227974912.0); if (unlikely(!__pyx_float_neg_2227974912_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2339542272_0 = PyFloat_FromDouble(-2339542272.0); if (unlikely(!__pyx_float_neg_2339542272_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2428805376_0 = PyFloat_FromDouble(-2428805376.0); if (unlikely(!__pyx_float_neg_2428805376_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2440455424_0 = PyFloat_FromDouble(-2440455424.0); if (unlikely(!__pyx_float_neg_2440455424_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2491724208_0 = PyFloat_FromDouble(-2491724208.0); if (unlikely(!__pyx_float_neg_2491724208_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2509978624_0 = PyFloat_FromDouble(-2509978624.0); if (unlikely(!__pyx_float_neg_2509978624_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2539908352_0 = PyFloat_FromDouble(-2539908352.0); if (unlikely(!__pyx_float_neg_2539908352_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2622219776_0 = PyFloat_FromDouble(-2622219776.0); if (unlikely(!__pyx_float_neg_2622219776_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_4380916480_0 = PyFloat_FromDouble(-4380916480.0); if (unlikely(!__pyx_float_neg_4380916480_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_5655776512_0 = PyFloat_FromDouble(-5655776512.0); if (unlikely(!__pyx_float_neg_5655776512_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_5744585216_0 = PyFloat_FromDouble(-5744585216.0); if (unlikely(!__pyx_float_neg_5744585216_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_6014713856_0 = PyFloat_FromDouble(-6014713856.0); if (unlikely(!__pyx_float_neg_6014713856_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_7491039488_0 = PyFloat_FromDouble(-7491039488.0); if (unlikely(!__pyx_float_neg_7491039488_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_8801696000_0 = PyFloat_FromDouble(-8801696000.0); if (unlikely(!__pyx_float_neg_8801696000_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_8813961984_0 = PyFloat_FromDouble(-8813961984.0); if (unlikely(!__pyx_float_neg_8813961984_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_10169320192_0 = PyFloat_FromDouble(-10169320192.0); if (unlikely(!__pyx_float_neg_10169320192_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_13886649344_0 = PyFloat_FromDouble(-13886649344.0); if (unlikely(!__pyx_float_neg_13886649344_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12 = PyInt_FromLong(12); if (unlikely(!__pyx_int_12)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_37 = PyInt_FromLong(37); if (unlikely(!__pyx_int_37)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_300 = PyInt_FromLong(300); if (unlikely(!__pyx_int_300)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_167926 = PyInt_FromLong(167926L); if (unlikely(!__pyx_int_167926)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_571666 = PyInt_FromLong(571666L); if (unlikely(!__pyx_int_571666)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2223662 = PyInt_FromLong(2223662L); if (unlikely(!__pyx_int_2223662)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2419271 = PyInt_FromLong(2419271L); if (unlikely(!__pyx_int_2419271)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7898580 = PyInt_FromLong(7898580L); if (unlikely(!__pyx_int_7898580)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8576647 = PyInt_FromLong(8576647L); if (unlikely(!__pyx_int_8576647)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10592446 = PyInt_FromLong(10592446L); if (unlikely(!__pyx_int_10592446)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_14249490 = PyInt_FromLong(14249490L); if (unlikely(!__pyx_int_14249490)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_16720502 = PyInt_FromLong(16720502L); if (unlikely(!__pyx_int_16720502)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_18144804 = PyInt_FromLong(18144804L); if (unlikely(!__pyx_int_18144804)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_21744403 = PyInt_FromLong(21744403L); if (unlikely(!__pyx_int_21744403)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_25169964 = PyInt_FromLong(25169964L); if (unlikely(!__pyx_int_25169964)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_26315144 = PyInt_FromLong(26315144L); if (unlikely(!__pyx_int_26315144)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_27364120 = PyInt_FromLong(27364120L); if (unlikely(!__pyx_int_27364120)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_32037354 = PyInt_FromLong(32037354L); if (unlikely(!__pyx_int_32037354)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_34126920 = PyInt_FromLong(34126920L); if (unlikely(!__pyx_int_34126920)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_35394350 = PyInt_FromLong(35394350L); if (unlikely(!__pyx_int_35394350)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_36436105 = PyInt_FromLong(36436105L); if (unlikely(!__pyx_int_36436105)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_48122566 = PyInt_FromLong(48122566L); if (unlikely(!__pyx_int_48122566)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_58645358 = PyInt_FromLong(58645358L); if (unlikely(!__pyx_int_58645358)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_59724479 = PyInt_FromLong(59724479L); if (unlikely(!__pyx_int_59724479)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_66238981 = PyInt_FromLong(66238981L); if (unlikely(!__pyx_int_66238981)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_83828686 = PyInt_FromLong(83828686L); if (unlikely(!__pyx_int_83828686)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_88973758 = PyInt_FromLong(88973758L); if (unlikely(!__pyx_int_88973758)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_113527478 = PyInt_FromLong(113527478L); if (unlikely(!__pyx_int_113527478)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_130320202 = PyInt_FromLong(130320202L); if (unlikely(!__pyx_int_130320202)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_131103026 = PyInt_FromLong(131103026L); if (unlikely(!__pyx_int_131103026)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_133117037 = PyInt_FromLong(133117037L); if (unlikely(!__pyx_int_133117037)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_182994245 = PyInt_FromLong(182994245L); if (unlikely(!__pyx_int_182994245)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_199724618 = PyInt_FromLong(199724618L); if (unlikely(!__pyx_int_199724618)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_244630504 = PyInt_FromLong(244630504L); if (unlikely(!__pyx_int_244630504)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_259052823 = PyInt_FromLong(259052823L); if (unlikely(!__pyx_int_259052823)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_316342484 = PyInt_FromLong(316342484L); if (unlikely(!__pyx_int_316342484)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_371100958 = PyInt_FromLong(371100958L); if (unlikely(!__pyx_int_371100958)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_391479032 = PyInt_FromLong(391479032L); if (unlikely(!__pyx_int_391479032)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_392337786 = PyInt_FromLong(392337786L); if (unlikely(!__pyx_int_392337786)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_541037598 = PyInt_FromLong(541037598L); if (unlikely(!__pyx_int_541037598)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_677188186 = PyInt_FromLong(677188186L); if (unlikely(!__pyx_int_677188186)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8855649026 = PyInt_FromString((char *)"8855649026", 0, 0); if (unlikely(!__pyx_int_8855649026)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12717649349 = PyInt_FromString((char *)"12717649349", 0, 0); if (unlikely(!__pyx_int_12717649349)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_53136528234 = PyInt_FromString((char *)"53136528234", 0, 0); if (unlikely(!__pyx_int_53136528234)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_53299789831 = PyInt_FromString((char *)"53299789831", 0, 0); if (unlikely(!__pyx_int_53299789831)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_168229436395 = PyInt_FromString((char *)"168229436395", 0, 0); if (unlikely(!__pyx_int_168229436395)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_313032053358 = PyInt_FromString((char *)"313032053358", 0, 0); if (unlikely(!__pyx_int_313032053358)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_515063456666 = PyInt_FromString((char *)"515063456666", 0, 0); if (unlikely(!__pyx_int_515063456666)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_626306385346 = PyInt_FromString((char *)"626306385346", 0, 0); if (unlikely(!__pyx_int_626306385346)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_824243981862 = PyInt_FromString((char *)"824243981862", 0, 0); if (unlikely(!__pyx_int_824243981862)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x9507d62c436 = PyInt_FromString((char *)"0x9507d62c436", 0, 0); if (unlikely(!__pyx_int_0x9507d62c436)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x9660e6b8684 = PyInt_FromString((char *)"0x9660e6b8684", 0, 0); if (unlikely(!__pyx_int_0x9660e6b8684)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x977cef39562 = PyInt_FromString((char *)"0x977cef39562", 0, 0); if (unlikely(!__pyx_int_0x977cef39562)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x9c81f15f8f5 = PyInt_FromString((char *)"0x9c81f15f8f5", 0, 0); if (unlikely(!__pyx_int_0x9c81f15f8f5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0xa5646e4f052 = PyInt_FromString((char *)"0xa5646e4f052", 0, 0); if (unlikely(!__pyx_int_0xa5646e4f052)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0xa573354fb9d = PyInt_FromString((char *)"0xa573354fb9d", 0, 0); if (unlikely(!__pyx_int_0xa573354fb9d)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0xb294917799f = PyInt_FromString((char *)"0xb294917799f", 0, 0); if (unlikely(!__pyx_int_0xb294917799f)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0xb38e85961b8 = PyInt_FromString((char *)"0xb38e85961b8", 0, 0); if (unlikely(!__pyx_int_0xb38e85961b8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0xbaef60da2c6 = PyInt_FromString((char *)"0xbaef60da2c6", 0, 0); if (unlikely(!__pyx_int_0xbaef60da2c6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0xca8cd5800f9 = PyInt_FromString((char *)"0xca8cd5800f9", 0, 0); if (unlikely(!__pyx_int_0xca8cd5800f9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0xe4562e88120 = PyInt_FromString((char *)"0xe4562e88120", 0, 0); if (unlikely(!__pyx_int_0xe4562e88120)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0xfc88ab58e0b = PyInt_FromString((char *)"0xfc88ab58e0b", 0, 0); if (unlikely(!__pyx_int_0xfc88ab58e0b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1110800675511 = PyInt_FromString((char *)"1110800675511", 0, 0); if (unlikely(!__pyx_int_1110800675511)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1175767851306 = PyInt_FromString((char *)"1175767851306", 0, 0); if (unlikely(!__pyx_int_1175767851306)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1436971721042 = PyInt_FromString((char *)"1436971721042", 0, 0); if (unlikely(!__pyx_int_1436971721042)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1708631550165 = PyInt_FromString((char *)"1708631550165", 0, 0); if (unlikely(!__pyx_int_1708631550165)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1821738041432 = PyInt_FromString((char *)"1821738041432", 0, 0); if (unlikely(!__pyx_int_1821738041432)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1845844064964 = PyInt_FromString((char *)"1845844064964", 0, 0); if (unlikely(!__pyx_int_1845844064964)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2968508455751 = PyInt_FromString((char *)"2968508455751", 0, 0); if (unlikely(!__pyx_int_2968508455751)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3490375050807 = PyInt_FromString((char *)"3490375050807", 0, 0); if (unlikely(!__pyx_int_3490375050807)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3491811426635 = PyInt_FromString((char *)"3491811426635", 0, 0); if (unlikely(!__pyx_int_3491811426635)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4800328458344 = PyInt_FromString((char *)"4800328458344", 0, 0); if (unlikely(!__pyx_int_4800328458344)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4998916135670 = PyInt_FromString((char *)"4998916135670", 0, 0); if (unlikely(!__pyx_int_4998916135670)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5332514997228 = PyInt_FromString((char *)"5332514997228", 0, 0); if (unlikely(!__pyx_int_5332514997228)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5531341956881 = PyInt_FromString((char *)"5531341956881", 0, 0); if (unlikely(!__pyx_int_5531341956881)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5992127393523 = PyInt_FromString((char *)"5992127393523", 0, 0); if (unlikely(!__pyx_int_5992127393523)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6118478847123 = PyInt_FromString((char *)"6118478847123", 0, 0); if (unlikely(!__pyx_int_6118478847123)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6629036171731 = PyInt_FromString((char *)"6629036171731", 0, 0); if (unlikely(!__pyx_int_6629036171731)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6897201046540 = PyInt_FromString((char *)"6897201046540", 0, 0); if (unlikely(!__pyx_int_6897201046540)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7235995254645 = PyInt_FromString((char *)"7235995254645", 0, 0); if (unlikely(!__pyx_int_7235995254645)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7325541012743 = PyInt_FromString((char *)"7325541012743", 0, 0); if (unlikely(!__pyx_int_7325541012743)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7428389236896 = PyInt_FromString((char *)"7428389236896", 0, 0); if (unlikely(!__pyx_int_7428389236896)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7507095323631 = PyInt_FromString((char *)"7507095323631", 0, 0); if (unlikely(!__pyx_int_7507095323631)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7694238899256 = PyInt_FromString((char *)"7694238899256", 0, 0); if (unlikely(!__pyx_int_7694238899256)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7884280772830 = PyInt_FromString((char *)"7884280772830", 0, 0); if (unlikely(!__pyx_int_7884280772830)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8607232746956 = PyInt_FromString((char *)"8607232746956", 0, 0); if (unlikely(!__pyx_int_8607232746956)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_9597572050458 = PyInt_FromString((char *)"9597572050458", 0, 0); if (unlikely(!__pyx_int_9597572050458)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_9790143307451 = PyInt_FromString((char *)"9790143307451", 0, 0); if (unlikely(!__pyx_int_9790143307451)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_9890708337231 = PyInt_FromString((char *)"9890708337231", 0, 0); if (unlikely(!__pyx_int_9890708337231)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x105293ff5bfe = PyInt_FromString((char *)"0x105293ff5bfe", 0, 0); if (unlikely(!__pyx_int_0x105293ff5bfe)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x120f2085deb4 = PyInt_FromString((char *)"0x120f2085deb4", 0, 0); if (unlikely(!__pyx_int_0x120f2085deb4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x1312c5fef504 = PyInt_FromString((char *)"0x1312c5fef504", 0, 0); if (unlikely(!__pyx_int_0x1312c5fef504)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x157f527fb1d4 = PyInt_FromString((char *)"0x157f527fb1d4", 0, 0); if (unlikely(!__pyx_int_0x157f527fb1d4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x15b1120a25de = PyInt_FromString((char *)"0x15b1120a25de", 0, 0); if (unlikely(!__pyx_int_0x15b1120a25de)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x15bd71393949 = PyInt_FromString((char *)"0x15bd71393949", 0, 0); if (unlikely(!__pyx_int_0x15bd71393949)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x1839ab81d6a2 = PyInt_FromString((char *)"0x1839ab81d6a2", 0, 0); if (unlikely(!__pyx_int_0x1839ab81d6a2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x193c10d5c555 = PyInt_FromString((char *)"0x193c10d5c555", 0, 0); if (unlikely(!__pyx_int_0x193c10d5c555)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x196f90195cb3 = PyInt_FromString((char *)"0x196f90195cb3", 0, 0); if (unlikely(!__pyx_int_0x196f90195cb3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x19a936e9e6f2 = PyInt_FromString((char *)"0x19a936e9e6f2", 0, 0); if (unlikely(!__pyx_int_0x19a936e9e6f2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x19b59fd426fa = PyInt_FromString((char *)"0x19b59fd426fa", 0, 0); if (unlikely(!__pyx_int_0x19b59fd426fa)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x22f9a2787068 = PyInt_FromString((char *)"0x22f9a2787068", 0, 0); if (unlikely(!__pyx_int_0x22f9a2787068)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x2528aad29cbb = PyInt_FromString((char *)"0x2528aad29cbb", 0, 0); if (unlikely(!__pyx_int_0x2528aad29cbb)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x27eebfaf00e2 = PyInt_FromString((char *)"0x27eebfaf00e2", 0, 0); if (unlikely(!__pyx_int_0x27eebfaf00e2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x2b17e83d52a2 = PyInt_FromString((char *)"0x2b17e83d52a2", 0, 0); if (unlikely(!__pyx_int_0x2b17e83d52a2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x2c4a1fdb349e = PyInt_FromString((char *)"0x2c4a1fdb349e", 0, 0); if (unlikely(!__pyx_int_0x2c4a1fdb349e)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x2f7ef1b78d0e = PyInt_FromString((char *)"0x2f7ef1b78d0e", 0, 0); if (unlikely(!__pyx_int_0x2f7ef1b78d0e)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x3d0738b72996 = PyInt_FromString((char *)"0x3d0738b72996", 0, 0); if (unlikely(!__pyx_int_0x3d0738b72996)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x433f57b789fe = PyInt_FromString((char *)"0x433f57b789fe", 0, 0); if (unlikely(!__pyx_int_0x433f57b789fe)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_5 = PyInt_FromLong(-5); if (unlikely(!__pyx_int_neg_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  return 0;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_7genexpr__pyx_v_7tbstock_5utils_5utils_i = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_utils(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_utils},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "utils",
      0, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initutils(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initutils(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_utils(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_utils(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_utils(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  double __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'utils' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("utils", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "utils" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_utils(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_tbstock__utils__utils) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "tbstock.utils.utils")) {
      if (unlikely((PyDict_SetItemString(modules, "tbstock.utils.utils", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  (void)__Pyx_modinit_type_init_code();
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "tbstock/utils/utils.py":1
 * import akshare as ak             # <<<<<<<<<<<<<<
 * import pandas as pd
 * import calendar
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_akshare_2, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ak, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":2
 * import akshare as ak
 * import pandas as pd             # <<<<<<<<<<<<<<
 * import calendar
 * from datetime import datetime, timedelta
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_pandas, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pd, __pyx_t_2) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":3
 * import akshare as ak
 * import pandas as pd
 * import calendar             # <<<<<<<<<<<<<<
 * from datetime import datetime, timedelta
 * import re
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_calendar, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_calendar, __pyx_t_2) < 0) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":4
 * import pandas as pd
 * import calendar
 * from datetime import datetime, timedelta             # <<<<<<<<<<<<<<
 * import re
 * import os
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_datetime);
  __Pyx_GIVEREF(__pyx_n_s_datetime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_datetime)) __PYX_ERR(0, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_timedelta);
  __Pyx_GIVEREF(__pyx_n_s_timedelta);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_timedelta)) __PYX_ERR(0, 4, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_datetime, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_timedelta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_timedelta, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":5
 * import calendar
 * from datetime import datetime, timedelta
 * import re             # <<<<<<<<<<<<<<
 * import os
 * from typing import Union, Dict, List
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_re, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_3) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":6
 * from datetime import datetime, timedelta
 * import re
 * import os             # <<<<<<<<<<<<<<
 * from typing import Union, Dict, List
 * import pickle
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_os, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_3) < 0) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":7
 * import re
 * import os
 * from typing import Union, Dict, List             # <<<<<<<<<<<<<<
 * import pickle
 * from loguru import logger
 */
  __pyx_t_3 = PyList_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_Union);
  __Pyx_GIVEREF(__pyx_n_s_Union);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_Union)) __PYX_ERR(0, 7, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Dict);
  __Pyx_GIVEREF(__pyx_n_s_Dict);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_Dict)) __PYX_ERR(0, 7, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_List);
  __Pyx_GIVEREF(__pyx_n_s_List);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 2, __pyx_n_s_List)) __PYX_ERR(0, 7, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_typing, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Union); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Union, __pyx_t_3) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Dict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Dict, __pyx_t_3) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_List); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_List, __pyx_t_3) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":8
 * import os
 * from typing import Union, Dict, List
 * import pickle             # <<<<<<<<<<<<<<
 * from loguru import logger
 * from collections import Counter
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_pickle, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pickle, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":9
 * from typing import Union, Dict, List
 * import pickle
 * from loguru import logger             # <<<<<<<<<<<<<<
 * from collections import Counter
 * import exchange_calendars as trade_date
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_logger);
  __Pyx_GIVEREF(__pyx_n_s_logger);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_logger)) __PYX_ERR(0, 9, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_loguru, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_logger); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_logger, __pyx_t_2) < 0) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":10
 * import pickle
 * from loguru import logger
 * from collections import Counter             # <<<<<<<<<<<<<<
 * import exchange_calendars as trade_date
 * import json
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_Counter);
  __Pyx_GIVEREF(__pyx_n_s_Counter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_Counter)) __PYX_ERR(0, 10, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Counter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Counter, __pyx_t_3) < 0) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":11
 * from loguru import logger
 * from collections import Counter
 * import exchange_calendars as trade_date             # <<<<<<<<<<<<<<
 * import json
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_exchange_calendars, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_trade_date, __pyx_t_2) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":12
 * from collections import Counter
 * import exchange_calendars as trade_date
 * import json             # <<<<<<<<<<<<<<
 * 
 * current_directory = os.getcwd()
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_json, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_json, __pyx_t_2) < 0) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":14
 * import json
 * 
 * current_directory = os.getcwd()             # <<<<<<<<<<<<<<
 * print('current_directory = ', current_directory)
 * logs_dir = '../assets/logs/'
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getcwd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_current_directory, __pyx_t_2) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":15
 * 
 * current_directory = os.getcwd()
 * print('current_directory = ', current_directory)             # <<<<<<<<<<<<<<
 * logs_dir = '../assets/logs/'
 * cookies_dir = '../assets/cookies/'
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_current_directory); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_kp_s_current_directory_2);
  __Pyx_GIVEREF(__pyx_kp_s_current_directory_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_s_current_directory_2)) __PYX_ERR(0, 15, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":16
 * current_directory = os.getcwd()
 * print('current_directory = ', current_directory)
 * logs_dir = '../assets/logs/'             # <<<<<<<<<<<<<<
 * cookies_dir = '../assets/cookies/'
 * update_db_logs_dir = '../assets/update_db_logs/'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_logs_dir, __pyx_kp_s_assets_logs) < 0) __PYX_ERR(0, 16, __pyx_L1_error)

  /* "tbstock/utils/utils.py":17
 * print('current_directory = ', current_directory)
 * logs_dir = '../assets/logs/'
 * cookies_dir = '../assets/cookies/'             # <<<<<<<<<<<<<<
 * update_db_logs_dir = '../assets/update_db_logs/'
 * update_strategy_logs_dir = '../assets/update_strategy_logs/'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cookies_dir, __pyx_kp_s_assets_cookies) < 0) __PYX_ERR(0, 17, __pyx_L1_error)

  /* "tbstock/utils/utils.py":18
 * logs_dir = '../assets/logs/'
 * cookies_dir = '../assets/cookies/'
 * update_db_logs_dir = '../assets/update_db_logs/'             # <<<<<<<<<<<<<<
 * update_strategy_logs_dir = '../assets/update_strategy_logs/'
 * audio_dir = '../assets/audios/'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_update_db_logs_dir, __pyx_kp_s_assets_update_db_logs) < 0) __PYX_ERR(0, 18, __pyx_L1_error)

  /* "tbstock/utils/utils.py":19
 * cookies_dir = '../assets/cookies/'
 * update_db_logs_dir = '../assets/update_db_logs/'
 * update_strategy_logs_dir = '../assets/update_strategy_logs/'             # <<<<<<<<<<<<<<
 * audio_dir = '../assets/audios/'
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_update_strategy_logs_dir, __pyx_kp_s_assets_update_strategy_logs) < 0) __PYX_ERR(0, 19, __pyx_L1_error)

  /* "tbstock/utils/utils.py":20
 * update_db_logs_dir = '../assets/update_db_logs/'
 * update_strategy_logs_dir = '../assets/update_strategy_logs/'
 * audio_dir = '../assets/audios/'             # <<<<<<<<<<<<<<
 * 
 * cover_img_dir = os.path.dirname(current_directory) + '/assets/cover_img/'
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_audio_dir, __pyx_kp_s_assets_audios) < 0) __PYX_ERR(0, 20, __pyx_L1_error)

  /* "tbstock/utils/utils.py":22
 * audio_dir = '../assets/audios/'
 * 
 * cover_img_dir = os.path.dirname(current_directory) + '/assets/cover_img/'             # <<<<<<<<<<<<<<
 * img_save_path_root = os.path.dirname(current_directory) + '/assets/imgs/'
 * video_save_path_root = os.path.dirname(current_directory) + '/assets/videos/'
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_dirname); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_current_directory); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_kp_s_assets_cover_img); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cover_img_dir, __pyx_t_3) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":23
 * 
 * cover_img_dir = os.path.dirname(current_directory) + '/assets/cover_img/'
 * img_save_path_root = os.path.dirname(current_directory) + '/assets/imgs/'             # <<<<<<<<<<<<<<
 * video_save_path_root = os.path.dirname(current_directory) + '/assets/videos/'
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_dirname); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_current_directory); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_kp_s_assets_imgs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_img_save_path_root, __pyx_t_4) < 0) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "tbstock/utils/utils.py":24
 * cover_img_dir = os.path.dirname(current_directory) + '/assets/cover_img/'
 * img_save_path_root = os.path.dirname(current_directory) + '/assets/imgs/'
 * video_save_path_root = os.path.dirname(current_directory) + '/assets/videos/'             # <<<<<<<<<<<<<<
 * 
 * edge_driver_path = '/home/paco/norm_envs/softwares/edgedriver_linux64/msedgedriver'
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dirname); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_current_directory); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_s_assets_videos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_video_save_path_root, __pyx_t_2) < 0) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":26
 * video_save_path_root = os.path.dirname(current_directory) + '/assets/videos/'
 * 
 * edge_driver_path = '/home/paco/norm_envs/softwares/edgedriver_linux64/msedgedriver'             # <<<<<<<<<<<<<<
 * 
 * # logger.remove(handler_id=None)  #
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_edge_driver_path, __pyx_kp_s_home_paco_norm_envs_softwares_e) < 0) __PYX_ERR(0, 26, __pyx_L1_error)

  /* "tbstock/utils/utils.py":29
 * 
 * # logger.remove(handler_id=None)  #
 * log_trace = logger.add(logs_dir + 'stock.log',             # <<<<<<<<<<<<<<
 *                        level='INFO',
 *                        rotation='50MB',
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logger); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_add); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logs_dir); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_kp_s_stock_log); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4)) __PYX_ERR(0, 29, __pyx_L1_error);
  __pyx_t_4 = 0;

  /* "tbstock/utils/utils.py":30
 * # logger.remove(handler_id=None)  #
 * log_trace = logger.add(logs_dir + 'stock.log',
 *                        level='INFO',             # <<<<<<<<<<<<<<
 *                        rotation='50MB',
 *                        encoding="utf-8",
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_level, __pyx_n_s_INFO) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rotation, __pyx_kp_s_50MB) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_encoding, __pyx_kp_s_utf_8) < 0) __PYX_ERR(0, 30, __pyx_L1_error)

  /* "tbstock/utils/utils.py":33
 *                        rotation='50MB',
 *                        encoding="utf-8",
 *                        enqueue=True,             # <<<<<<<<<<<<<<
 *                        retention="14 days")
 * logger.info("Start this log record.\n")
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_enqueue, Py_True) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_retention, __pyx_kp_s_14_days) < 0) __PYX_ERR(0, 30, __pyx_L1_error)

  /* "tbstock/utils/utils.py":29
 * 
 * # logger.remove(handler_id=None)  #
 * log_trace = logger.add(logs_dir + 'stock.log',             # <<<<<<<<<<<<<<
 *                        level='INFO',
 *                        rotation='50MB',
 */
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_log_trace, __pyx_t_5) < 0) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":35
 *                        enqueue=True,
 *                        retention="14 days")
 * logger.info("Start this log record.\n")             # <<<<<<<<<<<<<<
 * 
 * start_date = '20180101'
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_logger); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__40, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":37
 * logger.info("Start this log record.\n")
 * 
 * start_date = '20180101'             # <<<<<<<<<<<<<<
 * now_datetime = datetime.today()
 * # now_datetime = datetime(2024, 8, 29, 16, 25, 15)
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_start_date, __pyx_kp_s_20180101) < 0) __PYX_ERR(0, 37, __pyx_L1_error)

  /* "tbstock/utils/utils.py":38
 * 
 * start_date = '20180101'
 * now_datetime = datetime.today()             # <<<<<<<<<<<<<<
 * # now_datetime = datetime(2024, 8, 29, 16, 25, 15)
 * today_date = now_datetime.strftime('%Y%m%d')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_datetime); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_today); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_now_datetime, __pyx_t_5) < 0) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":40
 * now_datetime = datetime.today()
 * # now_datetime = datetime(2024, 8, 29, 16, 25, 15)
 * today_date = now_datetime.strftime('%Y%m%d')             # <<<<<<<<<<<<<<
 * 
 * year_list = [str(i) for i in range(int(start_date[0:4]), int(today_date[0:4]) + 1)]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_now_datetime); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strftime); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_today_date, __pyx_t_5) < 0) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":42
 * today_date = now_datetime.strftime('%Y%m%d')
 * 
 * year_list = [str(i) for i in range(int(start_date[0:4]), int(today_date[0:4]) + 1)]             # <<<<<<<<<<<<<<
 * sh_calendar = trade_date.get_calendar("XSHG")
 * 
 */
  { /* enter inner scope */
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_start_date); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 4, NULL, NULL, &__pyx_slice__42, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_today_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, 4, NULL, NULL, &__pyx_slice__42, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4)) __PYX_ERR(0, 42, __pyx_L4_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3)) __PYX_ERR(0, 42, __pyx_L4_error);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 42, __pyx_L4_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 42, __pyx_L4_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 42, __pyx_L4_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 42, __pyx_L4_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 42, __pyx_L4_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_7(__pyx_t_2);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 42, __pyx_L4_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XGOTREF(__pyx_7genexpr__pyx_v_7tbstock_5utils_5utils_i);
      __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_7tbstock_5utils_5utils_i, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Str(__pyx_7genexpr__pyx_v_7tbstock_5utils_5utils_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_5, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 42, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_7genexpr__pyx_v_7tbstock_5utils_5utils_i);
    __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_7tbstock_5utils_5utils_i, Py_None);
    goto __pyx_L8_exit_scope;
    __pyx_L4_error:;
    __Pyx_GOTREF(__pyx_7genexpr__pyx_v_7tbstock_5utils_5utils_i);
    __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_7tbstock_5utils_5utils_i, Py_None);
    goto __pyx_L1_error;
    __pyx_L8_exit_scope:;
  } /* exit inner scope */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_year_list, __pyx_t_5) < 0) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":43
 * 
 * year_list = [str(i) for i in range(int(start_date[0:4]), int(today_date[0:4]) + 1)]
 * sh_calendar = trade_date.get_calendar("XSHG")             # <<<<<<<<<<<<<<
 * 
 * positive_infinity = float('inf')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_trade_date); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_get_calendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sh_calendar, __pyx_t_5) < 0) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":45
 * sh_calendar = trade_date.get_calendar("XSHG")
 * 
 * positive_infinity = float('inf')             # <<<<<<<<<<<<<<
 * negative_infinity = float('-inf')
 * 
 */
  __pyx_t_8 = __Pyx_PyString_AsDouble(__pyx_n_s_inf); if (unlikely(__pyx_t_8 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 45, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_positive_infinity, __pyx_t_5) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":46
 * 
 * positive_infinity = float('inf')
 * negative_infinity = float('-inf')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_8 = __Pyx_PyString_AsDouble(__pyx_kp_s_inf_2); if (unlikely(__pyx_t_8 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 46, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_negative_infinity, __pyx_t_5) < 0) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":51
 * # print(f"year_list = {year_list}")
 * 
 * def checkCreatePath(directory):             # <<<<<<<<<<<<<<
 *     if not os.path.exists(directory):
 *         # os.makedirs()
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_1checkCreatePath, 0, __pyx_n_s_checkCreatePath, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__45)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_checkCreatePath, __pyx_t_5) < 0) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":60
 * 
 * 
 * checkCreatePath(logs_dir)             # <<<<<<<<<<<<<<
 * checkCreatePath(cookies_dir)
 * checkCreatePath(update_db_logs_dir)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_checkCreatePath); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logs_dir); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":61
 * 
 * checkCreatePath(logs_dir)
 * checkCreatePath(cookies_dir)             # <<<<<<<<<<<<<<
 * checkCreatePath(update_db_logs_dir)
 * checkCreatePath(update_strategy_logs_dir)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_checkCreatePath); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_cookies_dir); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":62
 * checkCreatePath(logs_dir)
 * checkCreatePath(cookies_dir)
 * checkCreatePath(update_db_logs_dir)             # <<<<<<<<<<<<<<
 * checkCreatePath(update_strategy_logs_dir)
 * checkCreatePath(img_save_path_root)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_checkCreatePath); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_update_db_logs_dir); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":63
 * checkCreatePath(cookies_dir)
 * checkCreatePath(update_db_logs_dir)
 * checkCreatePath(update_strategy_logs_dir)             # <<<<<<<<<<<<<<
 * checkCreatePath(img_save_path_root)
 * checkCreatePath(video_save_path_root)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_checkCreatePath); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_update_strategy_logs_dir); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":64
 * checkCreatePath(update_db_logs_dir)
 * checkCreatePath(update_strategy_logs_dir)
 * checkCreatePath(img_save_path_root)             # <<<<<<<<<<<<<<
 * checkCreatePath(video_save_path_root)
 * checkCreatePath(audio_dir)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_checkCreatePath); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_img_save_path_root); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":65
 * checkCreatePath(update_strategy_logs_dir)
 * checkCreatePath(img_save_path_root)
 * checkCreatePath(video_save_path_root)             # <<<<<<<<<<<<<<
 * checkCreatePath(audio_dir)
 * checkCreatePath(cover_img_dir)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_checkCreatePath); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_video_save_path_root); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":66
 * checkCreatePath(img_save_path_root)
 * checkCreatePath(video_save_path_root)
 * checkCreatePath(audio_dir)             # <<<<<<<<<<<<<<
 * checkCreatePath(cover_img_dir)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_checkCreatePath); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_audio_dir); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":67
 * checkCreatePath(video_save_path_root)
 * checkCreatePath(audio_dir)
 * checkCreatePath(cover_img_dir)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_checkCreatePath); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_cover_img_dir); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":70
 * 
 * 
 * def getLatestTradeDay(today_date):             # <<<<<<<<<<<<<<
 *     if not sh_calendar.is_session(today_date):
 *         latest_trade_day = sh_calendar.date_to_session(today_date, 'previous').strftime('%Y%m%d')
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_3getLatestTradeDay, 0, __pyx_n_s_getLatestTradeDay, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__47)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getLatestTradeDay, __pyx_t_5) < 0) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":80
 * 
 * 
 * latest_trade_day = getLatestTradeDay(today_date)             # <<<<<<<<<<<<<<
 * logger.info(f"latest_trade_day = {latest_trade_day}")
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_getLatestTradeDay); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_today_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_latest_trade_day, __pyx_t_3) < 0) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":81
 * 
 * latest_trade_day = getLatestTradeDay(today_date)
 * logger.info(f"latest_trade_day = {latest_trade_day}")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_logger); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_latest_trade_day); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_latest_trade_day_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":84
 * 
 * 
 * def getIndexCodeName() -> dict:             # <<<<<<<<<<<<<<
 *     str_dict = {"rc": 0, "rt": 6, "svr": 182994245, "lt": 1, "full": 1, "dlmkts": "", "data": {"total": 37, "diff": [
 *         {"f1": 2, "f2": 3051.28, "f3": 0.08, "f4": 2.49, "f5": 316342484, "f6": 318911097485.6, "f7": 1.11, "f8": 0.69, "f9": "-", "f10": 0.99,
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_dict_2) < 0) __PYX_ERR(0, 84, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_5getIndexCodeName, 0, __pyx_n_s_getIndexCodeName, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__49)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getIndexCodeName, __pyx_t_3) < 0) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":248
 * 
 * 
 * def updateLib() -> bool:             # <<<<<<<<<<<<<<
 *     update_lib_succeed = True
 *     out = os.system('pip install akshare --upgrade')
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 248, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_7updateLib, 0, __pyx_n_s_updateLib, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__51)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_updateLib, __pyx_t_5) < 0) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":273
 * 
 * 
 * def is_serializable(obj):             # <<<<<<<<<<<<<<
 *     try:
 *         pickle.dumps(obj)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_9is_serializable, 0, __pyx_n_s_is_serializable, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__53)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_is_serializable, __pyx_t_5) < 0) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":283
 * 
 * 
 * def check_serializability(obj):             # <<<<<<<<<<<<<<
 *     attributes = obj.__dict__
 *     non_serializable_attrs = []
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_11check_serializability, 0, __pyx_n_s_check_serializability, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__55)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_check_serializability, __pyx_t_5) < 0) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":292
 * 
 * 
 * def testCalendar():             # <<<<<<<<<<<<<<
 *     # date_str = '20190113'
 *     date_str = latest_trade_day
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_13testCalendar, 0, __pyx_n_s_testCalendar, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__57)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_testCalendar, __pyx_t_5) < 0) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":316
 * 
 * 
 * def extractAdministrativeRegions(text):             # <<<<<<<<<<<<<<
 *     #
 *     #
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_15extractAdministrativeRegions, 0, __pyx_n_s_extractAdministrativeRegions, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__59)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_extractAdministrativeRegions, __pyx_t_5) < 0) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":325
 * 
 * 
 * def startWithDigit(input_str):             # <<<<<<<<<<<<<<
 *     pattern = r'^\d'
 *     if re.match(pattern, input_str):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_17startWithDigit, 0, __pyx_n_s_startWithDigit, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__61)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_startWithDigit, __pyx_t_5) < 0) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":333
 * 
 * 
 * def listIntersection(data_list: Union[List, None] = None, *args) -> list:             # <<<<<<<<<<<<<<
 *     '''
 *     use example:
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_data_list, __pyx_kp_s_Union_List_None) < 0) __PYX_ERR(0, 333, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_list) < 0) __PYX_ERR(0, 333, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_19listIntersection, 0, __pyx_n_s_listIntersection, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__64);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_listIntersection, __pyx_t_3) < 0) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":360
 * 
 * 
 * def listUnion(data_list: Union[List, None] = None, *args) -> list:             # <<<<<<<<<<<<<<
 *     '''
 *     list
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_data_list, __pyx_kp_s_Union_List_None) < 0) __PYX_ERR(0, 360, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_list) < 0) __PYX_ERR(0, 360, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_21listUnion, 0, __pyx_n_s_listUnion, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__66)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__64);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_listUnion, __pyx_t_5) < 0) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":387
 * 
 * 
 * def strategyCount(data: Union[Dict, None] = None, **kwargs) -> pd.DataFrame():             # <<<<<<<<<<<<<<
 *     '''
 *     use example:
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_data, __pyx_kp_s_Union_Dict_None) < 0) __PYX_ERR(0, 387, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 387, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_23strategyCount, 0, __pyx_n_s_strategyCount, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__68)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__64);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_strategyCount, __pyx_t_3) < 0) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":419
 * 
 * 
 * def getFullStockCode(stock_code, mode='xx') -> str:             # <<<<<<<<<<<<<<
 *     '''
 *     # A 600 601 603 688 : 6068
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 419, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_25getFullStockCode, 0, __pyx_n_s_getFullStockCode, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__70)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__71);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getFullStockCode, __pyx_t_5) < 0) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":449
 * 
 * 
 * def isAPrimaryBoardStock(stock_code):             # <<<<<<<<<<<<<<
 *     if stock_code[0:2] in ["00", "30", "60", "68"] or stock_code[0] in ["4", "8"]:
 *         return True
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_27isAPrimaryBoardStock, 0, __pyx_n_s_isAPrimaryBoardStock, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__73)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_isAPrimaryBoardStock, __pyx_t_5) < 0) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":456
 * 
 * 
 * def getStockLimitUp(stock_code, stock_name):             # <<<<<<<<<<<<<<
 *     '''
 *     # 15610 %
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_29getStockLimitUp, 0, __pyx_n_s_getStockLimitUp, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__75)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getStockLimitUp, __pyx_t_5) < 0) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":481
 * 
 * 
 * def splitDataframeByYear(data_in) -> dict:             # <<<<<<<<<<<<<<
 *     result = {}
 *     date_type = data_in['date'].dtype
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_dict_2) < 0) __PYX_ERR(0, 481, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_31splitDataframeByYear, 0, __pyx_n_s_splitDataframeByYear, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__77)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_splitDataframeByYear, __pyx_t_3) < 0) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/utils/utils.py":491
 * 
 * 
 * class MyEncoder(json.JSONEncoder):             # <<<<<<<<<<<<<<
 *     def default(self, obj):
 *         if isinstance(obj, datetime):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_json); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_JSONEncoder); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5)) __PYX_ERR(0, 491, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_5, __pyx_n_s_MyEncoder, __pyx_n_s_MyEncoder, (PyObject *) NULL, __pyx_n_s_tbstock_utils_utils, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__pyx_t_5 != __pyx_t_3) {
    if (unlikely((PyDict_SetItemString(__pyx_t_4, "__orig_bases__", __pyx_t_3) < 0))) __PYX_ERR(0, 491, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "tbstock/utils/utils.py":492
 * 
 * class MyEncoder(json.JSONEncoder):
 *     def default(self, obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, datetime):
 *             return obj.isoformat()
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_9MyEncoder_1default, 0, __pyx_n_s_MyEncoder_default, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__79)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_t_9);
  PyList_Append(__pyx_t_3, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_default, __pyx_t_9) < 0) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "tbstock/utils/utils.py":497
 *         return super().default(obj)
 * 
 *     def insert_newlines(self, text, interval):             # <<<<<<<<<<<<<<
 *         """
 *         intervaltext
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_9MyEncoder_3insert_newlines, 0, __pyx_n_s_MyEncoder_insert_newlines, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__81)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_insert_newlines, __pyx_t_9) < 0) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "tbstock/utils/utils.py":530
 *         return wrapped_text
 * 
 *     def encode(self, obj):             # <<<<<<<<<<<<<<
 *         chunks = self.iterencode(obj, _one_shot=True)
 *         # print('chunks = ', chunks)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_9MyEncoder_5encode, 0, __pyx_n_s_MyEncoder_encode, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__83)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_encode, __pyx_t_9) < 0) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "tbstock/utils/utils.py":491
 * 
 * 
 * class MyEncoder(json.JSONEncoder):             # <<<<<<<<<<<<<<
 *     def default(self, obj):
 *         if isinstance(obj, datetime):
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_MyEncoder, __pyx_t_5, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_CyFunction_InitClassCell(__pyx_t_3, __pyx_t_9) < 0) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MyEncoder, __pyx_t_9) < 0) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":580
 * 
 * 
 * def loadJsonData(load_json_file, json_file_name=''):             # <<<<<<<<<<<<<<
 *     update_json = {}
 *     try:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_33loadJsonData, 0, __pyx_n_s_loadJsonData, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__85)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__86);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_loadJsonData, __pyx_t_5) < 0) __PYX_ERR(0, 580, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":593
 * 
 * 
 * def dumpJsonToFile(load_json_file, update_json, json_file_name='', use_cls=True):             # <<<<<<<<<<<<<<
 *     #  JSON
 *     try:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_35dumpJsonToFile, 0, __pyx_n_s_dumpJsonToFile, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__88)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__89);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dumpJsonToFile, __pyx_t_5) < 0) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":609
 * 
 * 
 * def getYearStartEndDate(year_str: str, mode='trade'):             # <<<<<<<<<<<<<<
 *     '''
 *     mode = 'trade'
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_year_str, __pyx_n_s_str) < 0) __PYX_ERR(0, 609, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_37getYearStartEndDate, 0, __pyx_n_s_getYearStartEndDate, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__91)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__92);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getYearStartEndDate, __pyx_t_2) < 0) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":627
 * 
 * 
 * def getDateDistribution(start_date: datetime, end_date: datetime):             # <<<<<<<<<<<<<<
 *     result = {}
 *     current_date = start_date
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_start_date, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_end_date, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_39getDateDistribution, 0, __pyx_n_s_getDateDistribution, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__94)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getDateDistribution, __pyx_t_5) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":640
 * 
 * 
 * def getMonthStartEndDate(year_str: str, month_str: str, mode='trade'):             # <<<<<<<<<<<<<<
 *     # calendar.monthrange
 *     year = int(year_str)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_year_str, __pyx_n_s_str) < 0) __PYX_ERR(0, 640, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_month_str, __pyx_n_s_str) < 0) __PYX_ERR(0, 640, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_41getMonthStartEndDate, 0, __pyx_n_s_getMonthStartEndDate, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__96)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__92);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getMonthStartEndDate, __pyx_t_2) < 0) __PYX_ERR(0, 640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":660
 * 
 * 
 * def getSuspendedStocks() -> list:             # <<<<<<<<<<<<<<
 *     stock_tfp_em_df = ak.stock_tfp_em(date=latest_trade_day)
 *     suspended_stock_list = list(stock_tfp_em_df[''])
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_list) < 0) __PYX_ERR(0, 660, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_43getSuspendedStocks, 0, __pyx_n_s_getSuspendedStocks, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__98)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSuspendedStocks, __pyx_t_5) < 0) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":666
 * 
 * 
 * def getWeekStartEndByDate(given_date: datetime, mode='trade'):             # <<<<<<<<<<<<<<
 *     # 06
 *     weekday = given_date.weekday()
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_given_date, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 666, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_45getWeekStartEndByDate, 0, __pyx_n_s_getWeekStartEndByDate, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__100)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__92);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getWeekStartEndByDate, __pyx_t_2) < 0) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":688
 * 
 * 
 * def isStockDataSaveToMysql():             # <<<<<<<<<<<<<<
 *     json_file_name = latest_trade_day + '_updatelog.json'
 *     load_json_file = update_db_logs_dir + json_file_name
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_47isStockDataSaveToMysql, 0, __pyx_n_s_isStockDataSaveToMysql, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__102)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_isStockDataSaveToMysql, __pyx_t_2) < 0) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":698
 * 
 * 
 * def isWeekLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     week, start_date, end_date = getWeekStartEndByDate(trade_date)
 *     if week == start_date and week == end_date:
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_trade_date, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 698, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_49isWeekLastTradeDay, 0, __pyx_n_s_isWeekLastTradeDay, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__104)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_isWeekLastTradeDay, __pyx_t_5) < 0) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":708
 * 
 * 
 * def isMonthLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     trade_year = str(trade_date.year)
 *     trade_month = str(trade_date.month)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_trade_date, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 708, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_51isMonthLastTradeDay, 0, __pyx_n_s_isMonthLastTradeDay, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__106)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_isMonthLastTradeDay, __pyx_t_2) < 0) __PYX_ERR(0, 708, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/utils/utils.py":718
 * 
 * 
 * def isYearLastTradeDay(trade_date: datetime):             # <<<<<<<<<<<<<<
 *     trade_year = str(trade_date.year)
 *     start_date, end_date = getYearStartEndDate(trade_year)
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_trade_date, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 718, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_53isYearLastTradeDay, 0, __pyx_n_s_isYearLastTradeDay, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__108)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_isYearLastTradeDay, __pyx_t_5) < 0) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":727
 * 
 * 
 * def test():             # <<<<<<<<<<<<<<
 *     # year = '2019'
 *     # start_date, end_date = getYearStartEndDate(year)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_5utils_5utils_55test, 0, __pyx_n_s_test, NULL, __pyx_n_s_tbstock_utils_utils, __pyx_d, ((PyObject *)__pyx_codeobj__110)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_5) < 0) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/utils/utils.py":782
 * 
 * 
 * if __name__ == '__main__':             # <<<<<<<<<<<<<<
 *     test()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_5, __pyx_n_s_main, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_10) {

    /* "tbstock/utils/utils.py":783
 * 
 * if __name__ == '__main__':
 *     test()             # <<<<<<<<<<<<<<
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_test); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "tbstock/utils/utils.py":782
 * 
 * 
 * if __name__ == '__main__':             # <<<<<<<<<<<<<<
 *     test()
 */
  }

  /* "tbstock/utils/utils.py":1
 * import akshare as ak             # <<<<<<<<<<<<<<
 * import pandas as pd
 * import calendar
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_2, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init tbstock.utils.utils", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init tbstock.utils.utils");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value);
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 0;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a != b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) != 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 1;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 1;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal != 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a != (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyObjectCall2Args */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod1 */
#if !(CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2)
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_GetMethod;
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a + (unsigned long)b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op2);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
static int
__Pyx_unicode_modifiable(PyObject *unicode)
{
    if (Py_REFCNT(unicode) != 1)
        return 0;
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* StringJoin */
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    (void) __Pyx_PyObject_CallMethod1;
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION < 3
    return _PyString_Join(sep, values);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    return _PyBytes_Join(sep, values);
#else
    return __Pyx_PyObject_CallMethod1(sep, __pyx_n_s_join, values);
#endif
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return with_error ? __Pyx_PyObject_GetAttrStr(obj, attr_name) : __Pyx_PyObject_GetAttrStrNoError(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* PyObjectFormat */
#if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* obj, PyObject* format_spec) {
    int ret;
    _PyUnicodeWriter writer;
    if (likely(PyFloat_CheckExact(obj))) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x03040000
        _PyUnicodeWriter_Init(&writer, 0);
#else
        _PyUnicodeWriter_Init(&writer);
#endif
        ret = _PyFloat_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else if (likely(PyLong_CheckExact(obj))) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x03040000
        _PyUnicodeWriter_Init(&writer, 0);
#else
        _PyUnicodeWriter_Init(&writer);
#endif
        ret = _PyLong_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else {
        return PyObject_Format(obj, format_spec);
    }
    if (unlikely(ret == -1)) {
        _PyUnicodeWriter_Dealloc(&writer);
        return NULL;
    }
    return _PyUnicodeWriter_Finish(&writer);
}
#endif

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__19);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__39;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* pybytes_as_double */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj) {
    PyObject *float_value;
#if PY_MAJOR_VERSION >= 3
    float_value = PyFloat_FromString(obj);
#else
    float_value = PyFloat_FromString(obj, 0);
#endif
    if (likely(float_value)) {
#if CYTHON_ASSUME_SAFE_MACROS
        double value = PyFloat_AS_DOUBLE(float_value);
#else
        double value = PyFloat_AsDouble(float_value);
#endif
        Py_DECREF(float_value);
        return value;
    }
    return (double)-1;
}
static const char* __Pyx__PyBytes_AsDouble_Copy(const char* start, char* buffer, Py_ssize_t length) {
    int last_was_punctuation = 1;
    Py_ssize_t i;
    for (i=0; i < length; i++) {
        char chr = start[i];
        int is_punctuation = (chr == '_') | (chr == '.') | (chr == 'e') | (chr == 'E');
        *buffer = chr;
        buffer += (chr != '_');
        if (unlikely(last_was_punctuation & is_punctuation)) goto parse_failure;
        last_was_punctuation = is_punctuation;
    }
    if (unlikely(last_was_punctuation)) goto parse_failure;
    *buffer = '\0';
    return buffer;
parse_failure:
    return NULL;
}
static double __Pyx__PyBytes_AsDouble_inf_nan(const char* start, Py_ssize_t length) {
    int matches = 1;
    char sign = start[0];
    int is_signed = (sign == '+') | (sign == '-');
    start += is_signed;
    length -= is_signed;
    switch (start[0]) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            matches &= (start[1] == 'a' || start[1] == 'A');
            matches &= (start[2] == 'n' || start[2] == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            matches &= (start[1] == 'n' || start[1] == 'N');
            matches &= (start[2] == 'f' || start[2] == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            matches &= (start[3] == 'i' || start[3] == 'I');
            matches &= (start[4] == 'n' || start[4] == 'N');
            matches &= (start[5] == 'i' || start[5] == 'I');
            matches &= (start[6] == 't' || start[6] == 'T');
            matches &= (start[7] == 'y' || start[7] == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static CYTHON_INLINE int __Pyx__PyBytes_AsDouble_IsSpace(char ch) {
    return (ch == 0x20) | !((ch < 0x9) | (ch > 0xd));
}
CYTHON_UNUSED static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length) {
    double value;
    Py_ssize_t i, digits;
    const char *last = start + length;
    char *end;
    while (__Pyx__PyBytes_AsDouble_IsSpace(*start))
        start++;
    while (start < last - 1 && __Pyx__PyBytes_AsDouble_IsSpace(last[-1]))
        last--;
    length = last - start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyBytes_AsDouble_inf_nan(start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    digits = 0;
    for (i=0; i < length; digits += start[i++] != '_');
    if (likely(digits == length)) {
        value = PyOS_string_to_double(start, &end, NULL);
    } else if (digits < 40) {
        char number[40];
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((digits + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if PY_VERSION_HEX >= 0x030d00A4
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base, *meth, *new_base, *result, *new_bases = NULL;
    size_bases = PyTuple_GET_SIZE(bases);
    for (i = 0; i < size_bases; i++) {
        base  = PyTuple_GET_ITEM(bases, i);
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_n_s_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                base = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base);
                Py_INCREF(base);
            }
        }
        j = PyList_GET_SIZE(new_bases);
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
    return result;
error:
    Py_XDECREF(new_bases);
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_MACROS
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
#if PY_VERSION_HEX >= 0x03030000
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
#else
    CYTHON_MAYBE_UNUSED_VAR(qualname);
#endif
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
static int __Pyx_SetNamesPEP487(PyObject *type_obj) {
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *names_to_set, *key, *value, *set_name, *tmp;
    Py_ssize_t i = 0;
#if CYTHON_USE_TYPE_SLOTS
    names_to_set = PyDict_Copy(type->tp_dict);
#else
    {
        PyObject *d = PyObject_GetAttr(type_obj, __pyx_n_s_dict);
        names_to_set = NULL;
        if (likely(d)) {
            PyObject *names_to_set = PyDict_New();
            int ret = likely(names_to_set) ? PyDict_Update(names_to_set, d) : -1;
            Py_DECREF(d);
            if (unlikely(ret < 0))
                Py_CLEAR(names_to_set);
        }
    }
#endif
    if (unlikely(names_to_set == NULL))
        goto bad;
    while (PyDict_Next(names_to_set, &i, &key, &value)) {
        set_name = __Pyx_PyObject_LookupSpecialNoError(value, __pyx_n_s_set_name);
        if (unlikely(set_name != NULL)) {
            tmp = __Pyx_PyObject_Call2Args(set_name, type_obj, key);
            Py_DECREF(set_name);
            if (unlikely(tmp == NULL)) {
                __Pyx_TypeName value_type_name =
                    __Pyx_PyType_GetName(Py_TYPE(value));
                __Pyx_TypeName type_name = __Pyx_PyType_GetName(type);
                PyErr_Format(PyExc_RuntimeError,
#if PY_MAJOR_VERSION >= 3
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %R " "in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name, key, type_name);
#else
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %.100s in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name,
                    PyString_Check(key) ? PyString_AS_STRING(key) : "?",
                    type_name);
#endif
                goto bad;
            } else {
                Py_DECREF(tmp);
            }
        }
        else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
    Py_DECREF(names_to_set);
    return 0;
bad:
    Py_XDECREF(names_to_set);
    return -1;
}
static PyObject *__Pyx_InitSubclassPEP487(PyObject *type_obj, PyObject *mkw) {
#if CYTHON_USE_TYPE_SLOTS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *mro = type->tp_mro;
    Py_ssize_t i, nbases;
    if (unlikely(!mro)) goto done;
    (void) &__Pyx_GetBuiltinName;
    Py_INCREF(mro);
    nbases = PyTuple_GET_SIZE(mro);
    assert(PyTuple_GET_ITEM(mro, 0) == type_obj);
    for (i = 1; i < nbases-1; i++) {
        PyObject *base, *dict, *meth;
        base = PyTuple_GET_ITEM(mro, i);
        dict = ((PyTypeObject *)base)->tp_dict;
        meth = __Pyx_PyDict_GetItemStrWithError(dict, __pyx_n_s_init_subclass);
        if (unlikely(meth)) {
            descrgetfunc f = Py_TYPE(meth)->tp_descr_get;
            PyObject *res;
            Py_INCREF(meth);
            if (likely(f)) {
                res = f(meth, NULL, type_obj);
                Py_DECREF(meth);
                if (unlikely(!res)) goto bad;
                meth = res;
            }
            res = __Pyx_PyObject_FastCallDict(meth, NULL, 0, mkw);
            Py_DECREF(meth);
            if (unlikely(!res)) goto bad;
            Py_DECREF(res);
            goto done;
        } else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
done:
    Py_XDECREF(mro);
    return type_obj;
bad:
    Py_XDECREF(mro);
    Py_DECREF(type_obj);
    return NULL;
#else
    PyObject *super_type, *super, *func, *res;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    super_type = __Pyx_GetBuiltinName(__pyx_n_s_super);
#else
    super_type = (PyObject*) &PySuper_Type;
    (void) &__Pyx_GetBuiltinName;
#endif
    super = likely(super_type) ? __Pyx_PyObject_Call2Args(super_type, type_obj, type_obj) : NULL;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    Py_XDECREF(super_type);
#endif
    if (unlikely(!super)) {
        Py_CLEAR(type_obj);
        goto done;
    }
    func = __Pyx_PyObject_GetAttrStrNoError(super, __pyx_n_s_init_subclass);
    Py_DECREF(super);
    if (likely(!func)) {
        if (unlikely(PyErr_Occurred()))
            Py_CLEAR(type_obj);
        goto done;
    }
    res = __Pyx_PyObject_FastCallDict(func, NULL, 0, mkw);
    Py_DECREF(func);
    if (unlikely(!res))
        Py_CLEAR(type_obj);
    Py_XDECREF(res);
done:
    return type_obj;
#endif
}
#endif
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET,
#if PY_VERSION_HEX < 0x030600A4
        (metaclass == (PyObject*)&PyType_Type) ? NULL : mkw
#else
        mkw
#endif
    );
    Py_XDECREF(owned_metaclass);
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
    if (likely(result) && likely(PyType_Check(result))) {
        if (unlikely(__Pyx_SetNamesPEP487(result) < 0)) {
            Py_CLEAR(result);
        } else {
            result = __Pyx_InitSubclassPEP487(result, mkw);
        }
    }
#else
    (void) &__Pyx_GetBuiltinName;
#endif
    return result;
}

/* CyFunctionClassCell */
static int __Pyx_CyFunction_InitClassCell(PyObject *cyfunctions, PyObject *classobj) {
    Py_ssize_t i, count = PyList_GET_SIZE(cyfunctions);
    for (i = 0; i < count; i++) {
        __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *)
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            PyList_GET_ITEM(cyfunctions, i);
#else
            PySequence_ITEM(cyfunctions, i);
        if (unlikely(!m))
            return -1;
#endif
        __Pyx_CyFunction_SetClassObj(m, classobj);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF((PyObject*)m);
#endif
    }
    return 0;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_n_s__111);
    }
    return name;
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CheckBinaryVersion */
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
