/* Generated by Cython 3.0.11 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "tbstock.dataAcquisition.stockDataCrawler",
        "sources": [
            "./tbstock/dataAcquisition/stockDataCrawler.py"
        ]
    },
    "module_name": "tbstock.dataAcquisition.stockDataCrawler"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_11" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x03000BF0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(Py_GIL_DISABLED) || defined(Py_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 0
  #endif
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__;  (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__tbstock__dataAcquisition__stockDataCrawler
#define __PYX_HAVE_API__tbstock__dataAcquisition__stockDataCrawler
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "tbstock/dataAcquisition/stockDataCrawler.py",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg
    #define __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg  /* no-op, __Pyx_Arg_FASTCALL is direct and this needs
                                                   to have the same reference counting */
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* CallUnboundCMethod2.proto */
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* py_dict_keys.proto */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Keys(PyObject* d);

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyObject_Str.proto */
#define __Pyx_PyObject_Str(obj)\
    (likely(PyString_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */

/* Module declarations from "tbstock.dataAcquisition.stockDataCrawler" */
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "tbstock.dataAcquisition.stockDataCrawler"
extern int __pyx_module_is_main_tbstock__dataAcquisition__stockDataCrawler;
int __pyx_module_is_main_tbstock__dataAcquisition__stockDataCrawler = 0;

/* Implementation of "tbstock.dataAcquisition.stockDataCrawler" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_print;
/* #### Code section: string_decls ### */
static const char __pyx_k_[] = "{}.{}";
static const char __pyx_k_0[] = "0";
static const char __pyx_k_1[] = "1";
static const char __pyx_k_2[] = "2";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_LD[] = "LD";
static const char __pyx_k_PC[] = "PC";
static const char __pyx_k_SD[] = "SD";
static const char __pyx_k__2[] = "";
static const char __pyx_k__3[] = "_";
static const char __pyx_k__4[] = "{";
static const char __pyx_k__5[] = ",";
static const char __pyx_k__7[] = "')";
static const char __pyx_k__9[] = "\")";
static const char __pyx_k_cb[] = "cb";
static const char __pyx_k_dt[] = "dt";
static const char __pyx_k_f2[] = "f2";
static const char __pyx_k_f3[] = "f3";
static const char __pyx_k_f4[] = "f4";
static const char __pyx_k_f5[] = "f5";
static const char __pyx_k_f6[] = "f6";
static const char __pyx_k_fs[] = "fs";
static const char __pyx_k_js[] = "js";
static const char __pyx_k_lt[] = "lt";
static const char __pyx_k_np[] = "np";
static const char __pyx_k_pd[] = "pd";
static const char __pyx_k_pn[] = "pn";
static const char __pyx_k_po[] = "po";
static const char __pyx_k_ps[] = "ps";
static const char __pyx_k_pz[] = "pz";
static const char __pyx_k_rc[] = "rc";
static const char __pyx_k_rt[] = "rt";
static const char __pyx_k_sh[] = "sh";
static const char __pyx_k_sr[] = "sr";
static const char __pyx_k_st[] = "st";
static const char __pyx_k_sz[] = "sz";
static const char __pyx_k_ut[] = "ut";
static const char __pyx_k_0_2[] = "0.";
static const char __pyx_k_101[] = "101";
static const char __pyx_k_1_1[] = "-1,-1";
static const char __pyx_k_1_2[] = "1.";
static const char __pyx_k_1_3[] = "-1";
static const char __pyx_k_200[] = "200";
static const char __pyx_k_250[] = "250";
static const char __pyx_k_2_2[] = "2.";
static const char __pyx_k_500[] = "500";
static const char __pyx_k_ALL[] = "ALL";
static const char __pyx_k_BPS[] = "BPS";
static const char __pyx_k_MLR[] = "MLR";
static const char __pyx_k_NEW[] = "NEW";
static const char __pyx_k_SPJ[] = "SPJ";
static const char __pyx_k_WEB[] = "WEB";
static const char __pyx_k_ZDF[] = "ZDF";
static const char __pyx_k__10[] = "\347\255\271\347\240\201\351\233\206\344\270\255\345\272\246";
static const char __pyx_k__11[] = "\350\202\241\344\270\234\346\210\267\346\225\260\347\273\237\350\256\241\346\210\252\346\255\242\346\227\245";
static const char __pyx_k__12[] = "\350\202\241\344\270\234\346\210\267\346\225\260\345\205\254\345\221\212\346\227\245\346\234\237";
static const char __pyx_k__13[] = "\350\202\241\344\270\234\346\210\267\346\225\260";
static const char __pyx_k__14[] = "\350\202\241\344\270\234\346\210\267\346\225\260\350\276\203\344\270\212\346\234\237\345\217\230\345\214\226%";
static const char __pyx_k__15[] = "\346\210\267\345\235\207\350\202\241\344\273\275\346\225\260\351\207\217";
static const char __pyx_k__16[] = "\346\210\267\345\235\207\350\202\241\344\273\275\346\225\260\351\207\217\350\276\203\344\270\212\346\234\237\345\217\230\345\214\226%";
static const char __pyx_k__17[] = "\350\202\241\344\273\267(\345\205\203)";
static const char __pyx_k__18[] = "\346\210\267\345\235\207\346\214\201\350\202\241\351\207\221\351\242\235(\345\205\203)";
static const char __pyx_k__19[] = "\345\215\201\345\244\247\350\202\241\344\270\234\346\214\201\350\202\241\345\220\210\350\256\241%";
static const char __pyx_k__20[] = "\345\215\201\345\244\247\346\265\201\345\212\250\350\202\241\344\270\234\346\214\201\350\202\241\345\220\210\350\256\241%";
static const char __pyx_k__22[] = "\346\212\245\345\221\212\346\234\237";
static const char __pyx_k__23[] = "\345\205\254\345\221\212\346\227\245\346\234\237";
static const char __pyx_k__24[] = "\345\237\272\346\234\254\346\257\217\350\202\241\346\224\266\347\233\212(\345\205\203)";
static const char __pyx_k__25[] = "\346\211\243\351\235\236\346\257\217\350\202\241\346\224\266\347\233\212(\345\205\203)";
static const char __pyx_k__26[] = "\347\250\200\351\207\212\346\257\217\350\202\241\346\224\266\347\233\212(\345\205\203)";
static const char __pyx_k__27[] = "\346\257\217\350\202\241\345\207\200\350\265\204\344\272\247(\345\205\203)";
static const char __pyx_k__28[] = "\346\257\217\350\202\241\345\205\254\347\247\257\351\207\221(\345\205\203)";
static const char __pyx_k__29[] = "\346\257\217\350\202\241\346\234\252\345\210\206\351\205\215\345\210\251\346\266\246(\345\205\203)";
static const char __pyx_k__30[] = "\346\257\217\350\202\241\347\273\217\350\220\245\347\216\260\351\207\221\346\265\201(\345\205\203)";
static const char __pyx_k__31[] = "\350\220\245\344\270\232\346\200\273\346\224\266\345\205\245(\345\205\203)";
static const char __pyx_k__32[] = "\346\257\233\345\210\251\346\266\246(\345\205\203)";
static const char __pyx_k__33[] = "\345\275\222\345\261\236\345\207\200\345\210\251\346\266\246(\345\205\203)";
static const char __pyx_k__34[] = "\346\211\243\351\235\236\345\207\200\345\210\251\346\266\246(\345\205\203)";
static const char __pyx_k__35[] = "\350\220\245\344\270\232\346\200\273\346\224\266\345\205\245\345\220\214\346\257\224\345\242\236\351\225\277\347\216\207(%)";
static const char __pyx_k__36[] = "\345\275\222\345\261\236\345\207\200\345\210\251\346\266\246\345\220\214\346\257\224\345\242\236\351\225\277\347\216\207(%)";
static const char __pyx_k__37[] = "\346\211\243\351\235\236\345\207\200\345\210\251\346\266\246\345\220\214\346\257\224\345\242\236\351\225\277\347\216\207(%)";
static const char __pyx_k__38[] = "\350\220\245\344\270\232\346\200\273\346\224\266\345\205\245\347\216\257\346\257\224\345\242\236\351\225\277\347\216\207(%)";
static const char __pyx_k__39[] = "\345\275\222\345\261\236\345\207\200\345\210\251\346\266\246\347\216\257\346\257\224\345\242\236\351\225\277\347\216\207(%)";
static const char __pyx_k__40[] = "\346\211\243\351\235\236\345\207\200\345\210\251\346\266\246\347\216\257\346\257\224\345\242\236\351\225\277\347\216\207(%)";
static const char __pyx_k__41[] = "\345\207\200\350\265\204\344\272\247\346\224\266\347\233\212\347\216\207(%)";
static const char __pyx_k__42[] = "\346\200\273\350\265\204\344\272\247\346\224\266\347\233\212\347\216\207(%)";
static const char __pyx_k__43[] = "\345\207\200\345\210\251\347\216\207(%)";
static const char __pyx_k__44[] = "\346\257\233\345\210\251\347\216\207(%)";
static const char __pyx_k__45[] = "\351\242\204\346\224\266\350\264\246\346\254\276/\350\220\245\344\270\232\346\200\273\346\224\266\345\205\245";
static const char __pyx_k__46[] = "\351\224\200\345\224\256\345\207\200\347\216\260\351\207\221\346\265\201/\350\220\245\344\270\232\346\200\273\346\224\266\345\205\245";
static const char __pyx_k__47[] = "\347\273\217\350\220\245\345\207\200\347\216\260\351\207\221\346\265\201/\350\220\245\344\270\232\346\200\273\346\224\266\345\205\245";
static const char __pyx_k__48[] = "\345\256\236\351\231\205\347\250\216\347\216\207(%)";
static const char __pyx_k__49[] = "\346\265\201\345\212\250\346\257\224\347\216\207";
static const char __pyx_k__50[] = "\351\200\237\345\212\250\346\257\224\347\216\207";
static const char __pyx_k__51[] = "\347\216\260\351\207\221\346\265\201\351\207\217\346\257\224\347\216\207";
static const char __pyx_k__52[] = "\350\265\204\344\272\247\350\264\237\345\200\272\347\216\207(%)";
static const char __pyx_k__53[] = "\346\235\203\347\233\212\347\263\273\346\225\260";
static const char __pyx_k__54[] = "\344\272\247\346\235\203\346\257\224\347\216\207";
static const char __pyx_k__55[] = "\346\200\273\350\265\204\344\272\247\345\221\250\350\275\254\345\244\251\346\225\260";
static const char __pyx_k__56[] = "\345\255\230\350\264\247\345\221\250\350\275\254\345\244\251\346\225\260";
static const char __pyx_k__57[] = "\345\272\224\346\224\266\350\264\246\346\254\276\345\221\250\350\275\254\345\244\251\346\225\260";
static const char __pyx_k__58[] = "\346\200\273\350\265\204\344\272\247\345\221\250\350\275\254\347\216\207(\346\254\241)";
static const char __pyx_k__59[] = "\345\255\230\350\264\247\345\221\250\350\275\254\347\216\207(\346\254\241)";
static const char __pyx_k__60[] = "\345\272\224\346\224\266\350\264\246\346\254\276\345\221\250\350\275\254\347\216\207(\346\254\241)";
static const char __pyx_k__62[] = ".";
static const char __pyx_k__63[] = "\350\202\241\347\245\250\344\273\243\347\240\201";
static const char __pyx_k__64[] = "\350\202\241\347\245\250\347\256\200\347\247\260";
static const char __pyx_k__65[] = "\346\200\273\350\202\241\346\234\254";
static const char __pyx_k__66[] = "\346\265\201\351\200\232\350\202\241";
static const char __pyx_k__67[] = "\350\241\214\344\270\232";
static const char __pyx_k__68[] = "\346\200\273\345\270\202\345\200\274";
static const char __pyx_k__69[] = "\346\265\201\351\200\232\345\270\202\345\200\274";
static const char __pyx_k__70[] = "\345\234\260\345\237\237\346\235\277\345\235\227";
static const char __pyx_k__71[] = "\344\270\212\345\270\202\346\227\266\351\227\264";
static const char __pyx_k__72[] = "-";
static const char __pyx_k__73[] = "\351\200\201\350\275\254\350\202\241\344\273\275-\351\200\201\350\275\254\346\200\273\346\257\224\344\276\213";
static const char __pyx_k__74[] = "\351\200\201\350\275\254\350\202\241\344\273\275-\351\200\201\350\202\241\346\257\224\344\276\213";
static const char __pyx_k__75[] = "\351\200\201\350\275\254\350\202\241\344\273\275-\350\275\254\350\202\241\346\257\224\344\276\213";
static const char __pyx_k__76[] = "\347\216\260\351\207\221\345\210\206\347\272\242-\347\216\260\351\207\221\345\210\206\347\272\242\346\257\224\344\276\213";
static const char __pyx_k__77[] = "\344\270\232\347\273\251\346\212\253\351\234\262\346\227\245\346\234\237";
static const char __pyx_k__78[] = "\350\202\241\346\235\203\347\231\273\350\256\260\346\227\245";
static const char __pyx_k__79[] = "\351\231\244\346\235\203\351\231\244\346\201\257\346\227\245";
static const char __pyx_k__80[] = "\346\226\271\346\241\210\350\277\233\345\272\246";
static const char __pyx_k__81[] = "\347\216\260\351\207\221\345\210\206\347\272\242-\347\216\260\351\207\221\345\210\206\347\272\242\346\257\224\344\276\213\346\217\217\350\277\260";
static const char __pyx_k__82[] = "\346\234\200\346\226\260\345\205\254\345\221\212\346\227\245\346\234\237";
static const char __pyx_k__83[] = "\346\257\217\350\202\241\346\224\266\347\233\212";
static const char __pyx_k__84[] = "\346\257\217\350\202\241\345\207\200\350\265\204\344\272\247";
static const char __pyx_k__85[] = "\346\257\217\350\202\241\345\205\254\347\247\257\351\207\221";
static const char __pyx_k__86[] = "\346\257\217\350\202\241\346\234\252\345\210\206\351\205\215\345\210\251\346\266\246";
static const char __pyx_k__87[] = "\345\207\200\345\210\251\346\266\246\345\220\214\346\257\224\345\242\236\351\225\277";
static const char __pyx_k__88[] = "\351\242\204\346\241\210\345\205\254\345\221\212\346\227\245";
static const char __pyx_k__89[] = "\347\216\260\351\207\221\345\210\206\347\272\242-\350\202\241\346\201\257\347\216\207";
static const char __pyx_k__90[] = "*";
static const char __pyx_k_beg[] = "beg";
static const char __pyx_k_bps[] = "bps";
static const char __pyx_k_csi[] = "csi";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_f12[] = "f12";
static const char __pyx_k_f14[] = "f14";
static const char __pyx_k_f15[] = "f15";
static const char __pyx_k_f16[] = "f16";
static const char __pyx_k_f17[] = "f17";
static const char __pyx_k_f18[] = "f18";
static const char __pyx_k_f57[] = "f57";
static const char __pyx_k_f58[] = "f58";
static const char __pyx_k_f84[] = "f84";
static const char __pyx_k_f85[] = "f85";
static const char __pyx_k_fid[] = "fid";
static const char __pyx_k_fqt[] = "fqt";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_klt[] = "klt";
static const char __pyx_k_low[] = "low";
static const char __pyx_k_map[] = "map";
static const char __pyx_k_new[] = "new";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sty[] = "sty";
static const char __pyx_k_svr[] = "svr";
static const char __pyx_k_url[] = "url";
static const char __pyx_k_CQBL[] = "CQBL";
static const char __pyx_k_DATE[] = "DATE";
static const char __pyx_k_JROA[] = "JROA";
static const char __pyx_k_QYCS[] = "QYCS";
static const char __pyx_k_RQYE[] = "RQYE";
static const char __pyx_k_RQYL[] = "RQYL";
static const char __pyx_k_RZYE[] = "RZYE";
static const char __pyx_k__132[] = "?";
static const char __pyx_k_ceil[] = "ceil";
static const char __pyx_k_code[] = "code";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_date[] = "date";
static const char __pyx_k_dect[] = "dect";
static const char __pyx_k_diff[] = "diff";
static const char __pyx_k_drop[] = "drop";
static const char __pyx_k_f116[] = "f116";
static const char __pyx_k_f117[] = "f117";
static const char __pyx_k_f127[] = "f127";
static const char __pyx_k_f128[] = "f128";
static const char __pyx_k_f189[] = "f189";
static const char __pyx_k_find[] = "find";
static const char __pyx_k_fltt[] = "fltt";
static const char __pyx_k_full[] = "full";
static const char __pyx_k_high[] = "high";
static const char __pyx_k_invt[] = "invt";
static const char __pyx_k_item[] = "item";
static const char __pyx_k_json[] = "json";
static const char __pyx_k_keys[] = "keys";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_math[] = "math";
static const char __pyx_k_mode[] = "mode";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_page[] = "page";
static const char __pyx_k_rqye[] = "rqye";
static const char __pyx_k_rqyl[] = "rqyl";
static const char __pyx_k_rzye[] = "rzye";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_test[] = "test";
static const char __pyx_k_text[] = "text";
static const char __pyx_k_type[] = "type";
static const char __pyx_k_CHZZL[] = "CHZZL";
static const char __pyx_k_EPSJB[] = "EPSJB";
static const char __pyx_k_EPSXS[] = "EPSXS";
static const char __pyx_k_HSF10[] = "HSF10";
static const char __pyx_k_PRICE[] = "PRICE";
static const char __pyx_k_ROEJQ[] = "ROEJQ";
static const char __pyx_k_RQCHL[] = "RQCHL";
static const char __pyx_k_RQJMG[] = "RQJMG";
static const char __pyx_k_RQMCL[] = "RQMCL";
static const char __pyx_k_RZCHE[] = "RZCHE";
static const char __pyx_k_RZJME[] = "RZJME";
static const char __pyx_k_RZMRE[] = "RZMRE";
static const char __pyx_k_SCODE[] = "SCODE";
static const char __pyx_k_XJLLB[] = "XJLLB";
static const char __pyx_k_XSJLL[] = "XSJLL";
static const char __pyx_k_XSMLL[] = "XSMLL";
static const char __pyx_k_Y_m_d[] = "%Y%m%d";
static const char __pyx_k_ZCFZL[] = "ZCFZL";
static const char __pyx_k_apply[] = "apply";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_empty[] = "empty";
static const char __pyx_k_float[] = "float";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_notna[] = "notna";
static const char __pyx_k_pages[] = "pages";
static const char __pyx_k_price[] = "price";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_rqchl[] = "rqchl";
static const char __pyx_k_rqjmg[] = "rqjmg";
static const char __pyx_k_rqmcl[] = "rqmcl";
static const char __pyx_k_rzche[] = "rzche";
static const char __pyx_k_rzjme[] = "rzjme";
static const char __pyx_k_rzmre[] = "rzmre";
static const char __pyx_k_scode[] = "(scode=\"";
static const char __pyx_k_secid[] = "secid";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_total[] = "total";
static const char __pyx_k_utils[] = "utils";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_wbp2u[] = "wbp2u";
static const char __pyx_k_000001[] = "000001";
static const char __pyx_k_300073[] = "300073";
static const char __pyx_k_600900[] = "600900";
static const char __pyx_k_688235[] = "688235";
static const char __pyx_k_CHZZTS[] = "CHZZTS";
static const char __pyx_k_DATE_2[] = "(DATE='";
static const char __pyx_k_MGZBGJ[] = "MGZBGJ";
static const char __pyx_k_RZRQYE[] = "RZRQYE";
static const char __pyx_k_RZYEZB[] = "RZYEZB";
static const char __pyx_k_TOAZZL[] = "TOAZZL";
static const char __pyx_k_ZZCJLL[] = "ZZCJLL";
static const char __pyx_k_amount[] = "amount";
static const char __pyx_k_big_df[] = "big_df";
static const char __pyx_k_ch_zzl[] = "ch_zzl";
static const char __pyx_k_client[] = "client";
static const char __pyx_k_coerce[] = "coerce";
static const char __pyx_k_concat[] = "concat";
static const char __pyx_k_decode[] = "decode";
static const char __pyx_k_dlmkts[] = "dlmkts";
static const char __pyx_k_eps_jb[] = "eps_jb";
static const char __pyx_k_eps_kf[] = "eps_kf";
static const char __pyx_k_eps_xs[] = "eps_xs";
static const char __pyx_k_errors[] = "errors";
static const char __pyx_k_fields[] = "fields";
static const char __pyx_k_filter[] = "filter";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_insert[] = "insert";
static const char __pyx_k_klines[] = "klines";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_pageNo[] = "pageNo";
static const char __pyx_k_pandas[] = "pandas";
static const char __pyx_k_params[] = "params";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_return[] = "return";
static const char __pyx_k_rzrqye[] = "rzrqye";
static const char __pyx_k_rzyezb[] = "rzyezb";
static const char __pyx_k_source[] = "source";
static const char __pyx_k_symbol[] = "symbol";
static const char __pyx_k_test_2[] = "__test__";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_volume[] = "volume";
static const char __pyx_k_BUY_AMT[] = "BUY_AMT";
static const char __pyx_k_EPSKCJB[] = "EPSKCJB";
static const char __pyx_k_MGWFPLR[] = "MGWFPLR";
static const char __pyx_k_SECNAME[] = "SECNAME";
static const char __pyx_k_TAXRATE[] = "TAXRATE";
static const char __pyx_k_YSZKZZL[] = "YSZKZZL";
static const char __pyx_k_ZZCZZTS[] = "ZZCZZTS";
static const char __pyx_k_ch_zzts[] = "ch_zzts";
static const char __pyx_k_columns[] = "columns";
static const char __pyx_k_demjson[] = "demjson";
static const char __pyx_k_fields1[] = "fields1";
static const char __pyx_k_fields2[] = "fields2";
static const char __pyx_k_inplace[] = "inplace";
static const char __pyx_k_pageNum[] = "pageNum";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_roe_jzc[] = "roe_jzc";
static const char __pyx_k_roe_zzc[] = "roe_zzc";
static const char __pyx_k_temp_df[] = "temp_df";
static const char __pyx_k_timeout[] = "timeout";
static const char __pyx_k_zzc_zzl[] = "zzc_zzl";
static const char __pyx_k_19900101[] = "19900101";
static const char __pyx_k_20500101[] = "20500101";
static const char __pyx_k_DIM_DATE[] = "DIM_DATE";
static const char __pyx_k_END_DATE[] = "END_DATE";
static const char __pyx_k_MGJYXJJE[] = "MGJYXJJE";
static const char __pyx_k_SECUCODE[] = "(SECUCODE=\"";
static const char __pyx_k_SELL_AMT[] = "SELL_AMT";
static const char __pyx_k_YSZKYYSR[] = "YSZKYYSR";
static const char __pyx_k_YSZKZZTS[] = "YSZKZZTS";
static const char __pyx_k_datetime[] = "datetime";
static const char __pyx_k_dim_date[] = "dim_date";
static const char __pyx_k_end_date[] = "end_date";
static const char __pyx_k_pageSize[] = "pageSize";
static const char __pyx_k_pub_date[] = "pub_date";
static const char __pyx_k_requests[] = "requests";
static const char __pyx_k_strptime[] = "strptime";
static const char __pyx_k_tax_rate[] = "tax_rate";
static const char __pyx_k_yszk_zzl[] = "yszk_zzl";
static const char __pyx_k_zzc_zzts[] = "zzc_zzts";
static const char __pyx_k_000001_SZ[] = "000001.SZ";
static const char __pyx_k_0_0_0_web[] = "|0|0|0|web";
static const char __pyx_k_688235_SH[] = "688235.SH";
static const char __pyx_k_DataFrame[] = "DataFrame";
static const char __pyx_k_JYXJLYYSR[] = "JYXJLYYSR";
static const char __pyx_k_XSJXLYYSR[] = "XSJXLYYSR";
static const char __pyx_k_bond_code[] = "bond_code";
static const char __pyx_k_bond_name[] = "bond_name";
static const char __pyx_k_csi931151[] = "csi931151";
static const char __pyx_k_data_json[] = "data_json";
static const char __pyx_k_data_text[] = "data_text";
static const char __pyx_k_pre_close[] = "pre_close";
static const char __pyx_k_quoteType[] = "quoteType";
static const char __pyx_k_sortTypes[] = "sortTypes";
static const char __pyx_k_yszk_zzts[] = "yszk_zzts";
static const char __pyx_k_2024_05_31[] = "2024-05-31";
static const char __pyx_k_HOLD_FOCUS[] = "HOLD_FOCUS";
static const char __pyx_k_TRADE_DATE[] = "TRADE_DATE";
static const char __pyx_k_add_amount[] = "add_amount";
static const char __pyx_k_add_volume[] = "add_volume";
static const char __pyx_k_bond_scale[] = "bond_scale";
static const char __pyx_k_buy_amount[] = "buy_amount";
static const char __pyx_k_hold_focus[] = "hold_focus";
static const char __pyx_k_holder_num[] = "holder_num";
static const char __pyx_k_kzz_all_df[] = "kzz_all_df";
static const char __pyx_k_market_map[] = "market_map";
static const char __pyx_k_net_amount[] = "net_amount";
static const char __pyx_k_pageNumber[] = "pageNumber";
static const char __pyx_k_reportName[] = "reportName";
static const char __pyx_k_start_date[] = "start_date";
static const char __pyx_k_stock_code[] = "stock_code";
static const char __pyx_k_stock_name[] = "stock_name";
static const char __pyx_k_to_numeric[] = "to_numeric";
static const char __pyx_k_total_item[] = "total_item";
static const char __pyx_k_trade_date[] = "trade_date";
static const char __pyx_k_CHANGE_RATE[] = "CHANGE_RATE";
static const char __pyx_k_CLOSE_PRICE[] = "CLOSE_PRICE";
static const char __pyx_k_HOLD_SHARES[] = "HOLD_SHARES";
static const char __pyx_k_KCFJCXSYJLR[] = "KCFJCXSYJLR";
static const char __pyx_k_KFJLRGDHBZC[] = "KFJLRGDHBZC";
static const char __pyx_k_NOTICE_DATE[] = "NOTICE_DATE";
static const char __pyx_k_PER_NETCASH[] = "PER_NETCASH";
static const char __pyx_k_PREDICT_AMC[] = "PREDICT_AMC";
static const char __pyx_k_REPORT_DATE[] = "REPORT_DATE";
static const char __pyx_k_ROE_DILUTED[] = "ROE_DILUTED";
static const char __pyx_k_YYZSRGDHBZC[] = "YYZSRGDHBZC";
static const char __pyx_k_change_rate[] = "change_rate";
static const char __pyx_k_column_dict[] = "column_dict";
static const char __pyx_k_hold_amount[] = "hold_amount";
static const char __pyx_k_hold_volume[] = "hold_volume";
static const char __pyx_k_hs300_close[] = "hs300_close";
static const char __pyx_k_net_cash_ps[] = "net_cash_ps";
static const char __pyx_k_notice_date[] = "notice_date";
static const char __pyx_k_price_ratio[] = "price_ratio";
static const char __pyx_k_quick_ratio[] = "quick_ratio";
static const char __pyx_k_report_date[] = "report_date";
static const char __pyx_k_reset_index[] = "reset_index";
static const char __pyx_k_sell_amount[] = "sell_amount";
static const char __pyx_k_sortColumns[] = "sortColumns";
static const char __pyx_k_to_datetime[] = "to_datetime";
static const char __pyx_k_total_pages[] = "total_pages";
static const char __pyx_k_AVG_HOLD_AMT[] = "AVG_HOLD_AMT";
static const char __pyx_k_GROSS_PROFIT[] = "GROSS_PROFIT";
static const char __pyx_k_NET_DEAL_AMT[] = "NET_DEAL_AMT";
static const char __pyx_k_TRADE_DATE_2[] = "(TRADE_DATE='";
static const char __pyx_k_change_ratio[] = "change_ratio";
static const char __pyx_k_code_id_dict[] = "code_id_dict";
static const char __pyx_k_equity_ratio[] = "equity_ratio";
static const char __pyx_k_gross_profit[] = "gross_profit";
static const char __pyx_k_hsgt_history[] = "hsgt_history";
static const char __pyx_k_ignore_index[] = "ignore_index";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_kzz_sh_em_df[] = "kzz_sh_em_df";
static const char __pyx_k_kzz_sz_em_df[] = "kzz_sz_em_df";
static const char __pyx_k_m_0_b_MK0354[] = "m:0 b:MK0354";
static const char __pyx_k_m_1_b_MK0354[] = "m:1 b:MK0354";
static const char __pyx_k_pd_DataFrame[] = "pd.DataFrame";
static const char __pyx_k_price_change[] = "price_change";
static const char __pyx_k_quoteColumns[] = "quoteColumns";
static const char __pyx_k_rzrq_history[] = "rzrq_history";
static const char __pyx_k_1596700547039[] = "1596700547039";
static const char __pyx_k_1640157544804[] = "1640157544804";
static const char __pyx_k_1717261171099[] = "1717261171099";
static const char __pyx_k_1717298612418[] = "1717298612418";
static const char __pyx_k_1717298688717[] = "1717298688717";
static const char __pyx_k_1721047529031[] = "1721047529031";
static const char __pyx_k_1721051595125[] = "1721051595125";
static const char __pyx_k_KCFJCXSYJLRTZ[] = "KCFJCXSYJLRTZ";
static const char __pyx_k_SECURITY_CODE[] = "SECURITY_CODE";
static const char __pyx_k_SECURITY_NAME[] = "SECURITY_NAME";
static const char __pyx_k_akshare_utils[] = "akshare.utils";
static const char __pyx_k_avg_amount_pa[] = "avg_amount_pa";
static const char __pyx_k_avg_volume_pa[] = "avg_volume_pa";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_code_name_map[] = "code_name_map";
static const char __pyx_k_current_ratio[] = "current_ratio";
static const char __pyx_k_kf_net_profit[] = "kf_net_profit";
static const char __pyx_k_stock_gdhs_df[] = "stock_gdhs_df";
static const char __pyx_k_stock_hsgt_df[] = "stock_hsgt_df";
static const char __pyx_k_stock_rzrq_df[] = "stock_rzrq_df";
static const char __pyx_k_tbstock_utils[] = "tbstock.utils";
static const char __pyx_k_ACCUM_DEAL_AMT[] = "ACCUM_DEAL_AMT";
static const char __pyx_k_ADD_MARKET_CAP[] = "ADD_MARKET_CAP";
static const char __pyx_k_DPNP_YOY_RATIO[] = "DPNP_YOY_RATIO";
static const char __pyx_k_RPTA_RZRQ_LSHJ[] = "RPTA_RZRQ_LSHJ";
static const char __pyx_k_TRANSFER_PRICE[] = "TRANSFER_PRICE";
static const char __pyx_k_TRANSFER_VALUE[] = "TRANSFER_VALUE";
static const char __pyx_k_code_id_map_em[] = "code_id_map_em";
static const char __pyx_k_f1_f2_f3_f4_f5[] = "f1,f2,f3,f4,f5";
static const char __pyx_k_is_null_result[] = "is_null_result";
static const char __pyx_k_transfer_price[] = "transfer_price";
static const char __pyx_k_transfer_value[] = "transfer_value";
static const char __pyx_k_AVG_FREE_SHARES[] = "AVG_FREE_SHARES";
static const char __pyx_k_HOLD_MARKET_CAP[] = "HOLD_MARKET_CAP";
static const char __pyx_k_INTERVAL_TYPE_1[] = "')(INTERVAL_TYPE=\"1\")";
static const char __pyx_k_MUTUAL_TYPE_005[] = "(MUTUAL_TYPE=\"005\")";
static const char __pyx_k_NETPROFITRPHBZC[] = "NETPROFITRPHBZC";
static const char __pyx_k_PARENTNETPROFIT[] = "PARENTNETPROFIT";
static const char __pyx_k_SECURITY_CODE_2[] = "(SECURITY_CODE=\"";
static const char __pyx_k_TOTAL_NUM_RATIO[] = "TOTAL_NUM_RATIO";
static const char __pyx_k_cash_flow_ratio[] = "cash_flow_ratio";
static const char __pyx_k_cols_to_convert[] = "cols_to_convert";
static const char __pyx_k_data_x_pages_tp[] = "{\"data\":(x),\"pages\":(tp)}";
static const char __pyx_k_hsgt_history_df[] = "hsgt_history_df";
static const char __pyx_k_rzrq_history_df[] = "rzrq_history_df";
static const char __pyx_k_sse_index_close[] = "sse_index_close";
static const char __pyx_k_HOLDER_TOTAL_NUM[] = "HOLDER_TOTAL_NUM";
static const char __pyx_k_HOLD_RATIO_TOTAL[] = "HOLD_RATIO_TOTAL";
static const char __pyx_k_NET_PROFIT_RATIO[] = "NET_PROFIT_RATIO";
static const char __pyx_k_RPT_BOND_CB_LIST[] = "RPT_BOND_CB_LIST";
static const char __pyx_k_TOTALOPERATEREVE[] = "TOTALOPERATEREVE";
static const char __pyx_k_accum_net_amount[] = "accum_net_amount";
static const char __pyx_k_column_name_dict[] = "column_name_dict";
static const char __pyx_k_holder_num_ratio[] = "holder_num_ratio";
static const char __pyx_k_kf_net_profit_hb[] = "kf_net_profit_hb";
static const char __pyx_k_kf_net_profit_tb[] = "kf_net_profit_tb";
static const char __pyx_k_kzz_trade_day_df[] = "kzz_trade_day_df";
static const char __pyx_k_latest_trade_day[] = "latest_trade_day";
static const char __pyx_k_net_profit_ratio[] = "net_profit_ratio";
static const char __pyx_k_08730299565686817[] = "08730299565686817";
static const char __pyx_k_ADD_SHARES_REPAIR[] = "ADD_SHARES_REPAIR";
static const char __pyx_k_FREE_SHARES_RATIO[] = "FREE_SHARES_RATIO";
static const char __pyx_k_INDEX_CHANGE_RATE[] = "INDEX_CHANGE_RATE";
static const char __pyx_k_INDEX_CLOSE_PRICE[] = "INDEX_CLOSE_PRICE";
static const char __pyx_k_INTERVAL_TYPE_1_2[] = "\")(INTERVAL_TYPE=\"1\")";
static const char __pyx_k_PARENTNETPROFITTZ[] = "PARENTNETPROFITTZ";
static const char __pyx_k_PUBLIC_START_DATE[] = "PUBLIC_START_DATE";
static const char __pyx_k_equity_multiplier[] = "equity_multiplier";
static const char __pyx_k_hold_volume_ratio[] = "hold_volume_ratio";
static const char __pyx_k_kzz_basic_info_em[] = "kzz_basic_info_em";
static const char __pyx_k_parent_net_profit[] = "parent_net_profit";
static const char __pyx_k_stock_hsgt_detail[] = "stock_hsgt_detail";
static const char __pyx_k_stock_rzrq_detail[] = "stock_rzrq_detail";
static const char __pyx_k_yszk_to_tor_ratio[] = "yszk_to_tor_ratio";
static const char __pyx_k_007949902328317804[] = "007949902328317804";
static const char __pyx_k_018998368837725255[] = "018998368837725255";
static const char __pyx_k_ACTUAL_ISSUE_SCALE[] = "ACTUAL_ISSUE_SCALE";
static const char __pyx_k_CONVERT_STOCK_CODE[] = "CONVERT_STOCK_CODE";
static const char __pyx_k_DEDU_PARENT_PROFIT[] = "DEDU_PARENT_PROFIT";
static const char __pyx_k_GROSS_PROFIT_RATIO[] = "GROSS_PROFIT_RATIO";
static const char __pyx_k_RPTA_WEB_RZRQ_GGMX[] = "RPTA_WEB_RZRQ_GGMX";
static const char __pyx_k_RPT_SHAREBONUS_DET[] = "RPT_SHAREBONUS_DET";
static const char __pyx_k_SECURITY_NAME_ABBR[] = "SECURITY_NAME_ABBR";
static const char __pyx_k_TOTALOPERATEREVETZ[] = "TOTALOPERATEREVETZ";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_capital_reserve_ps[] = "capital_reserve_ps";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_gross_profit_ratio[] = "gross_profit_ratio";
static const char __pyx_k_hs300_change_ratio[] = "hs300_change_ratio";
static const char __pyx_k_top_ten_ratio_free[] = "top_ten_ratio_free";
static const char __pyx_k_unassign_profit_ps[] = "unassign_profit_ps";
static const char __pyx_k_PER_CAPITAL_RESERVE[] = "PER_CAPITAL_RESERVE";
static const char __pyx_k_PER_UNASSIGN_PROFIT[] = "PER_UNASSIGN_PROFIT";
static const char __pyx_k_SECURITY_SHORT_NAME[] = "SECURITY_SHORT_NAME";
static const char __pyx_k_avg_volume_pa_ratio[] = "avg_volume_pa_ratio";
static const char __pyx_k_debt_to_asset_ratio[] = "debt_to_asset_ratio";
static const char __pyx_k_jyjxjl_to_tor_ratio[] = "jyjxjl_to_tor_ratio";
static const char __pyx_k_kzz_trade_day_em_df[] = "kzz_trade_day_em_df";
static const char __pyx_k_stock_all_hsgt_date[] = "stock_all_hsgt_date";
static const char __pyx_k_stock_all_rzrq_date[] = "stock_all_rzrq_date";
static const char __pyx_k_stock_hsgt_today_df[] = "stock_hsgt_today_df";
static const char __pyx_k_stock_rzrq_today_df[] = "stock_rzrq_today_df";
static const char __pyx_k_top_ten_ratio_total[] = "top_ten_ratio_total";
static const char __pyx_k_xsjxjl_to_tor_ratio[] = "xsjxjl_to_tor_ratio";
static const char __pyx_k_APP_F10_MAINFINADATA[] = "APP_F10_MAINFINADATA";
static const char __pyx_k_AVG_FREESHARES_RATIO[] = "AVG_FREESHARES_RATIO";
static const char __pyx_k_FREEHOLD_RATIO_TOTAL[] = "FREEHOLD_RATIO_TOTAL";
static const char __pyx_k_RPT_F10_EH_HOLDERNUM[] = "RPT_F10_EH_HOLDERNUM";
static const char __pyx_k_parent_net_profit_hb[] = "parent_net_profit_hb";
static const char __pyx_k_parent_net_profit_tb[] = "parent_net_profit_tb";
static const char __pyx_k_stock_fhps_detail_em[] = "stock_fhps_detail_em";
static const char __pyx_k_finance_mfd_report_df[] = "finance_mfd_report_df";
static const char __pyx_k_kzz_trade_day_info_em[] = "kzz_trade_day_info_em";
static const char __pyx_k_total_operate_revenue[] = "total_operate_revenue";
static const char __pyx_k_finance_mfd_quarter_df[] = "finance_mfd_quarter_df";
static const char __pyx_k_sse_index_change_ratio[] = "sse_index_change_ratio";
static const char __pyx_k_stock_zh_index_daily_em[] = "stock_zh_index_daily_em";
static const char __pyx_k_RPT_F10_QTR_MAINFINADATA[] = "RPT_F10_QTR_MAINFINADATA";
static const char __pyx_k_kzz_sh_trade_day_info_em[] = "kzz_sh_trade_day_info_em";
static const char __pyx_k_kzz_sz_trade_day_info_em[] = "kzz_sz_trade_day_info_em";
static const char __pyx_k_stock_individual_info_em[] = "stock_individual_info_em";
static const char __pyx_k_total_operate_revenue_hb[] = "total_operate_revenue_hb";
static const char __pyx_k_total_operate_revenue_tb[] = "total_operate_revenue_tb";
static const char __pyx_k_RPT_MUTUAL_STOCK_NORTHSTA[] = "RPT_MUTUAL_STOCK_NORTHSTA";
static const char __pyx_k_stock_zh_a_gdhs_detail_em[] = "stock_zh_a_gdhs_detail_em";
static const char __pyx_k_RPT_MUTUAL_DEALHISTORY_NEW[] = "RPT_MUTUAL_DEALHISTORY_NEW";
static const char __pyx_k_stock_finance_mfd_report_em[] = "stock_finance_mfd_report_em";
static const char __pyx_k_RPT_F10_FINANCE_MAINFINADATA[] = "RPT_F10_FINANCE_MAINFINADATA";
static const char __pyx_k_stock_finance_mfd_quarter_em[] = "stock_finance_mfd_quarter_em";
static const char __pyx_k_RPT_MUTUAL_HOLDSTOCKNDATE_STA[] = "RPT_MUTUAL_HOLDSTOCKNDATE_STA";
static const char __pyx_k_Date_2023_8_11_11_44_Desc_https[] = "\nDate: 2023/8/11 11:44\nDesc: \344\270\234\346\226\271\350\264\242\345\257\214\347\275\221-\344\270\252\350\202\241-\350\202\241\347\245\250\344\277\241\346\201\257\nhttps://quote.eastmoney.com/concept/sh603777.html?from=classic\n";
static const char __pyx_k_PUBLIC_START_DATE_SECURITY_CODE[] = "PUBLIC_START_DATE,SECURITY_CODE";
static const char __pyx_k_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE[] = "SCODE,SECNAME,DATE,SPJ,ZDF,RZYE,RZYEZB,RZMRE,RZCHE,RZJME,RQYE,RQYL,RQCHL,RQMCL,RQJMG,RZRQYE";
static const char __pyx_k_TRADE_DATE_NET_DEAL_AMT_BUY_AMT[] = "TRADE_DATE,NET_DEAL_AMT,BUY_AMT,SELL_AMT,ACCUM_DEAL_AMT,INDEX_CLOSE_PRICE,INDEX_CHANGE_RATE";
static const char __pyx_k_f51_f52_f53_f54_f55_f56_f57_f58[] = "f51,f52,f53,f54,f55,f56,f57,f58";
static const char __pyx_k_http_push2_eastmoney_com_api_qt[] = "http://push2.eastmoney.com/api/qt/stock/get";
static const char __pyx_k_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM[] = "DIM_DATE,NEW,ZDF,RZYE,RZYEZB,RZMRE,RZCHE,RZJME,RQYE,RQYL,RQCHL,RQMCL,RQJMG,RZRQYE";
static const char __pyx_k_SECURITY_CODE_SECURITY_NAME_ABBR[] = "SECURITY_CODE,SECURITY_NAME_ABBR,HOLD_FOCUS,END_DATE,NOTICE_DATE,HOLDER_TOTAL_NUM,TOTAL_NUM_RATIO,AVG_FREE_SHARES,AVG_FREESHARES_RATIO,PRICE,AVG_HOLD_AMT,HOLD_RATIO_TOTAL,FREEHOLD_RATIO_TOTAL";
static const char __pyx_k_SECURITY_CODE_SECURITY_NAME_TRAD[] = "SECURITY_CODE,SECURITY_NAME,TRADE_DATE,CLOSE_PRICE,CHANGE_RATE,HOLD_SHARES,HOLD_MARKET_CAP,FREE_SHARES_RATIO,ADD_SHARES_REPAIR,ADD_MARKET_CAP";
static const char __pyx_k_akshare_stock_feature_stock_hist[] = "akshare.stock_feature.stock_hist_em";
static const char __pyx_k_bd1d9ddb04089700cf9c27f6f7426281[] = "bd1d9ddb04089700cf9c27f6f7426281";
static const char __pyx_k_f120_f121_f122_f174_f175_f59_f16[] = "f120,f121,f122,f174,f175,f59,f163,f43,f57,f58,f169,f170,f46,f44,f51,f168,f47,f164,f116,f60,f45,f52,f50,f48,f167,f117,f71,f161,f49,f530,f135,f136,f137,f138,f139,f141,f142,f144,f145,f147,f148,f140,f143,f146,f149,f55,f62,f162,f92,f173,f104,f105,f84,f85,f183,f184,f185,f186,f187,f188,f189,f190,f191,f192,f107,f111,f86,f177,f78,f110,f262,f263,f264,f267,f268,f255,f256,f257,f258,f127,f199,f128,f198,f259,f260,f261,f171,f277,f278,f279,f288,f152,f250,f251,f252,f253,f254,f269,f270,f271,f272,f273,f274,f275,f276,f265,f266,f289,f290,f286,f285,f292,f293,f294,f295";
static const char __pyx_k_f12_f14_f2_f4_f3_f17_f15_f16_f18[] = "f12,f14,f2,f4,f3,f17,f15,f16,f18,f5,f6";
static const char __pyx_k_f2_01_CONVERT_STOCK_CODE_CONVERT[] = "f2~01~CONVERT_STOCK_CODE~CONVERT_STOCK_PRICE,f235~10~SECURITY_CODE~TRANSFER_PRICE,f236~10~SECURITY_CODE~TRANSFER_VALUE,f2~10~SECURITY_CODE~CURRENT_BOND_PRICE,f237~10~SECURITY_CODE~TRANSFER_PREMIUM_RATIO,f239~10~SECURITY_CODE~RESALE_TRIG_PRICE,f240~10~SECURITY_CODE~REDEEM_TRIG_PRICE,f23~01~CONVERT_STOCK_CODE~PBV_RATIO";
static const char __pyx_k_fa5fd1943c7b386f172d6893dbfba10b[] = "fa5fd1943c7b386f172d6893dbfba10b";
static const char __pyx_k_https_38_push2_eastmoney_com_api[] = "https://38.push2.eastmoney.com/api/qt/clist/get";
static const char __pyx_k_https_89_push2_eastmoney_com_api[] = "https://89.push2.eastmoney.com/api/qt/clist/get";
static const char __pyx_k_https_datacenter_eastmoney_com_s[] = "https://datacenter.eastmoney.com/securities/api/data/v1/get";
static const char __pyx_k_https_datacenter_web_eastmoney_c[] = "https://datacenter-web.eastmoney.com/api/data/v1/get";
static const char __pyx_k_https_push2his_eastmoney_com_api[] = "https://push2his.eastmoney.com/api/qt/stock/kline/get";
static const char __pyx_k_jQuery1124033485574041163946_159[] = "jQuery1124033485574041163946_1596700547000";
static const char __pyx_k_tbstock_dataAcquisition_stockDat[] = "tbstock/dataAcquisition/stockDataCrawler.py";
static const char __pyx_k_SECURITY_CODE_SECURITY_NAME_TRAD_2[] = "SECURITY_CODE,SECURITY_NAME,TRADE_DATE,CLOSE_PRICE,CHANGE_RATE,HOLD_SHARES,HOLD_MARKET_CAP,FREE_SHARES_RATIO,ADD_SHARES_REPAIR,PREDICT_AMC";
static const char __pyx_k_https_datacenter_eastmoney_com_s_2[] = "https://datacenter.eastmoney.com/securities/api/data/get";
static const char __pyx_k_tbstock_dataAcquisition_stockDat_2[] = "tbstock.dataAcquisition.stockDataCrawler";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_stock_zh_index_daily_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_start_date, PyObject *__pyx_v_end_date); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_2rzrq_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_4stock_all_rzrq_date(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_6stock_rzrq_detail(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode, PyObject *__pyx_v_symbol); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_8hsgt_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_10stock_all_hsgt_date(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_12stock_hsgt_detail(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode, PyObject *__pyx_v_symbol); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_14stock_zh_a_gdhs_detail_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_16stock_finance_mfd_quarter_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_18stock_finance_mfd_report_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_20stock_individual_info_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_22stock_fhps_detail_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_24kzz_sh_trade_day_info_em(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_26kzz_sz_trade_day_info_em(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_28kzz_trade_day_info_em(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_30kzz_basic_info_em(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_32test(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_keys = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_update = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyString_Type_find = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyString_Type_replace = {0, 0, 0, 0, 0};
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyObject *__pyx_kp_s_;
  PyObject *__pyx_kp_s_0;
  PyObject *__pyx_kp_s_000001;
  PyObject *__pyx_kp_s_000001_SZ;
  PyObject *__pyx_kp_s_007949902328317804;
  PyObject *__pyx_kp_s_018998368837725255;
  PyObject *__pyx_kp_s_08730299565686817;
  PyObject *__pyx_kp_s_0_0_0_web;
  PyObject *__pyx_kp_s_0_2;
  PyObject *__pyx_kp_s_1;
  PyObject *__pyx_kp_s_101;
  PyObject *__pyx_kp_s_1596700547039;
  PyObject *__pyx_kp_s_1640157544804;
  PyObject *__pyx_kp_s_1717261171099;
  PyObject *__pyx_kp_s_1717298612418;
  PyObject *__pyx_kp_s_1717298688717;
  PyObject *__pyx_kp_s_1721047529031;
  PyObject *__pyx_kp_s_1721051595125;
  PyObject *__pyx_kp_s_19900101;
  PyObject *__pyx_kp_s_1_1;
  PyObject *__pyx_kp_s_1_2;
  PyObject *__pyx_kp_s_1_3;
  PyObject *__pyx_kp_s_2;
  PyObject *__pyx_kp_s_200;
  PyObject *__pyx_kp_s_2024_05_31;
  PyObject *__pyx_kp_s_20500101;
  PyObject *__pyx_kp_s_250;
  PyObject *__pyx_kp_s_2_2;
  PyObject *__pyx_kp_s_300073;
  PyObject *__pyx_kp_s_500;
  PyObject *__pyx_kp_s_600900;
  PyObject *__pyx_kp_s_688235;
  PyObject *__pyx_kp_s_688235_SH;
  PyObject *__pyx_n_s_ACCUM_DEAL_AMT;
  PyObject *__pyx_n_s_ACTUAL_ISSUE_SCALE;
  PyObject *__pyx_n_s_ADD_MARKET_CAP;
  PyObject *__pyx_n_s_ADD_SHARES_REPAIR;
  PyObject *__pyx_n_s_ALL;
  PyObject *__pyx_n_s_APP_F10_MAINFINADATA;
  PyObject *__pyx_n_s_AVG_FREESHARES_RATIO;
  PyObject *__pyx_n_s_AVG_FREE_SHARES;
  PyObject *__pyx_n_s_AVG_HOLD_AMT;
  PyObject *__pyx_n_s_BPS;
  PyObject *__pyx_n_s_BUY_AMT;
  PyObject *__pyx_n_s_CHANGE_RATE;
  PyObject *__pyx_n_s_CHZZL;
  PyObject *__pyx_n_s_CHZZTS;
  PyObject *__pyx_n_s_CLOSE_PRICE;
  PyObject *__pyx_n_s_CONVERT_STOCK_CODE;
  PyObject *__pyx_n_s_CQBL;
  PyObject *__pyx_n_s_DATE;
  PyObject *__pyx_kp_u_DATE_2;
  PyObject *__pyx_n_s_DEDU_PARENT_PROFIT;
  PyObject *__pyx_n_s_DIM_DATE;
  PyObject *__pyx_kp_s_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM;
  PyObject *__pyx_n_s_DPNP_YOY_RATIO;
  PyObject *__pyx_n_s_DataFrame;
  PyObject *__pyx_n_s_END_DATE;
  PyObject *__pyx_n_s_EPSJB;
  PyObject *__pyx_n_s_EPSKCJB;
  PyObject *__pyx_n_s_EPSXS;
  PyObject *__pyx_n_s_FREEHOLD_RATIO_TOTAL;
  PyObject *__pyx_n_s_FREE_SHARES_RATIO;
  PyObject *__pyx_n_s_GROSS_PROFIT;
  PyObject *__pyx_n_s_GROSS_PROFIT_RATIO;
  PyObject *__pyx_n_s_HOLDER_TOTAL_NUM;
  PyObject *__pyx_n_s_HOLD_FOCUS;
  PyObject *__pyx_n_s_HOLD_MARKET_CAP;
  PyObject *__pyx_n_s_HOLD_RATIO_TOTAL;
  PyObject *__pyx_n_s_HOLD_SHARES;
  PyObject *__pyx_n_s_HSF10;
  PyObject *__pyx_n_s_INDEX_CHANGE_RATE;
  PyObject *__pyx_n_s_INDEX_CLOSE_PRICE;
  PyObject *__pyx_kp_u_INTERVAL_TYPE_1;
  PyObject *__pyx_kp_u_INTERVAL_TYPE_1_2;
  PyObject *__pyx_n_s_JROA;
  PyObject *__pyx_n_s_JYXJLYYSR;
  PyObject *__pyx_n_s_KCFJCXSYJLR;
  PyObject *__pyx_n_s_KCFJCXSYJLRTZ;
  PyObject *__pyx_n_s_KFJLRGDHBZC;
  PyObject *__pyx_n_s_LD;
  PyObject *__pyx_n_s_MGJYXJJE;
  PyObject *__pyx_n_s_MGWFPLR;
  PyObject *__pyx_n_s_MGZBGJ;
  PyObject *__pyx_n_s_MLR;
  PyObject *__pyx_kp_s_MUTUAL_TYPE_005;
  PyObject *__pyx_n_s_NETPROFITRPHBZC;
  PyObject *__pyx_n_s_NET_DEAL_AMT;
  PyObject *__pyx_n_s_NET_PROFIT_RATIO;
  PyObject *__pyx_n_s_NEW;
  PyObject *__pyx_n_s_NOTICE_DATE;
  PyObject *__pyx_n_s_PARENTNETPROFIT;
  PyObject *__pyx_n_s_PARENTNETPROFITTZ;
  PyObject *__pyx_n_s_PC;
  PyObject *__pyx_n_s_PER_CAPITAL_RESERVE;
  PyObject *__pyx_n_s_PER_NETCASH;
  PyObject *__pyx_n_s_PER_UNASSIGN_PROFIT;
  PyObject *__pyx_n_s_PREDICT_AMC;
  PyObject *__pyx_n_s_PRICE;
  PyObject *__pyx_n_s_PUBLIC_START_DATE;
  PyObject *__pyx_kp_s_PUBLIC_START_DATE_SECURITY_CODE;
  PyObject *__pyx_n_s_QYCS;
  PyObject *__pyx_n_s_REPORT_DATE;
  PyObject *__pyx_n_s_ROEJQ;
  PyObject *__pyx_n_s_ROE_DILUTED;
  PyObject *__pyx_n_s_RPTA_RZRQ_LSHJ;
  PyObject *__pyx_n_s_RPTA_WEB_RZRQ_GGMX;
  PyObject *__pyx_n_s_RPT_BOND_CB_LIST;
  PyObject *__pyx_n_s_RPT_F10_EH_HOLDERNUM;
  PyObject *__pyx_n_s_RPT_F10_FINANCE_MAINFINADATA;
  PyObject *__pyx_n_s_RPT_F10_QTR_MAINFINADATA;
  PyObject *__pyx_n_s_RPT_MUTUAL_DEALHISTORY_NEW;
  PyObject *__pyx_n_s_RPT_MUTUAL_HOLDSTOCKNDATE_STA;
  PyObject *__pyx_n_s_RPT_MUTUAL_STOCK_NORTHSTA;
  PyObject *__pyx_n_s_RPT_SHAREBONUS_DET;
  PyObject *__pyx_n_s_RQCHL;
  PyObject *__pyx_n_s_RQJMG;
  PyObject *__pyx_n_s_RQMCL;
  PyObject *__pyx_n_s_RQYE;
  PyObject *__pyx_n_s_RQYL;
  PyObject *__pyx_n_s_RZCHE;
  PyObject *__pyx_n_s_RZJME;
  PyObject *__pyx_n_s_RZMRE;
  PyObject *__pyx_n_s_RZRQYE;
  PyObject *__pyx_n_s_RZYE;
  PyObject *__pyx_n_s_RZYEZB;
  PyObject *__pyx_n_s_SCODE;
  PyObject *__pyx_kp_s_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE;
  PyObject *__pyx_n_s_SD;
  PyObject *__pyx_n_s_SECNAME;
  PyObject *__pyx_kp_u_SECUCODE;
  PyObject *__pyx_n_s_SECURITY_CODE;
  PyObject *__pyx_kp_u_SECURITY_CODE_2;
  PyObject *__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_ABBR;
  PyObject *__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD;
  PyObject *__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD_2;
  PyObject *__pyx_n_s_SECURITY_NAME;
  PyObject *__pyx_n_s_SECURITY_NAME_ABBR;
  PyObject *__pyx_n_s_SECURITY_SHORT_NAME;
  PyObject *__pyx_n_s_SELL_AMT;
  PyObject *__pyx_n_s_SPJ;
  PyObject *__pyx_n_s_TAXRATE;
  PyObject *__pyx_n_s_TOAZZL;
  PyObject *__pyx_n_s_TOTALOPERATEREVE;
  PyObject *__pyx_n_s_TOTALOPERATEREVETZ;
  PyObject *__pyx_n_s_TOTAL_NUM_RATIO;
  PyObject *__pyx_n_s_TRADE_DATE;
  PyObject *__pyx_kp_u_TRADE_DATE_2;
  PyObject *__pyx_kp_s_TRADE_DATE_NET_DEAL_AMT_BUY_AMT;
  PyObject *__pyx_n_s_TRANSFER_PRICE;
  PyObject *__pyx_n_s_TRANSFER_VALUE;
  PyObject *__pyx_n_s_WEB;
  PyObject *__pyx_n_s_XJLLB;
  PyObject *__pyx_n_s_XSJLL;
  PyObject *__pyx_n_s_XSJXLYYSR;
  PyObject *__pyx_n_s_XSMLL;
  PyObject *__pyx_n_s_YSZKYYSR;
  PyObject *__pyx_n_s_YSZKZZL;
  PyObject *__pyx_n_s_YSZKZZTS;
  PyObject *__pyx_n_s_YYZSRGDHBZC;
  PyObject *__pyx_kp_s_Y_m_d;
  PyObject *__pyx_n_s_ZCFZL;
  PyObject *__pyx_n_s_ZDF;
  PyObject *__pyx_n_s_ZZCJLL;
  PyObject *__pyx_n_s_ZZCZZTS;
  PyObject *__pyx_kp_s__10;
  PyObject *__pyx_kp_s__11;
  PyObject *__pyx_kp_s__12;
  PyObject *__pyx_kp_s__13;
  PyObject *__pyx_n_s__132;
  PyObject *__pyx_kp_s__14;
  PyObject *__pyx_kp_s__15;
  PyObject *__pyx_kp_s__16;
  PyObject *__pyx_kp_s__17;
  PyObject *__pyx_kp_s__18;
  PyObject *__pyx_kp_s__19;
  PyObject *__pyx_kp_s__2;
  PyObject *__pyx_kp_s__20;
  PyObject *__pyx_kp_s__22;
  PyObject *__pyx_kp_s__23;
  PyObject *__pyx_kp_s__24;
  PyObject *__pyx_kp_s__25;
  PyObject *__pyx_kp_s__26;
  PyObject *__pyx_kp_s__27;
  PyObject *__pyx_kp_s__28;
  PyObject *__pyx_kp_s__29;
  PyObject *__pyx_n_s__3;
  PyObject *__pyx_kp_s__30;
  PyObject *__pyx_kp_s__31;
  PyObject *__pyx_kp_s__32;
  PyObject *__pyx_kp_s__33;
  PyObject *__pyx_kp_s__34;
  PyObject *__pyx_kp_s__35;
  PyObject *__pyx_kp_s__36;
  PyObject *__pyx_kp_s__37;
  PyObject *__pyx_kp_s__38;
  PyObject *__pyx_kp_s__39;
  PyObject *__pyx_kp_s__4;
  PyObject *__pyx_kp_s__40;
  PyObject *__pyx_kp_s__41;
  PyObject *__pyx_kp_s__42;
  PyObject *__pyx_kp_s__43;
  PyObject *__pyx_kp_s__44;
  PyObject *__pyx_kp_s__45;
  PyObject *__pyx_kp_s__46;
  PyObject *__pyx_kp_s__47;
  PyObject *__pyx_kp_s__48;
  PyObject *__pyx_kp_s__49;
  PyObject *__pyx_kp_s__5;
  PyObject *__pyx_kp_s__50;
  PyObject *__pyx_kp_s__51;
  PyObject *__pyx_kp_s__52;
  PyObject *__pyx_kp_s__53;
  PyObject *__pyx_kp_s__54;
  PyObject *__pyx_kp_s__55;
  PyObject *__pyx_kp_s__56;
  PyObject *__pyx_kp_s__57;
  PyObject *__pyx_kp_s__58;
  PyObject *__pyx_kp_s__59;
  PyObject *__pyx_kp_s__60;
  PyObject *__pyx_kp_u__62;
  PyObject *__pyx_kp_s__63;
  PyObject *__pyx_kp_s__64;
  PyObject *__pyx_kp_s__65;
  PyObject *__pyx_kp_s__66;
  PyObject *__pyx_kp_s__67;
  PyObject *__pyx_kp_s__68;
  PyObject *__pyx_kp_s__69;
  PyObject *__pyx_kp_u__7;
  PyObject *__pyx_kp_s__70;
  PyObject *__pyx_kp_s__71;
  PyObject *__pyx_kp_s__72;
  PyObject *__pyx_kp_s__73;
  PyObject *__pyx_kp_s__74;
  PyObject *__pyx_kp_s__75;
  PyObject *__pyx_kp_s__76;
  PyObject *__pyx_kp_s__77;
  PyObject *__pyx_kp_s__78;
  PyObject *__pyx_kp_s__79;
  PyObject *__pyx_kp_s__80;
  PyObject *__pyx_kp_s__81;
  PyObject *__pyx_kp_s__82;
  PyObject *__pyx_kp_s__83;
  PyObject *__pyx_kp_s__84;
  PyObject *__pyx_kp_s__85;
  PyObject *__pyx_kp_s__86;
  PyObject *__pyx_kp_s__87;
  PyObject *__pyx_kp_s__88;
  PyObject *__pyx_kp_s__89;
  PyObject *__pyx_kp_u__9;
  PyObject *__pyx_n_s__90;
  PyObject *__pyx_n_s_accum_net_amount;
  PyObject *__pyx_n_s_add_amount;
  PyObject *__pyx_n_s_add_volume;
  PyObject *__pyx_n_s_akshare_stock_feature_stock_hist;
  PyObject *__pyx_n_s_akshare_utils;
  PyObject *__pyx_n_s_amount;
  PyObject *__pyx_n_s_apply;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_avg_amount_pa;
  PyObject *__pyx_n_s_avg_volume_pa;
  PyObject *__pyx_n_s_avg_volume_pa_ratio;
  PyObject *__pyx_n_s_bd1d9ddb04089700cf9c27f6f7426281;
  PyObject *__pyx_n_s_beg;
  PyObject *__pyx_n_s_big_df;
  PyObject *__pyx_n_s_bond_code;
  PyObject *__pyx_n_s_bond_name;
  PyObject *__pyx_n_s_bond_scale;
  PyObject *__pyx_n_s_bps;
  PyObject *__pyx_n_s_buy_amount;
  PyObject *__pyx_n_s_capital_reserve_ps;
  PyObject *__pyx_n_s_cash_flow_ratio;
  PyObject *__pyx_n_s_cb;
  PyObject *__pyx_n_s_ceil;
  PyObject *__pyx_n_s_ch_zzl;
  PyObject *__pyx_n_s_ch_zzts;
  PyObject *__pyx_n_s_change_rate;
  PyObject *__pyx_n_s_change_ratio;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_client;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_close;
  PyObject *__pyx_n_s_code;
  PyObject *__pyx_n_s_code_id_dict;
  PyObject *__pyx_n_s_code_id_map_em;
  PyObject *__pyx_n_s_code_name_map;
  PyObject *__pyx_n_s_coerce;
  PyObject *__pyx_n_s_cols_to_convert;
  PyObject *__pyx_n_s_column_dict;
  PyObject *__pyx_n_s_column_name_dict;
  PyObject *__pyx_n_s_columns;
  PyObject *__pyx_n_s_concat;
  PyObject *__pyx_n_s_csi;
  PyObject *__pyx_n_s_csi931151;
  PyObject *__pyx_n_s_current_ratio;
  PyObject *__pyx_n_s_data;
  PyObject *__pyx_n_s_data_json;
  PyObject *__pyx_n_s_data_text;
  PyObject *__pyx_kp_s_data_x_pages_tp;
  PyObject *__pyx_n_s_date;
  PyObject *__pyx_n_s_datetime;
  PyObject *__pyx_n_s_debt_to_asset_ratio;
  PyObject *__pyx_n_s_decode;
  PyObject *__pyx_n_s_dect;
  PyObject *__pyx_n_s_demjson;
  PyObject *__pyx_n_s_diff;
  PyObject *__pyx_n_s_dim_date;
  PyObject *__pyx_n_s_dlmkts;
  PyObject *__pyx_n_s_drop;
  PyObject *__pyx_n_s_dt;
  PyObject *__pyx_n_s_empty;
  PyObject *__pyx_n_s_end;
  PyObject *__pyx_n_s_end_date;
  PyObject *__pyx_n_s_eps_jb;
  PyObject *__pyx_n_s_eps_kf;
  PyObject *__pyx_n_s_eps_xs;
  PyObject *__pyx_n_s_equity_multiplier;
  PyObject *__pyx_n_s_equity_ratio;
  PyObject *__pyx_n_s_errors;
  PyObject *__pyx_n_s_f116;
  PyObject *__pyx_n_s_f117;
  PyObject *__pyx_n_s_f12;
  PyObject *__pyx_kp_s_f120_f121_f122_f174_f175_f59_f16;
  PyObject *__pyx_n_s_f127;
  PyObject *__pyx_n_s_f128;
  PyObject *__pyx_kp_s_f12_f14_f2_f4_f3_f17_f15_f16_f18;
  PyObject *__pyx_n_s_f14;
  PyObject *__pyx_n_s_f15;
  PyObject *__pyx_n_s_f16;
  PyObject *__pyx_n_s_f17;
  PyObject *__pyx_n_s_f18;
  PyObject *__pyx_n_s_f189;
  PyObject *__pyx_kp_s_f1_f2_f3_f4_f5;
  PyObject *__pyx_n_s_f2;
  PyObject *__pyx_kp_s_f2_01_CONVERT_STOCK_CODE_CONVERT;
  PyObject *__pyx_n_s_f3;
  PyObject *__pyx_n_s_f4;
  PyObject *__pyx_n_s_f5;
  PyObject *__pyx_kp_s_f51_f52_f53_f54_f55_f56_f57_f58;
  PyObject *__pyx_n_s_f57;
  PyObject *__pyx_n_s_f58;
  PyObject *__pyx_n_s_f6;
  PyObject *__pyx_n_s_f84;
  PyObject *__pyx_n_s_f85;
  PyObject *__pyx_n_s_fa5fd1943c7b386f172d6893dbfba10b;
  PyObject *__pyx_n_s_fid;
  PyObject *__pyx_n_s_fields;
  PyObject *__pyx_n_s_fields1;
  PyObject *__pyx_n_s_fields2;
  PyObject *__pyx_n_s_filter;
  PyObject *__pyx_n_s_finance_mfd_quarter_df;
  PyObject *__pyx_n_s_finance_mfd_report_df;
  PyObject *__pyx_n_s_find;
  PyObject *__pyx_n_s_float;
  PyObject *__pyx_n_s_fltt;
  PyObject *__pyx_n_s_format;
  PyObject *__pyx_n_s_fqt;
  PyObject *__pyx_n_s_fs;
  PyObject *__pyx_n_s_full;
  PyObject *__pyx_n_s_get;
  PyObject *__pyx_n_s_gross_profit;
  PyObject *__pyx_n_s_gross_profit_ratio;
  PyObject *__pyx_n_s_high;
  PyObject *__pyx_n_s_hold_amount;
  PyObject *__pyx_n_s_hold_focus;
  PyObject *__pyx_n_s_hold_volume;
  PyObject *__pyx_n_s_hold_volume_ratio;
  PyObject *__pyx_n_s_holder_num;
  PyObject *__pyx_n_s_holder_num_ratio;
  PyObject *__pyx_n_s_hs300_change_ratio;
  PyObject *__pyx_n_s_hs300_close;
  PyObject *__pyx_n_s_hsgt_history;
  PyObject *__pyx_n_s_hsgt_history_df;
  PyObject *__pyx_kp_s_http_push2_eastmoney_com_api_qt;
  PyObject *__pyx_kp_s_https_38_push2_eastmoney_com_api;
  PyObject *__pyx_kp_s_https_89_push2_eastmoney_com_api;
  PyObject *__pyx_kp_s_https_datacenter_eastmoney_com_s;
  PyObject *__pyx_kp_s_https_datacenter_eastmoney_com_s_2;
  PyObject *__pyx_kp_s_https_datacenter_web_eastmoney_c;
  PyObject *__pyx_kp_s_https_push2his_eastmoney_com_api;
  PyObject *__pyx_n_s_ignore_index;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_index;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_inplace;
  PyObject *__pyx_n_s_insert;
  PyObject *__pyx_n_s_invt;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_n_s_is_null_result;
  PyObject *__pyx_n_s_item;
  PyObject *__pyx_n_s_jQuery1124033485574041163946_159;
  PyObject *__pyx_n_s_js;
  PyObject *__pyx_n_s_json;
  PyObject *__pyx_n_s_jyjxjl_to_tor_ratio;
  PyObject *__pyx_n_s_keys;
  PyObject *__pyx_n_s_kf_net_profit;
  PyObject *__pyx_n_s_kf_net_profit_hb;
  PyObject *__pyx_n_s_kf_net_profit_tb;
  PyObject *__pyx_n_s_klines;
  PyObject *__pyx_n_s_klt;
  PyObject *__pyx_n_s_kzz_all_df;
  PyObject *__pyx_n_s_kzz_basic_info_em;
  PyObject *__pyx_n_s_kzz_sh_em_df;
  PyObject *__pyx_n_s_kzz_sh_trade_day_info_em;
  PyObject *__pyx_n_s_kzz_sz_em_df;
  PyObject *__pyx_n_s_kzz_sz_trade_day_info_em;
  PyObject *__pyx_n_s_kzz_trade_day_df;
  PyObject *__pyx_n_s_kzz_trade_day_em_df;
  PyObject *__pyx_n_s_kzz_trade_day_info_em;
  PyObject *__pyx_n_s_latest_trade_day;
  PyObject *__pyx_n_s_low;
  PyObject *__pyx_n_s_lt;
  PyObject *__pyx_kp_s_m_0_b_MK0354;
  PyObject *__pyx_kp_s_m_1_b_MK0354;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_map;
  PyObject *__pyx_n_s_market_map;
  PyObject *__pyx_n_s_math;
  PyObject *__pyx_n_s_mode;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_s_net_amount;
  PyObject *__pyx_n_s_net_cash_ps;
  PyObject *__pyx_n_s_net_profit_ratio;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_n_s_notice_date;
  PyObject *__pyx_n_s_notna;
  PyObject *__pyx_n_s_np;
  PyObject *__pyx_n_s_open;
  PyObject *__pyx_n_s_p;
  PyObject *__pyx_n_s_page;
  PyObject *__pyx_n_s_pageNo;
  PyObject *__pyx_n_s_pageNum;
  PyObject *__pyx_n_s_pageNumber;
  PyObject *__pyx_n_s_pageSize;
  PyObject *__pyx_n_s_pages;
  PyObject *__pyx_n_s_pandas;
  PyObject *__pyx_n_s_params;
  PyObject *__pyx_n_s_parent_net_profit;
  PyObject *__pyx_n_s_parent_net_profit_hb;
  PyObject *__pyx_n_s_parent_net_profit_tb;
  PyObject *__pyx_n_s_pd;
  PyObject *__pyx_kp_s_pd_DataFrame;
  PyObject *__pyx_n_s_pn;
  PyObject *__pyx_n_s_po;
  PyObject *__pyx_n_s_pre_close;
  PyObject *__pyx_n_s_price;
  PyObject *__pyx_n_s_price_change;
  PyObject *__pyx_n_s_price_ratio;
  PyObject *__pyx_n_s_print;
  PyObject *__pyx_n_s_ps;
  PyObject *__pyx_n_s_pub_date;
  PyObject *__pyx_n_s_pz;
  PyObject *__pyx_n_s_quick_ratio;
  PyObject *__pyx_n_s_quoteColumns;
  PyObject *__pyx_n_s_quoteType;
  PyObject *__pyx_n_s_r;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_rc;
  PyObject *__pyx_n_s_replace;
  PyObject *__pyx_n_s_reportName;
  PyObject *__pyx_n_s_report_date;
  PyObject *__pyx_n_s_requests;
  PyObject *__pyx_n_s_reset_index;
  PyObject *__pyx_n_s_result;
  PyObject *__pyx_n_s_return;
  PyObject *__pyx_n_s_roe_jzc;
  PyObject *__pyx_n_s_roe_zzc;
  PyObject *__pyx_n_s_rqchl;
  PyObject *__pyx_n_s_rqjmg;
  PyObject *__pyx_n_s_rqmcl;
  PyObject *__pyx_n_s_rqye;
  PyObject *__pyx_n_s_rqyl;
  PyObject *__pyx_n_s_rt;
  PyObject *__pyx_n_s_rzche;
  PyObject *__pyx_n_s_rzjme;
  PyObject *__pyx_n_s_rzmre;
  PyObject *__pyx_n_s_rzrq_history;
  PyObject *__pyx_n_s_rzrq_history_df;
  PyObject *__pyx_n_s_rzrqye;
  PyObject *__pyx_n_s_rzye;
  PyObject *__pyx_n_s_rzyezb;
  PyObject *__pyx_kp_u_scode;
  PyObject *__pyx_n_s_secid;
  PyObject *__pyx_n_s_sell_amount;
  PyObject *__pyx_n_s_sh;
  PyObject *__pyx_n_s_sortColumns;
  PyObject *__pyx_n_s_sortTypes;
  PyObject *__pyx_n_s_source;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_split;
  PyObject *__pyx_n_s_sr;
  PyObject *__pyx_n_s_sse_index_change_ratio;
  PyObject *__pyx_n_s_sse_index_close;
  PyObject *__pyx_n_s_st;
  PyObject *__pyx_n_s_start_date;
  PyObject *__pyx_n_s_stock_all_hsgt_date;
  PyObject *__pyx_n_s_stock_all_rzrq_date;
  PyObject *__pyx_n_s_stock_code;
  PyObject *__pyx_n_s_stock_fhps_detail_em;
  PyObject *__pyx_n_s_stock_finance_mfd_quarter_em;
  PyObject *__pyx_n_s_stock_finance_mfd_report_em;
  PyObject *__pyx_n_s_stock_gdhs_df;
  PyObject *__pyx_n_s_stock_hsgt_detail;
  PyObject *__pyx_n_s_stock_hsgt_df;
  PyObject *__pyx_n_s_stock_hsgt_today_df;
  PyObject *__pyx_n_s_stock_individual_info_em;
  PyObject *__pyx_n_s_stock_name;
  PyObject *__pyx_n_s_stock_rzrq_detail;
  PyObject *__pyx_n_s_stock_rzrq_df;
  PyObject *__pyx_n_s_stock_rzrq_today_df;
  PyObject *__pyx_n_s_stock_zh_a_gdhs_detail_em;
  PyObject *__pyx_n_s_stock_zh_index_daily_em;
  PyObject *__pyx_n_s_str;
  PyObject *__pyx_n_s_strptime;
  PyObject *__pyx_n_s_sty;
  PyObject *__pyx_n_s_svr;
  PyObject *__pyx_n_s_symbol;
  PyObject *__pyx_n_s_sz;
  PyObject *__pyx_n_s_tax_rate;
  PyObject *__pyx_kp_s_tbstock_dataAcquisition_stockDat;
  PyObject *__pyx_n_s_tbstock_dataAcquisition_stockDat_2;
  PyObject *__pyx_n_s_tbstock_utils;
  PyObject *__pyx_n_s_temp_df;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_test_2;
  PyObject *__pyx_n_s_text;
  PyObject *__pyx_n_s_timeout;
  PyObject *__pyx_n_s_to_datetime;
  PyObject *__pyx_n_s_to_numeric;
  PyObject *__pyx_n_s_top_ten_ratio_free;
  PyObject *__pyx_n_s_top_ten_ratio_total;
  PyObject *__pyx_n_s_total;
  PyObject *__pyx_n_s_total_item;
  PyObject *__pyx_n_s_total_operate_revenue;
  PyObject *__pyx_n_s_total_operate_revenue_hb;
  PyObject *__pyx_n_s_total_operate_revenue_tb;
  PyObject *__pyx_n_s_total_pages;
  PyObject *__pyx_n_s_trade_date;
  PyObject *__pyx_n_s_transfer_price;
  PyObject *__pyx_n_s_transfer_value;
  PyObject *__pyx_n_s_type;
  PyObject *__pyx_n_s_unassign_profit_ps;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_url;
  PyObject *__pyx_n_s_ut;
  PyObject *__pyx_n_s_utils;
  PyObject *__pyx_n_s_v;
  PyObject *__pyx_n_s_value;
  PyObject *__pyx_n_s_values;
  PyObject *__pyx_n_s_volume;
  PyObject *__pyx_n_s_wbp2u;
  PyObject *__pyx_n_s_xsjxjl_to_tor_ratio;
  PyObject *__pyx_n_s_yszk_to_tor_ratio;
  PyObject *__pyx_n_s_yszk_zzl;
  PyObject *__pyx_n_s_yszk_zzts;
  PyObject *__pyx_n_s_zzc_zzl;
  PyObject *__pyx_n_s_zzc_zzts;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_2;
  PyObject *__pyx_int_3;
  PyObject *__pyx_int_4;
  PyObject *__pyx_int_5;
  PyObject *__pyx_int_25;
  PyObject *__pyx_int_50;
  PyObject *__pyx_int_500;
  PyObject *__pyx_int_neg_1;
  PyObject *__pyx_slice__6;
  PyObject *__pyx_slice__8;
  PyObject *__pyx_slice__21;
  PyObject *__pyx_slice__61;
  PyObject *__pyx_tuple__91;
  PyObject *__pyx_tuple__93;
  PyObject *__pyx_tuple__94;
  PyObject *__pyx_tuple__96;
  PyObject *__pyx_tuple__97;
  PyObject *__pyx_tuple__99;
  PyObject *__pyx_tuple__100;
  PyObject *__pyx_tuple__102;
  PyObject *__pyx_tuple__103;
  PyObject *__pyx_tuple__105;
  PyObject *__pyx_tuple__107;
  PyObject *__pyx_tuple__109;
  PyObject *__pyx_tuple__111;
  PyObject *__pyx_tuple__112;
  PyObject *__pyx_tuple__114;
  PyObject *__pyx_tuple__115;
  PyObject *__pyx_tuple__117;
  PyObject *__pyx_tuple__119;
  PyObject *__pyx_tuple__120;
  PyObject *__pyx_tuple__122;
  PyObject *__pyx_tuple__123;
  PyObject *__pyx_tuple__126;
  PyObject *__pyx_tuple__128;
  PyObject *__pyx_tuple__130;
  PyObject *__pyx_codeobj__92;
  PyObject *__pyx_codeobj__95;
  PyObject *__pyx_codeobj__98;
  PyObject *__pyx_codeobj__101;
  PyObject *__pyx_codeobj__104;
  PyObject *__pyx_codeobj__106;
  PyObject *__pyx_codeobj__108;
  PyObject *__pyx_codeobj__110;
  PyObject *__pyx_codeobj__113;
  PyObject *__pyx_codeobj__116;
  PyObject *__pyx_codeobj__118;
  PyObject *__pyx_codeobj__121;
  PyObject *__pyx_codeobj__124;
  PyObject *__pyx_codeobj__125;
  PyObject *__pyx_codeobj__127;
  PyObject *__pyx_codeobj__129;
  PyObject *__pyx_codeobj__131;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_kp_s_);
  Py_CLEAR(clear_module_state->__pyx_kp_s_0);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000001);
  Py_CLEAR(clear_module_state->__pyx_kp_s_000001_SZ);
  Py_CLEAR(clear_module_state->__pyx_kp_s_007949902328317804);
  Py_CLEAR(clear_module_state->__pyx_kp_s_018998368837725255);
  Py_CLEAR(clear_module_state->__pyx_kp_s_08730299565686817);
  Py_CLEAR(clear_module_state->__pyx_kp_s_0_0_0_web);
  Py_CLEAR(clear_module_state->__pyx_kp_s_0_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1);
  Py_CLEAR(clear_module_state->__pyx_kp_s_101);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1596700547039);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1640157544804);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1717261171099);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1717298612418);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1717298688717);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1721047529031);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1721051595125);
  Py_CLEAR(clear_module_state->__pyx_kp_s_19900101);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1_1);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_200);
  Py_CLEAR(clear_module_state->__pyx_kp_s_2024_05_31);
  Py_CLEAR(clear_module_state->__pyx_kp_s_20500101);
  Py_CLEAR(clear_module_state->__pyx_kp_s_250);
  Py_CLEAR(clear_module_state->__pyx_kp_s_2_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_300073);
  Py_CLEAR(clear_module_state->__pyx_kp_s_500);
  Py_CLEAR(clear_module_state->__pyx_kp_s_600900);
  Py_CLEAR(clear_module_state->__pyx_kp_s_688235);
  Py_CLEAR(clear_module_state->__pyx_kp_s_688235_SH);
  Py_CLEAR(clear_module_state->__pyx_n_s_ACCUM_DEAL_AMT);
  Py_CLEAR(clear_module_state->__pyx_n_s_ACTUAL_ISSUE_SCALE);
  Py_CLEAR(clear_module_state->__pyx_n_s_ADD_MARKET_CAP);
  Py_CLEAR(clear_module_state->__pyx_n_s_ADD_SHARES_REPAIR);
  Py_CLEAR(clear_module_state->__pyx_n_s_ALL);
  Py_CLEAR(clear_module_state->__pyx_n_s_APP_F10_MAINFINADATA);
  Py_CLEAR(clear_module_state->__pyx_n_s_AVG_FREESHARES_RATIO);
  Py_CLEAR(clear_module_state->__pyx_n_s_AVG_FREE_SHARES);
  Py_CLEAR(clear_module_state->__pyx_n_s_AVG_HOLD_AMT);
  Py_CLEAR(clear_module_state->__pyx_n_s_BPS);
  Py_CLEAR(clear_module_state->__pyx_n_s_BUY_AMT);
  Py_CLEAR(clear_module_state->__pyx_n_s_CHANGE_RATE);
  Py_CLEAR(clear_module_state->__pyx_n_s_CHZZL);
  Py_CLEAR(clear_module_state->__pyx_n_s_CHZZTS);
  Py_CLEAR(clear_module_state->__pyx_n_s_CLOSE_PRICE);
  Py_CLEAR(clear_module_state->__pyx_n_s_CONVERT_STOCK_CODE);
  Py_CLEAR(clear_module_state->__pyx_n_s_CQBL);
  Py_CLEAR(clear_module_state->__pyx_n_s_DATE);
  Py_CLEAR(clear_module_state->__pyx_kp_u_DATE_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_DEDU_PARENT_PROFIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_DIM_DATE);
  Py_CLEAR(clear_module_state->__pyx_kp_s_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM);
  Py_CLEAR(clear_module_state->__pyx_n_s_DPNP_YOY_RATIO);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataFrame);
  Py_CLEAR(clear_module_state->__pyx_n_s_END_DATE);
  Py_CLEAR(clear_module_state->__pyx_n_s_EPSJB);
  Py_CLEAR(clear_module_state->__pyx_n_s_EPSKCJB);
  Py_CLEAR(clear_module_state->__pyx_n_s_EPSXS);
  Py_CLEAR(clear_module_state->__pyx_n_s_FREEHOLD_RATIO_TOTAL);
  Py_CLEAR(clear_module_state->__pyx_n_s_FREE_SHARES_RATIO);
  Py_CLEAR(clear_module_state->__pyx_n_s_GROSS_PROFIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_GROSS_PROFIT_RATIO);
  Py_CLEAR(clear_module_state->__pyx_n_s_HOLDER_TOTAL_NUM);
  Py_CLEAR(clear_module_state->__pyx_n_s_HOLD_FOCUS);
  Py_CLEAR(clear_module_state->__pyx_n_s_HOLD_MARKET_CAP);
  Py_CLEAR(clear_module_state->__pyx_n_s_HOLD_RATIO_TOTAL);
  Py_CLEAR(clear_module_state->__pyx_n_s_HOLD_SHARES);
  Py_CLEAR(clear_module_state->__pyx_n_s_HSF10);
  Py_CLEAR(clear_module_state->__pyx_n_s_INDEX_CHANGE_RATE);
  Py_CLEAR(clear_module_state->__pyx_n_s_INDEX_CLOSE_PRICE);
  Py_CLEAR(clear_module_state->__pyx_kp_u_INTERVAL_TYPE_1);
  Py_CLEAR(clear_module_state->__pyx_kp_u_INTERVAL_TYPE_1_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_JROA);
  Py_CLEAR(clear_module_state->__pyx_n_s_JYXJLYYSR);
  Py_CLEAR(clear_module_state->__pyx_n_s_KCFJCXSYJLR);
  Py_CLEAR(clear_module_state->__pyx_n_s_KCFJCXSYJLRTZ);
  Py_CLEAR(clear_module_state->__pyx_n_s_KFJLRGDHBZC);
  Py_CLEAR(clear_module_state->__pyx_n_s_LD);
  Py_CLEAR(clear_module_state->__pyx_n_s_MGJYXJJE);
  Py_CLEAR(clear_module_state->__pyx_n_s_MGWFPLR);
  Py_CLEAR(clear_module_state->__pyx_n_s_MGZBGJ);
  Py_CLEAR(clear_module_state->__pyx_n_s_MLR);
  Py_CLEAR(clear_module_state->__pyx_kp_s_MUTUAL_TYPE_005);
  Py_CLEAR(clear_module_state->__pyx_n_s_NETPROFITRPHBZC);
  Py_CLEAR(clear_module_state->__pyx_n_s_NET_DEAL_AMT);
  Py_CLEAR(clear_module_state->__pyx_n_s_NET_PROFIT_RATIO);
  Py_CLEAR(clear_module_state->__pyx_n_s_NEW);
  Py_CLEAR(clear_module_state->__pyx_n_s_NOTICE_DATE);
  Py_CLEAR(clear_module_state->__pyx_n_s_PARENTNETPROFIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_PARENTNETPROFITTZ);
  Py_CLEAR(clear_module_state->__pyx_n_s_PC);
  Py_CLEAR(clear_module_state->__pyx_n_s_PER_CAPITAL_RESERVE);
  Py_CLEAR(clear_module_state->__pyx_n_s_PER_NETCASH);
  Py_CLEAR(clear_module_state->__pyx_n_s_PER_UNASSIGN_PROFIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_PREDICT_AMC);
  Py_CLEAR(clear_module_state->__pyx_n_s_PRICE);
  Py_CLEAR(clear_module_state->__pyx_n_s_PUBLIC_START_DATE);
  Py_CLEAR(clear_module_state->__pyx_kp_s_PUBLIC_START_DATE_SECURITY_CODE);
  Py_CLEAR(clear_module_state->__pyx_n_s_QYCS);
  Py_CLEAR(clear_module_state->__pyx_n_s_REPORT_DATE);
  Py_CLEAR(clear_module_state->__pyx_n_s_ROEJQ);
  Py_CLEAR(clear_module_state->__pyx_n_s_ROE_DILUTED);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPTA_RZRQ_LSHJ);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPTA_WEB_RZRQ_GGMX);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPT_BOND_CB_LIST);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPT_F10_EH_HOLDERNUM);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPT_F10_FINANCE_MAINFINADATA);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPT_F10_QTR_MAINFINADATA);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPT_MUTUAL_DEALHISTORY_NEW);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPT_MUTUAL_HOLDSTOCKNDATE_STA);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPT_MUTUAL_STOCK_NORTHSTA);
  Py_CLEAR(clear_module_state->__pyx_n_s_RPT_SHAREBONUS_DET);
  Py_CLEAR(clear_module_state->__pyx_n_s_RQCHL);
  Py_CLEAR(clear_module_state->__pyx_n_s_RQJMG);
  Py_CLEAR(clear_module_state->__pyx_n_s_RQMCL);
  Py_CLEAR(clear_module_state->__pyx_n_s_RQYE);
  Py_CLEAR(clear_module_state->__pyx_n_s_RQYL);
  Py_CLEAR(clear_module_state->__pyx_n_s_RZCHE);
  Py_CLEAR(clear_module_state->__pyx_n_s_RZJME);
  Py_CLEAR(clear_module_state->__pyx_n_s_RZMRE);
  Py_CLEAR(clear_module_state->__pyx_n_s_RZRQYE);
  Py_CLEAR(clear_module_state->__pyx_n_s_RZYE);
  Py_CLEAR(clear_module_state->__pyx_n_s_RZYEZB);
  Py_CLEAR(clear_module_state->__pyx_n_s_SCODE);
  Py_CLEAR(clear_module_state->__pyx_kp_s_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE);
  Py_CLEAR(clear_module_state->__pyx_n_s_SD);
  Py_CLEAR(clear_module_state->__pyx_n_s_SECNAME);
  Py_CLEAR(clear_module_state->__pyx_kp_u_SECUCODE);
  Py_CLEAR(clear_module_state->__pyx_n_s_SECURITY_CODE);
  Py_CLEAR(clear_module_state->__pyx_kp_u_SECURITY_CODE_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_ABBR);
  Py_CLEAR(clear_module_state->__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD);
  Py_CLEAR(clear_module_state->__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_SECURITY_NAME);
  Py_CLEAR(clear_module_state->__pyx_n_s_SECURITY_NAME_ABBR);
  Py_CLEAR(clear_module_state->__pyx_n_s_SECURITY_SHORT_NAME);
  Py_CLEAR(clear_module_state->__pyx_n_s_SELL_AMT);
  Py_CLEAR(clear_module_state->__pyx_n_s_SPJ);
  Py_CLEAR(clear_module_state->__pyx_n_s_TAXRATE);
  Py_CLEAR(clear_module_state->__pyx_n_s_TOAZZL);
  Py_CLEAR(clear_module_state->__pyx_n_s_TOTALOPERATEREVE);
  Py_CLEAR(clear_module_state->__pyx_n_s_TOTALOPERATEREVETZ);
  Py_CLEAR(clear_module_state->__pyx_n_s_TOTAL_NUM_RATIO);
  Py_CLEAR(clear_module_state->__pyx_n_s_TRADE_DATE);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TRADE_DATE_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_TRADE_DATE_NET_DEAL_AMT_BUY_AMT);
  Py_CLEAR(clear_module_state->__pyx_n_s_TRANSFER_PRICE);
  Py_CLEAR(clear_module_state->__pyx_n_s_TRANSFER_VALUE);
  Py_CLEAR(clear_module_state->__pyx_n_s_WEB);
  Py_CLEAR(clear_module_state->__pyx_n_s_XJLLB);
  Py_CLEAR(clear_module_state->__pyx_n_s_XSJLL);
  Py_CLEAR(clear_module_state->__pyx_n_s_XSJXLYYSR);
  Py_CLEAR(clear_module_state->__pyx_n_s_XSMLL);
  Py_CLEAR(clear_module_state->__pyx_n_s_YSZKYYSR);
  Py_CLEAR(clear_module_state->__pyx_n_s_YSZKZZL);
  Py_CLEAR(clear_module_state->__pyx_n_s_YSZKZZTS);
  Py_CLEAR(clear_module_state->__pyx_n_s_YYZSRGDHBZC);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Y_m_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZCFZL);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZDF);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZZCJLL);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZZCZZTS);
  Py_CLEAR(clear_module_state->__pyx_kp_s__10);
  Py_CLEAR(clear_module_state->__pyx_kp_s__11);
  Py_CLEAR(clear_module_state->__pyx_kp_s__12);
  Py_CLEAR(clear_module_state->__pyx_kp_s__13);
  Py_CLEAR(clear_module_state->__pyx_n_s__132);
  Py_CLEAR(clear_module_state->__pyx_kp_s__14);
  Py_CLEAR(clear_module_state->__pyx_kp_s__15);
  Py_CLEAR(clear_module_state->__pyx_kp_s__16);
  Py_CLEAR(clear_module_state->__pyx_kp_s__17);
  Py_CLEAR(clear_module_state->__pyx_kp_s__18);
  Py_CLEAR(clear_module_state->__pyx_kp_s__19);
  Py_CLEAR(clear_module_state->__pyx_kp_s__2);
  Py_CLEAR(clear_module_state->__pyx_kp_s__20);
  Py_CLEAR(clear_module_state->__pyx_kp_s__22);
  Py_CLEAR(clear_module_state->__pyx_kp_s__23);
  Py_CLEAR(clear_module_state->__pyx_kp_s__24);
  Py_CLEAR(clear_module_state->__pyx_kp_s__25);
  Py_CLEAR(clear_module_state->__pyx_kp_s__26);
  Py_CLEAR(clear_module_state->__pyx_kp_s__27);
  Py_CLEAR(clear_module_state->__pyx_kp_s__28);
  Py_CLEAR(clear_module_state->__pyx_kp_s__29);
  Py_CLEAR(clear_module_state->__pyx_n_s__3);
  Py_CLEAR(clear_module_state->__pyx_kp_s__30);
  Py_CLEAR(clear_module_state->__pyx_kp_s__31);
  Py_CLEAR(clear_module_state->__pyx_kp_s__32);
  Py_CLEAR(clear_module_state->__pyx_kp_s__33);
  Py_CLEAR(clear_module_state->__pyx_kp_s__34);
  Py_CLEAR(clear_module_state->__pyx_kp_s__35);
  Py_CLEAR(clear_module_state->__pyx_kp_s__36);
  Py_CLEAR(clear_module_state->__pyx_kp_s__37);
  Py_CLEAR(clear_module_state->__pyx_kp_s__38);
  Py_CLEAR(clear_module_state->__pyx_kp_s__39);
  Py_CLEAR(clear_module_state->__pyx_kp_s__4);
  Py_CLEAR(clear_module_state->__pyx_kp_s__40);
  Py_CLEAR(clear_module_state->__pyx_kp_s__41);
  Py_CLEAR(clear_module_state->__pyx_kp_s__42);
  Py_CLEAR(clear_module_state->__pyx_kp_s__43);
  Py_CLEAR(clear_module_state->__pyx_kp_s__44);
  Py_CLEAR(clear_module_state->__pyx_kp_s__45);
  Py_CLEAR(clear_module_state->__pyx_kp_s__46);
  Py_CLEAR(clear_module_state->__pyx_kp_s__47);
  Py_CLEAR(clear_module_state->__pyx_kp_s__48);
  Py_CLEAR(clear_module_state->__pyx_kp_s__49);
  Py_CLEAR(clear_module_state->__pyx_kp_s__5);
  Py_CLEAR(clear_module_state->__pyx_kp_s__50);
  Py_CLEAR(clear_module_state->__pyx_kp_s__51);
  Py_CLEAR(clear_module_state->__pyx_kp_s__52);
  Py_CLEAR(clear_module_state->__pyx_kp_s__53);
  Py_CLEAR(clear_module_state->__pyx_kp_s__54);
  Py_CLEAR(clear_module_state->__pyx_kp_s__55);
  Py_CLEAR(clear_module_state->__pyx_kp_s__56);
  Py_CLEAR(clear_module_state->__pyx_kp_s__57);
  Py_CLEAR(clear_module_state->__pyx_kp_s__58);
  Py_CLEAR(clear_module_state->__pyx_kp_s__59);
  Py_CLEAR(clear_module_state->__pyx_kp_s__60);
  Py_CLEAR(clear_module_state->__pyx_kp_u__62);
  Py_CLEAR(clear_module_state->__pyx_kp_s__63);
  Py_CLEAR(clear_module_state->__pyx_kp_s__64);
  Py_CLEAR(clear_module_state->__pyx_kp_s__65);
  Py_CLEAR(clear_module_state->__pyx_kp_s__66);
  Py_CLEAR(clear_module_state->__pyx_kp_s__67);
  Py_CLEAR(clear_module_state->__pyx_kp_s__68);
  Py_CLEAR(clear_module_state->__pyx_kp_s__69);
  Py_CLEAR(clear_module_state->__pyx_kp_u__7);
  Py_CLEAR(clear_module_state->__pyx_kp_s__70);
  Py_CLEAR(clear_module_state->__pyx_kp_s__71);
  Py_CLEAR(clear_module_state->__pyx_kp_s__72);
  Py_CLEAR(clear_module_state->__pyx_kp_s__73);
  Py_CLEAR(clear_module_state->__pyx_kp_s__74);
  Py_CLEAR(clear_module_state->__pyx_kp_s__75);
  Py_CLEAR(clear_module_state->__pyx_kp_s__76);
  Py_CLEAR(clear_module_state->__pyx_kp_s__77);
  Py_CLEAR(clear_module_state->__pyx_kp_s__78);
  Py_CLEAR(clear_module_state->__pyx_kp_s__79);
  Py_CLEAR(clear_module_state->__pyx_kp_s__80);
  Py_CLEAR(clear_module_state->__pyx_kp_s__81);
  Py_CLEAR(clear_module_state->__pyx_kp_s__82);
  Py_CLEAR(clear_module_state->__pyx_kp_s__83);
  Py_CLEAR(clear_module_state->__pyx_kp_s__84);
  Py_CLEAR(clear_module_state->__pyx_kp_s__85);
  Py_CLEAR(clear_module_state->__pyx_kp_s__86);
  Py_CLEAR(clear_module_state->__pyx_kp_s__87);
  Py_CLEAR(clear_module_state->__pyx_kp_s__88);
  Py_CLEAR(clear_module_state->__pyx_kp_s__89);
  Py_CLEAR(clear_module_state->__pyx_kp_u__9);
  Py_CLEAR(clear_module_state->__pyx_n_s__90);
  Py_CLEAR(clear_module_state->__pyx_n_s_accum_net_amount);
  Py_CLEAR(clear_module_state->__pyx_n_s_add_amount);
  Py_CLEAR(clear_module_state->__pyx_n_s_add_volume);
  Py_CLEAR(clear_module_state->__pyx_n_s_akshare_stock_feature_stock_hist);
  Py_CLEAR(clear_module_state->__pyx_n_s_akshare_utils);
  Py_CLEAR(clear_module_state->__pyx_n_s_amount);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_avg_amount_pa);
  Py_CLEAR(clear_module_state->__pyx_n_s_avg_volume_pa);
  Py_CLEAR(clear_module_state->__pyx_n_s_avg_volume_pa_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_bd1d9ddb04089700cf9c27f6f7426281);
  Py_CLEAR(clear_module_state->__pyx_n_s_beg);
  Py_CLEAR(clear_module_state->__pyx_n_s_big_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_bond_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_bond_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_bond_scale);
  Py_CLEAR(clear_module_state->__pyx_n_s_bps);
  Py_CLEAR(clear_module_state->__pyx_n_s_buy_amount);
  Py_CLEAR(clear_module_state->__pyx_n_s_capital_reserve_ps);
  Py_CLEAR(clear_module_state->__pyx_n_s_cash_flow_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_ceil);
  Py_CLEAR(clear_module_state->__pyx_n_s_ch_zzl);
  Py_CLEAR(clear_module_state->__pyx_n_s_ch_zzts);
  Py_CLEAR(clear_module_state->__pyx_n_s_change_rate);
  Py_CLEAR(clear_module_state->__pyx_n_s_change_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_client);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_code_id_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_code_id_map_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_code_name_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_coerce);
  Py_CLEAR(clear_module_state->__pyx_n_s_cols_to_convert);
  Py_CLEAR(clear_module_state->__pyx_n_s_column_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_column_name_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_columns);
  Py_CLEAR(clear_module_state->__pyx_n_s_concat);
  Py_CLEAR(clear_module_state->__pyx_n_s_csi);
  Py_CLEAR(clear_module_state->__pyx_n_s_csi931151);
  Py_CLEAR(clear_module_state->__pyx_n_s_current_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_data_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_data_text);
  Py_CLEAR(clear_module_state->__pyx_kp_s_data_x_pages_tp);
  Py_CLEAR(clear_module_state->__pyx_n_s_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_debt_to_asset_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_decode);
  Py_CLEAR(clear_module_state->__pyx_n_s_dect);
  Py_CLEAR(clear_module_state->__pyx_n_s_demjson);
  Py_CLEAR(clear_module_state->__pyx_n_s_diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_dim_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_dlmkts);
  Py_CLEAR(clear_module_state->__pyx_n_s_drop);
  Py_CLEAR(clear_module_state->__pyx_n_s_dt);
  Py_CLEAR(clear_module_state->__pyx_n_s_empty);
  Py_CLEAR(clear_module_state->__pyx_n_s_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_eps_jb);
  Py_CLEAR(clear_module_state->__pyx_n_s_eps_kf);
  Py_CLEAR(clear_module_state->__pyx_n_s_eps_xs);
  Py_CLEAR(clear_module_state->__pyx_n_s_equity_multiplier);
  Py_CLEAR(clear_module_state->__pyx_n_s_equity_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_errors);
  Py_CLEAR(clear_module_state->__pyx_n_s_f116);
  Py_CLEAR(clear_module_state->__pyx_n_s_f117);
  Py_CLEAR(clear_module_state->__pyx_n_s_f12);
  Py_CLEAR(clear_module_state->__pyx_kp_s_f120_f121_f122_f174_f175_f59_f16);
  Py_CLEAR(clear_module_state->__pyx_n_s_f127);
  Py_CLEAR(clear_module_state->__pyx_n_s_f128);
  Py_CLEAR(clear_module_state->__pyx_kp_s_f12_f14_f2_f4_f3_f17_f15_f16_f18);
  Py_CLEAR(clear_module_state->__pyx_n_s_f14);
  Py_CLEAR(clear_module_state->__pyx_n_s_f15);
  Py_CLEAR(clear_module_state->__pyx_n_s_f16);
  Py_CLEAR(clear_module_state->__pyx_n_s_f17);
  Py_CLEAR(clear_module_state->__pyx_n_s_f18);
  Py_CLEAR(clear_module_state->__pyx_n_s_f189);
  Py_CLEAR(clear_module_state->__pyx_kp_s_f1_f2_f3_f4_f5);
  Py_CLEAR(clear_module_state->__pyx_n_s_f2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_f2_01_CONVERT_STOCK_CODE_CONVERT);
  Py_CLEAR(clear_module_state->__pyx_n_s_f3);
  Py_CLEAR(clear_module_state->__pyx_n_s_f4);
  Py_CLEAR(clear_module_state->__pyx_n_s_f5);
  Py_CLEAR(clear_module_state->__pyx_kp_s_f51_f52_f53_f54_f55_f56_f57_f58);
  Py_CLEAR(clear_module_state->__pyx_n_s_f57);
  Py_CLEAR(clear_module_state->__pyx_n_s_f58);
  Py_CLEAR(clear_module_state->__pyx_n_s_f6);
  Py_CLEAR(clear_module_state->__pyx_n_s_f84);
  Py_CLEAR(clear_module_state->__pyx_n_s_f85);
  Py_CLEAR(clear_module_state->__pyx_n_s_fa5fd1943c7b386f172d6893dbfba10b);
  Py_CLEAR(clear_module_state->__pyx_n_s_fid);
  Py_CLEAR(clear_module_state->__pyx_n_s_fields);
  Py_CLEAR(clear_module_state->__pyx_n_s_fields1);
  Py_CLEAR(clear_module_state->__pyx_n_s_fields2);
  Py_CLEAR(clear_module_state->__pyx_n_s_filter);
  Py_CLEAR(clear_module_state->__pyx_n_s_finance_mfd_quarter_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_finance_mfd_report_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_find);
  Py_CLEAR(clear_module_state->__pyx_n_s_float);
  Py_CLEAR(clear_module_state->__pyx_n_s_fltt);
  Py_CLEAR(clear_module_state->__pyx_n_s_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_fqt);
  Py_CLEAR(clear_module_state->__pyx_n_s_fs);
  Py_CLEAR(clear_module_state->__pyx_n_s_full);
  Py_CLEAR(clear_module_state->__pyx_n_s_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_gross_profit);
  Py_CLEAR(clear_module_state->__pyx_n_s_gross_profit_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_high);
  Py_CLEAR(clear_module_state->__pyx_n_s_hold_amount);
  Py_CLEAR(clear_module_state->__pyx_n_s_hold_focus);
  Py_CLEAR(clear_module_state->__pyx_n_s_hold_volume);
  Py_CLEAR(clear_module_state->__pyx_n_s_hold_volume_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_holder_num);
  Py_CLEAR(clear_module_state->__pyx_n_s_holder_num_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_hs300_change_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_hs300_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_hsgt_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_hsgt_history_df);
  Py_CLEAR(clear_module_state->__pyx_kp_s_http_push2_eastmoney_com_api_qt);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_38_push2_eastmoney_com_api);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_89_push2_eastmoney_com_api);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_datacenter_eastmoney_com_s);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_datacenter_eastmoney_com_s_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_datacenter_web_eastmoney_c);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_push2his_eastmoney_com_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_ignore_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_inplace);
  Py_CLEAR(clear_module_state->__pyx_n_s_insert);
  Py_CLEAR(clear_module_state->__pyx_n_s_invt);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_null_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_jQuery1124033485574041163946_159);
  Py_CLEAR(clear_module_state->__pyx_n_s_js);
  Py_CLEAR(clear_module_state->__pyx_n_s_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_jyjxjl_to_tor_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_kf_net_profit);
  Py_CLEAR(clear_module_state->__pyx_n_s_kf_net_profit_hb);
  Py_CLEAR(clear_module_state->__pyx_n_s_kf_net_profit_tb);
  Py_CLEAR(clear_module_state->__pyx_n_s_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_klt);
  Py_CLEAR(clear_module_state->__pyx_n_s_kzz_all_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_kzz_basic_info_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_kzz_sh_em_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_kzz_sh_trade_day_info_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_kzz_sz_em_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_kzz_sz_trade_day_info_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_kzz_trade_day_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_kzz_trade_day_em_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_kzz_trade_day_info_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_latest_trade_day);
  Py_CLEAR(clear_module_state->__pyx_n_s_low);
  Py_CLEAR(clear_module_state->__pyx_n_s_lt);
  Py_CLEAR(clear_module_state->__pyx_kp_s_m_0_b_MK0354);
  Py_CLEAR(clear_module_state->__pyx_kp_s_m_1_b_MK0354);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_market_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_math);
  Py_CLEAR(clear_module_state->__pyx_n_s_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_net_amount);
  Py_CLEAR(clear_module_state->__pyx_n_s_net_cash_ps);
  Py_CLEAR(clear_module_state->__pyx_n_s_net_profit_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_n_s_notice_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_notna);
  Py_CLEAR(clear_module_state->__pyx_n_s_np);
  Py_CLEAR(clear_module_state->__pyx_n_s_open);
  Py_CLEAR(clear_module_state->__pyx_n_s_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_page);
  Py_CLEAR(clear_module_state->__pyx_n_s_pageNo);
  Py_CLEAR(clear_module_state->__pyx_n_s_pageNum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pageNumber);
  Py_CLEAR(clear_module_state->__pyx_n_s_pageSize);
  Py_CLEAR(clear_module_state->__pyx_n_s_pages);
  Py_CLEAR(clear_module_state->__pyx_n_s_pandas);
  Py_CLEAR(clear_module_state->__pyx_n_s_params);
  Py_CLEAR(clear_module_state->__pyx_n_s_parent_net_profit);
  Py_CLEAR(clear_module_state->__pyx_n_s_parent_net_profit_hb);
  Py_CLEAR(clear_module_state->__pyx_n_s_parent_net_profit_tb);
  Py_CLEAR(clear_module_state->__pyx_n_s_pd);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pd_DataFrame);
  Py_CLEAR(clear_module_state->__pyx_n_s_pn);
  Py_CLEAR(clear_module_state->__pyx_n_s_po);
  Py_CLEAR(clear_module_state->__pyx_n_s_pre_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_price);
  Py_CLEAR(clear_module_state->__pyx_n_s_price_change);
  Py_CLEAR(clear_module_state->__pyx_n_s_price_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_print);
  Py_CLEAR(clear_module_state->__pyx_n_s_ps);
  Py_CLEAR(clear_module_state->__pyx_n_s_pub_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_pz);
  Py_CLEAR(clear_module_state->__pyx_n_s_quick_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_quoteColumns);
  Py_CLEAR(clear_module_state->__pyx_n_s_quoteType);
  Py_CLEAR(clear_module_state->__pyx_n_s_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_rc);
  Py_CLEAR(clear_module_state->__pyx_n_s_replace);
  Py_CLEAR(clear_module_state->__pyx_n_s_reportName);
  Py_CLEAR(clear_module_state->__pyx_n_s_report_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_requests);
  Py_CLEAR(clear_module_state->__pyx_n_s_reset_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_return);
  Py_CLEAR(clear_module_state->__pyx_n_s_roe_jzc);
  Py_CLEAR(clear_module_state->__pyx_n_s_roe_zzc);
  Py_CLEAR(clear_module_state->__pyx_n_s_rqchl);
  Py_CLEAR(clear_module_state->__pyx_n_s_rqjmg);
  Py_CLEAR(clear_module_state->__pyx_n_s_rqmcl);
  Py_CLEAR(clear_module_state->__pyx_n_s_rqye);
  Py_CLEAR(clear_module_state->__pyx_n_s_rqyl);
  Py_CLEAR(clear_module_state->__pyx_n_s_rt);
  Py_CLEAR(clear_module_state->__pyx_n_s_rzche);
  Py_CLEAR(clear_module_state->__pyx_n_s_rzjme);
  Py_CLEAR(clear_module_state->__pyx_n_s_rzmre);
  Py_CLEAR(clear_module_state->__pyx_n_s_rzrq_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_rzrq_history_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_rzrqye);
  Py_CLEAR(clear_module_state->__pyx_n_s_rzye);
  Py_CLEAR(clear_module_state->__pyx_n_s_rzyezb);
  Py_CLEAR(clear_module_state->__pyx_kp_u_scode);
  Py_CLEAR(clear_module_state->__pyx_n_s_secid);
  Py_CLEAR(clear_module_state->__pyx_n_s_sell_amount);
  Py_CLEAR(clear_module_state->__pyx_n_s_sh);
  Py_CLEAR(clear_module_state->__pyx_n_s_sortColumns);
  Py_CLEAR(clear_module_state->__pyx_n_s_sortTypes);
  Py_CLEAR(clear_module_state->__pyx_n_s_source);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_split);
  Py_CLEAR(clear_module_state->__pyx_n_s_sr);
  Py_CLEAR(clear_module_state->__pyx_n_s_sse_index_change_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_sse_index_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_st);
  Py_CLEAR(clear_module_state->__pyx_n_s_start_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_all_hsgt_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_all_rzrq_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_fhps_detail_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_finance_mfd_quarter_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_finance_mfd_report_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_gdhs_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_hsgt_detail);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_hsgt_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_hsgt_today_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_individual_info_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_rzrq_detail);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_rzrq_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_rzrq_today_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_zh_a_gdhs_detail_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_stock_zh_index_daily_em);
  Py_CLEAR(clear_module_state->__pyx_n_s_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_strptime);
  Py_CLEAR(clear_module_state->__pyx_n_s_sty);
  Py_CLEAR(clear_module_state->__pyx_n_s_svr);
  Py_CLEAR(clear_module_state->__pyx_n_s_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_tax_rate);
  Py_CLEAR(clear_module_state->__pyx_kp_s_tbstock_dataAcquisition_stockDat);
  Py_CLEAR(clear_module_state->__pyx_n_s_tbstock_dataAcquisition_stockDat_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_tbstock_utils);
  Py_CLEAR(clear_module_state->__pyx_n_s_temp_df);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_text);
  Py_CLEAR(clear_module_state->__pyx_n_s_timeout);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_numeric);
  Py_CLEAR(clear_module_state->__pyx_n_s_top_ten_ratio_free);
  Py_CLEAR(clear_module_state->__pyx_n_s_top_ten_ratio_total);
  Py_CLEAR(clear_module_state->__pyx_n_s_total);
  Py_CLEAR(clear_module_state->__pyx_n_s_total_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_total_operate_revenue);
  Py_CLEAR(clear_module_state->__pyx_n_s_total_operate_revenue_hb);
  Py_CLEAR(clear_module_state->__pyx_n_s_total_operate_revenue_tb);
  Py_CLEAR(clear_module_state->__pyx_n_s_total_pages);
  Py_CLEAR(clear_module_state->__pyx_n_s_trade_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_transfer_price);
  Py_CLEAR(clear_module_state->__pyx_n_s_transfer_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_unassign_profit_ps);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_url);
  Py_CLEAR(clear_module_state->__pyx_n_s_ut);
  Py_CLEAR(clear_module_state->__pyx_n_s_utils);
  Py_CLEAR(clear_module_state->__pyx_n_s_v);
  Py_CLEAR(clear_module_state->__pyx_n_s_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_volume);
  Py_CLEAR(clear_module_state->__pyx_n_s_wbp2u);
  Py_CLEAR(clear_module_state->__pyx_n_s_xsjxjl_to_tor_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_yszk_to_tor_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_yszk_zzl);
  Py_CLEAR(clear_module_state->__pyx_n_s_yszk_zzts);
  Py_CLEAR(clear_module_state->__pyx_n_s_zzc_zzl);
  Py_CLEAR(clear_module_state->__pyx_n_s_zzc_zzts);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_2);
  Py_CLEAR(clear_module_state->__pyx_int_3);
  Py_CLEAR(clear_module_state->__pyx_int_4);
  Py_CLEAR(clear_module_state->__pyx_int_5);
  Py_CLEAR(clear_module_state->__pyx_int_25);
  Py_CLEAR(clear_module_state->__pyx_int_50);
  Py_CLEAR(clear_module_state->__pyx_int_500);
  Py_CLEAR(clear_module_state->__pyx_int_neg_1);
  Py_CLEAR(clear_module_state->__pyx_slice__6);
  Py_CLEAR(clear_module_state->__pyx_slice__8);
  Py_CLEAR(clear_module_state->__pyx_slice__21);
  Py_CLEAR(clear_module_state->__pyx_slice__61);
  Py_CLEAR(clear_module_state->__pyx_tuple__91);
  Py_CLEAR(clear_module_state->__pyx_tuple__93);
  Py_CLEAR(clear_module_state->__pyx_tuple__94);
  Py_CLEAR(clear_module_state->__pyx_tuple__96);
  Py_CLEAR(clear_module_state->__pyx_tuple__97);
  Py_CLEAR(clear_module_state->__pyx_tuple__99);
  Py_CLEAR(clear_module_state->__pyx_tuple__100);
  Py_CLEAR(clear_module_state->__pyx_tuple__102);
  Py_CLEAR(clear_module_state->__pyx_tuple__103);
  Py_CLEAR(clear_module_state->__pyx_tuple__105);
  Py_CLEAR(clear_module_state->__pyx_tuple__107);
  Py_CLEAR(clear_module_state->__pyx_tuple__109);
  Py_CLEAR(clear_module_state->__pyx_tuple__111);
  Py_CLEAR(clear_module_state->__pyx_tuple__112);
  Py_CLEAR(clear_module_state->__pyx_tuple__114);
  Py_CLEAR(clear_module_state->__pyx_tuple__115);
  Py_CLEAR(clear_module_state->__pyx_tuple__117);
  Py_CLEAR(clear_module_state->__pyx_tuple__119);
  Py_CLEAR(clear_module_state->__pyx_tuple__120);
  Py_CLEAR(clear_module_state->__pyx_tuple__122);
  Py_CLEAR(clear_module_state->__pyx_tuple__123);
  Py_CLEAR(clear_module_state->__pyx_tuple__126);
  Py_CLEAR(clear_module_state->__pyx_tuple__128);
  Py_CLEAR(clear_module_state->__pyx_tuple__130);
  Py_CLEAR(clear_module_state->__pyx_codeobj__92);
  Py_CLEAR(clear_module_state->__pyx_codeobj__95);
  Py_CLEAR(clear_module_state->__pyx_codeobj__98);
  Py_CLEAR(clear_module_state->__pyx_codeobj__101);
  Py_CLEAR(clear_module_state->__pyx_codeobj__104);
  Py_CLEAR(clear_module_state->__pyx_codeobj__106);
  Py_CLEAR(clear_module_state->__pyx_codeobj__108);
  Py_CLEAR(clear_module_state->__pyx_codeobj__110);
  Py_CLEAR(clear_module_state->__pyx_codeobj__113);
  Py_CLEAR(clear_module_state->__pyx_codeobj__116);
  Py_CLEAR(clear_module_state->__pyx_codeobj__118);
  Py_CLEAR(clear_module_state->__pyx_codeobj__121);
  Py_CLEAR(clear_module_state->__pyx_codeobj__124);
  Py_CLEAR(clear_module_state->__pyx_codeobj__125);
  Py_CLEAR(clear_module_state->__pyx_codeobj__127);
  Py_CLEAR(clear_module_state->__pyx_codeobj__129);
  Py_CLEAR(clear_module_state->__pyx_codeobj__131);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_kp_s_);
  Py_VISIT(traverse_module_state->__pyx_kp_s_0);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000001);
  Py_VISIT(traverse_module_state->__pyx_kp_s_000001_SZ);
  Py_VISIT(traverse_module_state->__pyx_kp_s_007949902328317804);
  Py_VISIT(traverse_module_state->__pyx_kp_s_018998368837725255);
  Py_VISIT(traverse_module_state->__pyx_kp_s_08730299565686817);
  Py_VISIT(traverse_module_state->__pyx_kp_s_0_0_0_web);
  Py_VISIT(traverse_module_state->__pyx_kp_s_0_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1);
  Py_VISIT(traverse_module_state->__pyx_kp_s_101);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1596700547039);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1640157544804);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1717261171099);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1717298612418);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1717298688717);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1721047529031);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1721051595125);
  Py_VISIT(traverse_module_state->__pyx_kp_s_19900101);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1_1);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_200);
  Py_VISIT(traverse_module_state->__pyx_kp_s_2024_05_31);
  Py_VISIT(traverse_module_state->__pyx_kp_s_20500101);
  Py_VISIT(traverse_module_state->__pyx_kp_s_250);
  Py_VISIT(traverse_module_state->__pyx_kp_s_2_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_300073);
  Py_VISIT(traverse_module_state->__pyx_kp_s_500);
  Py_VISIT(traverse_module_state->__pyx_kp_s_600900);
  Py_VISIT(traverse_module_state->__pyx_kp_s_688235);
  Py_VISIT(traverse_module_state->__pyx_kp_s_688235_SH);
  Py_VISIT(traverse_module_state->__pyx_n_s_ACCUM_DEAL_AMT);
  Py_VISIT(traverse_module_state->__pyx_n_s_ACTUAL_ISSUE_SCALE);
  Py_VISIT(traverse_module_state->__pyx_n_s_ADD_MARKET_CAP);
  Py_VISIT(traverse_module_state->__pyx_n_s_ADD_SHARES_REPAIR);
  Py_VISIT(traverse_module_state->__pyx_n_s_ALL);
  Py_VISIT(traverse_module_state->__pyx_n_s_APP_F10_MAINFINADATA);
  Py_VISIT(traverse_module_state->__pyx_n_s_AVG_FREESHARES_RATIO);
  Py_VISIT(traverse_module_state->__pyx_n_s_AVG_FREE_SHARES);
  Py_VISIT(traverse_module_state->__pyx_n_s_AVG_HOLD_AMT);
  Py_VISIT(traverse_module_state->__pyx_n_s_BPS);
  Py_VISIT(traverse_module_state->__pyx_n_s_BUY_AMT);
  Py_VISIT(traverse_module_state->__pyx_n_s_CHANGE_RATE);
  Py_VISIT(traverse_module_state->__pyx_n_s_CHZZL);
  Py_VISIT(traverse_module_state->__pyx_n_s_CHZZTS);
  Py_VISIT(traverse_module_state->__pyx_n_s_CLOSE_PRICE);
  Py_VISIT(traverse_module_state->__pyx_n_s_CONVERT_STOCK_CODE);
  Py_VISIT(traverse_module_state->__pyx_n_s_CQBL);
  Py_VISIT(traverse_module_state->__pyx_n_s_DATE);
  Py_VISIT(traverse_module_state->__pyx_kp_u_DATE_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_DEDU_PARENT_PROFIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_DIM_DATE);
  Py_VISIT(traverse_module_state->__pyx_kp_s_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM);
  Py_VISIT(traverse_module_state->__pyx_n_s_DPNP_YOY_RATIO);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataFrame);
  Py_VISIT(traverse_module_state->__pyx_n_s_END_DATE);
  Py_VISIT(traverse_module_state->__pyx_n_s_EPSJB);
  Py_VISIT(traverse_module_state->__pyx_n_s_EPSKCJB);
  Py_VISIT(traverse_module_state->__pyx_n_s_EPSXS);
  Py_VISIT(traverse_module_state->__pyx_n_s_FREEHOLD_RATIO_TOTAL);
  Py_VISIT(traverse_module_state->__pyx_n_s_FREE_SHARES_RATIO);
  Py_VISIT(traverse_module_state->__pyx_n_s_GROSS_PROFIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_GROSS_PROFIT_RATIO);
  Py_VISIT(traverse_module_state->__pyx_n_s_HOLDER_TOTAL_NUM);
  Py_VISIT(traverse_module_state->__pyx_n_s_HOLD_FOCUS);
  Py_VISIT(traverse_module_state->__pyx_n_s_HOLD_MARKET_CAP);
  Py_VISIT(traverse_module_state->__pyx_n_s_HOLD_RATIO_TOTAL);
  Py_VISIT(traverse_module_state->__pyx_n_s_HOLD_SHARES);
  Py_VISIT(traverse_module_state->__pyx_n_s_HSF10);
  Py_VISIT(traverse_module_state->__pyx_n_s_INDEX_CHANGE_RATE);
  Py_VISIT(traverse_module_state->__pyx_n_s_INDEX_CLOSE_PRICE);
  Py_VISIT(traverse_module_state->__pyx_kp_u_INTERVAL_TYPE_1);
  Py_VISIT(traverse_module_state->__pyx_kp_u_INTERVAL_TYPE_1_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_JROA);
  Py_VISIT(traverse_module_state->__pyx_n_s_JYXJLYYSR);
  Py_VISIT(traverse_module_state->__pyx_n_s_KCFJCXSYJLR);
  Py_VISIT(traverse_module_state->__pyx_n_s_KCFJCXSYJLRTZ);
  Py_VISIT(traverse_module_state->__pyx_n_s_KFJLRGDHBZC);
  Py_VISIT(traverse_module_state->__pyx_n_s_LD);
  Py_VISIT(traverse_module_state->__pyx_n_s_MGJYXJJE);
  Py_VISIT(traverse_module_state->__pyx_n_s_MGWFPLR);
  Py_VISIT(traverse_module_state->__pyx_n_s_MGZBGJ);
  Py_VISIT(traverse_module_state->__pyx_n_s_MLR);
  Py_VISIT(traverse_module_state->__pyx_kp_s_MUTUAL_TYPE_005);
  Py_VISIT(traverse_module_state->__pyx_n_s_NETPROFITRPHBZC);
  Py_VISIT(traverse_module_state->__pyx_n_s_NET_DEAL_AMT);
  Py_VISIT(traverse_module_state->__pyx_n_s_NET_PROFIT_RATIO);
  Py_VISIT(traverse_module_state->__pyx_n_s_NEW);
  Py_VISIT(traverse_module_state->__pyx_n_s_NOTICE_DATE);
  Py_VISIT(traverse_module_state->__pyx_n_s_PARENTNETPROFIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_PARENTNETPROFITTZ);
  Py_VISIT(traverse_module_state->__pyx_n_s_PC);
  Py_VISIT(traverse_module_state->__pyx_n_s_PER_CAPITAL_RESERVE);
  Py_VISIT(traverse_module_state->__pyx_n_s_PER_NETCASH);
  Py_VISIT(traverse_module_state->__pyx_n_s_PER_UNASSIGN_PROFIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_PREDICT_AMC);
  Py_VISIT(traverse_module_state->__pyx_n_s_PRICE);
  Py_VISIT(traverse_module_state->__pyx_n_s_PUBLIC_START_DATE);
  Py_VISIT(traverse_module_state->__pyx_kp_s_PUBLIC_START_DATE_SECURITY_CODE);
  Py_VISIT(traverse_module_state->__pyx_n_s_QYCS);
  Py_VISIT(traverse_module_state->__pyx_n_s_REPORT_DATE);
  Py_VISIT(traverse_module_state->__pyx_n_s_ROEJQ);
  Py_VISIT(traverse_module_state->__pyx_n_s_ROE_DILUTED);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPTA_RZRQ_LSHJ);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPTA_WEB_RZRQ_GGMX);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPT_BOND_CB_LIST);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPT_F10_EH_HOLDERNUM);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPT_F10_FINANCE_MAINFINADATA);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPT_F10_QTR_MAINFINADATA);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPT_MUTUAL_DEALHISTORY_NEW);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPT_MUTUAL_HOLDSTOCKNDATE_STA);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPT_MUTUAL_STOCK_NORTHSTA);
  Py_VISIT(traverse_module_state->__pyx_n_s_RPT_SHAREBONUS_DET);
  Py_VISIT(traverse_module_state->__pyx_n_s_RQCHL);
  Py_VISIT(traverse_module_state->__pyx_n_s_RQJMG);
  Py_VISIT(traverse_module_state->__pyx_n_s_RQMCL);
  Py_VISIT(traverse_module_state->__pyx_n_s_RQYE);
  Py_VISIT(traverse_module_state->__pyx_n_s_RQYL);
  Py_VISIT(traverse_module_state->__pyx_n_s_RZCHE);
  Py_VISIT(traverse_module_state->__pyx_n_s_RZJME);
  Py_VISIT(traverse_module_state->__pyx_n_s_RZMRE);
  Py_VISIT(traverse_module_state->__pyx_n_s_RZRQYE);
  Py_VISIT(traverse_module_state->__pyx_n_s_RZYE);
  Py_VISIT(traverse_module_state->__pyx_n_s_RZYEZB);
  Py_VISIT(traverse_module_state->__pyx_n_s_SCODE);
  Py_VISIT(traverse_module_state->__pyx_kp_s_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE);
  Py_VISIT(traverse_module_state->__pyx_n_s_SD);
  Py_VISIT(traverse_module_state->__pyx_n_s_SECNAME);
  Py_VISIT(traverse_module_state->__pyx_kp_u_SECUCODE);
  Py_VISIT(traverse_module_state->__pyx_n_s_SECURITY_CODE);
  Py_VISIT(traverse_module_state->__pyx_kp_u_SECURITY_CODE_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_ABBR);
  Py_VISIT(traverse_module_state->__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD);
  Py_VISIT(traverse_module_state->__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_SECURITY_NAME);
  Py_VISIT(traverse_module_state->__pyx_n_s_SECURITY_NAME_ABBR);
  Py_VISIT(traverse_module_state->__pyx_n_s_SECURITY_SHORT_NAME);
  Py_VISIT(traverse_module_state->__pyx_n_s_SELL_AMT);
  Py_VISIT(traverse_module_state->__pyx_n_s_SPJ);
  Py_VISIT(traverse_module_state->__pyx_n_s_TAXRATE);
  Py_VISIT(traverse_module_state->__pyx_n_s_TOAZZL);
  Py_VISIT(traverse_module_state->__pyx_n_s_TOTALOPERATEREVE);
  Py_VISIT(traverse_module_state->__pyx_n_s_TOTALOPERATEREVETZ);
  Py_VISIT(traverse_module_state->__pyx_n_s_TOTAL_NUM_RATIO);
  Py_VISIT(traverse_module_state->__pyx_n_s_TRADE_DATE);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TRADE_DATE_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_TRADE_DATE_NET_DEAL_AMT_BUY_AMT);
  Py_VISIT(traverse_module_state->__pyx_n_s_TRANSFER_PRICE);
  Py_VISIT(traverse_module_state->__pyx_n_s_TRANSFER_VALUE);
  Py_VISIT(traverse_module_state->__pyx_n_s_WEB);
  Py_VISIT(traverse_module_state->__pyx_n_s_XJLLB);
  Py_VISIT(traverse_module_state->__pyx_n_s_XSJLL);
  Py_VISIT(traverse_module_state->__pyx_n_s_XSJXLYYSR);
  Py_VISIT(traverse_module_state->__pyx_n_s_XSMLL);
  Py_VISIT(traverse_module_state->__pyx_n_s_YSZKYYSR);
  Py_VISIT(traverse_module_state->__pyx_n_s_YSZKZZL);
  Py_VISIT(traverse_module_state->__pyx_n_s_YSZKZZTS);
  Py_VISIT(traverse_module_state->__pyx_n_s_YYZSRGDHBZC);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Y_m_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZCFZL);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZDF);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZZCJLL);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZZCZZTS);
  Py_VISIT(traverse_module_state->__pyx_kp_s__10);
  Py_VISIT(traverse_module_state->__pyx_kp_s__11);
  Py_VISIT(traverse_module_state->__pyx_kp_s__12);
  Py_VISIT(traverse_module_state->__pyx_kp_s__13);
  Py_VISIT(traverse_module_state->__pyx_n_s__132);
  Py_VISIT(traverse_module_state->__pyx_kp_s__14);
  Py_VISIT(traverse_module_state->__pyx_kp_s__15);
  Py_VISIT(traverse_module_state->__pyx_kp_s__16);
  Py_VISIT(traverse_module_state->__pyx_kp_s__17);
  Py_VISIT(traverse_module_state->__pyx_kp_s__18);
  Py_VISIT(traverse_module_state->__pyx_kp_s__19);
  Py_VISIT(traverse_module_state->__pyx_kp_s__2);
  Py_VISIT(traverse_module_state->__pyx_kp_s__20);
  Py_VISIT(traverse_module_state->__pyx_kp_s__22);
  Py_VISIT(traverse_module_state->__pyx_kp_s__23);
  Py_VISIT(traverse_module_state->__pyx_kp_s__24);
  Py_VISIT(traverse_module_state->__pyx_kp_s__25);
  Py_VISIT(traverse_module_state->__pyx_kp_s__26);
  Py_VISIT(traverse_module_state->__pyx_kp_s__27);
  Py_VISIT(traverse_module_state->__pyx_kp_s__28);
  Py_VISIT(traverse_module_state->__pyx_kp_s__29);
  Py_VISIT(traverse_module_state->__pyx_n_s__3);
  Py_VISIT(traverse_module_state->__pyx_kp_s__30);
  Py_VISIT(traverse_module_state->__pyx_kp_s__31);
  Py_VISIT(traverse_module_state->__pyx_kp_s__32);
  Py_VISIT(traverse_module_state->__pyx_kp_s__33);
  Py_VISIT(traverse_module_state->__pyx_kp_s__34);
  Py_VISIT(traverse_module_state->__pyx_kp_s__35);
  Py_VISIT(traverse_module_state->__pyx_kp_s__36);
  Py_VISIT(traverse_module_state->__pyx_kp_s__37);
  Py_VISIT(traverse_module_state->__pyx_kp_s__38);
  Py_VISIT(traverse_module_state->__pyx_kp_s__39);
  Py_VISIT(traverse_module_state->__pyx_kp_s__4);
  Py_VISIT(traverse_module_state->__pyx_kp_s__40);
  Py_VISIT(traverse_module_state->__pyx_kp_s__41);
  Py_VISIT(traverse_module_state->__pyx_kp_s__42);
  Py_VISIT(traverse_module_state->__pyx_kp_s__43);
  Py_VISIT(traverse_module_state->__pyx_kp_s__44);
  Py_VISIT(traverse_module_state->__pyx_kp_s__45);
  Py_VISIT(traverse_module_state->__pyx_kp_s__46);
  Py_VISIT(traverse_module_state->__pyx_kp_s__47);
  Py_VISIT(traverse_module_state->__pyx_kp_s__48);
  Py_VISIT(traverse_module_state->__pyx_kp_s__49);
  Py_VISIT(traverse_module_state->__pyx_kp_s__5);
  Py_VISIT(traverse_module_state->__pyx_kp_s__50);
  Py_VISIT(traverse_module_state->__pyx_kp_s__51);
  Py_VISIT(traverse_module_state->__pyx_kp_s__52);
  Py_VISIT(traverse_module_state->__pyx_kp_s__53);
  Py_VISIT(traverse_module_state->__pyx_kp_s__54);
  Py_VISIT(traverse_module_state->__pyx_kp_s__55);
  Py_VISIT(traverse_module_state->__pyx_kp_s__56);
  Py_VISIT(traverse_module_state->__pyx_kp_s__57);
  Py_VISIT(traverse_module_state->__pyx_kp_s__58);
  Py_VISIT(traverse_module_state->__pyx_kp_s__59);
  Py_VISIT(traverse_module_state->__pyx_kp_s__60);
  Py_VISIT(traverse_module_state->__pyx_kp_u__62);
  Py_VISIT(traverse_module_state->__pyx_kp_s__63);
  Py_VISIT(traverse_module_state->__pyx_kp_s__64);
  Py_VISIT(traverse_module_state->__pyx_kp_s__65);
  Py_VISIT(traverse_module_state->__pyx_kp_s__66);
  Py_VISIT(traverse_module_state->__pyx_kp_s__67);
  Py_VISIT(traverse_module_state->__pyx_kp_s__68);
  Py_VISIT(traverse_module_state->__pyx_kp_s__69);
  Py_VISIT(traverse_module_state->__pyx_kp_u__7);
  Py_VISIT(traverse_module_state->__pyx_kp_s__70);
  Py_VISIT(traverse_module_state->__pyx_kp_s__71);
  Py_VISIT(traverse_module_state->__pyx_kp_s__72);
  Py_VISIT(traverse_module_state->__pyx_kp_s__73);
  Py_VISIT(traverse_module_state->__pyx_kp_s__74);
  Py_VISIT(traverse_module_state->__pyx_kp_s__75);
  Py_VISIT(traverse_module_state->__pyx_kp_s__76);
  Py_VISIT(traverse_module_state->__pyx_kp_s__77);
  Py_VISIT(traverse_module_state->__pyx_kp_s__78);
  Py_VISIT(traverse_module_state->__pyx_kp_s__79);
  Py_VISIT(traverse_module_state->__pyx_kp_s__80);
  Py_VISIT(traverse_module_state->__pyx_kp_s__81);
  Py_VISIT(traverse_module_state->__pyx_kp_s__82);
  Py_VISIT(traverse_module_state->__pyx_kp_s__83);
  Py_VISIT(traverse_module_state->__pyx_kp_s__84);
  Py_VISIT(traverse_module_state->__pyx_kp_s__85);
  Py_VISIT(traverse_module_state->__pyx_kp_s__86);
  Py_VISIT(traverse_module_state->__pyx_kp_s__87);
  Py_VISIT(traverse_module_state->__pyx_kp_s__88);
  Py_VISIT(traverse_module_state->__pyx_kp_s__89);
  Py_VISIT(traverse_module_state->__pyx_kp_u__9);
  Py_VISIT(traverse_module_state->__pyx_n_s__90);
  Py_VISIT(traverse_module_state->__pyx_n_s_accum_net_amount);
  Py_VISIT(traverse_module_state->__pyx_n_s_add_amount);
  Py_VISIT(traverse_module_state->__pyx_n_s_add_volume);
  Py_VISIT(traverse_module_state->__pyx_n_s_akshare_stock_feature_stock_hist);
  Py_VISIT(traverse_module_state->__pyx_n_s_akshare_utils);
  Py_VISIT(traverse_module_state->__pyx_n_s_amount);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_avg_amount_pa);
  Py_VISIT(traverse_module_state->__pyx_n_s_avg_volume_pa);
  Py_VISIT(traverse_module_state->__pyx_n_s_avg_volume_pa_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_bd1d9ddb04089700cf9c27f6f7426281);
  Py_VISIT(traverse_module_state->__pyx_n_s_beg);
  Py_VISIT(traverse_module_state->__pyx_n_s_big_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_bond_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_bond_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_bond_scale);
  Py_VISIT(traverse_module_state->__pyx_n_s_bps);
  Py_VISIT(traverse_module_state->__pyx_n_s_buy_amount);
  Py_VISIT(traverse_module_state->__pyx_n_s_capital_reserve_ps);
  Py_VISIT(traverse_module_state->__pyx_n_s_cash_flow_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_ceil);
  Py_VISIT(traverse_module_state->__pyx_n_s_ch_zzl);
  Py_VISIT(traverse_module_state->__pyx_n_s_ch_zzts);
  Py_VISIT(traverse_module_state->__pyx_n_s_change_rate);
  Py_VISIT(traverse_module_state->__pyx_n_s_change_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_client);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_code_id_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_code_id_map_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_code_name_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_coerce);
  Py_VISIT(traverse_module_state->__pyx_n_s_cols_to_convert);
  Py_VISIT(traverse_module_state->__pyx_n_s_column_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_column_name_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_columns);
  Py_VISIT(traverse_module_state->__pyx_n_s_concat);
  Py_VISIT(traverse_module_state->__pyx_n_s_csi);
  Py_VISIT(traverse_module_state->__pyx_n_s_csi931151);
  Py_VISIT(traverse_module_state->__pyx_n_s_current_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_data_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_data_text);
  Py_VISIT(traverse_module_state->__pyx_kp_s_data_x_pages_tp);
  Py_VISIT(traverse_module_state->__pyx_n_s_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_debt_to_asset_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_decode);
  Py_VISIT(traverse_module_state->__pyx_n_s_dect);
  Py_VISIT(traverse_module_state->__pyx_n_s_demjson);
  Py_VISIT(traverse_module_state->__pyx_n_s_diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_dim_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_dlmkts);
  Py_VISIT(traverse_module_state->__pyx_n_s_drop);
  Py_VISIT(traverse_module_state->__pyx_n_s_dt);
  Py_VISIT(traverse_module_state->__pyx_n_s_empty);
  Py_VISIT(traverse_module_state->__pyx_n_s_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_eps_jb);
  Py_VISIT(traverse_module_state->__pyx_n_s_eps_kf);
  Py_VISIT(traverse_module_state->__pyx_n_s_eps_xs);
  Py_VISIT(traverse_module_state->__pyx_n_s_equity_multiplier);
  Py_VISIT(traverse_module_state->__pyx_n_s_equity_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_errors);
  Py_VISIT(traverse_module_state->__pyx_n_s_f116);
  Py_VISIT(traverse_module_state->__pyx_n_s_f117);
  Py_VISIT(traverse_module_state->__pyx_n_s_f12);
  Py_VISIT(traverse_module_state->__pyx_kp_s_f120_f121_f122_f174_f175_f59_f16);
  Py_VISIT(traverse_module_state->__pyx_n_s_f127);
  Py_VISIT(traverse_module_state->__pyx_n_s_f128);
  Py_VISIT(traverse_module_state->__pyx_kp_s_f12_f14_f2_f4_f3_f17_f15_f16_f18);
  Py_VISIT(traverse_module_state->__pyx_n_s_f14);
  Py_VISIT(traverse_module_state->__pyx_n_s_f15);
  Py_VISIT(traverse_module_state->__pyx_n_s_f16);
  Py_VISIT(traverse_module_state->__pyx_n_s_f17);
  Py_VISIT(traverse_module_state->__pyx_n_s_f18);
  Py_VISIT(traverse_module_state->__pyx_n_s_f189);
  Py_VISIT(traverse_module_state->__pyx_kp_s_f1_f2_f3_f4_f5);
  Py_VISIT(traverse_module_state->__pyx_n_s_f2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_f2_01_CONVERT_STOCK_CODE_CONVERT);
  Py_VISIT(traverse_module_state->__pyx_n_s_f3);
  Py_VISIT(traverse_module_state->__pyx_n_s_f4);
  Py_VISIT(traverse_module_state->__pyx_n_s_f5);
  Py_VISIT(traverse_module_state->__pyx_kp_s_f51_f52_f53_f54_f55_f56_f57_f58);
  Py_VISIT(traverse_module_state->__pyx_n_s_f57);
  Py_VISIT(traverse_module_state->__pyx_n_s_f58);
  Py_VISIT(traverse_module_state->__pyx_n_s_f6);
  Py_VISIT(traverse_module_state->__pyx_n_s_f84);
  Py_VISIT(traverse_module_state->__pyx_n_s_f85);
  Py_VISIT(traverse_module_state->__pyx_n_s_fa5fd1943c7b386f172d6893dbfba10b);
  Py_VISIT(traverse_module_state->__pyx_n_s_fid);
  Py_VISIT(traverse_module_state->__pyx_n_s_fields);
  Py_VISIT(traverse_module_state->__pyx_n_s_fields1);
  Py_VISIT(traverse_module_state->__pyx_n_s_fields2);
  Py_VISIT(traverse_module_state->__pyx_n_s_filter);
  Py_VISIT(traverse_module_state->__pyx_n_s_finance_mfd_quarter_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_finance_mfd_report_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_find);
  Py_VISIT(traverse_module_state->__pyx_n_s_float);
  Py_VISIT(traverse_module_state->__pyx_n_s_fltt);
  Py_VISIT(traverse_module_state->__pyx_n_s_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_fqt);
  Py_VISIT(traverse_module_state->__pyx_n_s_fs);
  Py_VISIT(traverse_module_state->__pyx_n_s_full);
  Py_VISIT(traverse_module_state->__pyx_n_s_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_gross_profit);
  Py_VISIT(traverse_module_state->__pyx_n_s_gross_profit_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_high);
  Py_VISIT(traverse_module_state->__pyx_n_s_hold_amount);
  Py_VISIT(traverse_module_state->__pyx_n_s_hold_focus);
  Py_VISIT(traverse_module_state->__pyx_n_s_hold_volume);
  Py_VISIT(traverse_module_state->__pyx_n_s_hold_volume_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_holder_num);
  Py_VISIT(traverse_module_state->__pyx_n_s_holder_num_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_hs300_change_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_hs300_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_hsgt_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_hsgt_history_df);
  Py_VISIT(traverse_module_state->__pyx_kp_s_http_push2_eastmoney_com_api_qt);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_38_push2_eastmoney_com_api);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_89_push2_eastmoney_com_api);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_datacenter_eastmoney_com_s);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_datacenter_eastmoney_com_s_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_datacenter_web_eastmoney_c);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_push2his_eastmoney_com_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_ignore_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_inplace);
  Py_VISIT(traverse_module_state->__pyx_n_s_insert);
  Py_VISIT(traverse_module_state->__pyx_n_s_invt);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_null_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_jQuery1124033485574041163946_159);
  Py_VISIT(traverse_module_state->__pyx_n_s_js);
  Py_VISIT(traverse_module_state->__pyx_n_s_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_jyjxjl_to_tor_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_kf_net_profit);
  Py_VISIT(traverse_module_state->__pyx_n_s_kf_net_profit_hb);
  Py_VISIT(traverse_module_state->__pyx_n_s_kf_net_profit_tb);
  Py_VISIT(traverse_module_state->__pyx_n_s_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_klt);
  Py_VISIT(traverse_module_state->__pyx_n_s_kzz_all_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_kzz_basic_info_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_kzz_sh_em_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_kzz_sh_trade_day_info_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_kzz_sz_em_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_kzz_sz_trade_day_info_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_kzz_trade_day_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_kzz_trade_day_em_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_kzz_trade_day_info_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_latest_trade_day);
  Py_VISIT(traverse_module_state->__pyx_n_s_low);
  Py_VISIT(traverse_module_state->__pyx_n_s_lt);
  Py_VISIT(traverse_module_state->__pyx_kp_s_m_0_b_MK0354);
  Py_VISIT(traverse_module_state->__pyx_kp_s_m_1_b_MK0354);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_market_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_math);
  Py_VISIT(traverse_module_state->__pyx_n_s_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_net_amount);
  Py_VISIT(traverse_module_state->__pyx_n_s_net_cash_ps);
  Py_VISIT(traverse_module_state->__pyx_n_s_net_profit_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_n_s_notice_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_notna);
  Py_VISIT(traverse_module_state->__pyx_n_s_np);
  Py_VISIT(traverse_module_state->__pyx_n_s_open);
  Py_VISIT(traverse_module_state->__pyx_n_s_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_page);
  Py_VISIT(traverse_module_state->__pyx_n_s_pageNo);
  Py_VISIT(traverse_module_state->__pyx_n_s_pageNum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pageNumber);
  Py_VISIT(traverse_module_state->__pyx_n_s_pageSize);
  Py_VISIT(traverse_module_state->__pyx_n_s_pages);
  Py_VISIT(traverse_module_state->__pyx_n_s_pandas);
  Py_VISIT(traverse_module_state->__pyx_n_s_params);
  Py_VISIT(traverse_module_state->__pyx_n_s_parent_net_profit);
  Py_VISIT(traverse_module_state->__pyx_n_s_parent_net_profit_hb);
  Py_VISIT(traverse_module_state->__pyx_n_s_parent_net_profit_tb);
  Py_VISIT(traverse_module_state->__pyx_n_s_pd);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pd_DataFrame);
  Py_VISIT(traverse_module_state->__pyx_n_s_pn);
  Py_VISIT(traverse_module_state->__pyx_n_s_po);
  Py_VISIT(traverse_module_state->__pyx_n_s_pre_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_price);
  Py_VISIT(traverse_module_state->__pyx_n_s_price_change);
  Py_VISIT(traverse_module_state->__pyx_n_s_price_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_print);
  Py_VISIT(traverse_module_state->__pyx_n_s_ps);
  Py_VISIT(traverse_module_state->__pyx_n_s_pub_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_pz);
  Py_VISIT(traverse_module_state->__pyx_n_s_quick_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_quoteColumns);
  Py_VISIT(traverse_module_state->__pyx_n_s_quoteType);
  Py_VISIT(traverse_module_state->__pyx_n_s_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_rc);
  Py_VISIT(traverse_module_state->__pyx_n_s_replace);
  Py_VISIT(traverse_module_state->__pyx_n_s_reportName);
  Py_VISIT(traverse_module_state->__pyx_n_s_report_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_requests);
  Py_VISIT(traverse_module_state->__pyx_n_s_reset_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_return);
  Py_VISIT(traverse_module_state->__pyx_n_s_roe_jzc);
  Py_VISIT(traverse_module_state->__pyx_n_s_roe_zzc);
  Py_VISIT(traverse_module_state->__pyx_n_s_rqchl);
  Py_VISIT(traverse_module_state->__pyx_n_s_rqjmg);
  Py_VISIT(traverse_module_state->__pyx_n_s_rqmcl);
  Py_VISIT(traverse_module_state->__pyx_n_s_rqye);
  Py_VISIT(traverse_module_state->__pyx_n_s_rqyl);
  Py_VISIT(traverse_module_state->__pyx_n_s_rt);
  Py_VISIT(traverse_module_state->__pyx_n_s_rzche);
  Py_VISIT(traverse_module_state->__pyx_n_s_rzjme);
  Py_VISIT(traverse_module_state->__pyx_n_s_rzmre);
  Py_VISIT(traverse_module_state->__pyx_n_s_rzrq_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_rzrq_history_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_rzrqye);
  Py_VISIT(traverse_module_state->__pyx_n_s_rzye);
  Py_VISIT(traverse_module_state->__pyx_n_s_rzyezb);
  Py_VISIT(traverse_module_state->__pyx_kp_u_scode);
  Py_VISIT(traverse_module_state->__pyx_n_s_secid);
  Py_VISIT(traverse_module_state->__pyx_n_s_sell_amount);
  Py_VISIT(traverse_module_state->__pyx_n_s_sh);
  Py_VISIT(traverse_module_state->__pyx_n_s_sortColumns);
  Py_VISIT(traverse_module_state->__pyx_n_s_sortTypes);
  Py_VISIT(traverse_module_state->__pyx_n_s_source);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_split);
  Py_VISIT(traverse_module_state->__pyx_n_s_sr);
  Py_VISIT(traverse_module_state->__pyx_n_s_sse_index_change_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_sse_index_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_st);
  Py_VISIT(traverse_module_state->__pyx_n_s_start_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_all_hsgt_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_all_rzrq_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_fhps_detail_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_finance_mfd_quarter_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_finance_mfd_report_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_gdhs_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_hsgt_detail);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_hsgt_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_hsgt_today_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_individual_info_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_rzrq_detail);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_rzrq_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_rzrq_today_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_zh_a_gdhs_detail_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_stock_zh_index_daily_em);
  Py_VISIT(traverse_module_state->__pyx_n_s_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_strptime);
  Py_VISIT(traverse_module_state->__pyx_n_s_sty);
  Py_VISIT(traverse_module_state->__pyx_n_s_svr);
  Py_VISIT(traverse_module_state->__pyx_n_s_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_tax_rate);
  Py_VISIT(traverse_module_state->__pyx_kp_s_tbstock_dataAcquisition_stockDat);
  Py_VISIT(traverse_module_state->__pyx_n_s_tbstock_dataAcquisition_stockDat_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_tbstock_utils);
  Py_VISIT(traverse_module_state->__pyx_n_s_temp_df);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_text);
  Py_VISIT(traverse_module_state->__pyx_n_s_timeout);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_numeric);
  Py_VISIT(traverse_module_state->__pyx_n_s_top_ten_ratio_free);
  Py_VISIT(traverse_module_state->__pyx_n_s_top_ten_ratio_total);
  Py_VISIT(traverse_module_state->__pyx_n_s_total);
  Py_VISIT(traverse_module_state->__pyx_n_s_total_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_total_operate_revenue);
  Py_VISIT(traverse_module_state->__pyx_n_s_total_operate_revenue_hb);
  Py_VISIT(traverse_module_state->__pyx_n_s_total_operate_revenue_tb);
  Py_VISIT(traverse_module_state->__pyx_n_s_total_pages);
  Py_VISIT(traverse_module_state->__pyx_n_s_trade_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_transfer_price);
  Py_VISIT(traverse_module_state->__pyx_n_s_transfer_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_unassign_profit_ps);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_url);
  Py_VISIT(traverse_module_state->__pyx_n_s_ut);
  Py_VISIT(traverse_module_state->__pyx_n_s_utils);
  Py_VISIT(traverse_module_state->__pyx_n_s_v);
  Py_VISIT(traverse_module_state->__pyx_n_s_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_volume);
  Py_VISIT(traverse_module_state->__pyx_n_s_wbp2u);
  Py_VISIT(traverse_module_state->__pyx_n_s_xsjxjl_to_tor_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_yszk_to_tor_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_yszk_zzl);
  Py_VISIT(traverse_module_state->__pyx_n_s_yszk_zzts);
  Py_VISIT(traverse_module_state->__pyx_n_s_zzc_zzl);
  Py_VISIT(traverse_module_state->__pyx_n_s_zzc_zzts);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_2);
  Py_VISIT(traverse_module_state->__pyx_int_3);
  Py_VISIT(traverse_module_state->__pyx_int_4);
  Py_VISIT(traverse_module_state->__pyx_int_5);
  Py_VISIT(traverse_module_state->__pyx_int_25);
  Py_VISIT(traverse_module_state->__pyx_int_50);
  Py_VISIT(traverse_module_state->__pyx_int_500);
  Py_VISIT(traverse_module_state->__pyx_int_neg_1);
  Py_VISIT(traverse_module_state->__pyx_slice__6);
  Py_VISIT(traverse_module_state->__pyx_slice__8);
  Py_VISIT(traverse_module_state->__pyx_slice__21);
  Py_VISIT(traverse_module_state->__pyx_slice__61);
  Py_VISIT(traverse_module_state->__pyx_tuple__91);
  Py_VISIT(traverse_module_state->__pyx_tuple__93);
  Py_VISIT(traverse_module_state->__pyx_tuple__94);
  Py_VISIT(traverse_module_state->__pyx_tuple__96);
  Py_VISIT(traverse_module_state->__pyx_tuple__97);
  Py_VISIT(traverse_module_state->__pyx_tuple__99);
  Py_VISIT(traverse_module_state->__pyx_tuple__100);
  Py_VISIT(traverse_module_state->__pyx_tuple__102);
  Py_VISIT(traverse_module_state->__pyx_tuple__103);
  Py_VISIT(traverse_module_state->__pyx_tuple__105);
  Py_VISIT(traverse_module_state->__pyx_tuple__107);
  Py_VISIT(traverse_module_state->__pyx_tuple__109);
  Py_VISIT(traverse_module_state->__pyx_tuple__111);
  Py_VISIT(traverse_module_state->__pyx_tuple__112);
  Py_VISIT(traverse_module_state->__pyx_tuple__114);
  Py_VISIT(traverse_module_state->__pyx_tuple__115);
  Py_VISIT(traverse_module_state->__pyx_tuple__117);
  Py_VISIT(traverse_module_state->__pyx_tuple__119);
  Py_VISIT(traverse_module_state->__pyx_tuple__120);
  Py_VISIT(traverse_module_state->__pyx_tuple__122);
  Py_VISIT(traverse_module_state->__pyx_tuple__123);
  Py_VISIT(traverse_module_state->__pyx_tuple__126);
  Py_VISIT(traverse_module_state->__pyx_tuple__128);
  Py_VISIT(traverse_module_state->__pyx_tuple__130);
  Py_VISIT(traverse_module_state->__pyx_codeobj__92);
  Py_VISIT(traverse_module_state->__pyx_codeobj__95);
  Py_VISIT(traverse_module_state->__pyx_codeobj__98);
  Py_VISIT(traverse_module_state->__pyx_codeobj__101);
  Py_VISIT(traverse_module_state->__pyx_codeobj__104);
  Py_VISIT(traverse_module_state->__pyx_codeobj__106);
  Py_VISIT(traverse_module_state->__pyx_codeobj__108);
  Py_VISIT(traverse_module_state->__pyx_codeobj__110);
  Py_VISIT(traverse_module_state->__pyx_codeobj__113);
  Py_VISIT(traverse_module_state->__pyx_codeobj__116);
  Py_VISIT(traverse_module_state->__pyx_codeobj__118);
  Py_VISIT(traverse_module_state->__pyx_codeobj__121);
  Py_VISIT(traverse_module_state->__pyx_codeobj__124);
  Py_VISIT(traverse_module_state->__pyx_codeobj__125);
  Py_VISIT(traverse_module_state->__pyx_codeobj__127);
  Py_VISIT(traverse_module_state->__pyx_codeobj__129);
  Py_VISIT(traverse_module_state->__pyx_codeobj__131);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_kp_s_ __pyx_mstate_global->__pyx_kp_s_
#define __pyx_kp_s_0 __pyx_mstate_global->__pyx_kp_s_0
#define __pyx_kp_s_000001 __pyx_mstate_global->__pyx_kp_s_000001
#define __pyx_kp_s_000001_SZ __pyx_mstate_global->__pyx_kp_s_000001_SZ
#define __pyx_kp_s_007949902328317804 __pyx_mstate_global->__pyx_kp_s_007949902328317804
#define __pyx_kp_s_018998368837725255 __pyx_mstate_global->__pyx_kp_s_018998368837725255
#define __pyx_kp_s_08730299565686817 __pyx_mstate_global->__pyx_kp_s_08730299565686817
#define __pyx_kp_s_0_0_0_web __pyx_mstate_global->__pyx_kp_s_0_0_0_web
#define __pyx_kp_s_0_2 __pyx_mstate_global->__pyx_kp_s_0_2
#define __pyx_kp_s_1 __pyx_mstate_global->__pyx_kp_s_1
#define __pyx_kp_s_101 __pyx_mstate_global->__pyx_kp_s_101
#define __pyx_kp_s_1596700547039 __pyx_mstate_global->__pyx_kp_s_1596700547039
#define __pyx_kp_s_1640157544804 __pyx_mstate_global->__pyx_kp_s_1640157544804
#define __pyx_kp_s_1717261171099 __pyx_mstate_global->__pyx_kp_s_1717261171099
#define __pyx_kp_s_1717298612418 __pyx_mstate_global->__pyx_kp_s_1717298612418
#define __pyx_kp_s_1717298688717 __pyx_mstate_global->__pyx_kp_s_1717298688717
#define __pyx_kp_s_1721047529031 __pyx_mstate_global->__pyx_kp_s_1721047529031
#define __pyx_kp_s_1721051595125 __pyx_mstate_global->__pyx_kp_s_1721051595125
#define __pyx_kp_s_19900101 __pyx_mstate_global->__pyx_kp_s_19900101
#define __pyx_kp_s_1_1 __pyx_mstate_global->__pyx_kp_s_1_1
#define __pyx_kp_s_1_2 __pyx_mstate_global->__pyx_kp_s_1_2
#define __pyx_kp_s_1_3 __pyx_mstate_global->__pyx_kp_s_1_3
#define __pyx_kp_s_2 __pyx_mstate_global->__pyx_kp_s_2
#define __pyx_kp_s_200 __pyx_mstate_global->__pyx_kp_s_200
#define __pyx_kp_s_2024_05_31 __pyx_mstate_global->__pyx_kp_s_2024_05_31
#define __pyx_kp_s_20500101 __pyx_mstate_global->__pyx_kp_s_20500101
#define __pyx_kp_s_250 __pyx_mstate_global->__pyx_kp_s_250
#define __pyx_kp_s_2_2 __pyx_mstate_global->__pyx_kp_s_2_2
#define __pyx_kp_s_300073 __pyx_mstate_global->__pyx_kp_s_300073
#define __pyx_kp_s_500 __pyx_mstate_global->__pyx_kp_s_500
#define __pyx_kp_s_600900 __pyx_mstate_global->__pyx_kp_s_600900
#define __pyx_kp_s_688235 __pyx_mstate_global->__pyx_kp_s_688235
#define __pyx_kp_s_688235_SH __pyx_mstate_global->__pyx_kp_s_688235_SH
#define __pyx_n_s_ACCUM_DEAL_AMT __pyx_mstate_global->__pyx_n_s_ACCUM_DEAL_AMT
#define __pyx_n_s_ACTUAL_ISSUE_SCALE __pyx_mstate_global->__pyx_n_s_ACTUAL_ISSUE_SCALE
#define __pyx_n_s_ADD_MARKET_CAP __pyx_mstate_global->__pyx_n_s_ADD_MARKET_CAP
#define __pyx_n_s_ADD_SHARES_REPAIR __pyx_mstate_global->__pyx_n_s_ADD_SHARES_REPAIR
#define __pyx_n_s_ALL __pyx_mstate_global->__pyx_n_s_ALL
#define __pyx_n_s_APP_F10_MAINFINADATA __pyx_mstate_global->__pyx_n_s_APP_F10_MAINFINADATA
#define __pyx_n_s_AVG_FREESHARES_RATIO __pyx_mstate_global->__pyx_n_s_AVG_FREESHARES_RATIO
#define __pyx_n_s_AVG_FREE_SHARES __pyx_mstate_global->__pyx_n_s_AVG_FREE_SHARES
#define __pyx_n_s_AVG_HOLD_AMT __pyx_mstate_global->__pyx_n_s_AVG_HOLD_AMT
#define __pyx_n_s_BPS __pyx_mstate_global->__pyx_n_s_BPS
#define __pyx_n_s_BUY_AMT __pyx_mstate_global->__pyx_n_s_BUY_AMT
#define __pyx_n_s_CHANGE_RATE __pyx_mstate_global->__pyx_n_s_CHANGE_RATE
#define __pyx_n_s_CHZZL __pyx_mstate_global->__pyx_n_s_CHZZL
#define __pyx_n_s_CHZZTS __pyx_mstate_global->__pyx_n_s_CHZZTS
#define __pyx_n_s_CLOSE_PRICE __pyx_mstate_global->__pyx_n_s_CLOSE_PRICE
#define __pyx_n_s_CONVERT_STOCK_CODE __pyx_mstate_global->__pyx_n_s_CONVERT_STOCK_CODE
#define __pyx_n_s_CQBL __pyx_mstate_global->__pyx_n_s_CQBL
#define __pyx_n_s_DATE __pyx_mstate_global->__pyx_n_s_DATE
#define __pyx_kp_u_DATE_2 __pyx_mstate_global->__pyx_kp_u_DATE_2
#define __pyx_n_s_DEDU_PARENT_PROFIT __pyx_mstate_global->__pyx_n_s_DEDU_PARENT_PROFIT
#define __pyx_n_s_DIM_DATE __pyx_mstate_global->__pyx_n_s_DIM_DATE
#define __pyx_kp_s_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM __pyx_mstate_global->__pyx_kp_s_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM
#define __pyx_n_s_DPNP_YOY_RATIO __pyx_mstate_global->__pyx_n_s_DPNP_YOY_RATIO
#define __pyx_n_s_DataFrame __pyx_mstate_global->__pyx_n_s_DataFrame
#define __pyx_n_s_END_DATE __pyx_mstate_global->__pyx_n_s_END_DATE
#define __pyx_n_s_EPSJB __pyx_mstate_global->__pyx_n_s_EPSJB
#define __pyx_n_s_EPSKCJB __pyx_mstate_global->__pyx_n_s_EPSKCJB
#define __pyx_n_s_EPSXS __pyx_mstate_global->__pyx_n_s_EPSXS
#define __pyx_n_s_FREEHOLD_RATIO_TOTAL __pyx_mstate_global->__pyx_n_s_FREEHOLD_RATIO_TOTAL
#define __pyx_n_s_FREE_SHARES_RATIO __pyx_mstate_global->__pyx_n_s_FREE_SHARES_RATIO
#define __pyx_n_s_GROSS_PROFIT __pyx_mstate_global->__pyx_n_s_GROSS_PROFIT
#define __pyx_n_s_GROSS_PROFIT_RATIO __pyx_mstate_global->__pyx_n_s_GROSS_PROFIT_RATIO
#define __pyx_n_s_HOLDER_TOTAL_NUM __pyx_mstate_global->__pyx_n_s_HOLDER_TOTAL_NUM
#define __pyx_n_s_HOLD_FOCUS __pyx_mstate_global->__pyx_n_s_HOLD_FOCUS
#define __pyx_n_s_HOLD_MARKET_CAP __pyx_mstate_global->__pyx_n_s_HOLD_MARKET_CAP
#define __pyx_n_s_HOLD_RATIO_TOTAL __pyx_mstate_global->__pyx_n_s_HOLD_RATIO_TOTAL
#define __pyx_n_s_HOLD_SHARES __pyx_mstate_global->__pyx_n_s_HOLD_SHARES
#define __pyx_n_s_HSF10 __pyx_mstate_global->__pyx_n_s_HSF10
#define __pyx_n_s_INDEX_CHANGE_RATE __pyx_mstate_global->__pyx_n_s_INDEX_CHANGE_RATE
#define __pyx_n_s_INDEX_CLOSE_PRICE __pyx_mstate_global->__pyx_n_s_INDEX_CLOSE_PRICE
#define __pyx_kp_u_INTERVAL_TYPE_1 __pyx_mstate_global->__pyx_kp_u_INTERVAL_TYPE_1
#define __pyx_kp_u_INTERVAL_TYPE_1_2 __pyx_mstate_global->__pyx_kp_u_INTERVAL_TYPE_1_2
#define __pyx_n_s_JROA __pyx_mstate_global->__pyx_n_s_JROA
#define __pyx_n_s_JYXJLYYSR __pyx_mstate_global->__pyx_n_s_JYXJLYYSR
#define __pyx_n_s_KCFJCXSYJLR __pyx_mstate_global->__pyx_n_s_KCFJCXSYJLR
#define __pyx_n_s_KCFJCXSYJLRTZ __pyx_mstate_global->__pyx_n_s_KCFJCXSYJLRTZ
#define __pyx_n_s_KFJLRGDHBZC __pyx_mstate_global->__pyx_n_s_KFJLRGDHBZC
#define __pyx_n_s_LD __pyx_mstate_global->__pyx_n_s_LD
#define __pyx_n_s_MGJYXJJE __pyx_mstate_global->__pyx_n_s_MGJYXJJE
#define __pyx_n_s_MGWFPLR __pyx_mstate_global->__pyx_n_s_MGWFPLR
#define __pyx_n_s_MGZBGJ __pyx_mstate_global->__pyx_n_s_MGZBGJ
#define __pyx_n_s_MLR __pyx_mstate_global->__pyx_n_s_MLR
#define __pyx_kp_s_MUTUAL_TYPE_005 __pyx_mstate_global->__pyx_kp_s_MUTUAL_TYPE_005
#define __pyx_n_s_NETPROFITRPHBZC __pyx_mstate_global->__pyx_n_s_NETPROFITRPHBZC
#define __pyx_n_s_NET_DEAL_AMT __pyx_mstate_global->__pyx_n_s_NET_DEAL_AMT
#define __pyx_n_s_NET_PROFIT_RATIO __pyx_mstate_global->__pyx_n_s_NET_PROFIT_RATIO
#define __pyx_n_s_NEW __pyx_mstate_global->__pyx_n_s_NEW
#define __pyx_n_s_NOTICE_DATE __pyx_mstate_global->__pyx_n_s_NOTICE_DATE
#define __pyx_n_s_PARENTNETPROFIT __pyx_mstate_global->__pyx_n_s_PARENTNETPROFIT
#define __pyx_n_s_PARENTNETPROFITTZ __pyx_mstate_global->__pyx_n_s_PARENTNETPROFITTZ
#define __pyx_n_s_PC __pyx_mstate_global->__pyx_n_s_PC
#define __pyx_n_s_PER_CAPITAL_RESERVE __pyx_mstate_global->__pyx_n_s_PER_CAPITAL_RESERVE
#define __pyx_n_s_PER_NETCASH __pyx_mstate_global->__pyx_n_s_PER_NETCASH
#define __pyx_n_s_PER_UNASSIGN_PROFIT __pyx_mstate_global->__pyx_n_s_PER_UNASSIGN_PROFIT
#define __pyx_n_s_PREDICT_AMC __pyx_mstate_global->__pyx_n_s_PREDICT_AMC
#define __pyx_n_s_PRICE __pyx_mstate_global->__pyx_n_s_PRICE
#define __pyx_n_s_PUBLIC_START_DATE __pyx_mstate_global->__pyx_n_s_PUBLIC_START_DATE
#define __pyx_kp_s_PUBLIC_START_DATE_SECURITY_CODE __pyx_mstate_global->__pyx_kp_s_PUBLIC_START_DATE_SECURITY_CODE
#define __pyx_n_s_QYCS __pyx_mstate_global->__pyx_n_s_QYCS
#define __pyx_n_s_REPORT_DATE __pyx_mstate_global->__pyx_n_s_REPORT_DATE
#define __pyx_n_s_ROEJQ __pyx_mstate_global->__pyx_n_s_ROEJQ
#define __pyx_n_s_ROE_DILUTED __pyx_mstate_global->__pyx_n_s_ROE_DILUTED
#define __pyx_n_s_RPTA_RZRQ_LSHJ __pyx_mstate_global->__pyx_n_s_RPTA_RZRQ_LSHJ
#define __pyx_n_s_RPTA_WEB_RZRQ_GGMX __pyx_mstate_global->__pyx_n_s_RPTA_WEB_RZRQ_GGMX
#define __pyx_n_s_RPT_BOND_CB_LIST __pyx_mstate_global->__pyx_n_s_RPT_BOND_CB_LIST
#define __pyx_n_s_RPT_F10_EH_HOLDERNUM __pyx_mstate_global->__pyx_n_s_RPT_F10_EH_HOLDERNUM
#define __pyx_n_s_RPT_F10_FINANCE_MAINFINADATA __pyx_mstate_global->__pyx_n_s_RPT_F10_FINANCE_MAINFINADATA
#define __pyx_n_s_RPT_F10_QTR_MAINFINADATA __pyx_mstate_global->__pyx_n_s_RPT_F10_QTR_MAINFINADATA
#define __pyx_n_s_RPT_MUTUAL_DEALHISTORY_NEW __pyx_mstate_global->__pyx_n_s_RPT_MUTUAL_DEALHISTORY_NEW
#define __pyx_n_s_RPT_MUTUAL_HOLDSTOCKNDATE_STA __pyx_mstate_global->__pyx_n_s_RPT_MUTUAL_HOLDSTOCKNDATE_STA
#define __pyx_n_s_RPT_MUTUAL_STOCK_NORTHSTA __pyx_mstate_global->__pyx_n_s_RPT_MUTUAL_STOCK_NORTHSTA
#define __pyx_n_s_RPT_SHAREBONUS_DET __pyx_mstate_global->__pyx_n_s_RPT_SHAREBONUS_DET
#define __pyx_n_s_RQCHL __pyx_mstate_global->__pyx_n_s_RQCHL
#define __pyx_n_s_RQJMG __pyx_mstate_global->__pyx_n_s_RQJMG
#define __pyx_n_s_RQMCL __pyx_mstate_global->__pyx_n_s_RQMCL
#define __pyx_n_s_RQYE __pyx_mstate_global->__pyx_n_s_RQYE
#define __pyx_n_s_RQYL __pyx_mstate_global->__pyx_n_s_RQYL
#define __pyx_n_s_RZCHE __pyx_mstate_global->__pyx_n_s_RZCHE
#define __pyx_n_s_RZJME __pyx_mstate_global->__pyx_n_s_RZJME
#define __pyx_n_s_RZMRE __pyx_mstate_global->__pyx_n_s_RZMRE
#define __pyx_n_s_RZRQYE __pyx_mstate_global->__pyx_n_s_RZRQYE
#define __pyx_n_s_RZYE __pyx_mstate_global->__pyx_n_s_RZYE
#define __pyx_n_s_RZYEZB __pyx_mstate_global->__pyx_n_s_RZYEZB
#define __pyx_n_s_SCODE __pyx_mstate_global->__pyx_n_s_SCODE
#define __pyx_kp_s_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE __pyx_mstate_global->__pyx_kp_s_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE
#define __pyx_n_s_SD __pyx_mstate_global->__pyx_n_s_SD
#define __pyx_n_s_SECNAME __pyx_mstate_global->__pyx_n_s_SECNAME
#define __pyx_kp_u_SECUCODE __pyx_mstate_global->__pyx_kp_u_SECUCODE
#define __pyx_n_s_SECURITY_CODE __pyx_mstate_global->__pyx_n_s_SECURITY_CODE
#define __pyx_kp_u_SECURITY_CODE_2 __pyx_mstate_global->__pyx_kp_u_SECURITY_CODE_2
#define __pyx_kp_s_SECURITY_CODE_SECURITY_NAME_ABBR __pyx_mstate_global->__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_ABBR
#define __pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD __pyx_mstate_global->__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD
#define __pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD_2 __pyx_mstate_global->__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD_2
#define __pyx_n_s_SECURITY_NAME __pyx_mstate_global->__pyx_n_s_SECURITY_NAME
#define __pyx_n_s_SECURITY_NAME_ABBR __pyx_mstate_global->__pyx_n_s_SECURITY_NAME_ABBR
#define __pyx_n_s_SECURITY_SHORT_NAME __pyx_mstate_global->__pyx_n_s_SECURITY_SHORT_NAME
#define __pyx_n_s_SELL_AMT __pyx_mstate_global->__pyx_n_s_SELL_AMT
#define __pyx_n_s_SPJ __pyx_mstate_global->__pyx_n_s_SPJ
#define __pyx_n_s_TAXRATE __pyx_mstate_global->__pyx_n_s_TAXRATE
#define __pyx_n_s_TOAZZL __pyx_mstate_global->__pyx_n_s_TOAZZL
#define __pyx_n_s_TOTALOPERATEREVE __pyx_mstate_global->__pyx_n_s_TOTALOPERATEREVE
#define __pyx_n_s_TOTALOPERATEREVETZ __pyx_mstate_global->__pyx_n_s_TOTALOPERATEREVETZ
#define __pyx_n_s_TOTAL_NUM_RATIO __pyx_mstate_global->__pyx_n_s_TOTAL_NUM_RATIO
#define __pyx_n_s_TRADE_DATE __pyx_mstate_global->__pyx_n_s_TRADE_DATE
#define __pyx_kp_u_TRADE_DATE_2 __pyx_mstate_global->__pyx_kp_u_TRADE_DATE_2
#define __pyx_kp_s_TRADE_DATE_NET_DEAL_AMT_BUY_AMT __pyx_mstate_global->__pyx_kp_s_TRADE_DATE_NET_DEAL_AMT_BUY_AMT
#define __pyx_n_s_TRANSFER_PRICE __pyx_mstate_global->__pyx_n_s_TRANSFER_PRICE
#define __pyx_n_s_TRANSFER_VALUE __pyx_mstate_global->__pyx_n_s_TRANSFER_VALUE
#define __pyx_n_s_WEB __pyx_mstate_global->__pyx_n_s_WEB
#define __pyx_n_s_XJLLB __pyx_mstate_global->__pyx_n_s_XJLLB
#define __pyx_n_s_XSJLL __pyx_mstate_global->__pyx_n_s_XSJLL
#define __pyx_n_s_XSJXLYYSR __pyx_mstate_global->__pyx_n_s_XSJXLYYSR
#define __pyx_n_s_XSMLL __pyx_mstate_global->__pyx_n_s_XSMLL
#define __pyx_n_s_YSZKYYSR __pyx_mstate_global->__pyx_n_s_YSZKYYSR
#define __pyx_n_s_YSZKZZL __pyx_mstate_global->__pyx_n_s_YSZKZZL
#define __pyx_n_s_YSZKZZTS __pyx_mstate_global->__pyx_n_s_YSZKZZTS
#define __pyx_n_s_YYZSRGDHBZC __pyx_mstate_global->__pyx_n_s_YYZSRGDHBZC
#define __pyx_kp_s_Y_m_d __pyx_mstate_global->__pyx_kp_s_Y_m_d
#define __pyx_n_s_ZCFZL __pyx_mstate_global->__pyx_n_s_ZCFZL
#define __pyx_n_s_ZDF __pyx_mstate_global->__pyx_n_s_ZDF
#define __pyx_n_s_ZZCJLL __pyx_mstate_global->__pyx_n_s_ZZCJLL
#define __pyx_n_s_ZZCZZTS __pyx_mstate_global->__pyx_n_s_ZZCZZTS
#define __pyx_kp_s__10 __pyx_mstate_global->__pyx_kp_s__10
#define __pyx_kp_s__11 __pyx_mstate_global->__pyx_kp_s__11
#define __pyx_kp_s__12 __pyx_mstate_global->__pyx_kp_s__12
#define __pyx_kp_s__13 __pyx_mstate_global->__pyx_kp_s__13
#define __pyx_n_s__132 __pyx_mstate_global->__pyx_n_s__132
#define __pyx_kp_s__14 __pyx_mstate_global->__pyx_kp_s__14
#define __pyx_kp_s__15 __pyx_mstate_global->__pyx_kp_s__15
#define __pyx_kp_s__16 __pyx_mstate_global->__pyx_kp_s__16
#define __pyx_kp_s__17 __pyx_mstate_global->__pyx_kp_s__17
#define __pyx_kp_s__18 __pyx_mstate_global->__pyx_kp_s__18
#define __pyx_kp_s__19 __pyx_mstate_global->__pyx_kp_s__19
#define __pyx_kp_s__2 __pyx_mstate_global->__pyx_kp_s__2
#define __pyx_kp_s__20 __pyx_mstate_global->__pyx_kp_s__20
#define __pyx_kp_s__22 __pyx_mstate_global->__pyx_kp_s__22
#define __pyx_kp_s__23 __pyx_mstate_global->__pyx_kp_s__23
#define __pyx_kp_s__24 __pyx_mstate_global->__pyx_kp_s__24
#define __pyx_kp_s__25 __pyx_mstate_global->__pyx_kp_s__25
#define __pyx_kp_s__26 __pyx_mstate_global->__pyx_kp_s__26
#define __pyx_kp_s__27 __pyx_mstate_global->__pyx_kp_s__27
#define __pyx_kp_s__28 __pyx_mstate_global->__pyx_kp_s__28
#define __pyx_kp_s__29 __pyx_mstate_global->__pyx_kp_s__29
#define __pyx_n_s__3 __pyx_mstate_global->__pyx_n_s__3
#define __pyx_kp_s__30 __pyx_mstate_global->__pyx_kp_s__30
#define __pyx_kp_s__31 __pyx_mstate_global->__pyx_kp_s__31
#define __pyx_kp_s__32 __pyx_mstate_global->__pyx_kp_s__32
#define __pyx_kp_s__33 __pyx_mstate_global->__pyx_kp_s__33
#define __pyx_kp_s__34 __pyx_mstate_global->__pyx_kp_s__34
#define __pyx_kp_s__35 __pyx_mstate_global->__pyx_kp_s__35
#define __pyx_kp_s__36 __pyx_mstate_global->__pyx_kp_s__36
#define __pyx_kp_s__37 __pyx_mstate_global->__pyx_kp_s__37
#define __pyx_kp_s__38 __pyx_mstate_global->__pyx_kp_s__38
#define __pyx_kp_s__39 __pyx_mstate_global->__pyx_kp_s__39
#define __pyx_kp_s__4 __pyx_mstate_global->__pyx_kp_s__4
#define __pyx_kp_s__40 __pyx_mstate_global->__pyx_kp_s__40
#define __pyx_kp_s__41 __pyx_mstate_global->__pyx_kp_s__41
#define __pyx_kp_s__42 __pyx_mstate_global->__pyx_kp_s__42
#define __pyx_kp_s__43 __pyx_mstate_global->__pyx_kp_s__43
#define __pyx_kp_s__44 __pyx_mstate_global->__pyx_kp_s__44
#define __pyx_kp_s__45 __pyx_mstate_global->__pyx_kp_s__45
#define __pyx_kp_s__46 __pyx_mstate_global->__pyx_kp_s__46
#define __pyx_kp_s__47 __pyx_mstate_global->__pyx_kp_s__47
#define __pyx_kp_s__48 __pyx_mstate_global->__pyx_kp_s__48
#define __pyx_kp_s__49 __pyx_mstate_global->__pyx_kp_s__49
#define __pyx_kp_s__5 __pyx_mstate_global->__pyx_kp_s__5
#define __pyx_kp_s__50 __pyx_mstate_global->__pyx_kp_s__50
#define __pyx_kp_s__51 __pyx_mstate_global->__pyx_kp_s__51
#define __pyx_kp_s__52 __pyx_mstate_global->__pyx_kp_s__52
#define __pyx_kp_s__53 __pyx_mstate_global->__pyx_kp_s__53
#define __pyx_kp_s__54 __pyx_mstate_global->__pyx_kp_s__54
#define __pyx_kp_s__55 __pyx_mstate_global->__pyx_kp_s__55
#define __pyx_kp_s__56 __pyx_mstate_global->__pyx_kp_s__56
#define __pyx_kp_s__57 __pyx_mstate_global->__pyx_kp_s__57
#define __pyx_kp_s__58 __pyx_mstate_global->__pyx_kp_s__58
#define __pyx_kp_s__59 __pyx_mstate_global->__pyx_kp_s__59
#define __pyx_kp_s__60 __pyx_mstate_global->__pyx_kp_s__60
#define __pyx_kp_u__62 __pyx_mstate_global->__pyx_kp_u__62
#define __pyx_kp_s__63 __pyx_mstate_global->__pyx_kp_s__63
#define __pyx_kp_s__64 __pyx_mstate_global->__pyx_kp_s__64
#define __pyx_kp_s__65 __pyx_mstate_global->__pyx_kp_s__65
#define __pyx_kp_s__66 __pyx_mstate_global->__pyx_kp_s__66
#define __pyx_kp_s__67 __pyx_mstate_global->__pyx_kp_s__67
#define __pyx_kp_s__68 __pyx_mstate_global->__pyx_kp_s__68
#define __pyx_kp_s__69 __pyx_mstate_global->__pyx_kp_s__69
#define __pyx_kp_u__7 __pyx_mstate_global->__pyx_kp_u__7
#define __pyx_kp_s__70 __pyx_mstate_global->__pyx_kp_s__70
#define __pyx_kp_s__71 __pyx_mstate_global->__pyx_kp_s__71
#define __pyx_kp_s__72 __pyx_mstate_global->__pyx_kp_s__72
#define __pyx_kp_s__73 __pyx_mstate_global->__pyx_kp_s__73
#define __pyx_kp_s__74 __pyx_mstate_global->__pyx_kp_s__74
#define __pyx_kp_s__75 __pyx_mstate_global->__pyx_kp_s__75
#define __pyx_kp_s__76 __pyx_mstate_global->__pyx_kp_s__76
#define __pyx_kp_s__77 __pyx_mstate_global->__pyx_kp_s__77
#define __pyx_kp_s__78 __pyx_mstate_global->__pyx_kp_s__78
#define __pyx_kp_s__79 __pyx_mstate_global->__pyx_kp_s__79
#define __pyx_kp_s__80 __pyx_mstate_global->__pyx_kp_s__80
#define __pyx_kp_s__81 __pyx_mstate_global->__pyx_kp_s__81
#define __pyx_kp_s__82 __pyx_mstate_global->__pyx_kp_s__82
#define __pyx_kp_s__83 __pyx_mstate_global->__pyx_kp_s__83
#define __pyx_kp_s__84 __pyx_mstate_global->__pyx_kp_s__84
#define __pyx_kp_s__85 __pyx_mstate_global->__pyx_kp_s__85
#define __pyx_kp_s__86 __pyx_mstate_global->__pyx_kp_s__86
#define __pyx_kp_s__87 __pyx_mstate_global->__pyx_kp_s__87
#define __pyx_kp_s__88 __pyx_mstate_global->__pyx_kp_s__88
#define __pyx_kp_s__89 __pyx_mstate_global->__pyx_kp_s__89
#define __pyx_kp_u__9 __pyx_mstate_global->__pyx_kp_u__9
#define __pyx_n_s__90 __pyx_mstate_global->__pyx_n_s__90
#define __pyx_n_s_accum_net_amount __pyx_mstate_global->__pyx_n_s_accum_net_amount
#define __pyx_n_s_add_amount __pyx_mstate_global->__pyx_n_s_add_amount
#define __pyx_n_s_add_volume __pyx_mstate_global->__pyx_n_s_add_volume
#define __pyx_n_s_akshare_stock_feature_stock_hist __pyx_mstate_global->__pyx_n_s_akshare_stock_feature_stock_hist
#define __pyx_n_s_akshare_utils __pyx_mstate_global->__pyx_n_s_akshare_utils
#define __pyx_n_s_amount __pyx_mstate_global->__pyx_n_s_amount
#define __pyx_n_s_apply __pyx_mstate_global->__pyx_n_s_apply
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_avg_amount_pa __pyx_mstate_global->__pyx_n_s_avg_amount_pa
#define __pyx_n_s_avg_volume_pa __pyx_mstate_global->__pyx_n_s_avg_volume_pa
#define __pyx_n_s_avg_volume_pa_ratio __pyx_mstate_global->__pyx_n_s_avg_volume_pa_ratio
#define __pyx_n_s_bd1d9ddb04089700cf9c27f6f7426281 __pyx_mstate_global->__pyx_n_s_bd1d9ddb04089700cf9c27f6f7426281
#define __pyx_n_s_beg __pyx_mstate_global->__pyx_n_s_beg
#define __pyx_n_s_big_df __pyx_mstate_global->__pyx_n_s_big_df
#define __pyx_n_s_bond_code __pyx_mstate_global->__pyx_n_s_bond_code
#define __pyx_n_s_bond_name __pyx_mstate_global->__pyx_n_s_bond_name
#define __pyx_n_s_bond_scale __pyx_mstate_global->__pyx_n_s_bond_scale
#define __pyx_n_s_bps __pyx_mstate_global->__pyx_n_s_bps
#define __pyx_n_s_buy_amount __pyx_mstate_global->__pyx_n_s_buy_amount
#define __pyx_n_s_capital_reserve_ps __pyx_mstate_global->__pyx_n_s_capital_reserve_ps
#define __pyx_n_s_cash_flow_ratio __pyx_mstate_global->__pyx_n_s_cash_flow_ratio
#define __pyx_n_s_cb __pyx_mstate_global->__pyx_n_s_cb
#define __pyx_n_s_ceil __pyx_mstate_global->__pyx_n_s_ceil
#define __pyx_n_s_ch_zzl __pyx_mstate_global->__pyx_n_s_ch_zzl
#define __pyx_n_s_ch_zzts __pyx_mstate_global->__pyx_n_s_ch_zzts
#define __pyx_n_s_change_rate __pyx_mstate_global->__pyx_n_s_change_rate
#define __pyx_n_s_change_ratio __pyx_mstate_global->__pyx_n_s_change_ratio
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_client __pyx_mstate_global->__pyx_n_s_client
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_close __pyx_mstate_global->__pyx_n_s_close
#define __pyx_n_s_code __pyx_mstate_global->__pyx_n_s_code
#define __pyx_n_s_code_id_dict __pyx_mstate_global->__pyx_n_s_code_id_dict
#define __pyx_n_s_code_id_map_em __pyx_mstate_global->__pyx_n_s_code_id_map_em
#define __pyx_n_s_code_name_map __pyx_mstate_global->__pyx_n_s_code_name_map
#define __pyx_n_s_coerce __pyx_mstate_global->__pyx_n_s_coerce
#define __pyx_n_s_cols_to_convert __pyx_mstate_global->__pyx_n_s_cols_to_convert
#define __pyx_n_s_column_dict __pyx_mstate_global->__pyx_n_s_column_dict
#define __pyx_n_s_column_name_dict __pyx_mstate_global->__pyx_n_s_column_name_dict
#define __pyx_n_s_columns __pyx_mstate_global->__pyx_n_s_columns
#define __pyx_n_s_concat __pyx_mstate_global->__pyx_n_s_concat
#define __pyx_n_s_csi __pyx_mstate_global->__pyx_n_s_csi
#define __pyx_n_s_csi931151 __pyx_mstate_global->__pyx_n_s_csi931151
#define __pyx_n_s_current_ratio __pyx_mstate_global->__pyx_n_s_current_ratio
#define __pyx_n_s_data __pyx_mstate_global->__pyx_n_s_data
#define __pyx_n_s_data_json __pyx_mstate_global->__pyx_n_s_data_json
#define __pyx_n_s_data_text __pyx_mstate_global->__pyx_n_s_data_text
#define __pyx_kp_s_data_x_pages_tp __pyx_mstate_global->__pyx_kp_s_data_x_pages_tp
#define __pyx_n_s_date __pyx_mstate_global->__pyx_n_s_date
#define __pyx_n_s_datetime __pyx_mstate_global->__pyx_n_s_datetime
#define __pyx_n_s_debt_to_asset_ratio __pyx_mstate_global->__pyx_n_s_debt_to_asset_ratio
#define __pyx_n_s_decode __pyx_mstate_global->__pyx_n_s_decode
#define __pyx_n_s_dect __pyx_mstate_global->__pyx_n_s_dect
#define __pyx_n_s_demjson __pyx_mstate_global->__pyx_n_s_demjson
#define __pyx_n_s_diff __pyx_mstate_global->__pyx_n_s_diff
#define __pyx_n_s_dim_date __pyx_mstate_global->__pyx_n_s_dim_date
#define __pyx_n_s_dlmkts __pyx_mstate_global->__pyx_n_s_dlmkts
#define __pyx_n_s_drop __pyx_mstate_global->__pyx_n_s_drop
#define __pyx_n_s_dt __pyx_mstate_global->__pyx_n_s_dt
#define __pyx_n_s_empty __pyx_mstate_global->__pyx_n_s_empty
#define __pyx_n_s_end __pyx_mstate_global->__pyx_n_s_end
#define __pyx_n_s_end_date __pyx_mstate_global->__pyx_n_s_end_date
#define __pyx_n_s_eps_jb __pyx_mstate_global->__pyx_n_s_eps_jb
#define __pyx_n_s_eps_kf __pyx_mstate_global->__pyx_n_s_eps_kf
#define __pyx_n_s_eps_xs __pyx_mstate_global->__pyx_n_s_eps_xs
#define __pyx_n_s_equity_multiplier __pyx_mstate_global->__pyx_n_s_equity_multiplier
#define __pyx_n_s_equity_ratio __pyx_mstate_global->__pyx_n_s_equity_ratio
#define __pyx_n_s_errors __pyx_mstate_global->__pyx_n_s_errors
#define __pyx_n_s_f116 __pyx_mstate_global->__pyx_n_s_f116
#define __pyx_n_s_f117 __pyx_mstate_global->__pyx_n_s_f117
#define __pyx_n_s_f12 __pyx_mstate_global->__pyx_n_s_f12
#define __pyx_kp_s_f120_f121_f122_f174_f175_f59_f16 __pyx_mstate_global->__pyx_kp_s_f120_f121_f122_f174_f175_f59_f16
#define __pyx_n_s_f127 __pyx_mstate_global->__pyx_n_s_f127
#define __pyx_n_s_f128 __pyx_mstate_global->__pyx_n_s_f128
#define __pyx_kp_s_f12_f14_f2_f4_f3_f17_f15_f16_f18 __pyx_mstate_global->__pyx_kp_s_f12_f14_f2_f4_f3_f17_f15_f16_f18
#define __pyx_n_s_f14 __pyx_mstate_global->__pyx_n_s_f14
#define __pyx_n_s_f15 __pyx_mstate_global->__pyx_n_s_f15
#define __pyx_n_s_f16 __pyx_mstate_global->__pyx_n_s_f16
#define __pyx_n_s_f17 __pyx_mstate_global->__pyx_n_s_f17
#define __pyx_n_s_f18 __pyx_mstate_global->__pyx_n_s_f18
#define __pyx_n_s_f189 __pyx_mstate_global->__pyx_n_s_f189
#define __pyx_kp_s_f1_f2_f3_f4_f5 __pyx_mstate_global->__pyx_kp_s_f1_f2_f3_f4_f5
#define __pyx_n_s_f2 __pyx_mstate_global->__pyx_n_s_f2
#define __pyx_kp_s_f2_01_CONVERT_STOCK_CODE_CONVERT __pyx_mstate_global->__pyx_kp_s_f2_01_CONVERT_STOCK_CODE_CONVERT
#define __pyx_n_s_f3 __pyx_mstate_global->__pyx_n_s_f3
#define __pyx_n_s_f4 __pyx_mstate_global->__pyx_n_s_f4
#define __pyx_n_s_f5 __pyx_mstate_global->__pyx_n_s_f5
#define __pyx_kp_s_f51_f52_f53_f54_f55_f56_f57_f58 __pyx_mstate_global->__pyx_kp_s_f51_f52_f53_f54_f55_f56_f57_f58
#define __pyx_n_s_f57 __pyx_mstate_global->__pyx_n_s_f57
#define __pyx_n_s_f58 __pyx_mstate_global->__pyx_n_s_f58
#define __pyx_n_s_f6 __pyx_mstate_global->__pyx_n_s_f6
#define __pyx_n_s_f84 __pyx_mstate_global->__pyx_n_s_f84
#define __pyx_n_s_f85 __pyx_mstate_global->__pyx_n_s_f85
#define __pyx_n_s_fa5fd1943c7b386f172d6893dbfba10b __pyx_mstate_global->__pyx_n_s_fa5fd1943c7b386f172d6893dbfba10b
#define __pyx_n_s_fid __pyx_mstate_global->__pyx_n_s_fid
#define __pyx_n_s_fields __pyx_mstate_global->__pyx_n_s_fields
#define __pyx_n_s_fields1 __pyx_mstate_global->__pyx_n_s_fields1
#define __pyx_n_s_fields2 __pyx_mstate_global->__pyx_n_s_fields2
#define __pyx_n_s_filter __pyx_mstate_global->__pyx_n_s_filter
#define __pyx_n_s_finance_mfd_quarter_df __pyx_mstate_global->__pyx_n_s_finance_mfd_quarter_df
#define __pyx_n_s_finance_mfd_report_df __pyx_mstate_global->__pyx_n_s_finance_mfd_report_df
#define __pyx_n_s_find __pyx_mstate_global->__pyx_n_s_find
#define __pyx_n_s_float __pyx_mstate_global->__pyx_n_s_float
#define __pyx_n_s_fltt __pyx_mstate_global->__pyx_n_s_fltt
#define __pyx_n_s_format __pyx_mstate_global->__pyx_n_s_format
#define __pyx_n_s_fqt __pyx_mstate_global->__pyx_n_s_fqt
#define __pyx_n_s_fs __pyx_mstate_global->__pyx_n_s_fs
#define __pyx_n_s_full __pyx_mstate_global->__pyx_n_s_full
#define __pyx_n_s_get __pyx_mstate_global->__pyx_n_s_get
#define __pyx_n_s_gross_profit __pyx_mstate_global->__pyx_n_s_gross_profit
#define __pyx_n_s_gross_profit_ratio __pyx_mstate_global->__pyx_n_s_gross_profit_ratio
#define __pyx_n_s_high __pyx_mstate_global->__pyx_n_s_high
#define __pyx_n_s_hold_amount __pyx_mstate_global->__pyx_n_s_hold_amount
#define __pyx_n_s_hold_focus __pyx_mstate_global->__pyx_n_s_hold_focus
#define __pyx_n_s_hold_volume __pyx_mstate_global->__pyx_n_s_hold_volume
#define __pyx_n_s_hold_volume_ratio __pyx_mstate_global->__pyx_n_s_hold_volume_ratio
#define __pyx_n_s_holder_num __pyx_mstate_global->__pyx_n_s_holder_num
#define __pyx_n_s_holder_num_ratio __pyx_mstate_global->__pyx_n_s_holder_num_ratio
#define __pyx_n_s_hs300_change_ratio __pyx_mstate_global->__pyx_n_s_hs300_change_ratio
#define __pyx_n_s_hs300_close __pyx_mstate_global->__pyx_n_s_hs300_close
#define __pyx_n_s_hsgt_history __pyx_mstate_global->__pyx_n_s_hsgt_history
#define __pyx_n_s_hsgt_history_df __pyx_mstate_global->__pyx_n_s_hsgt_history_df
#define __pyx_kp_s_http_push2_eastmoney_com_api_qt __pyx_mstate_global->__pyx_kp_s_http_push2_eastmoney_com_api_qt
#define __pyx_kp_s_https_38_push2_eastmoney_com_api __pyx_mstate_global->__pyx_kp_s_https_38_push2_eastmoney_com_api
#define __pyx_kp_s_https_89_push2_eastmoney_com_api __pyx_mstate_global->__pyx_kp_s_https_89_push2_eastmoney_com_api
#define __pyx_kp_s_https_datacenter_eastmoney_com_s __pyx_mstate_global->__pyx_kp_s_https_datacenter_eastmoney_com_s
#define __pyx_kp_s_https_datacenter_eastmoney_com_s_2 __pyx_mstate_global->__pyx_kp_s_https_datacenter_eastmoney_com_s_2
#define __pyx_kp_s_https_datacenter_web_eastmoney_c __pyx_mstate_global->__pyx_kp_s_https_datacenter_web_eastmoney_c
#define __pyx_kp_s_https_push2his_eastmoney_com_api __pyx_mstate_global->__pyx_kp_s_https_push2his_eastmoney_com_api
#define __pyx_n_s_ignore_index __pyx_mstate_global->__pyx_n_s_ignore_index
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_index __pyx_mstate_global->__pyx_n_s_index
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_inplace __pyx_mstate_global->__pyx_n_s_inplace
#define __pyx_n_s_insert __pyx_mstate_global->__pyx_n_s_insert
#define __pyx_n_s_invt __pyx_mstate_global->__pyx_n_s_invt
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_n_s_is_null_result __pyx_mstate_global->__pyx_n_s_is_null_result
#define __pyx_n_s_item __pyx_mstate_global->__pyx_n_s_item
#define __pyx_n_s_jQuery1124033485574041163946_159 __pyx_mstate_global->__pyx_n_s_jQuery1124033485574041163946_159
#define __pyx_n_s_js __pyx_mstate_global->__pyx_n_s_js
#define __pyx_n_s_json __pyx_mstate_global->__pyx_n_s_json
#define __pyx_n_s_jyjxjl_to_tor_ratio __pyx_mstate_global->__pyx_n_s_jyjxjl_to_tor_ratio
#define __pyx_n_s_keys __pyx_mstate_global->__pyx_n_s_keys
#define __pyx_n_s_kf_net_profit __pyx_mstate_global->__pyx_n_s_kf_net_profit
#define __pyx_n_s_kf_net_profit_hb __pyx_mstate_global->__pyx_n_s_kf_net_profit_hb
#define __pyx_n_s_kf_net_profit_tb __pyx_mstate_global->__pyx_n_s_kf_net_profit_tb
#define __pyx_n_s_klines __pyx_mstate_global->__pyx_n_s_klines
#define __pyx_n_s_klt __pyx_mstate_global->__pyx_n_s_klt
#define __pyx_n_s_kzz_all_df __pyx_mstate_global->__pyx_n_s_kzz_all_df
#define __pyx_n_s_kzz_basic_info_em __pyx_mstate_global->__pyx_n_s_kzz_basic_info_em
#define __pyx_n_s_kzz_sh_em_df __pyx_mstate_global->__pyx_n_s_kzz_sh_em_df
#define __pyx_n_s_kzz_sh_trade_day_info_em __pyx_mstate_global->__pyx_n_s_kzz_sh_trade_day_info_em
#define __pyx_n_s_kzz_sz_em_df __pyx_mstate_global->__pyx_n_s_kzz_sz_em_df
#define __pyx_n_s_kzz_sz_trade_day_info_em __pyx_mstate_global->__pyx_n_s_kzz_sz_trade_day_info_em
#define __pyx_n_s_kzz_trade_day_df __pyx_mstate_global->__pyx_n_s_kzz_trade_day_df
#define __pyx_n_s_kzz_trade_day_em_df __pyx_mstate_global->__pyx_n_s_kzz_trade_day_em_df
#define __pyx_n_s_kzz_trade_day_info_em __pyx_mstate_global->__pyx_n_s_kzz_trade_day_info_em
#define __pyx_n_s_latest_trade_day __pyx_mstate_global->__pyx_n_s_latest_trade_day
#define __pyx_n_s_low __pyx_mstate_global->__pyx_n_s_low
#define __pyx_n_s_lt __pyx_mstate_global->__pyx_n_s_lt
#define __pyx_kp_s_m_0_b_MK0354 __pyx_mstate_global->__pyx_kp_s_m_0_b_MK0354
#define __pyx_kp_s_m_1_b_MK0354 __pyx_mstate_global->__pyx_kp_s_m_1_b_MK0354
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_map __pyx_mstate_global->__pyx_n_s_map
#define __pyx_n_s_market_map __pyx_mstate_global->__pyx_n_s_market_map
#define __pyx_n_s_math __pyx_mstate_global->__pyx_n_s_math
#define __pyx_n_s_mode __pyx_mstate_global->__pyx_n_s_mode
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_s_net_amount __pyx_mstate_global->__pyx_n_s_net_amount
#define __pyx_n_s_net_cash_ps __pyx_mstate_global->__pyx_n_s_net_cash_ps
#define __pyx_n_s_net_profit_ratio __pyx_mstate_global->__pyx_n_s_net_profit_ratio
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_n_s_notice_date __pyx_mstate_global->__pyx_n_s_notice_date
#define __pyx_n_s_notna __pyx_mstate_global->__pyx_n_s_notna
#define __pyx_n_s_np __pyx_mstate_global->__pyx_n_s_np
#define __pyx_n_s_open __pyx_mstate_global->__pyx_n_s_open
#define __pyx_n_s_p __pyx_mstate_global->__pyx_n_s_p
#define __pyx_n_s_page __pyx_mstate_global->__pyx_n_s_page
#define __pyx_n_s_pageNo __pyx_mstate_global->__pyx_n_s_pageNo
#define __pyx_n_s_pageNum __pyx_mstate_global->__pyx_n_s_pageNum
#define __pyx_n_s_pageNumber __pyx_mstate_global->__pyx_n_s_pageNumber
#define __pyx_n_s_pageSize __pyx_mstate_global->__pyx_n_s_pageSize
#define __pyx_n_s_pages __pyx_mstate_global->__pyx_n_s_pages
#define __pyx_n_s_pandas __pyx_mstate_global->__pyx_n_s_pandas
#define __pyx_n_s_params __pyx_mstate_global->__pyx_n_s_params
#define __pyx_n_s_parent_net_profit __pyx_mstate_global->__pyx_n_s_parent_net_profit
#define __pyx_n_s_parent_net_profit_hb __pyx_mstate_global->__pyx_n_s_parent_net_profit_hb
#define __pyx_n_s_parent_net_profit_tb __pyx_mstate_global->__pyx_n_s_parent_net_profit_tb
#define __pyx_n_s_pd __pyx_mstate_global->__pyx_n_s_pd
#define __pyx_kp_s_pd_DataFrame __pyx_mstate_global->__pyx_kp_s_pd_DataFrame
#define __pyx_n_s_pn __pyx_mstate_global->__pyx_n_s_pn
#define __pyx_n_s_po __pyx_mstate_global->__pyx_n_s_po
#define __pyx_n_s_pre_close __pyx_mstate_global->__pyx_n_s_pre_close
#define __pyx_n_s_price __pyx_mstate_global->__pyx_n_s_price
#define __pyx_n_s_price_change __pyx_mstate_global->__pyx_n_s_price_change
#define __pyx_n_s_price_ratio __pyx_mstate_global->__pyx_n_s_price_ratio
#define __pyx_n_s_print __pyx_mstate_global->__pyx_n_s_print
#define __pyx_n_s_ps __pyx_mstate_global->__pyx_n_s_ps
#define __pyx_n_s_pub_date __pyx_mstate_global->__pyx_n_s_pub_date
#define __pyx_n_s_pz __pyx_mstate_global->__pyx_n_s_pz
#define __pyx_n_s_quick_ratio __pyx_mstate_global->__pyx_n_s_quick_ratio
#define __pyx_n_s_quoteColumns __pyx_mstate_global->__pyx_n_s_quoteColumns
#define __pyx_n_s_quoteType __pyx_mstate_global->__pyx_n_s_quoteType
#define __pyx_n_s_r __pyx_mstate_global->__pyx_n_s_r
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_rc __pyx_mstate_global->__pyx_n_s_rc
#define __pyx_n_s_replace __pyx_mstate_global->__pyx_n_s_replace
#define __pyx_n_s_reportName __pyx_mstate_global->__pyx_n_s_reportName
#define __pyx_n_s_report_date __pyx_mstate_global->__pyx_n_s_report_date
#define __pyx_n_s_requests __pyx_mstate_global->__pyx_n_s_requests
#define __pyx_n_s_reset_index __pyx_mstate_global->__pyx_n_s_reset_index
#define __pyx_n_s_result __pyx_mstate_global->__pyx_n_s_result
#define __pyx_n_s_return __pyx_mstate_global->__pyx_n_s_return
#define __pyx_n_s_roe_jzc __pyx_mstate_global->__pyx_n_s_roe_jzc
#define __pyx_n_s_roe_zzc __pyx_mstate_global->__pyx_n_s_roe_zzc
#define __pyx_n_s_rqchl __pyx_mstate_global->__pyx_n_s_rqchl
#define __pyx_n_s_rqjmg __pyx_mstate_global->__pyx_n_s_rqjmg
#define __pyx_n_s_rqmcl __pyx_mstate_global->__pyx_n_s_rqmcl
#define __pyx_n_s_rqye __pyx_mstate_global->__pyx_n_s_rqye
#define __pyx_n_s_rqyl __pyx_mstate_global->__pyx_n_s_rqyl
#define __pyx_n_s_rt __pyx_mstate_global->__pyx_n_s_rt
#define __pyx_n_s_rzche __pyx_mstate_global->__pyx_n_s_rzche
#define __pyx_n_s_rzjme __pyx_mstate_global->__pyx_n_s_rzjme
#define __pyx_n_s_rzmre __pyx_mstate_global->__pyx_n_s_rzmre
#define __pyx_n_s_rzrq_history __pyx_mstate_global->__pyx_n_s_rzrq_history
#define __pyx_n_s_rzrq_history_df __pyx_mstate_global->__pyx_n_s_rzrq_history_df
#define __pyx_n_s_rzrqye __pyx_mstate_global->__pyx_n_s_rzrqye
#define __pyx_n_s_rzye __pyx_mstate_global->__pyx_n_s_rzye
#define __pyx_n_s_rzyezb __pyx_mstate_global->__pyx_n_s_rzyezb
#define __pyx_kp_u_scode __pyx_mstate_global->__pyx_kp_u_scode
#define __pyx_n_s_secid __pyx_mstate_global->__pyx_n_s_secid
#define __pyx_n_s_sell_amount __pyx_mstate_global->__pyx_n_s_sell_amount
#define __pyx_n_s_sh __pyx_mstate_global->__pyx_n_s_sh
#define __pyx_n_s_sortColumns __pyx_mstate_global->__pyx_n_s_sortColumns
#define __pyx_n_s_sortTypes __pyx_mstate_global->__pyx_n_s_sortTypes
#define __pyx_n_s_source __pyx_mstate_global->__pyx_n_s_source
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_split __pyx_mstate_global->__pyx_n_s_split
#define __pyx_n_s_sr __pyx_mstate_global->__pyx_n_s_sr
#define __pyx_n_s_sse_index_change_ratio __pyx_mstate_global->__pyx_n_s_sse_index_change_ratio
#define __pyx_n_s_sse_index_close __pyx_mstate_global->__pyx_n_s_sse_index_close
#define __pyx_n_s_st __pyx_mstate_global->__pyx_n_s_st
#define __pyx_n_s_start_date __pyx_mstate_global->__pyx_n_s_start_date
#define __pyx_n_s_stock_all_hsgt_date __pyx_mstate_global->__pyx_n_s_stock_all_hsgt_date
#define __pyx_n_s_stock_all_rzrq_date __pyx_mstate_global->__pyx_n_s_stock_all_rzrq_date
#define __pyx_n_s_stock_code __pyx_mstate_global->__pyx_n_s_stock_code
#define __pyx_n_s_stock_fhps_detail_em __pyx_mstate_global->__pyx_n_s_stock_fhps_detail_em
#define __pyx_n_s_stock_finance_mfd_quarter_em __pyx_mstate_global->__pyx_n_s_stock_finance_mfd_quarter_em
#define __pyx_n_s_stock_finance_mfd_report_em __pyx_mstate_global->__pyx_n_s_stock_finance_mfd_report_em
#define __pyx_n_s_stock_gdhs_df __pyx_mstate_global->__pyx_n_s_stock_gdhs_df
#define __pyx_n_s_stock_hsgt_detail __pyx_mstate_global->__pyx_n_s_stock_hsgt_detail
#define __pyx_n_s_stock_hsgt_df __pyx_mstate_global->__pyx_n_s_stock_hsgt_df
#define __pyx_n_s_stock_hsgt_today_df __pyx_mstate_global->__pyx_n_s_stock_hsgt_today_df
#define __pyx_n_s_stock_individual_info_em __pyx_mstate_global->__pyx_n_s_stock_individual_info_em
#define __pyx_n_s_stock_name __pyx_mstate_global->__pyx_n_s_stock_name
#define __pyx_n_s_stock_rzrq_detail __pyx_mstate_global->__pyx_n_s_stock_rzrq_detail
#define __pyx_n_s_stock_rzrq_df __pyx_mstate_global->__pyx_n_s_stock_rzrq_df
#define __pyx_n_s_stock_rzrq_today_df __pyx_mstate_global->__pyx_n_s_stock_rzrq_today_df
#define __pyx_n_s_stock_zh_a_gdhs_detail_em __pyx_mstate_global->__pyx_n_s_stock_zh_a_gdhs_detail_em
#define __pyx_n_s_stock_zh_index_daily_em __pyx_mstate_global->__pyx_n_s_stock_zh_index_daily_em
#define __pyx_n_s_str __pyx_mstate_global->__pyx_n_s_str
#define __pyx_n_s_strptime __pyx_mstate_global->__pyx_n_s_strptime
#define __pyx_n_s_sty __pyx_mstate_global->__pyx_n_s_sty
#define __pyx_n_s_svr __pyx_mstate_global->__pyx_n_s_svr
#define __pyx_n_s_symbol __pyx_mstate_global->__pyx_n_s_symbol
#define __pyx_n_s_sz __pyx_mstate_global->__pyx_n_s_sz
#define __pyx_n_s_tax_rate __pyx_mstate_global->__pyx_n_s_tax_rate
#define __pyx_kp_s_tbstock_dataAcquisition_stockDat __pyx_mstate_global->__pyx_kp_s_tbstock_dataAcquisition_stockDat
#define __pyx_n_s_tbstock_dataAcquisition_stockDat_2 __pyx_mstate_global->__pyx_n_s_tbstock_dataAcquisition_stockDat_2
#define __pyx_n_s_tbstock_utils __pyx_mstate_global->__pyx_n_s_tbstock_utils
#define __pyx_n_s_temp_df __pyx_mstate_global->__pyx_n_s_temp_df
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_test_2 __pyx_mstate_global->__pyx_n_s_test_2
#define __pyx_n_s_text __pyx_mstate_global->__pyx_n_s_text
#define __pyx_n_s_timeout __pyx_mstate_global->__pyx_n_s_timeout
#define __pyx_n_s_to_datetime __pyx_mstate_global->__pyx_n_s_to_datetime
#define __pyx_n_s_to_numeric __pyx_mstate_global->__pyx_n_s_to_numeric
#define __pyx_n_s_top_ten_ratio_free __pyx_mstate_global->__pyx_n_s_top_ten_ratio_free
#define __pyx_n_s_top_ten_ratio_total __pyx_mstate_global->__pyx_n_s_top_ten_ratio_total
#define __pyx_n_s_total __pyx_mstate_global->__pyx_n_s_total
#define __pyx_n_s_total_item __pyx_mstate_global->__pyx_n_s_total_item
#define __pyx_n_s_total_operate_revenue __pyx_mstate_global->__pyx_n_s_total_operate_revenue
#define __pyx_n_s_total_operate_revenue_hb __pyx_mstate_global->__pyx_n_s_total_operate_revenue_hb
#define __pyx_n_s_total_operate_revenue_tb __pyx_mstate_global->__pyx_n_s_total_operate_revenue_tb
#define __pyx_n_s_total_pages __pyx_mstate_global->__pyx_n_s_total_pages
#define __pyx_n_s_trade_date __pyx_mstate_global->__pyx_n_s_trade_date
#define __pyx_n_s_transfer_price __pyx_mstate_global->__pyx_n_s_transfer_price
#define __pyx_n_s_transfer_value __pyx_mstate_global->__pyx_n_s_transfer_value
#define __pyx_n_s_type __pyx_mstate_global->__pyx_n_s_type
#define __pyx_n_s_unassign_profit_ps __pyx_mstate_global->__pyx_n_s_unassign_profit_ps
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_url __pyx_mstate_global->__pyx_n_s_url
#define __pyx_n_s_ut __pyx_mstate_global->__pyx_n_s_ut
#define __pyx_n_s_utils __pyx_mstate_global->__pyx_n_s_utils
#define __pyx_n_s_v __pyx_mstate_global->__pyx_n_s_v
#define __pyx_n_s_value __pyx_mstate_global->__pyx_n_s_value
#define __pyx_n_s_values __pyx_mstate_global->__pyx_n_s_values
#define __pyx_n_s_volume __pyx_mstate_global->__pyx_n_s_volume
#define __pyx_n_s_wbp2u __pyx_mstate_global->__pyx_n_s_wbp2u
#define __pyx_n_s_xsjxjl_to_tor_ratio __pyx_mstate_global->__pyx_n_s_xsjxjl_to_tor_ratio
#define __pyx_n_s_yszk_to_tor_ratio __pyx_mstate_global->__pyx_n_s_yszk_to_tor_ratio
#define __pyx_n_s_yszk_zzl __pyx_mstate_global->__pyx_n_s_yszk_zzl
#define __pyx_n_s_yszk_zzts __pyx_mstate_global->__pyx_n_s_yszk_zzts
#define __pyx_n_s_zzc_zzl __pyx_mstate_global->__pyx_n_s_zzc_zzl
#define __pyx_n_s_zzc_zzts __pyx_mstate_global->__pyx_n_s_zzc_zzts
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_2 __pyx_mstate_global->__pyx_int_2
#define __pyx_int_3 __pyx_mstate_global->__pyx_int_3
#define __pyx_int_4 __pyx_mstate_global->__pyx_int_4
#define __pyx_int_5 __pyx_mstate_global->__pyx_int_5
#define __pyx_int_25 __pyx_mstate_global->__pyx_int_25
#define __pyx_int_50 __pyx_mstate_global->__pyx_int_50
#define __pyx_int_500 __pyx_mstate_global->__pyx_int_500
#define __pyx_int_neg_1 __pyx_mstate_global->__pyx_int_neg_1
#define __pyx_slice__6 __pyx_mstate_global->__pyx_slice__6
#define __pyx_slice__8 __pyx_mstate_global->__pyx_slice__8
#define __pyx_slice__21 __pyx_mstate_global->__pyx_slice__21
#define __pyx_slice__61 __pyx_mstate_global->__pyx_slice__61
#define __pyx_tuple__91 __pyx_mstate_global->__pyx_tuple__91
#define __pyx_tuple__93 __pyx_mstate_global->__pyx_tuple__93
#define __pyx_tuple__94 __pyx_mstate_global->__pyx_tuple__94
#define __pyx_tuple__96 __pyx_mstate_global->__pyx_tuple__96
#define __pyx_tuple__97 __pyx_mstate_global->__pyx_tuple__97
#define __pyx_tuple__99 __pyx_mstate_global->__pyx_tuple__99
#define __pyx_tuple__100 __pyx_mstate_global->__pyx_tuple__100
#define __pyx_tuple__102 __pyx_mstate_global->__pyx_tuple__102
#define __pyx_tuple__103 __pyx_mstate_global->__pyx_tuple__103
#define __pyx_tuple__105 __pyx_mstate_global->__pyx_tuple__105
#define __pyx_tuple__107 __pyx_mstate_global->__pyx_tuple__107
#define __pyx_tuple__109 __pyx_mstate_global->__pyx_tuple__109
#define __pyx_tuple__111 __pyx_mstate_global->__pyx_tuple__111
#define __pyx_tuple__112 __pyx_mstate_global->__pyx_tuple__112
#define __pyx_tuple__114 __pyx_mstate_global->__pyx_tuple__114
#define __pyx_tuple__115 __pyx_mstate_global->__pyx_tuple__115
#define __pyx_tuple__117 __pyx_mstate_global->__pyx_tuple__117
#define __pyx_tuple__119 __pyx_mstate_global->__pyx_tuple__119
#define __pyx_tuple__120 __pyx_mstate_global->__pyx_tuple__120
#define __pyx_tuple__122 __pyx_mstate_global->__pyx_tuple__122
#define __pyx_tuple__123 __pyx_mstate_global->__pyx_tuple__123
#define __pyx_tuple__126 __pyx_mstate_global->__pyx_tuple__126
#define __pyx_tuple__128 __pyx_mstate_global->__pyx_tuple__128
#define __pyx_tuple__130 __pyx_mstate_global->__pyx_tuple__130
#define __pyx_codeobj__92 __pyx_mstate_global->__pyx_codeobj__92
#define __pyx_codeobj__95 __pyx_mstate_global->__pyx_codeobj__95
#define __pyx_codeobj__98 __pyx_mstate_global->__pyx_codeobj__98
#define __pyx_codeobj__101 __pyx_mstate_global->__pyx_codeobj__101
#define __pyx_codeobj__104 __pyx_mstate_global->__pyx_codeobj__104
#define __pyx_codeobj__106 __pyx_mstate_global->__pyx_codeobj__106
#define __pyx_codeobj__108 __pyx_mstate_global->__pyx_codeobj__108
#define __pyx_codeobj__110 __pyx_mstate_global->__pyx_codeobj__110
#define __pyx_codeobj__113 __pyx_mstate_global->__pyx_codeobj__113
#define __pyx_codeobj__116 __pyx_mstate_global->__pyx_codeobj__116
#define __pyx_codeobj__118 __pyx_mstate_global->__pyx_codeobj__118
#define __pyx_codeobj__121 __pyx_mstate_global->__pyx_codeobj__121
#define __pyx_codeobj__124 __pyx_mstate_global->__pyx_codeobj__124
#define __pyx_codeobj__125 __pyx_mstate_global->__pyx_codeobj__125
#define __pyx_codeobj__127 __pyx_mstate_global->__pyx_codeobj__127
#define __pyx_codeobj__129 __pyx_mstate_global->__pyx_codeobj__129
#define __pyx_codeobj__131 __pyx_mstate_global->__pyx_codeobj__131
/* #### Code section: module_code ### */

/* "tbstock/dataAcquisition/stockDataCrawler.py":17
 * 
 * 
 * def stock_zh_index_daily_em(             # <<<<<<<<<<<<<<
 *         symbol: str = "csi931151",
 *         start_date: str = "19900101",
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_1stock_zh_index_daily_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_stock_zh_index_daily_em, "\n    \344\270\234\346\226\271\350\264\242\345\257\214\347\275\221-\350\202\241\347\245\250\346\214\207\346\225\260\346\225\260\346\215\256\n    https://quote.eastmoney.com/center/hszs.html\n    :param symbol: \345\270\246\345\270\202\345\234\272\346\240\207\350\257\206\347\232\204\346\214\207\346\225\260\344\273\243\347\240\201; sz: \346\267\261\344\272\244\346\211\200, sh: \344\270\212\344\272\244\346\211\200, csi: \344\270\255\344\277\241\346\214\207\346\225\260 + id(000905)\n    :type symbol: str\n    :param start_date: \345\274\200\345\247\213\346\227\266\351\227\264\n    :type start_date: str\n    :param end_date: \347\273\223\346\235\237\346\227\266\351\227\264\n    :type end_date: str\n    :return: \346\214\207\346\225\260\346\225\260\346\215\256\n    :rtype: pandas.DataFrame\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_1stock_zh_index_daily_em = {"stock_zh_index_daily_em", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_1stock_zh_index_daily_em, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_stock_zh_index_daily_em};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_1stock_zh_index_daily_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_start_date = 0;
  PyObject *__pyx_v_end_date = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_zh_index_daily_em (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_symbol,&__pyx_n_s_start_date,&__pyx_n_s_end_date,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_n_s_csi931151)));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_kp_s_19900101)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_kp_s_20500101)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 17, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_start_date);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 17, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_end_date);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 17, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_zh_index_daily_em") < 0)) __PYX_ERR(0, 17, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_symbol = ((PyObject*)values[0]);
    __pyx_v_start_date = ((PyObject*)values[1]);
    __pyx_v_end_date = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_zh_index_daily_em", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 17, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_zh_index_daily_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_symbol), (&PyString_Type), 0, "symbol", 1))) __PYX_ERR(0, 18, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_start_date), (&PyString_Type), 0, "start_date", 1))) __PYX_ERR(0, 19, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_end_date), (&PyString_Type), 0, "end_date", 1))) __PYX_ERR(0, 20, __pyx_L1_error)
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_stock_zh_index_daily_em(__pyx_self, __pyx_v_symbol, __pyx_v_start_date, __pyx_v_end_date);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_stock_zh_index_daily_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_start_date, PyObject *__pyx_v_end_date) {
  PyObject *__pyx_v_market_map = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_secid = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_text = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_7genexpr__pyx_v_item = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_zh_index_daily_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":34
 *     :rtype: pandas.DataFrame
 *     """
 *     market_map = {"sz": "0", "sh": "1", "csi": "2"}             # <<<<<<<<<<<<<<
 *     url = "https://push2his.eastmoney.com/api/qt/stock/kline/get"
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sz, __pyx_kp_s_0) < 0) __PYX_ERR(0, 34, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sh, __pyx_kp_s_1) < 0) __PYX_ERR(0, 34, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_csi, __pyx_kp_s_2) < 0) __PYX_ERR(0, 34, __pyx_L1_error)
  __pyx_v_market_map = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":35
 *     """
 *     market_map = {"sz": "0", "sh": "1", "csi": "2"}
 *     url = "https://push2his.eastmoney.com/api/qt/stock/kline/get"             # <<<<<<<<<<<<<<
 * 
 *     if symbol.find("sz") != -1:
 */
  __Pyx_INCREF(__pyx_kp_s_https_push2his_eastmoney_com_api);
  __pyx_v_url = __pyx_kp_s_https_push2his_eastmoney_com_api;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":37
 *     url = "https://push2his.eastmoney.com/api/qt/stock/kline/get"
 * 
 *     if symbol.find("sz") != -1:             # <<<<<<<<<<<<<<
 *         secid = "{}.{}".format(market_map["sz"], symbol.replace("sz", ""))
 *     elif symbol.find("0.") != -1:
 */
  __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyString_Type_find, __pyx_v_symbol, __pyx_n_s_sz); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyInt_BoolNeObjC(__pyx_t_1, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":38
 * 
 *     if symbol.find("sz") != -1:
 *         secid = "{}.{}".format(market_map["sz"], symbol.replace("sz", ""))             # <<<<<<<<<<<<<<
 *     elif symbol.find("0.") != -1:
 *         secid = symbol
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 38, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_market_map, __pyx_n_s_sz); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 38, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyString_Type_replace, __pyx_v_symbol, __pyx_n_s_sz, __pyx_kp_s__2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 38, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_4, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 38, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_secid = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":37
 *     url = "https://push2his.eastmoney.com/api/qt/stock/kline/get"
 * 
 *     if symbol.find("sz") != -1:             # <<<<<<<<<<<<<<
 *         secid = "{}.{}".format(market_map["sz"], symbol.replace("sz", ""))
 *     elif symbol.find("0.") != -1:
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":39
 *     if symbol.find("sz") != -1:
 *         secid = "{}.{}".format(market_map["sz"], symbol.replace("sz", ""))
 *     elif symbol.find("0.") != -1:             # <<<<<<<<<<<<<<
 *         secid = symbol
 *     elif symbol.find("sh") != -1:
 */
  __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyString_Type_find, __pyx_v_symbol, __pyx_kp_s_0_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyInt_BoolNeObjC(__pyx_t_1, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":40
 *         secid = "{}.{}".format(market_map["sz"], symbol.replace("sz", ""))
 *     elif symbol.find("0.") != -1:
 *         secid = symbol             # <<<<<<<<<<<<<<
 *     elif symbol.find("sh") != -1:
 *         secid = "{}.{}".format(market_map["sh"], symbol.replace("sh", ""))
 */
    __Pyx_INCREF(__pyx_v_symbol);
    __pyx_v_secid = __pyx_v_symbol;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":39
 *     if symbol.find("sz") != -1:
 *         secid = "{}.{}".format(market_map["sz"], symbol.replace("sz", ""))
 *     elif symbol.find("0.") != -1:             # <<<<<<<<<<<<<<
 *         secid = symbol
 *     elif symbol.find("sh") != -1:
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":41
 *     elif symbol.find("0.") != -1:
 *         secid = symbol
 *     elif symbol.find("sh") != -1:             # <<<<<<<<<<<<<<
 *         secid = "{}.{}".format(market_map["sh"], symbol.replace("sh", ""))
 *     elif symbol.find("1.") != -1:
 */
  __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyString_Type_find, __pyx_v_symbol, __pyx_n_s_sh); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyInt_BoolNeObjC(__pyx_t_1, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":42
 *         secid = symbol
 *     elif symbol.find("sh") != -1:
 *         secid = "{}.{}".format(market_map["sh"], symbol.replace("sh", ""))             # <<<<<<<<<<<<<<
 *     elif symbol.find("1.") != -1:
 *         secid = symbol
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_market_map, __pyx_n_s_sh); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 42, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyString_Type_replace, __pyx_v_symbol, __pyx_n_s_sh, __pyx_kp_s__2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 42, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_5, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 42, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_secid = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":41
 *     elif symbol.find("0.") != -1:
 *         secid = symbol
 *     elif symbol.find("sh") != -1:             # <<<<<<<<<<<<<<
 *         secid = "{}.{}".format(market_map["sh"], symbol.replace("sh", ""))
 *     elif symbol.find("1.") != -1:
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":43
 *     elif symbol.find("sh") != -1:
 *         secid = "{}.{}".format(market_map["sh"], symbol.replace("sh", ""))
 *     elif symbol.find("1.") != -1:             # <<<<<<<<<<<<<<
 *         secid = symbol
 *     elif symbol.find("csi") != -1:
 */
  __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyString_Type_find, __pyx_v_symbol, __pyx_kp_s_1_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyInt_BoolNeObjC(__pyx_t_1, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":44
 *         secid = "{}.{}".format(market_map["sh"], symbol.replace("sh", ""))
 *     elif symbol.find("1.") != -1:
 *         secid = symbol             # <<<<<<<<<<<<<<
 *     elif symbol.find("csi") != -1:
 *         secid = "{}.{}".format(market_map["csi"], symbol.replace("csi", ""))
 */
    __Pyx_INCREF(__pyx_v_symbol);
    __pyx_v_secid = __pyx_v_symbol;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":43
 *     elif symbol.find("sh") != -1:
 *         secid = "{}.{}".format(market_map["sh"], symbol.replace("sh", ""))
 *     elif symbol.find("1.") != -1:             # <<<<<<<<<<<<<<
 *         secid = symbol
 *     elif symbol.find("csi") != -1:
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":45
 *     elif symbol.find("1.") != -1:
 *         secid = symbol
 *     elif symbol.find("csi") != -1:             # <<<<<<<<<<<<<<
 *         secid = "{}.{}".format(market_map["csi"], symbol.replace("csi", ""))
 *     elif symbol.find("2.") != -1:
 */
  __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyString_Type_find, __pyx_v_symbol, __pyx_n_s_csi); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyInt_BoolNeObjC(__pyx_t_1, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":46
 *         secid = symbol
 *     elif symbol.find("csi") != -1:
 *         secid = "{}.{}".format(market_map["csi"], symbol.replace("csi", ""))             # <<<<<<<<<<<<<<
 *     elif symbol.find("2.") != -1:
 *         secid = symbol
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_market_map, __pyx_n_s_csi); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyString_Type_replace, __pyx_v_symbol, __pyx_n_s_csi, __pyx_kp_s__2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_4, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 46, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_secid = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":45
 *     elif symbol.find("1.") != -1:
 *         secid = symbol
 *     elif symbol.find("csi") != -1:             # <<<<<<<<<<<<<<
 *         secid = "{}.{}".format(market_map["csi"], symbol.replace("csi", ""))
 *     elif symbol.find("2.") != -1:
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":47
 *     elif symbol.find("csi") != -1:
 *         secid = "{}.{}".format(market_map["csi"], symbol.replace("csi", ""))
 *     elif symbol.find("2.") != -1:             # <<<<<<<<<<<<<<
 *         secid = symbol
 *     else:
 */
  __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyString_Type_find, __pyx_v_symbol, __pyx_kp_s_2_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyInt_BoolNeObjC(__pyx_t_1, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":48
 *         secid = "{}.{}".format(market_map["csi"], symbol.replace("csi", ""))
 *     elif symbol.find("2.") != -1:
 *         secid = symbol             # <<<<<<<<<<<<<<
 *     else:
 *         return pd.DataFrame()
 */
    __Pyx_INCREF(__pyx_v_symbol);
    __pyx_v_secid = __pyx_v_symbol;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":47
 *     elif symbol.find("csi") != -1:
 *         secid = "{}.{}".format(market_map["csi"], symbol.replace("csi", ""))
 *     elif symbol.find("2.") != -1:             # <<<<<<<<<<<<<<
 *         secid = symbol
 *     else:
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":50
 *         secid = symbol
 *     else:
 *         return pd.DataFrame()             # <<<<<<<<<<<<<<
 *     params = {
 *         "cb": "jQuery1124033485574041163946_1596700547000",
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 50, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":52
 *         return pd.DataFrame()
 *     params = {
 *         "cb": "jQuery1124033485574041163946_1596700547000",             # <<<<<<<<<<<<<<
 *         "secid": secid,
 *         "ut": "fa5fd1943c7b386f172d6893dbfba10b",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_cb, __pyx_n_s_jQuery1124033485574041163946_159) < 0) __PYX_ERR(0, 52, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":53
 *     params = {
 *         "cb": "jQuery1124033485574041163946_1596700547000",
 *         "secid": secid,             # <<<<<<<<<<<<<<
 *         "ut": "fa5fd1943c7b386f172d6893dbfba10b",
 *         "fields1": "f1,f2,f3,f4,f5",
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_secid, __pyx_v_secid) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ut, __pyx_n_s_fa5fd1943c7b386f172d6893dbfba10b) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fields1, __pyx_kp_s_f1_f2_f3_f4_f5) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fields2, __pyx_kp_s_f51_f52_f53_f54_f55_f56_f57_f58) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_klt, __pyx_kp_s_101) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fqt, __pyx_kp_s_0) < 0) __PYX_ERR(0, 52, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":59
 *         "klt": "101",  #
 *         "fqt": "0",
 *         "beg": start_date,             # <<<<<<<<<<<<<<
 *         "end": end_date,
 *         "_": "1596700547039",
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_beg, __pyx_v_start_date) < 0) __PYX_ERR(0, 52, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":60
 *         "fqt": "0",
 *         "beg": start_date,
 *         "end": end_date,             # <<<<<<<<<<<<<<
 *         "_": "1596700547039",
 *     }
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_end, __pyx_v_end_date) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s__3, __pyx_kp_s_1596700547039) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":63
 *         "_": "1596700547039",
 *     }
 *     r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *     data_text = r.text
 *     data_json = demjson.decode(data_text[data_text.find("{"): -2])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 63, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 63, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_r = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":64
 *     }
 *     r = requests.get(url, params=params)
 *     data_text = r.text             # <<<<<<<<<<<<<<
 *     data_json = demjson.decode(data_text[data_text.find("{"): -2])
 *     temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]["klines"]])
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_data_text = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":65
 *     r = requests.get(url, params=params)
 *     data_text = r.text
 *     data_json = demjson.decode(data_text[data_text.find("{"): -2])             # <<<<<<<<<<<<<<
 *     temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]["klines"]])
 *     # check temp_df data availability before further transformations which may raise errors
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_demjson); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_decode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_data_text, __pyx_n_s_find); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_s__4};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_data_text, 0, -2L, &__pyx_t_3, NULL, NULL, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_data_json = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":66
 *     data_text = r.text
 *     data_json = demjson.decode(data_text[data_text.find("{"): -2])
 *     temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]["klines"]])             # <<<<<<<<<<<<<<
 *     # check temp_df data availability before further transformations which may raise errors
 *     if temp_df.empty:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 66, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 66, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_s_klines); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 66, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
      __pyx_t_3 = __pyx_t_6; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 66, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 66, __pyx_L6_error)
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 66, __pyx_L6_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_6); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 66, __pyx_L6_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 66, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 66, __pyx_L6_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_6); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 66, __pyx_L6_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 66, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_9(__pyx_t_3);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 66, __pyx_L6_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_item, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_7genexpr__pyx_v_item, __pyx_n_s_split); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 66, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_kp_s__5};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 66, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 66, __pyx_L6_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_item); __pyx_7genexpr__pyx_v_item = 0;
    goto __pyx_L10_exit_scope;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_item); __pyx_7genexpr__pyx_v_item = 0;
    goto __pyx_L1_error;
    __pyx_L10_exit_scope:;
  } /* exit inner scope */
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_1};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_v_temp_df = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":68
 *     temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]["klines"]])
 *     # check temp_df data availability before further transformations which may raise errors
 *     if temp_df.empty:             # <<<<<<<<<<<<<<
 *         return pd.DataFrame()
 *     temp_df.columns = ["date", "open", "close", "high", "low", "volume", "amount", "_"]
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_temp_df, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":69
 *     # check temp_df data availability before further transformations which may raise errors
 *     if temp_df.empty:
 *         return pd.DataFrame()             # <<<<<<<<<<<<<<
 *     temp_df.columns = ["date", "open", "close", "high", "low", "volume", "amount", "_"]
 *     temp_df = temp_df[["date", "open", "close", "high", "low", "volume", "amount"]]
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 69, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":68
 *     temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]["klines"]])
 *     # check temp_df data availability before further transformations which may raise errors
 *     if temp_df.empty:             # <<<<<<<<<<<<<<
 *         return pd.DataFrame()
 *     temp_df.columns = ["date", "open", "close", "high", "low", "volume", "amount", "_"]
 */
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":70
 *     if temp_df.empty:
 *         return pd.DataFrame()
 *     temp_df.columns = ["date", "open", "close", "high", "low", "volume", "amount", "_"]             # <<<<<<<<<<<<<<
 *     temp_df = temp_df[["date", "open", "close", "high", "low", "volume", "amount"]]
 *     temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
 */
  __pyx_t_4 = PyList_New(8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_n_s_date);
  __Pyx_GIVEREF(__pyx_n_s_date);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_date)) __PYX_ERR(0, 70, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_open);
  __Pyx_GIVEREF(__pyx_n_s_open);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 1, __pyx_n_s_open)) __PYX_ERR(0, 70, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_close);
  __Pyx_GIVEREF(__pyx_n_s_close);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 2, __pyx_n_s_close)) __PYX_ERR(0, 70, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_high);
  __Pyx_GIVEREF(__pyx_n_s_high);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 3, __pyx_n_s_high)) __PYX_ERR(0, 70, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_low);
  __Pyx_GIVEREF(__pyx_n_s_low);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 4, __pyx_n_s_low)) __PYX_ERR(0, 70, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_volume);
  __Pyx_GIVEREF(__pyx_n_s_volume);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 5, __pyx_n_s_volume)) __PYX_ERR(0, 70, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_amount);
  __Pyx_GIVEREF(__pyx_n_s_amount);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 6, __pyx_n_s_amount)) __PYX_ERR(0, 70, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s__3);
  __Pyx_GIVEREF(__pyx_n_s__3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 7, __pyx_n_s__3)) __PYX_ERR(0, 70, __pyx_L1_error);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_temp_df, __pyx_n_s_columns, __pyx_t_4) < 0) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":71
 *         return pd.DataFrame()
 *     temp_df.columns = ["date", "open", "close", "high", "low", "volume", "amount", "_"]
 *     temp_df = temp_df[["date", "open", "close", "high", "low", "volume", "amount"]]             # <<<<<<<<<<<<<<
 *     temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
 *     temp_df["close"] = pd.to_numeric(temp_df["close"], errors="coerce")
 */
  __pyx_t_4 = PyList_New(7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_n_s_date);
  __Pyx_GIVEREF(__pyx_n_s_date);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_date)) __PYX_ERR(0, 71, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_open);
  __Pyx_GIVEREF(__pyx_n_s_open);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 1, __pyx_n_s_open)) __PYX_ERR(0, 71, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_close);
  __Pyx_GIVEREF(__pyx_n_s_close);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 2, __pyx_n_s_close)) __PYX_ERR(0, 71, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_high);
  __Pyx_GIVEREF(__pyx_n_s_high);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 3, __pyx_n_s_high)) __PYX_ERR(0, 71, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_low);
  __Pyx_GIVEREF(__pyx_n_s_low);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 4, __pyx_n_s_low)) __PYX_ERR(0, 71, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_volume);
  __Pyx_GIVEREF(__pyx_n_s_volume);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 5, __pyx_n_s_volume)) __PYX_ERR(0, 71, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_amount);
  __Pyx_GIVEREF(__pyx_n_s_amount);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 6, __pyx_n_s_amount)) __PYX_ERR(0, 71, __pyx_L1_error);
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_temp_df, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_temp_df, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":72
 *     temp_df.columns = ["date", "open", "close", "high", "low", "volume", "amount", "_"]
 *     temp_df = temp_df[["date", "open", "close", "high", "low", "volume", "amount"]]
 *     temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")             # <<<<<<<<<<<<<<
 *     temp_df["close"] = pd.to_numeric(temp_df["close"], errors="coerce")
 *     temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_temp_df, __pyx_n_s_open); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 72, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_temp_df, __pyx_n_s_open, __pyx_t_3) < 0))) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":73
 *     temp_df = temp_df[["date", "open", "close", "high", "low", "volume", "amount"]]
 *     temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
 *     temp_df["close"] = pd.to_numeric(temp_df["close"], errors="coerce")             # <<<<<<<<<<<<<<
 *     temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
 *     temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_temp_df, __pyx_n_s_close); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 73, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 73, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_temp_df, __pyx_n_s_close, __pyx_t_4) < 0))) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":74
 *     temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
 *     temp_df["close"] = pd.to_numeric(temp_df["close"], errors="coerce")
 *     temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")             # <<<<<<<<<<<<<<
 *     temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
 *     temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pd); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_temp_df, __pyx_n_s_high); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(0, 74, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 74, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_temp_df, __pyx_n_s_high, __pyx_t_1) < 0))) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":75
 *     temp_df["close"] = pd.to_numeric(temp_df["close"], errors="coerce")
 *     temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
 *     temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")             # <<<<<<<<<<<<<<
 *     temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
 *     temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_temp_df, __pyx_n_s_low); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 75, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 75, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_temp_df, __pyx_n_s_low, __pyx_t_3) < 0))) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":76
 *     temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
 *     temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
 *     temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")             # <<<<<<<<<<<<<<
 *     temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
 *     return temp_df
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_temp_df, __pyx_n_s_volume); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 76, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_temp_df, __pyx_n_s_volume, __pyx_t_4) < 0))) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":77
 *     temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
 *     temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
 *     temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")             # <<<<<<<<<<<<<<
 *     return temp_df
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pd); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_temp_df, __pyx_n_s_amount); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(0, 77, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 77, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_temp_df, __pyx_n_s_amount, __pyx_t_1) < 0))) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":78
 *     temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
 *     temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
 *     return temp_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_temp_df);
  __pyx_r = __pyx_v_temp_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":17
 * 
 * 
 * def stock_zh_index_daily_em(             # <<<<<<<<<<<<<<
 *         symbol: str = "csi931151",
 *         start_date: str = "19900101",
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_zh_index_daily_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_market_map);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_secid);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_text);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":81
 * 
 * 
 * def rzrq_history(mode='new') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/rzrq/total.html
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_3rzrq_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_2rzrq_history, "\n    https://data.eastmoney.com/rzrq/total.html\n\n    mode = 'new':\350\216\267\345\217\226\346\234\200\346\226\260\347\232\204\344\270\200\351\241\26550\344\270\252\350\236\215\350\265\204\350\236\215\345\210\270\347\232\204\346\225\260\346\215\256\n    mode = 'all':\350\216\267\345\217\226\344\270\234\346\226\271\350\264\242\345\257\214\346\211\200\346\234\211\350\236\215\350\265\204\350\236\215\345\210\270\347\232\204\346\225\260\346\215\256\n\n    https://datacenter-web.eastmoney.com/api/data/v1/get\n    ?callback=datatable3892639\n    &reportName=RPTA_RZRQ_LSHJ\n    &columns=ALL\n    &source=WEB\n    &sortColumns=dim_date\n    &sortTypes=-1\n    &pageNumber=2\n    &pageSize=50\n    &filter=\n    &pageNo=2\n    &p=2\n    &pageNum=2\n    &_=1717261171099\n\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_3rzrq_history = {"rzrq_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_3rzrq_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_2rzrq_history};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_3rzrq_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_mode = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rzrq_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_mode,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_new)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 81, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "rzrq_history") < 0)) __PYX_ERR(0, 81, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_mode = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("rzrq_history", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 81, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.rzrq_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_2rzrq_history(__pyx_self, __pyx_v_mode);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_2rzrq_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode) {
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_rzrq_history_df = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_total_pages = NULL;
  PyObject *__pyx_v_page = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rzrq_history", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":105
 *     :return:
 *     '''
 *     column_dict = {'DIM_DATE': 'date',             # <<<<<<<<<<<<<<
 *                    'NEW': 'hs300_close',
 *                    'ZDF': 'hs300_change_ratio',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_DIM_DATE, __pyx_n_s_date) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NEW, __pyx_n_s_hs300_close) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ZDF, __pyx_n_s_hs300_change_ratio) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZYE, __pyx_n_s_rzye) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZYEZB, __pyx_n_s_rzyezb) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZMRE, __pyx_n_s_rzmre) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZCHE, __pyx_n_s_rzche) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZJME, __pyx_n_s_rzjme) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQYE, __pyx_n_s_rqye) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQYL, __pyx_n_s_rqyl) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQMCL, __pyx_n_s_rqmcl) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQCHL, __pyx_n_s_rqchl) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQJMG, __pyx_n_s_rqjmg) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZRQYE, __pyx_n_s_rzrqye) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":121
 *                    }
 * 
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "reportName": "RPTA_RZRQ_LSHJ",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_web_eastmoney_c);
  __pyx_v_url = __pyx_kp_s_https_datacenter_web_eastmoney_c;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":123
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
 *     params = {
 *         "reportName": "RPTA_RZRQ_LSHJ",             # <<<<<<<<<<<<<<
 *         # "columns": "ALL",
 *         "columns": "DIM_DATE,NEW,ZDF,RZYE,RZYEZB,RZMRE,RZCHE,RZJME,RQYE,RQYL,RQCHL,RQMCL,RQJMG,RZRQYE",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPTA_RZRQ_LSHJ) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_kp_s_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_n_s_dim_date) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_kp_s_1_3) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_kp_s_1) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_kp_s_500) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNo, __pyx_kp_s_1) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_p, __pyx_kp_s_1) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNum, __pyx_kp_s_1) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s__3, __pyx_kp_s_1717261171099) < 0) __PYX_ERR(0, 123, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":137
 *     }
 * 
 *     rzrq_history_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     if mode == 'new':
 *         params.update({"pageSize": 50})
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_rzrq_history_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":138
 * 
 *     rzrq_history_df = pd.DataFrame()
 *     if mode == 'new':             # <<<<<<<<<<<<<<
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_new, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 138, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":139
 *     rzrq_history_df = pd.DataFrame()
 *     if mode == 'new':
 *         params.update({"pageSize": 50})             # <<<<<<<<<<<<<<
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_int_50) < 0) __PYX_ERR(0, 139, __pyx_L1_error)
    __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":140
 *     if mode == 'new':
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         rzrq_history_df = pd.DataFrame(data_json["result"]["data"])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_requests); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_url)) __PYX_ERR(0, 140, __pyx_L1_error);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 140, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_r = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":141
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         rzrq_history_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 141, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_data_json = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":142
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         rzrq_history_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *     else:
 *         r = requests.get(url, params=params)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 142, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_rzrq_history_df, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":138
 * 
 *     rzrq_history_df = pd.DataFrame()
 *     if mode == 'new':             # <<<<<<<<<<<<<<
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":144
 *         rzrq_history_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_requests); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_url)) __PYX_ERR(0, 144, __pyx_L1_error);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 144, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_r = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":145
 *     else:
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 145, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 145, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_v_data_json = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":146
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])             # <<<<<<<<<<<<<<
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})
 */
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_pages); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_total_pages = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":147
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *             params.update({"pageNumber": page})
 *             params.update({"pageNo": page})
 */
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_total_pages, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1)) __PYX_ERR(0, 147, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 147, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 147, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 147, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 147, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 147, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_8(__pyx_t_1);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 147, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_page, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":148
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})             # <<<<<<<<<<<<<<
 *             params.update({"pageNo": page})
 *             params.update({"p": page})
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 148, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_pageNumber, __pyx_v_page) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
      __pyx_t_6 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 148, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":149
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})
 *             params.update({"pageNo": page})             # <<<<<<<<<<<<<<
 *             params.update({"p": page})
 *             params.update({"pageNum": page})
 */
      __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 149, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_pageNo, __pyx_v_page) < 0) __PYX_ERR(0, 149, __pyx_L1_error)
      __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 149, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":150
 *             params.update({"pageNumber": page})
 *             params.update({"pageNo": page})
 *             params.update({"p": page})             # <<<<<<<<<<<<<<
 *             params.update({"pageNum": page})
 *             r = requests.get(url, params=params)
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 150, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_p, __pyx_v_page) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
      __pyx_t_6 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 150, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":151
 *             params.update({"pageNo": page})
 *             params.update({"p": page})
 *             params.update({"pageNum": page})             # <<<<<<<<<<<<<<
 *             r = requests.get(url, params=params)
 *             data_json = r.json()
 */
      __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_pageNum, __pyx_v_page) < 0) __PYX_ERR(0, 151, __pyx_L1_error)
      __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":152
 *             params.update({"p": page})
 *             params.update({"pageNum": page})
 *             r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_requests); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_url);
      __Pyx_GIVEREF(__pyx_v_url);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_url)) __PYX_ERR(0, 152, __pyx_L1_error);
      __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 152, __pyx_L1_error)
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":153
 *             params.update({"pageNum": page})
 *             r = requests.get(url, params=params)
 *             data_json = r.json()             # <<<<<<<<<<<<<<
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 *             rzrq_history_df = pd.concat([rzrq_history_df, temp_df], ignore_index=True)
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 153, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 153, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_data_json, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":154
 *             r = requests.get(url, params=params)
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *             rzrq_history_df = pd.concat([rzrq_history_df, temp_df], ignore_index=True)
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_6};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_temp_df, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":155
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 *             rzrq_history_df = pd.concat([rzrq_history_df, temp_df], ignore_index=True)             # <<<<<<<<<<<<<<
 * 
 *     rzrq_history_df = rzrq_history_df[column_dict.keys()]
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pd); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_concat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyList_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_v_rzrq_history_df);
      __Pyx_GIVEREF(__pyx_v_rzrq_history_df);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_v_rzrq_history_df)) __PYX_ERR(0, 155, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_temp_df);
      __Pyx_GIVEREF(__pyx_v_temp_df);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 1, __pyx_v_temp_df)) __PYX_ERR(0, 155, __pyx_L1_error);
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_9);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_9)) __PYX_ERR(0, 155, __pyx_L1_error);
      __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 155, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF_SET(__pyx_v_rzrq_history_df, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":147
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *             params.update({"pageNumber": page})
 *             params.update({"pageNo": page})
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":157
 *             rzrq_history_df = pd.concat([rzrq_history_df, temp_df], ignore_index=True)
 * 
 *     rzrq_history_df = rzrq_history_df[column_dict.keys()]             # <<<<<<<<<<<<<<
 *     rzrq_history_df.columns = column_dict.values()
 *     rzrq_history_df["date"] = pd.to_datetime(rzrq_history_df["date"], errors="coerce").dt.date
 */
  __pyx_t_1 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_rzrq_history_df, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_rzrq_history_df, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":158
 * 
 *     rzrq_history_df = rzrq_history_df[column_dict.keys()]
 *     rzrq_history_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 *     rzrq_history_df["date"] = pd.to_datetime(rzrq_history_df["date"], errors="coerce").dt.date
 *     cols_to_convert = rzrq_history_df.columns[1:]
 */
  __pyx_t_3 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_rzrq_history_df, __pyx_n_s_columns, __pyx_t_3) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":159
 *     rzrq_history_df = rzrq_history_df[column_dict.keys()]
 *     rzrq_history_df.columns = column_dict.values()
 *     rzrq_history_df["date"] = pd.to_datetime(rzrq_history_df["date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     cols_to_convert = rzrq_history_df.columns[1:]
 *     rzrq_history_df[cols_to_convert] = rzrq_history_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_rzrq_history_df, __pyx_n_s_date); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 159, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 159, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_dt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_date); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_rzrq_history_df, __pyx_n_s_date, __pyx_t_6) < 0))) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":160
 *     rzrq_history_df.columns = column_dict.values()
 *     rzrq_history_df["date"] = pd.to_datetime(rzrq_history_df["date"], errors="coerce").dt.date
 *     cols_to_convert = rzrq_history_df.columns[1:]             # <<<<<<<<<<<<<<
 *     rzrq_history_df[cols_to_convert] = rzrq_history_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_rzrq_history_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_6, 1, 0, NULL, NULL, &__pyx_slice__6, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_cols_to_convert = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":161
 *     rzrq_history_df["date"] = pd.to_datetime(rzrq_history_df["date"], errors="coerce").dt.date
 *     cols_to_convert = rzrq_history_df.columns[1:]
 *     rzrq_history_df[cols_to_convert] = rzrq_history_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 * 
 *     # rzrq_history_df['rzyezb'].fillna(0, inplace=True)
 */
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_rzrq_history_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_apply); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9)) __PYX_ERR(0, 161, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 161, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_rzrq_history_df, __pyx_v_cols_to_convert, __pyx_t_1) < 0))) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":164
 * 
 *     # rzrq_history_df['rzyezb'].fillna(0, inplace=True)
 *     return rzrq_history_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_rzrq_history_df);
  __pyx_r = __pyx_v_rzrq_history_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":81
 * 
 * 
 * def rzrq_history(mode='new') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/rzrq/total.html
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.rzrq_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_rzrq_history_df);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_total_pages);
  __Pyx_XDECREF(__pyx_v_page);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":167
 * 
 * 
 * def stock_all_rzrq_date(trade_date='2024-05-31') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_5stock_all_rzrq_date(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_4stock_all_rzrq_date, "\n    \346\214\207\345\256\232\344\272\244\346\230\223\346\227\245\346\211\200\346\234\211\350\202\241\347\245\250\347\232\204\350\236\215\350\265\204\350\236\215\345\210\270\344\270\252\350\202\241\346\203\205\345\206\265\n    https://data.eastmoney.com/rzrq/detail/all.html\n\n    https://datacenter-web.eastmoney.com/api/data/v1/get\n    ?callback=datatable1027232\n    &reportName=RPTA_WEB_RZRQ_GGMX\n    &columns=ALL\n    &source=WEB\n    &pageNumber=2\n    &pageSize=50\n    &sortColumns=RZJME\n    &sortTypes=-1\n    &filter=(DATE%3D%272024-05-31%27)\n    &pageNo=2\n    &p=2\n    &pageNum=2\n    &_=1717298612418\n\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_5stock_all_rzrq_date = {"stock_all_rzrq_date", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_5stock_all_rzrq_date, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_4stock_all_rzrq_date};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_5stock_all_rzrq_date(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_trade_date = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_all_rzrq_date (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_trade_date,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_s_2024_05_31)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_trade_date);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 167, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_all_rzrq_date") < 0)) __PYX_ERR(0, 167, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_trade_date = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_all_rzrq_date", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 167, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_all_rzrq_date", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_4stock_all_rzrq_date(__pyx_self, __pyx_v_trade_date);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_4stock_all_rzrq_date(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date) {
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_stock_rzrq_today_df = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_total_pages = NULL;
  PyObject *__pyx_v_page = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_all_rzrq_date", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":189
 *     :return:
 *     '''
 *     column_dict = {'SCODE': 'code',             # <<<<<<<<<<<<<<
 *                    'SECNAME': 'name',
 *                    'DATE': 'date',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SCODE, __pyx_n_s_code) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECNAME, __pyx_n_s_name) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_DATE, __pyx_n_s_date) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SPJ, __pyx_n_s_close) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ZDF, __pyx_n_s_change_ratio) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZYE, __pyx_n_s_rzye) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZYEZB, __pyx_n_s_rzyezb) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZMRE, __pyx_n_s_rzmre) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZCHE, __pyx_n_s_rzche) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZJME, __pyx_n_s_rzjme) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQYE, __pyx_n_s_rqye) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQYL, __pyx_n_s_rqyl) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQMCL, __pyx_n_s_rqmcl) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQCHL, __pyx_n_s_rqchl) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQJMG, __pyx_n_s_rqjmg) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZRQYE, __pyx_n_s_rzrqye) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":207
 *                    }
 * 
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "reportName": "RPTA_WEB_RZRQ_GGMX",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_web_eastmoney_c);
  __pyx_v_url = __pyx_kp_s_https_datacenter_web_eastmoney_c;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":209
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
 *     params = {
 *         "reportName": "RPTA_WEB_RZRQ_GGMX",             # <<<<<<<<<<<<<<
 *         # "columns": "ALL",
 *         "columns": "SCODE,SECNAME,DATE,SPJ,ZDF,RZYE,RZYEZB,RZMRE,RZCHE,RZJME,RQYE,RQYL,RQCHL,RQMCL,RQJMG,RZRQYE",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPTA_WEB_RZRQ_GGMX) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_kp_s_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_kp_s_1) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_kp_s_500) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_n_s_RZJME) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_kp_s_1_3) < 0) __PYX_ERR(0, 209, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":217
 *         "sortColumns": "RZJME",
 *         "sortTypes": "-1",
 *         "filter": f"(DATE='{trade_date}')",             # <<<<<<<<<<<<<<
 *         "pageNo": "1",
 *         "p": "1",
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_DATE_2);
  __pyx_t_3 += 7;
  __Pyx_GIVEREF(__pyx_kp_u_DATE_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_DATE_2);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_trade_date, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__7);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__7);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__7);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_filter, __pyx_t_5) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNo, __pyx_kp_s_1) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_p, __pyx_kp_s_1) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNum, __pyx_kp_s_1) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s__3, __pyx_kp_s_1717298612418) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":224
 *     }
 * 
 *     stock_rzrq_today_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_stock_rzrq_today_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":225
 * 
 *     stock_rzrq_today_df = pd.DataFrame()
 *     r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 225, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 225, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_r = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":226
 *     stock_rzrq_today_df = pd.DataFrame()
 *     r = requests.get(url, params=params)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_v_data_json = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":227
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])             # <<<<<<<<<<<<<<
 *     for page in range(1, total_pages + 1):
 *         params.update({"pageNumber": page})
 */
  __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_7, __pyx_n_s_pages); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyNumber_Int(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_total_pages = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":228
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pageNumber": page})
 *         params.update({"pageNo": page})
 */
  __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_total_pages, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_int_1)) __PYX_ERR(0, 228, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_7)) __PYX_ERR(0, 228, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
    __pyx_t_5 = __pyx_t_7; __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 228, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 228, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_3); __Pyx_INCREF(__pyx_t_7); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 228, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 228, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 228, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_3); __Pyx_INCREF(__pyx_t_7); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 228, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 228, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_8(__pyx_t_5);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 228, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_page, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":229
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):
 *         params.update({"pageNumber": page})             # <<<<<<<<<<<<<<
 *         params.update({"pageNo": page})
 *         params.update({"p": page})
 */
    __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_pageNumber, __pyx_v_page) < 0) __PYX_ERR(0, 229, __pyx_L1_error)
    __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":230
 *     for page in range(1, total_pages + 1):
 *         params.update({"pageNumber": page})
 *         params.update({"pageNo": page})             # <<<<<<<<<<<<<<
 *         params.update({"p": page})
 *         params.update({"pageNum": page})
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNo, __pyx_v_page) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
    __pyx_t_7 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":231
 *         params.update({"pageNumber": page})
 *         params.update({"pageNo": page})
 *         params.update({"p": page})             # <<<<<<<<<<<<<<
 *         params.update({"pageNum": page})
 *         r = requests.get(url, params=params)
 */
    __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_p, __pyx_v_page) < 0) __PYX_ERR(0, 231, __pyx_L1_error)
    __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":232
 *         params.update({"pageNo": page})
 *         params.update({"p": page})
 *         params.update({"pageNum": page})             # <<<<<<<<<<<<<<
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 232, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNum, __pyx_v_page) < 0) __PYX_ERR(0, 232, __pyx_L1_error)
    __pyx_t_7 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 232, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":233
 *         params.update({"p": page})
 *         params.update({"pageNum": page})
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_requests); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_url)) __PYX_ERR(0, 233, __pyx_L1_error);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 233, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":234
 *         params.update({"pageNum": page})
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 *         stock_rzrq_today_df = pd.concat([stock_rzrq_today_df, temp_df], ignore_index=True)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 234, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_data_json, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":235
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *         stock_rzrq_today_df = pd.concat([stock_rzrq_today_df, temp_df], ignore_index=True)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 235, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_temp_df, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":236
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 *         stock_rzrq_today_df = pd.concat([stock_rzrq_today_df, temp_df], ignore_index=True)             # <<<<<<<<<<<<<<
 * 
 *     stock_rzrq_today_df = stock_rzrq_today_df[column_dict.keys()]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pd); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_concat); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyList_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_v_stock_rzrq_today_df);
    __Pyx_GIVEREF(__pyx_v_stock_rzrq_today_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_v_stock_rzrq_today_df)) __PYX_ERR(0, 236, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_temp_df);
    __Pyx_GIVEREF(__pyx_v_temp_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 1, __pyx_v_temp_df)) __PYX_ERR(0, 236, __pyx_L1_error);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_9);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_9)) __PYX_ERR(0, 236, __pyx_L1_error);
    __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 236, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF_SET(__pyx_v_stock_rzrq_today_df, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":228
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pageNumber": page})
 *         params.update({"pageNo": page})
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":238
 *         stock_rzrq_today_df = pd.concat([stock_rzrq_today_df, temp_df], ignore_index=True)
 * 
 *     stock_rzrq_today_df = stock_rzrq_today_df[column_dict.keys()]             # <<<<<<<<<<<<<<
 *     stock_rzrq_today_df.columns = column_dict.values()
 *     stock_rzrq_today_df["date"] = pd.to_datetime(stock_rzrq_today_df["date"], errors="coerce").dt.date
 */
  __pyx_t_5 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_stock_rzrq_today_df, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_stock_rzrq_today_df, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":239
 * 
 *     stock_rzrq_today_df = stock_rzrq_today_df[column_dict.keys()]
 *     stock_rzrq_today_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 *     stock_rzrq_today_df["date"] = pd.to_datetime(stock_rzrq_today_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_rzrq_today_df.columns[3:]
 */
  __pyx_t_2 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_stock_rzrq_today_df, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":240
 *     stock_rzrq_today_df = stock_rzrq_today_df[column_dict.keys()]
 *     stock_rzrq_today_df.columns = column_dict.values()
 *     stock_rzrq_today_df["date"] = pd.to_datetime(stock_rzrq_today_df["date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     cols_to_convert = stock_rzrq_today_df.columns[3:]
 *     stock_rzrq_today_df[cols_to_convert] = stock_rzrq_today_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_stock_rzrq_today_df, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 240, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_rzrq_today_df, __pyx_n_s_date, __pyx_t_1) < 0))) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":241
 *     stock_rzrq_today_df.columns = column_dict.values()
 *     stock_rzrq_today_df["date"] = pd.to_datetime(stock_rzrq_today_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_rzrq_today_df.columns[3:]             # <<<<<<<<<<<<<<
 *     stock_rzrq_today_df[cols_to_convert] = stock_rzrq_today_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return stock_rzrq_today_df
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_stock_rzrq_today_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_1, 3, 0, NULL, NULL, &__pyx_slice__8, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cols_to_convert = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":242
 *     stock_rzrq_today_df["date"] = pd.to_datetime(stock_rzrq_today_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_rzrq_today_df.columns[3:]
 *     stock_rzrq_today_df[cols_to_convert] = stock_rzrq_today_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 *     return stock_rzrq_today_df
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_stock_rzrq_today_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_apply); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_9)) __PYX_ERR(0, 242, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 242, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_rzrq_today_df, __pyx_v_cols_to_convert, __pyx_t_5) < 0))) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":243
 *     cols_to_convert = stock_rzrq_today_df.columns[3:]
 *     stock_rzrq_today_df[cols_to_convert] = stock_rzrq_today_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return stock_rzrq_today_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_stock_rzrq_today_df);
  __pyx_r = __pyx_v_stock_rzrq_today_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":167
 * 
 * 
 * def stock_all_rzrq_date(trade_date='2024-05-31') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_all_rzrq_date", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_stock_rzrq_today_df);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_total_pages);
  __Pyx_XDECREF(__pyx_v_page);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":246
 * 
 * 
 * def stock_rzrq_detail(mode='new', symbol='000001') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/rzrq/stock/600900.html
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_7stock_rzrq_detail(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_6stock_rzrq_detail, "\n    https://data.eastmoney.com/rzrq/stock/600900.html\n\n    https://datacenter-web.eastmoney.com/api/data/v1/get\n    ?callback=datatable4768160\n    &reportName=RPTA_WEB_RZRQ_GGMX\n    &columns=ALL\n    &source=WEB\n    &sortColumns=date\n    &sortTypes=-1\n    &pageNumber=2\n    &pageSize=50\n    &filter=(scode%3D%22600171%22)\n    &pageNo=2\n    &p=2\n    &pageNum=2\n    &_=1717298688717\n\n    :param symbol:\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_7stock_rzrq_detail = {"stock_rzrq_detail", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_7stock_rzrq_detail, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_6stock_rzrq_detail};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_7stock_rzrq_detail(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_mode = 0;
  PyObject *__pyx_v_symbol = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_rzrq_detail (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_mode,&__pyx_n_s_symbol,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_new)));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_s_000001)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 246, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 246, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_rzrq_detail") < 0)) __PYX_ERR(0, 246, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_mode = values[0];
    __pyx_v_symbol = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_rzrq_detail", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 246, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_rzrq_detail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_6stock_rzrq_detail(__pyx_self, __pyx_v_mode, __pyx_v_symbol);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_6stock_rzrq_detail(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode, PyObject *__pyx_v_symbol) {
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_stock_rzrq_df = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_total_pages = NULL;
  PyObject *__pyx_v_page = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_rzrq_detail", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":268
 *     :return:
 *     '''
 *     column_dict = {'SCODE': 'code',             # <<<<<<<<<<<<<<
 *                    'SECNAME': 'name',
 *                    'DATE': 'date',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SCODE, __pyx_n_s_code) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECNAME, __pyx_n_s_name) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_DATE, __pyx_n_s_date) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SPJ, __pyx_n_s_close) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ZDF, __pyx_n_s_change_ratio) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZYE, __pyx_n_s_rzye) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZYEZB, __pyx_n_s_rzyezb) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZMRE, __pyx_n_s_rzmre) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZCHE, __pyx_n_s_rzche) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZJME, __pyx_n_s_rzjme) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQYE, __pyx_n_s_rqye) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQYL, __pyx_n_s_rqyl) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQMCL, __pyx_n_s_rqmcl) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQCHL, __pyx_n_s_rqchl) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RQJMG, __pyx_n_s_rqjmg) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_RZRQYE, __pyx_n_s_rzrqye) < 0) __PYX_ERR(0, 268, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":286
 *                    }
 * 
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "reportName": "RPTA_WEB_RZRQ_GGMX",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_web_eastmoney_c);
  __pyx_v_url = __pyx_kp_s_https_datacenter_web_eastmoney_c;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":288
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
 *     params = {
 *         "reportName": "RPTA_WEB_RZRQ_GGMX",             # <<<<<<<<<<<<<<
 *         # "columns": "ALL",
 *         "columns": "SCODE,SECNAME,DATE,SPJ,ZDF,RZYE,RZYEZB,RZMRE,RZCHE,RZJME,RQYE,RQYL,RQCHL,RQMCL,RQJMG,RZRQYE",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPTA_WEB_RZRQ_GGMX) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_kp_s_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_n_s_date) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_kp_s_1_3) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_kp_s_1) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_kp_s_500) < 0) __PYX_ERR(0, 288, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":296
 *         "pageNumber": "1",
 *         "pageSize": "500",
 *         "filter": f'(scode="{symbol}")',             # <<<<<<<<<<<<<<
 *         "pageNo": "1",
 *         "p": "1",
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_scode);
  __pyx_t_3 += 8;
  __Pyx_GIVEREF(__pyx_kp_u_scode);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_scode);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_symbol, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__9);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__9);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__9);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_filter, __pyx_t_5) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNo, __pyx_kp_s_1) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_p, __pyx_kp_s_1) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNum, __pyx_kp_s_1) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s__3, __pyx_kp_s_1717298688717) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":303
 *     }
 * 
 *     stock_rzrq_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     if mode == 'new':
 *         params.update({"pageSize": 50})
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_stock_rzrq_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":304
 * 
 *     stock_rzrq_df = pd.DataFrame()
 *     if mode == 'new':             # <<<<<<<<<<<<<<
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 */
  __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_new, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 304, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":305
 *     stock_rzrq_df = pd.DataFrame()
 *     if mode == 'new':
 *         params.update({"pageSize": 50})             # <<<<<<<<<<<<<<
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_int_50) < 0) __PYX_ERR(0, 305, __pyx_L1_error)
    __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":306
 *     if mode == 'new':
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         stock_rzrq_df = pd.DataFrame(data_json["result"]["data"])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_requests); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_url)) __PYX_ERR(0, 306, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 306, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_r = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":307
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         stock_rzrq_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 307, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_v_data_json = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":308
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         stock_rzrq_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *     else:
 *         r = requests.get(url, params=params)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_5, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 308, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_stock_rzrq_df, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":304
 * 
 *     stock_rzrq_df = pd.DataFrame()
 *     if mode == 'new':             # <<<<<<<<<<<<<<
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":310
 *         stock_rzrq_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_requests); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_url)) __PYX_ERR(0, 310, __pyx_L1_error);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 310, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_r = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":311
 *     else:
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_v_data_json = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":312
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])             # <<<<<<<<<<<<<<
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})
 */
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_5, __pyx_n_s_pages); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_total_pages = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":313
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *             params.update({"pageNumber": page})
 *             params.update({"pageNo": page})
 */
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_total_pages, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1)) __PYX_ERR(0, 313, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
      __pyx_t_1 = __pyx_t_5; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 313, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 313, __pyx_L1_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 313, __pyx_L1_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 313, __pyx_L1_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 313, __pyx_L1_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_9(__pyx_t_1);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 313, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_page, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":314
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})             # <<<<<<<<<<<<<<
 *             params.update({"pageNo": page})
 *             params.update({"p": page})
 */
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_pageNumber, __pyx_v_page) < 0) __PYX_ERR(0, 314, __pyx_L1_error)
      __pyx_t_8 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":315
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})
 *             params.update({"pageNo": page})             # <<<<<<<<<<<<<<
 *             params.update({"p": page})
 *             params.update({"pageNum": page})
 */
      __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_pageNo, __pyx_v_page) < 0) __PYX_ERR(0, 315, __pyx_L1_error)
      __pyx_t_5 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":316
 *             params.update({"pageNumber": page})
 *             params.update({"pageNo": page})
 *             params.update({"p": page})             # <<<<<<<<<<<<<<
 *             params.update({"pageNum": page})
 *             r = requests.get(url, params=params)
 */
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_p, __pyx_v_page) < 0) __PYX_ERR(0, 316, __pyx_L1_error)
      __pyx_t_8 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":317
 *             params.update({"pageNo": page})
 *             params.update({"p": page})
 *             params.update({"pageNum": page})             # <<<<<<<<<<<<<<
 *             r = requests.get(url, params=params)
 *             data_json = r.json()
 */
      __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 317, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_pageNum, __pyx_v_page) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
      __pyx_t_5 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 317, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":318
 *             params.update({"p": page})
 *             params.update({"pageNum": page})
 *             r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_requests); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_get); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_url);
      __Pyx_GIVEREF(__pyx_v_url);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_url)) __PYX_ERR(0, 318, __pyx_L1_error);
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 318, __pyx_L1_error)
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":319
 *             params.update({"pageNum": page})
 *             r = requests.get(url, params=params)
 *             data_json = r.json()             # <<<<<<<<<<<<<<
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 *             stock_rzrq_df = pd.concat([stock_rzrq_df, temp_df], ignore_index=True)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 319, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 319, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_data_json, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":320
 *             r = requests.get(url, params=params)
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *             stock_rzrq_df = pd.concat([stock_rzrq_df, temp_df], ignore_index=True)
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_8};
        __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 320, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_temp_df, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":321
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 *             stock_rzrq_df = pd.concat([stock_rzrq_df, temp_df], ignore_index=True)             # <<<<<<<<<<<<<<
 * 
 *     stock_rzrq_df = stock_rzrq_df[column_dict.keys()]
 */
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pd); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_concat); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyList_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_v_stock_rzrq_df);
      __Pyx_GIVEREF(__pyx_v_stock_rzrq_df);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_10, 0, __pyx_v_stock_rzrq_df)) __PYX_ERR(0, 321, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_temp_df);
      __Pyx_GIVEREF(__pyx_v_temp_df);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_10, 1, __pyx_v_temp_df)) __PYX_ERR(0, 321, __pyx_L1_error);
      __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_10);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10)) __PYX_ERR(0, 321, __pyx_L1_error);
      __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 321, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF_SET(__pyx_v_stock_rzrq_df, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":313
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *             params.update({"pageNumber": page})
 *             params.update({"pageNo": page})
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":323
 *             stock_rzrq_df = pd.concat([stock_rzrq_df, temp_df], ignore_index=True)
 * 
 *     stock_rzrq_df = stock_rzrq_df[column_dict.keys()]             # <<<<<<<<<<<<<<
 *     stock_rzrq_df.columns = column_dict.values()
 *     stock_rzrq_df["date"] = pd.to_datetime(stock_rzrq_df["date"], errors="coerce").dt.date
 */
  __pyx_t_1 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_stock_rzrq_df, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_stock_rzrq_df, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":324
 * 
 *     stock_rzrq_df = stock_rzrq_df[column_dict.keys()]
 *     stock_rzrq_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 *     stock_rzrq_df["date"] = pd.to_datetime(stock_rzrq_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_rzrq_df.columns[3:]
 */
  __pyx_t_2 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_stock_rzrq_df, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 324, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":325
 *     stock_rzrq_df = stock_rzrq_df[column_dict.keys()]
 *     stock_rzrq_df.columns = column_dict.values()
 *     stock_rzrq_df["date"] = pd.to_datetime(stock_rzrq_df["date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     cols_to_convert = stock_rzrq_df.columns[3:]
 *     stock_rzrq_df[cols_to_convert] = stock_rzrq_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_stock_rzrq_df, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_2)) __PYX_ERR(0, 325, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 325, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_rzrq_df, __pyx_n_s_date, __pyx_t_8) < 0))) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":326
 *     stock_rzrq_df.columns = column_dict.values()
 *     stock_rzrq_df["date"] = pd.to_datetime(stock_rzrq_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_rzrq_df.columns[3:]             # <<<<<<<<<<<<<<
 *     stock_rzrq_df[cols_to_convert] = stock_rzrq_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return stock_rzrq_df
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_stock_rzrq_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_8, 3, 0, NULL, NULL, &__pyx_slice__8, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_v_cols_to_convert = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":327
 *     stock_rzrq_df["date"] = pd.to_datetime(stock_rzrq_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_rzrq_df.columns[3:]
 *     stock_rzrq_df[cols_to_convert] = stock_rzrq_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 *     return stock_rzrq_df
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_stock_rzrq_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_apply); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_10)) __PYX_ERR(0, 327, __pyx_L1_error);
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 327, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_rzrq_df, __pyx_v_cols_to_convert, __pyx_t_1) < 0))) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":328
 *     cols_to_convert = stock_rzrq_df.columns[3:]
 *     stock_rzrq_df[cols_to_convert] = stock_rzrq_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return stock_rzrq_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_stock_rzrq_df);
  __pyx_r = __pyx_v_stock_rzrq_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":246
 * 
 * 
 * def stock_rzrq_detail(mode='new', symbol='000001') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/rzrq/stock/600900.html
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_rzrq_detail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_stock_rzrq_df);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_total_pages);
  __Pyx_XDECREF(__pyx_v_page);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":331
 * 
 * 
 * def hsgt_history(mode='new') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     mode = 'new':50
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_9hsgt_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_8hsgt_history, "\n    mode = 'new':\350\216\267\345\217\226\346\234\200\346\226\260\347\232\204\344\270\200\351\241\26550\344\270\252\346\262\252\346\267\261\346\270\257\351\200\232\347\232\204\346\225\260\346\215\256\n    mode = 'all':\350\216\267\345\217\226\344\270\234\346\226\271\350\264\242\345\257\214\346\211\200\346\234\211\346\262\252\346\267\261\346\270\257\351\200\232\347\232\204\346\225\260\346\215\256\n    https://data.eastmoney.com/hsgt/hsgthistory.html\n\n    https://datacenter-web.eastmoney.com/api/data/v1/get\n    ?callback=jQuery1123020007266204580576_1717297862120\n    &sortColumns=TRADE_DATE\n    &sortTypes=-1\n    &pageSize=50\n    &pageNumber=1\n    &reportName=RPT_MUTUAL_DEALHISTORY_NEW\n    &columns=ALL\n    &source=WEB\n    &client=WEB\n    &filter=(MUTUAL_TYPE%3D%22005%22)\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_9hsgt_history = {"hsgt_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_9hsgt_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_8hsgt_history};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_9hsgt_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_mode = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hsgt_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_mode,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_new)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 331, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "hsgt_history") < 0)) __PYX_ERR(0, 331, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_mode = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("hsgt_history", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 331, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.hsgt_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_8hsgt_history(__pyx_self, __pyx_v_mode);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_8hsgt_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode) {
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_hsgt_history_df = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_total_pages = NULL;
  PyObject *__pyx_v_page = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hsgt_history", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":350
 *     :return:
 *     '''
 *     column_dict = {'TRADE_DATE': 'date',             # <<<<<<<<<<<<<<
 *                    'NET_DEAL_AMT': 'net_amount',
 *                    'BUY_AMT': 'buy_amount',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TRADE_DATE, __pyx_n_s_date) < 0) __PYX_ERR(0, 350, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NET_DEAL_AMT, __pyx_n_s_net_amount) < 0) __PYX_ERR(0, 350, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_BUY_AMT, __pyx_n_s_buy_amount) < 0) __PYX_ERR(0, 350, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SELL_AMT, __pyx_n_s_sell_amount) < 0) __PYX_ERR(0, 350, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ACCUM_DEAL_AMT, __pyx_n_s_accum_net_amount) < 0) __PYX_ERR(0, 350, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_INDEX_CLOSE_PRICE, __pyx_n_s_sse_index_close) < 0) __PYX_ERR(0, 350, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_INDEX_CHANGE_RATE, __pyx_n_s_sse_index_change_ratio) < 0) __PYX_ERR(0, 350, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":359
 *                    }
 * 
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "sortColumns": "TRADE_DATE",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_web_eastmoney_c);
  __pyx_v_url = __pyx_kp_s_https_datacenter_web_eastmoney_c;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":361
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
 *     params = {
 *         "sortColumns": "TRADE_DATE",             # <<<<<<<<<<<<<<
 *         "sortTypes": "-1",
 *         "pageSize": "500",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_n_s_TRADE_DATE) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_kp_s_1_3) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_kp_s_500) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_kp_s_1) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPT_MUTUAL_DEALHISTORY_NEW) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_kp_s_TRADE_DATE_NET_DEAL_AMT_BUY_AMT) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_client, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_filter, __pyx_kp_s_MUTUAL_TYPE_005) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":373
 *     }
 * 
 *     hsgt_history_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     if mode == 'new':
 *         params.update({"pageSize": 50})
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 373, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_hsgt_history_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":374
 * 
 *     hsgt_history_df = pd.DataFrame()
 *     if mode == 'new':             # <<<<<<<<<<<<<<
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 */
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_new, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 374, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":375
 *     hsgt_history_df = pd.DataFrame()
 *     if mode == 'new':
 *         params.update({"pageSize": 50})             # <<<<<<<<<<<<<<
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_int_50) < 0) __PYX_ERR(0, 375, __pyx_L1_error)
    __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":376
 *     if mode == 'new':
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         hsgt_history_df = pd.DataFrame(data_json["result"]["data"])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_requests); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 376, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 376, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 376, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_url)) __PYX_ERR(0, 376, __pyx_L1_error);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 376, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 376, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 376, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_r = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":377
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         hsgt_history_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 377, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_data_json = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":378
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         hsgt_history_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *     else:
 *         r = requests.get(url, params=params)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 378, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_hsgt_history_df, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":374
 * 
 *     hsgt_history_df = pd.DataFrame()
 *     if mode == 'new':             # <<<<<<<<<<<<<<
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":380
 *         hsgt_history_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_requests); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_url)) __PYX_ERR(0, 380, __pyx_L1_error);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 380, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_r = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":381
 *     else:
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 381, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_v_data_json = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":382
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])             # <<<<<<<<<<<<<<
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})
 */
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_pages); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_total_pages = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":383
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *             params.update({"pageNumber": page})
 *             r = requests.get(url, params=params)
 */
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_total_pages, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1)) __PYX_ERR(0, 383, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 383, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 383, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 383, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 383, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 383, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_8(__pyx_t_1);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 383, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_page, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":384
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})             # <<<<<<<<<<<<<<
 *             r = requests.get(url, params=params)
 *             data_json = r.json()
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 384, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_pageNumber, __pyx_v_page) < 0) __PYX_ERR(0, 384, __pyx_L1_error)
      __pyx_t_6 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 384, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":385
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})
 *             r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_requests); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_url);
      __Pyx_GIVEREF(__pyx_v_url);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_url)) __PYX_ERR(0, 385, __pyx_L1_error);
      __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 385, __pyx_L1_error)
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":386
 *             params.update({"pageNumber": page})
 *             r = requests.get(url, params=params)
 *             data_json = r.json()             # <<<<<<<<<<<<<<
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 *             hsgt_history_df = pd.concat([hsgt_history_df, temp_df], ignore_index=True)
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 386, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_data_json, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":387
 *             r = requests.get(url, params=params)
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *             hsgt_history_df = pd.concat([hsgt_history_df, temp_df], ignore_index=True)
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 387, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_temp_df, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":388
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 *             hsgt_history_df = pd.concat([hsgt_history_df, temp_df], ignore_index=True)             # <<<<<<<<<<<<<<
 * 
 *     hsgt_history_df = hsgt_history_df[column_dict.keys()]
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pd); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_concat); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyList_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_v_hsgt_history_df);
      __Pyx_GIVEREF(__pyx_v_hsgt_history_df);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_v_hsgt_history_df)) __PYX_ERR(0, 388, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_temp_df);
      __Pyx_GIVEREF(__pyx_v_temp_df);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 1, __pyx_v_temp_df)) __PYX_ERR(0, 388, __pyx_L1_error);
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_9);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_9)) __PYX_ERR(0, 388, __pyx_L1_error);
      __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 388, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF_SET(__pyx_v_hsgt_history_df, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":383
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *             params.update({"pageNumber": page})
 *             r = requests.get(url, params=params)
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":390
 *             hsgt_history_df = pd.concat([hsgt_history_df, temp_df], ignore_index=True)
 * 
 *     hsgt_history_df = hsgt_history_df[column_dict.keys()]             # <<<<<<<<<<<<<<
 *     hsgt_history_df.columns = column_dict.values()
 *     hsgt_history_df["date"] = pd.to_datetime(hsgt_history_df["date"], errors="coerce").dt.date
 */
  __pyx_t_1 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_hsgt_history_df, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_hsgt_history_df, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":391
 * 
 *     hsgt_history_df = hsgt_history_df[column_dict.keys()]
 *     hsgt_history_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 *     hsgt_history_df["date"] = pd.to_datetime(hsgt_history_df["date"], errors="coerce").dt.date
 *     cols_to_convert = hsgt_history_df.columns[1:]
 */
  __pyx_t_3 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_hsgt_history_df, __pyx_n_s_columns, __pyx_t_3) < 0) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":392
 *     hsgt_history_df = hsgt_history_df[column_dict.keys()]
 *     hsgt_history_df.columns = column_dict.values()
 *     hsgt_history_df["date"] = pd.to_datetime(hsgt_history_df["date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     cols_to_convert = hsgt_history_df.columns[1:]
 *     hsgt_history_df[cols_to_convert] = hsgt_history_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_hsgt_history_df, __pyx_n_s_date); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 392, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_hsgt_history_df, __pyx_n_s_date, __pyx_t_2) < 0))) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":393
 *     hsgt_history_df.columns = column_dict.values()
 *     hsgt_history_df["date"] = pd.to_datetime(hsgt_history_df["date"], errors="coerce").dt.date
 *     cols_to_convert = hsgt_history_df.columns[1:]             # <<<<<<<<<<<<<<
 *     hsgt_history_df[cols_to_convert] = hsgt_history_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return hsgt_history_df
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_hsgt_history_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_2, 1, 0, NULL, NULL, &__pyx_slice__6, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_cols_to_convert = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":394
 *     hsgt_history_df["date"] = pd.to_datetime(hsgt_history_df["date"], errors="coerce").dt.date
 *     cols_to_convert = hsgt_history_df.columns[1:]
 *     hsgt_history_df[cols_to_convert] = hsgt_history_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 *     return hsgt_history_df
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_hsgt_history_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_apply); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9)) __PYX_ERR(0, 394, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 394, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_hsgt_history_df, __pyx_v_cols_to_convert, __pyx_t_1) < 0))) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":395
 *     cols_to_convert = hsgt_history_df.columns[1:]
 *     hsgt_history_df[cols_to_convert] = hsgt_history_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return hsgt_history_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_hsgt_history_df);
  __pyx_r = __pyx_v_hsgt_history_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":331
 * 
 * 
 * def hsgt_history(mode='new') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     mode = 'new':50
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.hsgt_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_hsgt_history_df);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_total_pages);
  __Pyx_XDECREF(__pyx_v_page);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":398
 * 
 * 
 * def stock_all_hsgt_date(trade_date='2024-05-31') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_11stock_all_hsgt_date(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_10stock_all_hsgt_date, "\n    \346\214\207\345\256\232\344\272\244\346\230\223\346\227\245\346\211\200\346\234\211\350\202\241\347\245\250\347\232\204\346\262\252\346\267\261\346\270\257\351\200\232\344\270\252\350\202\241\350\265\204\351\207\221\n    https://data.eastmoney.com/hsgt/hsgtDetail/ggzj.html\n\n    https://datacenter-web.eastmoney.com/api/data/v1/get\n    ?callback=jQuery112304217373241718583_1717298455604\n    &sortColumns=ADD_MARKET_CAP\n    &sortTypes=-1\n    &pageSize=50\n    &pageNumber=2\n    &reportName=RPT_MUTUAL_STOCK_NORTHSTA\n    &columns=ALL\n    &source=WEB\n    &client=WEB\n    &filter=(TRADE_DATE%3D%272024-05-31%27)(INTERVAL_TYPE%3D%221%22)\n\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_11stock_all_hsgt_date = {"stock_all_hsgt_date", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_11stock_all_hsgt_date, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_10stock_all_hsgt_date};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_11stock_all_hsgt_date(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_trade_date = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_all_hsgt_date (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_trade_date,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_s_2024_05_31)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_trade_date);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 398, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_all_hsgt_date") < 0)) __PYX_ERR(0, 398, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_trade_date = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_all_hsgt_date", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 398, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_all_hsgt_date", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_10stock_all_hsgt_date(__pyx_self, __pyx_v_trade_date);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_10stock_all_hsgt_date(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_trade_date) {
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_stock_hsgt_today_df = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_total_pages = NULL;
  PyObject *__pyx_v_page = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_all_hsgt_date", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":417
 *     :return:
 *     '''
 *     column_dict = {'SECURITY_CODE': 'code',             # <<<<<<<<<<<<<<
 *                    'SECURITY_NAME': 'name',
 *                    'TRADE_DATE': 'date',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_CODE, __pyx_n_s_code) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_NAME, __pyx_n_s_name) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TRADE_DATE, __pyx_n_s_date) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CLOSE_PRICE, __pyx_n_s_close) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CHANGE_RATE, __pyx_n_s_change_rate) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLD_SHARES, __pyx_n_s_hold_volume) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLD_MARKET_CAP, __pyx_n_s_hold_amount) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_FREE_SHARES_RATIO, __pyx_n_s_hold_volume_ratio) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ADD_SHARES_REPAIR, __pyx_n_s_add_volume) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ADD_MARKET_CAP, __pyx_n_s_add_amount) < 0) __PYX_ERR(0, 417, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":429
 *                    }
 * 
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "sortColumns": "ADD_MARKET_CAP",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_web_eastmoney_c);
  __pyx_v_url = __pyx_kp_s_https_datacenter_web_eastmoney_c;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":431
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
 *     params = {
 *         "sortColumns": "ADD_MARKET_CAP",             # <<<<<<<<<<<<<<
 *         "sortTypes": "-1",
 *         "pageSize": "500",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_n_s_ADD_MARKET_CAP) < 0) __PYX_ERR(0, 431, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_kp_s_1_3) < 0) __PYX_ERR(0, 431, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_kp_s_500) < 0) __PYX_ERR(0, 431, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_kp_s_1) < 0) __PYX_ERR(0, 431, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPT_MUTUAL_STOCK_NORTHSTA) < 0) __PYX_ERR(0, 431, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD) < 0) __PYX_ERR(0, 431, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 431, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_client, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 431, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":440
 *         "source": "WEB",
 *         "client": "WEB",
 *         "filter": f"(TRADE_DATE='{trade_date}')(INTERVAL_TYPE=\"1\")"             # <<<<<<<<<<<<<<
 *     }
 * 
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_TRADE_DATE_2);
  __pyx_t_3 += 13;
  __Pyx_GIVEREF(__pyx_kp_u_TRADE_DATE_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_TRADE_DATE_2);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_trade_date, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u_INTERVAL_TYPE_1);
  __pyx_t_3 += 21;
  __Pyx_GIVEREF(__pyx_kp_u_INTERVAL_TYPE_1);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_INTERVAL_TYPE_1);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_filter, __pyx_t_5) < 0) __PYX_ERR(0, 431, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":443
 *     }
 * 
 *     stock_hsgt_today_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_stock_hsgt_today_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":444
 * 
 *     stock_hsgt_today_df = pd.DataFrame()
 *     r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 444, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 444, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_r = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":445
 *     stock_hsgt_today_df = pd.DataFrame()
 *     r = requests.get(url, params=params)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 445, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_v_data_json = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":446
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])             # <<<<<<<<<<<<<<
 *     for page in range(1, total_pages + 1):
 *         params.update({"pageNumber": page})
 */
  __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_7, __pyx_n_s_pages); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyNumber_Int(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_total_pages = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":447
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pageNumber": page})
 *         r = requests.get(url, params=params)
 */
  __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_total_pages, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_int_1)) __PYX_ERR(0, 447, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_7)) __PYX_ERR(0, 447, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
    __pyx_t_5 = __pyx_t_7; __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 447, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 447, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_3); __Pyx_INCREF(__pyx_t_7); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 447, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 447, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 447, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_3); __Pyx_INCREF(__pyx_t_7); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 447, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 447, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_8(__pyx_t_5);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 447, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_page, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":448
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):
 *         params.update({"pageNumber": page})             # <<<<<<<<<<<<<<
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 */
    __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_pageNumber, __pyx_v_page) < 0) __PYX_ERR(0, 448, __pyx_L1_error)
    __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":449
 *     for page in range(1, total_pages + 1):
 *         params.update({"pageNumber": page})
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 449, __pyx_L1_error);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 449, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":450
 *         params.update({"pageNumber": page})
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 *         stock_hsgt_today_df = pd.concat([stock_hsgt_today_df, temp_df], ignore_index=True)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_data_json, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":451
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *         stock_hsgt_today_df = pd.concat([stock_hsgt_today_df, temp_df], ignore_index=True)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_temp_df, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":452
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 *         stock_hsgt_today_df = pd.concat([stock_hsgt_today_df, temp_df], ignore_index=True)             # <<<<<<<<<<<<<<
 * 
 *     stock_hsgt_today_df = stock_hsgt_today_df[column_dict.keys()]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pd); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_concat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyList_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_v_stock_hsgt_today_df);
    __Pyx_GIVEREF(__pyx_v_stock_hsgt_today_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_v_stock_hsgt_today_df)) __PYX_ERR(0, 452, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_temp_df);
    __Pyx_GIVEREF(__pyx_v_temp_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 1, __pyx_v_temp_df)) __PYX_ERR(0, 452, __pyx_L1_error);
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_9);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9)) __PYX_ERR(0, 452, __pyx_L1_error);
    __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 452, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF_SET(__pyx_v_stock_hsgt_today_df, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":447
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pageNumber": page})
 *         r = requests.get(url, params=params)
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":454
 *         stock_hsgt_today_df = pd.concat([stock_hsgt_today_df, temp_df], ignore_index=True)
 * 
 *     stock_hsgt_today_df = stock_hsgt_today_df[column_dict.keys()]             # <<<<<<<<<<<<<<
 *     stock_hsgt_today_df.columns = column_dict.values()
 *     stock_hsgt_today_df["date"] = pd.to_datetime(stock_hsgt_today_df["date"], errors="coerce").dt.date
 */
  __pyx_t_5 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_stock_hsgt_today_df, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_stock_hsgt_today_df, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":455
 * 
 *     stock_hsgt_today_df = stock_hsgt_today_df[column_dict.keys()]
 *     stock_hsgt_today_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 *     stock_hsgt_today_df["date"] = pd.to_datetime(stock_hsgt_today_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_hsgt_today_df.columns[3:]
 */
  __pyx_t_2 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_stock_hsgt_today_df, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":456
 *     stock_hsgt_today_df = stock_hsgt_today_df[column_dict.keys()]
 *     stock_hsgt_today_df.columns = column_dict.values()
 *     stock_hsgt_today_df["date"] = pd.to_datetime(stock_hsgt_today_df["date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     cols_to_convert = stock_hsgt_today_df.columns[3:]
 *     stock_hsgt_today_df[cols_to_convert] = stock_hsgt_today_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_stock_hsgt_today_df, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 456, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_hsgt_today_df, __pyx_n_s_date, __pyx_t_7) < 0))) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":457
 *     stock_hsgt_today_df.columns = column_dict.values()
 *     stock_hsgt_today_df["date"] = pd.to_datetime(stock_hsgt_today_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_hsgt_today_df.columns[3:]             # <<<<<<<<<<<<<<
 *     stock_hsgt_today_df[cols_to_convert] = stock_hsgt_today_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return stock_hsgt_today_df
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_stock_hsgt_today_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_7, 3, 0, NULL, NULL, &__pyx_slice__8, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_cols_to_convert = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":458
 *     stock_hsgt_today_df["date"] = pd.to_datetime(stock_hsgt_today_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_hsgt_today_df.columns[3:]
 *     stock_hsgt_today_df[cols_to_convert] = stock_hsgt_today_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 *     return stock_hsgt_today_df
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_stock_hsgt_today_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_apply); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 458, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_hsgt_today_df, __pyx_v_cols_to_convert, __pyx_t_5) < 0))) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":459
 *     cols_to_convert = stock_hsgt_today_df.columns[3:]
 *     stock_hsgt_today_df[cols_to_convert] = stock_hsgt_today_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return stock_hsgt_today_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_stock_hsgt_today_df);
  __pyx_r = __pyx_v_stock_hsgt_today_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":398
 * 
 * 
 * def stock_all_hsgt_date(trade_date='2024-05-31') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_all_hsgt_date", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_stock_hsgt_today_df);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_total_pages);
  __Pyx_XDECREF(__pyx_v_page);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":462
 * 
 * 
 * def stock_hsgt_detail(mode='new', symbol: str = "000001") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/hsgt/StockHdDetail/601899.html
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_13stock_hsgt_detail(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_12stock_hsgt_detail, "\n    https://data.eastmoney.com/hsgt/StockHdDetail/601899.html\n\n    https://datacenter-web.eastmoney.com/api/data/v1/get\n    ?callback=jQuery1123014484142179972537_1717298504619\n    &sortColumns=TRADE_DATE\n    &sortTypes=-1\n    &pageSize=50\n    &pageNumber=1\n    &reportName=RPT_MUTUAL_HOLDSTOCKNDATE_STA\n    &columns=SECUCODE%2CSECURITY_CODE%2CSECURITY_NAME%2CTRADE_DATE%2CCLOSE_PRICE%2CCHANGE_RATE%2CHOLD_SHARES%2CHOLD_MARKET_CAP%2CA_SHARES_RATIO%2CHOLD_SHARES_RATIO%2CFREE_SHARES_RATIO%2CTOTAL_SHARES_RATIO%2CADD_SHARES_REPAIR%2CPREDICT_AMC%2CHMC_CHANGE\n    &filter=(SECUCODE%3D%22300696.SZ%22)(INTERVAL_TYPE%3D%221%22)\n    &source=WEB\n    &client=WEB\n\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_13stock_hsgt_detail = {"stock_hsgt_detail", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_13stock_hsgt_detail, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_12stock_hsgt_detail};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_13stock_hsgt_detail(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_mode = 0;
  PyObject *__pyx_v_symbol = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_hsgt_detail (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_mode,&__pyx_n_s_symbol,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_new)));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_kp_s_000001)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 462, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 462, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_hsgt_detail") < 0)) __PYX_ERR(0, 462, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_mode = values[0];
    __pyx_v_symbol = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_hsgt_detail", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 462, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_hsgt_detail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_symbol), (&PyString_Type), 0, "symbol", 1))) __PYX_ERR(0, 462, __pyx_L1_error)
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_12stock_hsgt_detail(__pyx_self, __pyx_v_mode, __pyx_v_symbol);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_12stock_hsgt_detail(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode, PyObject *__pyx_v_symbol) {
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_stock_hsgt_df = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_total_pages = NULL;
  PyObject *__pyx_v_page = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_hsgt_detail", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":480
 *     :return:
 *     '''
 *     column_dict = {'SECURITY_CODE': 'code',             # <<<<<<<<<<<<<<
 *                    'SECURITY_NAME': 'name',
 *                    'TRADE_DATE': 'date',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_CODE, __pyx_n_s_code) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_NAME, __pyx_n_s_name) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TRADE_DATE, __pyx_n_s_date) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CLOSE_PRICE, __pyx_n_s_close) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CHANGE_RATE, __pyx_n_s_change_rate) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLD_SHARES, __pyx_n_s_hold_volume) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLD_MARKET_CAP, __pyx_n_s_hold_amount) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_FREE_SHARES_RATIO, __pyx_n_s_hold_volume_ratio) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ADD_SHARES_REPAIR, __pyx_n_s_add_volume) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PREDICT_AMC, __pyx_n_s_add_amount) < 0) __PYX_ERR(0, 480, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":492
 *                    }
 * 
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "sortColumns": "TRADE_DATE",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_web_eastmoney_c);
  __pyx_v_url = __pyx_kp_s_https_datacenter_web_eastmoney_c;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":494
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
 *     params = {
 *         "sortColumns": "TRADE_DATE",             # <<<<<<<<<<<<<<
 *         "sortTypes": "-1",
 *         "pageSize": "500",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_n_s_TRADE_DATE) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_kp_s_1_3) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_kp_s_500) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_kp_s_1) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPT_MUTUAL_HOLDSTOCKNDATE_STA) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD_2) < 0) __PYX_ERR(0, 494, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":500
 *         "reportName": "RPT_MUTUAL_HOLDSTOCKNDATE_STA",
 *         "columns": "SECURITY_CODE,SECURITY_NAME,TRADE_DATE,CLOSE_PRICE,CHANGE_RATE,HOLD_SHARES,HOLD_MARKET_CAP,FREE_SHARES_RATIO,ADD_SHARES_REPAIR,PREDICT_AMC",
 *         "filter": f'(SECURITY_CODE="{symbol}")(INTERVAL_TYPE="1")',             # <<<<<<<<<<<<<<
 *         "source": "WEB",
 *         "client": "WEB"
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_SECURITY_CODE_2);
  __pyx_t_3 += 16;
  __Pyx_GIVEREF(__pyx_kp_u_SECURITY_CODE_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_SECURITY_CODE_2);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_symbol, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u_INTERVAL_TYPE_1_2);
  __pyx_t_3 += 21;
  __Pyx_GIVEREF(__pyx_kp_u_INTERVAL_TYPE_1_2);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_INTERVAL_TYPE_1_2);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_filter, __pyx_t_5) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_client, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":504
 *         "client": "WEB"
 *     }
 *     stock_hsgt_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     if mode == 'new':
 *         params.update({"pageSize": 50})
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_stock_hsgt_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":505
 *     }
 *     stock_hsgt_df = pd.DataFrame()
 *     if mode == 'new':             # <<<<<<<<<<<<<<
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 */
  __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_new, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 505, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":506
 *     stock_hsgt_df = pd.DataFrame()
 *     if mode == 'new':
 *         params.update({"pageSize": 50})             # <<<<<<<<<<<<<<
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_int_50) < 0) __PYX_ERR(0, 506, __pyx_L1_error)
    __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":507
 *     if mode == 'new':
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         stock_hsgt_df = pd.DataFrame(data_json["result"]["data"])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_requests); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_url)) __PYX_ERR(0, 507, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 507, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_r = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":508
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         stock_hsgt_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_v_data_json = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":509
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         stock_hsgt_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *     else:
 *         r = requests.get(url, params=params)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_5, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 509, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_stock_hsgt_df, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":505
 *     }
 *     stock_hsgt_df = pd.DataFrame()
 *     if mode == 'new':             # <<<<<<<<<<<<<<
 *         params.update({"pageSize": 50})
 *         r = requests.get(url, params=params)
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":511
 *         stock_hsgt_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_requests); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_url)) __PYX_ERR(0, 511, __pyx_L1_error);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 511, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_r = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":512
 *     else:
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_v_data_json = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":513
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])             # <<<<<<<<<<<<<<
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})
 */
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_5, __pyx_n_s_pages); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_total_pages = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":514
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *             params.update({"pageNumber": page})
 *             r = requests.get(url, params=params)
 */
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_total_pages, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1)) __PYX_ERR(0, 514, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5)) __PYX_ERR(0, 514, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
      __pyx_t_1 = __pyx_t_5; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 514, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 514, __pyx_L1_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 514, __pyx_L1_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 514, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 514, __pyx_L1_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 514, __pyx_L1_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 514, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_9(__pyx_t_1);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 514, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_page, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":515
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})             # <<<<<<<<<<<<<<
 *             r = requests.get(url, params=params)
 *             data_json = r.json()
 */
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_pageNumber, __pyx_v_page) < 0) __PYX_ERR(0, 515, __pyx_L1_error)
      __pyx_t_8 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":516
 *         for page in range(1, total_pages + 1):
 *             params.update({"pageNumber": page})
 *             r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_requests); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_v_url);
      __Pyx_GIVEREF(__pyx_v_url);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_url)) __PYX_ERR(0, 516, __pyx_L1_error);
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 516, __pyx_L1_error)
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":517
 *             params.update({"pageNumber": page})
 *             r = requests.get(url, params=params)
 *             data_json = r.json()             # <<<<<<<<<<<<<<
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 *             stock_hsgt_df = pd.concat([stock_hsgt_df, temp_df], ignore_index=True)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 517, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 517, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_data_json, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":518
 *             r = requests.get(url, params=params)
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *             stock_hsgt_df = pd.concat([stock_hsgt_df, temp_df], ignore_index=True)
 *     stock_hsgt_df = stock_hsgt_df[column_dict.keys()]
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 518, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 518, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 518, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 518, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
        __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 518, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_temp_df, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":519
 *             data_json = r.json()
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 *             stock_hsgt_df = pd.concat([stock_hsgt_df, temp_df], ignore_index=True)             # <<<<<<<<<<<<<<
 *     stock_hsgt_df = stock_hsgt_df[column_dict.keys()]
 *     stock_hsgt_df.columns = column_dict.values()
 */
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pd); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_concat); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyList_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_v_stock_hsgt_df);
      __Pyx_GIVEREF(__pyx_v_stock_hsgt_df);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_10, 0, __pyx_v_stock_hsgt_df)) __PYX_ERR(0, 519, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_temp_df);
      __Pyx_GIVEREF(__pyx_v_temp_df);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_10, 1, __pyx_v_temp_df)) __PYX_ERR(0, 519, __pyx_L1_error);
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_10);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_10)) __PYX_ERR(0, 519, __pyx_L1_error);
      __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 519, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_5, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF_SET(__pyx_v_stock_hsgt_df, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "tbstock/dataAcquisition/stockDataCrawler.py":514
 *         data_json = r.json()
 *         total_pages = int(data_json["result"]["pages"])
 *         for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *             params.update({"pageNumber": page})
 *             r = requests.get(url, params=params)
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":520
 *             temp_df = pd.DataFrame(data_json["result"]["data"])
 *             stock_hsgt_df = pd.concat([stock_hsgt_df, temp_df], ignore_index=True)
 *     stock_hsgt_df = stock_hsgt_df[column_dict.keys()]             # <<<<<<<<<<<<<<
 *     stock_hsgt_df.columns = column_dict.values()
 *     stock_hsgt_df["date"] = pd.to_datetime(stock_hsgt_df["date"], errors="coerce").dt.date
 */
  __pyx_t_1 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_stock_hsgt_df, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_stock_hsgt_df, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":521
 *             stock_hsgt_df = pd.concat([stock_hsgt_df, temp_df], ignore_index=True)
 *     stock_hsgt_df = stock_hsgt_df[column_dict.keys()]
 *     stock_hsgt_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 *     stock_hsgt_df["date"] = pd.to_datetime(stock_hsgt_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_hsgt_df.columns[3:]
 */
  __pyx_t_2 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_stock_hsgt_df, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":522
 *     stock_hsgt_df = stock_hsgt_df[column_dict.keys()]
 *     stock_hsgt_df.columns = column_dict.values()
 *     stock_hsgt_df["date"] = pd.to_datetime(stock_hsgt_df["date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     cols_to_convert = stock_hsgt_df.columns[3:]
 *     stock_hsgt_df[cols_to_convert] = stock_hsgt_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_stock_hsgt_df, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 522, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_hsgt_df, __pyx_n_s_date, __pyx_t_5) < 0))) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":523
 *     stock_hsgt_df.columns = column_dict.values()
 *     stock_hsgt_df["date"] = pd.to_datetime(stock_hsgt_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_hsgt_df.columns[3:]             # <<<<<<<<<<<<<<
 *     stock_hsgt_df[cols_to_convert] = stock_hsgt_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return stock_hsgt_df
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_stock_hsgt_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_5, 3, 0, NULL, NULL, &__pyx_slice__8, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_cols_to_convert = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":524
 *     stock_hsgt_df["date"] = pd.to_datetime(stock_hsgt_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_hsgt_df.columns[3:]
 *     stock_hsgt_df[cols_to_convert] = stock_hsgt_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 *     return stock_hsgt_df
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_stock_hsgt_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_10)) __PYX_ERR(0, 524, __pyx_L1_error);
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 524, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_hsgt_df, __pyx_v_cols_to_convert, __pyx_t_1) < 0))) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":525
 *     cols_to_convert = stock_hsgt_df.columns[3:]
 *     stock_hsgt_df[cols_to_convert] = stock_hsgt_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return stock_hsgt_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_stock_hsgt_df);
  __pyx_r = __pyx_v_stock_hsgt_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":462
 * 
 * 
 * def stock_hsgt_detail(mode='new', symbol: str = "000001") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/hsgt/StockHdDetail/601899.html
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_hsgt_detail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_stock_hsgt_df);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_total_pages);
  __Pyx_XDECREF(__pyx_v_page);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":528
 * 
 * 
 * def stock_zh_a_gdhs_detail_em(symbol: str = "000001.SZ") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     https://emweb.securities.eastmoney.com/pc_hsf10/pages/index.html?type=web&code=SZ300342&color=b#/gdyj
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_15stock_zh_a_gdhs_detail_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_14stock_zh_a_gdhs_detail_em, "\n    https://emweb.securities.eastmoney.com/pc_hsf10/pages/index.html?type=web&code=SZ300342&color=b#/gdyj\n    https://datacenter.eastmoney.com/securities/api/data/v1/get\n    ?reportName=RPT_F10_EH_HOLDERNUM\n    &columns=SECUCODE%2CSECURITY_CODE%2CEND_DATE%2CHOLDER_TOTAL_NUM%2CTOTAL_NUM_RATIO%2CAVG_FREE_SHARES%2CAVG_FREESHARES_RATIO%2CHOLD_FOCUS%2CPRICE%2CAVG_HOLD_AMT%2CHOLD_RATIO_TOTAL%2CFREEHOLD_RATIO_TOTAL\n    &quoteColumns=\n    &filter=(SECUCODE%3D%22000002.SZ%22)\n    &pageNumber=1\n    &pageSize=8\n    &sortTypes=-1\n    &sortColumns=END_DATE\n    &source=HSF10\n    &client=PC\n    &v=08730299565686817\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_15stock_zh_a_gdhs_detail_em = {"stock_zh_a_gdhs_detail_em", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_15stock_zh_a_gdhs_detail_em, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_14stock_zh_a_gdhs_detail_em};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_15stock_zh_a_gdhs_detail_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_symbol = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_zh_a_gdhs_detail_em (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_symbol,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_kp_s_000001_SZ)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 528, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_zh_a_gdhs_detail_em") < 0)) __PYX_ERR(0, 528, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_symbol = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_zh_a_gdhs_detail_em", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 528, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_zh_a_gdhs_detail_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_symbol), (&PyString_Type), 0, "symbol", 1))) __PYX_ERR(0, 528, __pyx_L1_error)
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_14stock_zh_a_gdhs_detail_em(__pyx_self, __pyx_v_symbol);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_14stock_zh_a_gdhs_detail_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol) {
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_column_dict = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_column_name_dict = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_stock_gdhs_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_zh_a_gdhs_detail_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":545
 *     """
 * 
 *     url = "https://datacenter.eastmoney.com/securities/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "reportName": "RPT_F10_EH_HOLDERNUM",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_eastmoney_com_s);
  __pyx_v_url = __pyx_kp_s_https_datacenter_eastmoney_com_s;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":547
 *     url = "https://datacenter.eastmoney.com/securities/api/data/v1/get"
 *     params = {
 *         "reportName": "RPT_F10_EH_HOLDERNUM",             # <<<<<<<<<<<<<<
 *         "columns": "SECURITY_CODE,SECURITY_NAME_ABBR,HOLD_FOCUS,END_DATE,NOTICE_DATE,HOLDER_TOTAL_NUM,TOTAL_NUM_RATIO,AVG_FREE_SHARES,AVG_FREESHARES_RATIO,PRICE,AVG_HOLD_AMT,HOLD_RATIO_TOTAL,FREEHOLD_RATIO_TOTAL",
 *         # "columns": "ALL",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPT_F10_EH_HOLDERNUM) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_kp_s_SECURITY_CODE_SECURITY_NAME_ABBR) < 0) __PYX_ERR(0, 547, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":550
 *         "columns": "SECURITY_CODE,SECURITY_NAME_ABBR,HOLD_FOCUS,END_DATE,NOTICE_DATE,HOLDER_TOTAL_NUM,TOTAL_NUM_RATIO,AVG_FREE_SHARES,AVG_FREESHARES_RATIO,PRICE,AVG_HOLD_AMT,HOLD_RATIO_TOTAL,FREEHOLD_RATIO_TOTAL",
 *         # "columns": "ALL",
 *         "filter": f'(SECUCODE="{symbol}")',             # <<<<<<<<<<<<<<
 *         "pageNumber": 1,
 *         "pageSize": 500,
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_SECUCODE);
  __pyx_t_3 += 11;
  __Pyx_GIVEREF(__pyx_kp_u_SECUCODE);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_SECUCODE);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_symbol, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__9);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__9);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__9);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_filter, __pyx_t_5) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_int_1) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_int_500) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_int_neg_1) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_n_s_END_DATE) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_HSF10) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_client, __pyx_n_s_PC) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_v, __pyx_kp_s_08730299565686817) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":559
 *         "v": "08730299565686817"
 *     }
 *     column_dict = {'SECURITY_CODE': 'code',             # <<<<<<<<<<<<<<
 *                    'SECURITY_NAME_ABBR': 'name',
 *                    'HOLD_FOCUS': 'hold_focus',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_CODE, __pyx_n_s_code) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_NAME_ABBR, __pyx_n_s_name) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLD_FOCUS, __pyx_n_s_hold_focus) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_END_DATE, __pyx_n_s_date) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NOTICE_DATE, __pyx_n_s_notice_date) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLDER_TOTAL_NUM, __pyx_n_s_holder_num) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOTAL_NUM_RATIO, __pyx_n_s_holder_num_ratio) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_AVG_FREE_SHARES, __pyx_n_s_avg_volume_pa) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_AVG_FREESHARES_RATIO, __pyx_n_s_avg_volume_pa_ratio) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PRICE, __pyx_n_s_price) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_AVG_HOLD_AMT, __pyx_n_s_avg_amount_pa) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLD_RATIO_TOTAL, __pyx_n_s_top_ten_ratio_total) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_FREEHOLD_RATIO_TOTAL, __pyx_n_s_top_ten_ratio_free) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":573
 *                    'FREEHOLD_RATIO_TOTAL': 'top_ten_ratio_free'
 *                    }
 *     column_name_dict = {'SECURITY_CODE': 'code',             # <<<<<<<<<<<<<<
 *                         'SECURITY_NAME_ABBR': 'name',
 *                         'HOLD_FOCUS': '',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_CODE, __pyx_n_s_code) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_NAME_ABBR, __pyx_n_s_name) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLD_FOCUS, __pyx_kp_s__10) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_END_DATE, __pyx_kp_s__11) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NOTICE_DATE, __pyx_kp_s__12) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLDER_TOTAL_NUM, __pyx_kp_s__13) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOTAL_NUM_RATIO, __pyx_kp_s__14) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_AVG_FREE_SHARES, __pyx_kp_s__15) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_AVG_FREESHARES_RATIO, __pyx_kp_s__16) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PRICE, __pyx_kp_s__17) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_AVG_HOLD_AMT, __pyx_kp_s__18) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_HOLD_RATIO_TOTAL, __pyx_kp_s__19) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_FREEHOLD_RATIO_TOTAL, __pyx_kp_s__20) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  __pyx_v_column_name_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":587
 *                         'FREEHOLD_RATIO_TOTAL': '%'
 *                         }
 *     r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 *     stock_gdhs_df = pd.DataFrame(data_json["result"]["data"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 587, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 587, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_r = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":588
 *                         }
 *     r = requests.get(url, params=params)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 *     stock_gdhs_df = pd.DataFrame(data_json["result"]["data"])
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 588, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_data_json = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":589
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 *     stock_gdhs_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 * 
 *     stock_gdhs_df = stock_gdhs_df[column_dict.keys()]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_stock_gdhs_df = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":591
 *     stock_gdhs_df = pd.DataFrame(data_json["result"]["data"])
 * 
 *     stock_gdhs_df = stock_gdhs_df[column_dict.keys()]             # <<<<<<<<<<<<<<
 *     stock_gdhs_df.columns = column_dict.values()
 * 
 */
  __pyx_t_6 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_stock_gdhs_df, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_stock_gdhs_df, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":592
 * 
 *     stock_gdhs_df = stock_gdhs_df[column_dict.keys()]
 *     stock_gdhs_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 * 
 *     stock_gdhs_df["date"] = pd.to_datetime(stock_gdhs_df["date"], errors="coerce").dt.date
 */
  __pyx_t_1 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_stock_gdhs_df, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":594
 *     stock_gdhs_df.columns = column_dict.values()
 * 
 *     stock_gdhs_df["date"] = pd.to_datetime(stock_gdhs_df["date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     stock_gdhs_df["notice_date"] = pd.to_datetime(stock_gdhs_df["notice_date"], errors="coerce").dt.date
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_stock_gdhs_df, __pyx_n_s_date); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 594, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_gdhs_df, __pyx_n_s_date, __pyx_t_2) < 0))) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":595
 * 
 *     stock_gdhs_df["date"] = pd.to_datetime(stock_gdhs_df["date"], errors="coerce").dt.date
 *     stock_gdhs_df["notice_date"] = pd.to_datetime(stock_gdhs_df["notice_date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 * 
 *     cols_to_convert = stock_gdhs_df.columns[5:]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_stock_gdhs_df, __pyx_n_s_notice_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 595, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_gdhs_df, __pyx_n_s_notice_date, __pyx_t_6) < 0))) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":597
 *     stock_gdhs_df["notice_date"] = pd.to_datetime(stock_gdhs_df["notice_date"], errors="coerce").dt.date
 * 
 *     cols_to_convert = stock_gdhs_df.columns[5:]             # <<<<<<<<<<<<<<
 *     stock_gdhs_df[cols_to_convert] = stock_gdhs_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_stock_gdhs_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_6, 5, 0, NULL, NULL, &__pyx_slice__21, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_cols_to_convert = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":598
 * 
 *     cols_to_convert = stock_gdhs_df.columns[5:]
 *     stock_gdhs_df[cols_to_convert] = stock_gdhs_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 * 
 *     return stock_gdhs_df
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_stock_gdhs_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_apply); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5)) __PYX_ERR(0, 598, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 598, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_stock_gdhs_df, __pyx_v_cols_to_convert, __pyx_t_1) < 0))) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":600
 *     stock_gdhs_df[cols_to_convert] = stock_gdhs_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 * 
 *     return stock_gdhs_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_stock_gdhs_df);
  __pyx_r = __pyx_v_stock_gdhs_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":528
 * 
 * 
 * def stock_zh_a_gdhs_detail_em(symbol: str = "000001.SZ") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     https://emweb.securities.eastmoney.com/pc_hsf10/pages/index.html?type=web&code=SZ300342&color=b#/gdyj
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_zh_a_gdhs_detail_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_column_name_dict);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_stock_gdhs_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":603
 * 
 * 
 * def stock_finance_mfd_quarter_em(symbol: str = "688235.SH", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_17stock_finance_mfd_quarter_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_16stock_finance_mfd_quarter_em, "\n    \350\216\267\345\217\226\344\270\234\346\226\271\350\264\242\345\257\214\357\274\214\345\215\225\345\255\243\345\272\246\357\274\214\344\270\273\350\246\201\350\264\242\345\212\241\346\214\207\346\240\207\n    https://emweb.securities.eastmoney.com/pc_hsf10/pages/index.html?type=web&code=SZ300342&color=b#/cwfx\n\n    https://datacenter.eastmoney.com/securities/api/data/v1/get\n    ?reportName=RPT_F10_QTR_MAINFINADATA\n    &columns=ALL\n    &quoteColumns=\n    &filter=(SECUCODE%3D%22002567.SZ%22)\n    &pageNumber=1\n    &pageSize=9\n    &sortTypes=-1\n    &sortColumns=REPORT_DATE\n    &source=HSF10\n    &client=PC\n    &v=007949902328317804\n\n    :param symbol:\n    :param timeout:\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_17stock_finance_mfd_quarter_em = {"stock_finance_mfd_quarter_em", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_17stock_finance_mfd_quarter_em, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_16stock_finance_mfd_quarter_em};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_17stock_finance_mfd_quarter_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_finance_mfd_quarter_em (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_symbol,&__pyx_n_s_timeout,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_kp_s_688235_SH)));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 603, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_timeout);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 603, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_finance_mfd_quarter_em") < 0)) __PYX_ERR(0, 603, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_symbol = ((PyObject*)values[0]);
    __pyx_v_timeout = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_finance_mfd_quarter_em", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 603, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_finance_mfd_quarter_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_symbol), (&PyString_Type), 0, "symbol", 1))) __PYX_ERR(0, 603, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_timeout), (&PyFloat_Type), 1, "timeout", 1))) __PYX_ERR(0, 603, __pyx_L1_error)
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_16stock_finance_mfd_quarter_em(__pyx_self, __pyx_v_symbol, __pyx_v_timeout);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_16stock_finance_mfd_quarter_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_finance_mfd_quarter_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_finance_mfd_quarter_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":625
 *     :return:
 *     '''
 *     url = "https://datacenter.eastmoney.com/securities/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "reportName": "RPT_F10_QTR_MAINFINADATA",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_eastmoney_com_s);
  __pyx_v_url = __pyx_kp_s_https_datacenter_eastmoney_com_s;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":627
 *     url = "https://datacenter.eastmoney.com/securities/api/data/v1/get"
 *     params = {
 *         "reportName": "RPT_F10_QTR_MAINFINADATA",             # <<<<<<<<<<<<<<
 *         "columns": "ALL",
 *         "filter": f'(SECUCODE="{symbol}")',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPT_F10_QTR_MAINFINADATA) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_n_s_ALL) < 0) __PYX_ERR(0, 627, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":629
 *         "reportName": "RPT_F10_QTR_MAINFINADATA",
 *         "columns": "ALL",
 *         "filter": f'(SECUCODE="{symbol}")',             # <<<<<<<<<<<<<<
 *         "pageNumber": 1,
 *         "pageSize": 25,  # 2018
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_SECUCODE);
  __pyx_t_3 += 11;
  __Pyx_GIVEREF(__pyx_kp_u_SECUCODE);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_SECUCODE);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_symbol, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__9);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__9);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__9);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_filter, __pyx_t_5) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_int_1) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_int_25) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_int_neg_1) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_n_s_REPORT_DATE) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_HSF10) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_client, __pyx_n_s_PC) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_v, __pyx_kp_s_007949902328317804) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":639
 *     }
 * 
 *     column_dict = {'SECURITY_CODE': 'code',             # <<<<<<<<<<<<<<
 *                    'SECURITY_NAME_ABBR': 'name',
 *                    'REPORT_DATE': 'report_date',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(22); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_CODE, __pyx_n_s_code) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_NAME_ABBR, __pyx_n_s_name) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_REPORT_DATE, __pyx_n_s_report_date) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_EPSJB, __pyx_n_s_eps_jb) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_BPS, __pyx_n_s_bps) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PER_CAPITAL_RESERVE, __pyx_n_s_capital_reserve_ps) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PER_UNASSIGN_PROFIT, __pyx_n_s_unassign_profit_ps) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PER_NETCASH, __pyx_n_s_net_cash_ps) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOTALOPERATEREVE, __pyx_n_s_total_operate_revenue) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_GROSS_PROFIT, __pyx_n_s_gross_profit) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PARENTNETPROFIT, __pyx_n_s_parent_net_profit) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_DEDU_PARENT_PROFIT, __pyx_n_s_kf_net_profit) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOTALOPERATEREVETZ, __pyx_n_s_total_operate_revenue_tb) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PARENTNETPROFITTZ, __pyx_n_s_parent_net_profit_tb) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_DPNP_YOY_RATIO, __pyx_n_s_kf_net_profit_tb) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_YYZSRGDHBZC, __pyx_n_s_total_operate_revenue_hb) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NETPROFITRPHBZC, __pyx_n_s_parent_net_profit_hb) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_KFJLRGDHBZC, __pyx_n_s_kf_net_profit_hb) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ROE_DILUTED, __pyx_n_s_roe_jzc) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_JROA, __pyx_n_s_roe_zzc) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_GROSS_PROFIT_RATIO, __pyx_n_s_gross_profit_ratio) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NET_PROFIT_RATIO, __pyx_n_s_net_profit_ratio) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":663
 *                    }
 * 
 *     r = requests.get(url, params=params, timeout=timeout)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 *     finance_mfd_quarter_df = pd.DataFrame(data_json["result"]["data"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 663, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 663, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_timeout, __pyx_v_timeout) < 0) __PYX_ERR(0, 663, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_r = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":664
 * 
 *     r = requests.get(url, params=params, timeout=timeout)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 *     finance_mfd_quarter_df = pd.DataFrame(data_json["result"]["data"])
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_data_json = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":665
 *     r = requests.get(url, params=params, timeout=timeout)
 *     data_json = r.json()
 *     finance_mfd_quarter_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 * 
 *     finance_mfd_quarter_df = finance_mfd_quarter_df[column_dict.keys()]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 665, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_finance_mfd_quarter_df = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":667
 *     finance_mfd_quarter_df = pd.DataFrame(data_json["result"]["data"])
 * 
 *     finance_mfd_quarter_df = finance_mfd_quarter_df[column_dict.keys()]             # <<<<<<<<<<<<<<
 *     finance_mfd_quarter_df.columns = column_dict.values()
 * 
 */
  __pyx_t_6 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_finance_mfd_quarter_df, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_finance_mfd_quarter_df, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":668
 * 
 *     finance_mfd_quarter_df = finance_mfd_quarter_df[column_dict.keys()]
 *     finance_mfd_quarter_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 * 
 *     finance_mfd_quarter_df["report_date"] = pd.to_datetime(finance_mfd_quarter_df["report_date"], errors="coerce").dt.date
 */
  __pyx_t_1 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_finance_mfd_quarter_df, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":670
 *     finance_mfd_quarter_df.columns = column_dict.values()
 * 
 *     finance_mfd_quarter_df["report_date"] = pd.to_datetime(finance_mfd_quarter_df["report_date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 * 
 *     cols_to_convert = finance_mfd_quarter_df.columns[3:]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_finance_mfd_quarter_df, __pyx_n_s_report_date); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 670, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_finance_mfd_quarter_df, __pyx_n_s_report_date, __pyx_t_2) < 0))) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":672
 *     finance_mfd_quarter_df["report_date"] = pd.to_datetime(finance_mfd_quarter_df["report_date"], errors="coerce").dt.date
 * 
 *     cols_to_convert = finance_mfd_quarter_df.columns[3:]             # <<<<<<<<<<<<<<
 *     finance_mfd_quarter_df[cols_to_convert] = finance_mfd_quarter_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_finance_mfd_quarter_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_2, 3, 0, NULL, NULL, &__pyx_slice__8, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_cols_to_convert = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":673
 * 
 *     cols_to_convert = finance_mfd_quarter_df.columns[3:]
 *     finance_mfd_quarter_df[cols_to_convert] = finance_mfd_quarter_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 * 
 *     return finance_mfd_quarter_df
 */
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_finance_mfd_quarter_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_apply); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5)) __PYX_ERR(0, 673, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 673, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_finance_mfd_quarter_df, __pyx_v_cols_to_convert, __pyx_t_6) < 0))) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":675
 *     finance_mfd_quarter_df[cols_to_convert] = finance_mfd_quarter_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 * 
 *     return finance_mfd_quarter_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_finance_mfd_quarter_df);
  __pyx_r = __pyx_v_finance_mfd_quarter_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":603
 * 
 * 
 * def stock_finance_mfd_quarter_em(symbol: str = "688235.SH", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_finance_mfd_quarter_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_finance_mfd_quarter_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":678
 * 
 * 
 * def stock_finance_mfd_report_em(symbol: str = "688235.SH", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_19stock_finance_mfd_report_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_18stock_finance_mfd_report_em, "\n    \350\216\267\345\217\226\344\270\234\346\226\271\350\264\242\345\257\214\357\274\214\346\212\245\345\221\212\346\234\237\357\274\214\344\270\273\350\246\201\350\264\242\345\212\241\346\214\207\346\240\207\n    https://emweb.securities.eastmoney.com/pc_hsf10/pages/index.html?type=web&code=SZ300342&color=b#/cwfx\n\n    https://datacenter.eastmoney.com/securities/api/data/get\n    ?type=RPT_F10_FINANCE_MAINFINADATA\n    &sty=APP_F10_MAINFINADATA\n    &quoteColumns=\n    &filter=(SECUCODE%3D%22002567.SZ%22)\n    &p=1\n    &ps=9\n    &sr=-1\n    &st=REPORT_DATE\n    &source=HSF10\n    &client=PC\n    &v=018998368837725255\n    :param symbol:\n    :param timeout:\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_19stock_finance_mfd_report_em = {"stock_finance_mfd_report_em", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_19stock_finance_mfd_report_em, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_18stock_finance_mfd_report_em};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_19stock_finance_mfd_report_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_finance_mfd_report_em (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_symbol,&__pyx_n_s_timeout,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_kp_s_688235_SH)));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 678, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_timeout);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 678, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_finance_mfd_report_em") < 0)) __PYX_ERR(0, 678, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_symbol = ((PyObject*)values[0]);
    __pyx_v_timeout = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_finance_mfd_report_em", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 678, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_finance_mfd_report_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_symbol), (&PyString_Type), 0, "symbol", 1))) __PYX_ERR(0, 678, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_timeout), (&PyFloat_Type), 1, "timeout", 1))) __PYX_ERR(0, 678, __pyx_L1_error)
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_18stock_finance_mfd_report_em(__pyx_self, __pyx_v_symbol, __pyx_v_timeout);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_18stock_finance_mfd_report_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_column_dict = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_column_name_dict = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_finance_mfd_report_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_finance_mfd_report_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":700
 *     '''
 * 
 *     url = "https://datacenter.eastmoney.com/securities/api/data/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         'type': 'RPT_F10_FINANCE_MAINFINADATA',
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_eastmoney_com_s_2);
  __pyx_v_url = __pyx_kp_s_https_datacenter_eastmoney_com_s_2;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":702
 *     url = "https://datacenter.eastmoney.com/securities/api/data/get"
 *     params = {
 *         'type': 'RPT_F10_FINANCE_MAINFINADATA',             # <<<<<<<<<<<<<<
 *         'sty': 'APP_F10_MAINFINADATA',
 *         'filter': f'(SECUCODE="{symbol}")',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_RPT_F10_FINANCE_MAINFINADATA) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sty, __pyx_n_s_APP_F10_MAINFINADATA) < 0) __PYX_ERR(0, 702, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":704
 *         'type': 'RPT_F10_FINANCE_MAINFINADATA',
 *         'sty': 'APP_F10_MAINFINADATA',
 *         'filter': f'(SECUCODE="{symbol}")',             # <<<<<<<<<<<<<<
 *         'p': 1,
 *         'ps': 25,  # 2018
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_SECUCODE);
  __pyx_t_3 += 11;
  __Pyx_GIVEREF(__pyx_kp_u_SECUCODE);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_SECUCODE);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_symbol, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__9);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__9);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__9);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_filter, __pyx_t_5) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_p, __pyx_int_1) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ps, __pyx_int_25) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sr, __pyx_int_neg_1) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_st, __pyx_n_s_REPORT_DATE) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_HSF10) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_client, __pyx_n_s_PC) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_v, __pyx_kp_s_018998368837725255) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":714
 *     }
 * 
 *     column_dict = {'SECURITY_CODE': 'code',             # <<<<<<<<<<<<<<
 *                    'SECURITY_NAME_ABBR': 'name',
 *                    'REPORT_DATE': 'report_date',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(41); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_CODE, __pyx_n_s_code) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_NAME_ABBR, __pyx_n_s_name) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_REPORT_DATE, __pyx_n_s_report_date) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NOTICE_DATE, __pyx_n_s_notice_date) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_EPSJB, __pyx_n_s_eps_jb) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_EPSKCJB, __pyx_n_s_eps_kf) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_EPSXS, __pyx_n_s_eps_xs) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_BPS, __pyx_n_s_bps) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_MGZBGJ, __pyx_n_s_capital_reserve_ps) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_MGWFPLR, __pyx_n_s_unassign_profit_ps) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_MGJYXJJE, __pyx_n_s_net_cash_ps) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOTALOPERATEREVE, __pyx_n_s_total_operate_revenue) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_MLR, __pyx_n_s_gross_profit) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PARENTNETPROFIT, __pyx_n_s_parent_net_profit) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_KCFJCXSYJLR, __pyx_n_s_kf_net_profit) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOTALOPERATEREVETZ, __pyx_n_s_total_operate_revenue_tb) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PARENTNETPROFITTZ, __pyx_n_s_parent_net_profit_tb) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_KCFJCXSYJLRTZ, __pyx_n_s_kf_net_profit_tb) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_YYZSRGDHBZC, __pyx_n_s_total_operate_revenue_hb) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NETPROFITRPHBZC, __pyx_n_s_parent_net_profit_hb) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_KFJLRGDHBZC, __pyx_n_s_kf_net_profit_hb) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ROEJQ, __pyx_n_s_roe_jzc) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ZZCJLL, __pyx_n_s_roe_zzc) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_XSMLL, __pyx_n_s_gross_profit_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_XSJLL, __pyx_n_s_net_profit_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_YSZKYYSR, __pyx_n_s_yszk_to_tor_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_XSJXLYYSR, __pyx_n_s_xsjxjl_to_tor_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_JYXJLYYSR, __pyx_n_s_jyjxjl_to_tor_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TAXRATE, __pyx_n_s_tax_rate) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_LD, __pyx_n_s_current_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SD, __pyx_n_s_quick_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_XJLLB, __pyx_n_s_cash_flow_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ZCFZL, __pyx_n_s_debt_to_asset_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_QYCS, __pyx_n_s_equity_multiplier) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CQBL, __pyx_n_s_equity_ratio) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ZZCZZTS, __pyx_n_s_zzc_zzts) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CHZZTS, __pyx_n_s_ch_zzts) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_YSZKZZTS, __pyx_n_s_yszk_zzts) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOAZZL, __pyx_n_s_zzc_zzl) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CHZZL, __pyx_n_s_ch_zzl) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_YSZKZZL, __pyx_n_s_yszk_zzl) < 0) __PYX_ERR(0, 714, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":756
 *                    'YSZKZZL': 'yszk_zzl'
 *                    }
 *     column_name_dict = {'SECURITY_CODE': 'code',             # <<<<<<<<<<<<<<
 *                         'SECURITY_NAME_ABBR': 'name',
 *                         'REPORT_DATE': '',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(41); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_CODE, __pyx_n_s_code) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_NAME_ABBR, __pyx_n_s_name) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_REPORT_DATE, __pyx_kp_s__22) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NOTICE_DATE, __pyx_kp_s__23) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_EPSJB, __pyx_kp_s__24) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_EPSKCJB, __pyx_kp_s__25) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_EPSXS, __pyx_kp_s__26) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_BPS, __pyx_kp_s__27) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_MGZBGJ, __pyx_kp_s__28) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_MGWFPLR, __pyx_kp_s__29) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_MGJYXJJE, __pyx_kp_s__30) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOTALOPERATEREVE, __pyx_kp_s__31) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_MLR, __pyx_kp_s__32) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PARENTNETPROFIT, __pyx_kp_s__33) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_KCFJCXSYJLR, __pyx_kp_s__34) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOTALOPERATEREVETZ, __pyx_kp_s__35) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PARENTNETPROFITTZ, __pyx_kp_s__36) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_KCFJCXSYJLRTZ, __pyx_kp_s__37) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_YYZSRGDHBZC, __pyx_kp_s__38) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_NETPROFITRPHBZC, __pyx_kp_s__39) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_KFJLRGDHBZC, __pyx_kp_s__40) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ROEJQ, __pyx_kp_s__41) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ZZCJLL, __pyx_kp_s__42) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_XSJLL, __pyx_kp_s__43) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_XSMLL, __pyx_kp_s__44) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_YSZKYYSR, __pyx_kp_s__45) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_XSJXLYYSR, __pyx_kp_s__46) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_JYXJLYYSR, __pyx_kp_s__47) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TAXRATE, __pyx_kp_s__48) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_LD, __pyx_kp_s__49) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SD, __pyx_kp_s__50) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_XJLLB, __pyx_kp_s__51) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ZCFZL, __pyx_kp_s__52) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_QYCS, __pyx_kp_s__53) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CQBL, __pyx_kp_s__54) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ZZCZZTS, __pyx_kp_s__55) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CHZZTS, __pyx_kp_s__56) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_YSZKZZTS, __pyx_kp_s__57) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TOAZZL, __pyx_kp_s__58) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CHZZL, __pyx_kp_s__59) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_YSZKZZL, __pyx_kp_s__60) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  __pyx_v_column_name_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":798
 *                         'YSZKZZL': '()'
 *                         }
 *     r = requests.get(url, params=params, timeout=timeout)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 *     finance_mfd_report_df = pd.DataFrame(data_json["result"]["data"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 798, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 798, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_timeout, __pyx_v_timeout) < 0) __PYX_ERR(0, 798, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_r = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":799
 *                         }
 *     r = requests.get(url, params=params, timeout=timeout)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 *     finance_mfd_report_df = pd.DataFrame(data_json["result"]["data"])
 *     finance_mfd_report_df = finance_mfd_report_df[column_dict.keys()]
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_data_json = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":800
 *     r = requests.get(url, params=params, timeout=timeout)
 *     data_json = r.json()
 *     finance_mfd_report_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *     finance_mfd_report_df = finance_mfd_report_df[column_dict.keys()]
 *     finance_mfd_report_df.columns = column_dict.values()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 800, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_finance_mfd_report_df = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":801
 *     data_json = r.json()
 *     finance_mfd_report_df = pd.DataFrame(data_json["result"]["data"])
 *     finance_mfd_report_df = finance_mfd_report_df[column_dict.keys()]             # <<<<<<<<<<<<<<
 *     finance_mfd_report_df.columns = column_dict.values()
 * 
 */
  __pyx_t_6 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_finance_mfd_report_df, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_finance_mfd_report_df, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":802
 *     finance_mfd_report_df = pd.DataFrame(data_json["result"]["data"])
 *     finance_mfd_report_df = finance_mfd_report_df[column_dict.keys()]
 *     finance_mfd_report_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 * 
 *     finance_mfd_report_df["report_date"] = pd.to_datetime(finance_mfd_report_df["report_date"], errors="coerce").dt.date
 */
  __pyx_t_1 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_finance_mfd_report_df, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":804
 *     finance_mfd_report_df.columns = column_dict.values()
 * 
 *     finance_mfd_report_df["report_date"] = pd.to_datetime(finance_mfd_report_df["report_date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     finance_mfd_report_df["notice_date"] = pd.to_datetime(finance_mfd_report_df["notice_date"], errors="coerce").dt.date
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_finance_mfd_report_df, __pyx_n_s_report_date); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 804, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 804, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_finance_mfd_report_df, __pyx_n_s_report_date, __pyx_t_2) < 0))) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":805
 * 
 *     finance_mfd_report_df["report_date"] = pd.to_datetime(finance_mfd_report_df["report_date"], errors="coerce").dt.date
 *     finance_mfd_report_df["notice_date"] = pd.to_datetime(finance_mfd_report_df["notice_date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 * 
 *     cols_to_convert = finance_mfd_report_df.columns[4:]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_finance_mfd_report_df, __pyx_n_s_notice_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 805, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 805, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_finance_mfd_report_df, __pyx_n_s_notice_date, __pyx_t_6) < 0))) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":807
 *     finance_mfd_report_df["notice_date"] = pd.to_datetime(finance_mfd_report_df["notice_date"], errors="coerce").dt.date
 * 
 *     cols_to_convert = finance_mfd_report_df.columns[4:]             # <<<<<<<<<<<<<<
 *     finance_mfd_report_df[cols_to_convert] = finance_mfd_report_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return finance_mfd_report_df
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_finance_mfd_report_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_6, 4, 0, NULL, NULL, &__pyx_slice__61, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_cols_to_convert = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":808
 * 
 *     cols_to_convert = finance_mfd_report_df.columns[4:]
 *     finance_mfd_report_df[cols_to_convert] = finance_mfd_report_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 *     return finance_mfd_report_df
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_finance_mfd_report_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_apply); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5)) __PYX_ERR(0, 808, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 808, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_finance_mfd_report_df, __pyx_v_cols_to_convert, __pyx_t_1) < 0))) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":809
 *     cols_to_convert = finance_mfd_report_df.columns[4:]
 *     finance_mfd_report_df[cols_to_convert] = finance_mfd_report_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return finance_mfd_report_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_finance_mfd_report_df);
  __pyx_r = __pyx_v_finance_mfd_report_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":678
 * 
 * 
 * def stock_finance_mfd_report_em(symbol: str = "688235.SH", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_finance_mfd_report_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_column_name_dict);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_finance_mfd_report_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":812
 * 
 * 
 * def stock_individual_info_em(symbol: str = "688235", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     --
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_21stock_individual_info_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_20stock_individual_info_em, "\n    \344\270\234\346\226\271\350\264\242\345\257\214-\344\270\252\350\202\241-\350\202\241\347\245\250\344\277\241\346\201\257\n    https://quote.eastmoney.com/concept/sh603777.html?from=classic\n    :param symbol: \350\202\241\347\245\250\344\273\243\347\240\201\n    :type symbol: str\n    :param timeout: choice of None or a positive float number\n    :type timeout: float\n    :return: \350\202\241\347\245\250\344\277\241\346\201\257\n    :rtype: pandas.DataFrame\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_21stock_individual_info_em = {"stock_individual_info_em", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_21stock_individual_info_em, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_20stock_individual_info_em};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_21stock_individual_info_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_individual_info_em (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_symbol,&__pyx_n_s_timeout,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_kp_s_688235)));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 812, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_timeout);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 812, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_individual_info_em") < 0)) __PYX_ERR(0, 812, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_symbol = ((PyObject*)values[0]);
    __pyx_v_timeout = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_individual_info_em", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 812, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_individual_info_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_symbol), (&PyString_Type), 0, "symbol", 1))) __PYX_ERR(0, 812, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_timeout), (&PyFloat_Type), 1, "timeout", 1))) __PYX_ERR(0, 812, __pyx_L1_error)
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_20stock_individual_info_em(__pyx_self, __pyx_v_symbol, __pyx_v_timeout);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_20stock_individual_info_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_v_code_id_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_code_name_map = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_individual_info_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":823
 *     :rtype: pandas.DataFrame
 *     """
 *     code_id_dict = code_id_map_em()             # <<<<<<<<<<<<<<
 *     url = "http://push2.eastmoney.com/api/qt/stock/get"
 *     params = {
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_code_id_map_em); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 823, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_code_id_dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":824
 *     """
 *     code_id_dict = code_id_map_em()
 *     url = "http://push2.eastmoney.com/api/qt/stock/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "ut": "fa5fd1943c7b386f172d6893dbfba10b",
 */
  __Pyx_INCREF(__pyx_kp_s_http_push2_eastmoney_com_api_qt);
  __pyx_v_url = __pyx_kp_s_http_push2_eastmoney_com_api_qt;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":826
 *     url = "http://push2.eastmoney.com/api/qt/stock/get"
 *     params = {
 *         "ut": "fa5fd1943c7b386f172d6893dbfba10b",             # <<<<<<<<<<<<<<
 *         "fltt": "2",
 *         "invt": "2",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ut, __pyx_n_s_fa5fd1943c7b386f172d6893dbfba10b) < 0) __PYX_ERR(0, 826, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fltt, __pyx_kp_s_2) < 0) __PYX_ERR(0, 826, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_invt, __pyx_kp_s_2) < 0) __PYX_ERR(0, 826, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fields, __pyx_kp_s_f120_f121_f122_f174_f175_f59_f16) < 0) __PYX_ERR(0, 826, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":830
 *         "invt": "2",
 *         "fields": "f120,f121,f122,f174,f175,f59,f163,f43,f57,f58,f169,f170,f46,f44,f51,f168,f47,f164,f116,f60,f45,f52,f50,f48,f167,f117,f71,f161,f49,f530,f135,f136,f137,f138,f139,f141,f142,f144,f145,f147,f148,f140,f143,f146,f149,f55,f62,f162,f92,f173,f104,f105,f84,f85,f183,f184,f185,f186,f187,f188,f189,f190,f191,f192,f107,f111,f86,f177,f78,f110,f262,f263,f264,f267,f268,f255,f256,f257,f258,f127,f199,f128,f198,f259,f260,f261,f171,f277,f278,f279,f288,f152,f250,f251,f252,f253,f254,f269,f270,f271,f272,f273,f274,f275,f276,f265,f266,f289,f290,f286,f285,f292,f293,f294,f295",
 *         "secid": f"{code_id_dict[symbol]}.{symbol}",             # <<<<<<<<<<<<<<
 *         "_": "1640157544804",
 *     }
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = 0;
  __pyx_t_6 = 127;
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_code_id_dict, __pyx_v_symbol); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_INCREF(__pyx_kp_u__62);
  __pyx_t_5 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__62);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_kp_u__62);
  __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_v_symbol, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_secid, __pyx_t_7) < 0) __PYX_ERR(0, 826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s__3, __pyx_kp_s_1640157544804) < 0) __PYX_ERR(0, 826, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":833
 *         "_": "1640157544804",
 *     }
 *     r = requests.get(url, params=params, timeout=timeout)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 *     temp_df = pd.DataFrame(data_json)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 833, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 833, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_timeout, __pyx_v_timeout) < 0) __PYX_ERR(0, 833, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_r = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":834
 *     }
 *     r = requests.get(url, params=params, timeout=timeout)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 *     temp_df = pd.DataFrame(data_json)
 *     temp_df.reset_index(inplace=True)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 834, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_data_json = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":835
 *     r = requests.get(url, params=params, timeout=timeout)
 *     data_json = r.json()
 *     temp_df = pd.DataFrame(data_json)             # <<<<<<<<<<<<<<
 *     temp_df.reset_index(inplace=True)
 *     del temp_df["rc"]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_data_json};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_temp_df = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":836
 *     data_json = r.json()
 *     temp_df = pd.DataFrame(data_json)
 *     temp_df.reset_index(inplace=True)             # <<<<<<<<<<<<<<
 *     del temp_df["rc"]
 *     del temp_df["rt"]
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_temp_df, __pyx_n_s_reset_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_inplace, Py_True) < 0) __PYX_ERR(0, 836, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":837
 *     temp_df = pd.DataFrame(data_json)
 *     temp_df.reset_index(inplace=True)
 *     del temp_df["rc"]             # <<<<<<<<<<<<<<
 *     del temp_df["rt"]
 *     del temp_df["svr"]
 */
  if (unlikely((PyObject_DelItem(__pyx_v_temp_df, __pyx_n_s_rc) < 0))) __PYX_ERR(0, 837, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":838
 *     temp_df.reset_index(inplace=True)
 *     del temp_df["rc"]
 *     del temp_df["rt"]             # <<<<<<<<<<<<<<
 *     del temp_df["svr"]
 *     del temp_df["lt"]
 */
  if (unlikely((PyObject_DelItem(__pyx_v_temp_df, __pyx_n_s_rt) < 0))) __PYX_ERR(0, 838, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":839
 *     del temp_df["rc"]
 *     del temp_df["rt"]
 *     del temp_df["svr"]             # <<<<<<<<<<<<<<
 *     del temp_df["lt"]
 *     del temp_df["full"]
 */
  if (unlikely((PyObject_DelItem(__pyx_v_temp_df, __pyx_n_s_svr) < 0))) __PYX_ERR(0, 839, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":840
 *     del temp_df["rt"]
 *     del temp_df["svr"]
 *     del temp_df["lt"]             # <<<<<<<<<<<<<<
 *     del temp_df["full"]
 *     code_name_map = {
 */
  if (unlikely((PyObject_DelItem(__pyx_v_temp_df, __pyx_n_s_lt) < 0))) __PYX_ERR(0, 840, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":841
 *     del temp_df["svr"]
 *     del temp_df["lt"]
 *     del temp_df["full"]             # <<<<<<<<<<<<<<
 *     code_name_map = {
 *         "f57": "",
 */
  if (unlikely((PyObject_DelItem(__pyx_v_temp_df, __pyx_n_s_full) < 0))) __PYX_ERR(0, 841, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":843
 *     del temp_df["full"]
 *     code_name_map = {
 *         "f57": "",             # <<<<<<<<<<<<<<
 *         "f58": "",
 *         "f84": "",
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_f57, __pyx_kp_s__63) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_f58, __pyx_kp_s__64) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_f84, __pyx_kp_s__65) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_f85, __pyx_kp_s__66) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_f127, __pyx_kp_s__67) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_f116, __pyx_kp_s__68) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_f117, __pyx_kp_s__69) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_f128, __pyx_kp_s__70) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_f189, __pyx_kp_s__71) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  __pyx_v_code_name_map = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":853
 *         "f189": "",
 *     }
 *     temp_df["index"] = temp_df["index"].map(code_name_map)             # <<<<<<<<<<<<<<
 *     temp_df = temp_df[pd.notna(temp_df["index"])]
 *     if "dlmkts" in temp_df.columns:
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_temp_df, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_map); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_code_name_map};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 853, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (unlikely((PyObject_SetItem(__pyx_v_temp_df, __pyx_n_s_index, __pyx_t_2) < 0))) __PYX_ERR(0, 853, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":854
 *     }
 *     temp_df["index"] = temp_df["index"].map(code_name_map)
 *     temp_df = temp_df[pd.notna(temp_df["index"])]             # <<<<<<<<<<<<<<
 *     if "dlmkts" in temp_df.columns:
 *         del temp_df["dlmkts"]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_notna); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_temp_df, __pyx_n_s_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 854, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_temp_df, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_temp_df, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":855
 *     temp_df["index"] = temp_df["index"].map(code_name_map)
 *     temp_df = temp_df[pd.notna(temp_df["index"])]
 *     if "dlmkts" in temp_df.columns:             # <<<<<<<<<<<<<<
 *         del temp_df["dlmkts"]
 *     temp_df.columns = [
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_temp_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_dlmkts, __pyx_t_1, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 855, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_8) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":856
 *     temp_df = temp_df[pd.notna(temp_df["index"])]
 *     if "dlmkts" in temp_df.columns:
 *         del temp_df["dlmkts"]             # <<<<<<<<<<<<<<
 *     temp_df.columns = [
 *         "item",
 */
    if (unlikely((PyObject_DelItem(__pyx_v_temp_df, __pyx_n_s_dlmkts) < 0))) __PYX_ERR(0, 856, __pyx_L1_error)

    /* "tbstock/dataAcquisition/stockDataCrawler.py":855
 *     temp_df["index"] = temp_df["index"].map(code_name_map)
 *     temp_df = temp_df[pd.notna(temp_df["index"])]
 *     if "dlmkts" in temp_df.columns:             # <<<<<<<<<<<<<<
 *         del temp_df["dlmkts"]
 *     temp_df.columns = [
 */
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":857
 *     if "dlmkts" in temp_df.columns:
 *         del temp_df["dlmkts"]
 *     temp_df.columns = [             # <<<<<<<<<<<<<<
 *         "item",
 *         "value",
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_item);
  __Pyx_GIVEREF(__pyx_n_s_item);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_item)) __PYX_ERR(0, 857, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_value);
  __Pyx_GIVEREF(__pyx_n_s_value);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_value)) __PYX_ERR(0, 857, __pyx_L1_error);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_temp_df, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 857, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":861
 *         "value",
 *     ]
 *     temp_df.reset_index(inplace=True, drop=True)             # <<<<<<<<<<<<<<
 *     return temp_df
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_temp_df, __pyx_n_s_reset_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_inplace, Py_True) < 0) __PYX_ERR(0, 861, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_drop, Py_True) < 0) __PYX_ERR(0, 861, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":862
 *     ]
 *     temp_df.reset_index(inplace=True, drop=True)
 *     return temp_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_temp_df);
  __pyx_r = __pyx_v_temp_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":812
 * 
 * 
 * def stock_individual_info_em(symbol: str = "688235", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     --
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_individual_info_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_code_id_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_code_name_map);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":865
 * 
 * 
 * def stock_fhps_detail_em(symbol: str = "300073") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     ---
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_23stock_fhps_detail_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_22stock_fhps_detail_em, "\n    \344\270\234\346\226\271\350\264\242\345\257\214\347\275\221-\346\225\260\346\215\256\344\270\255\345\277\203-\345\210\206\347\272\242\351\200\201\351\205\215-\345\210\206\347\272\242\351\200\201\351\205\215\350\257\246\346\203\205\n    https://data.eastmoney.com/yjfp/detail/300073.html\n    :param symbol: \350\202\241\347\245\250\344\273\243\347\240\201\n    :type symbol: str\n    :return: \345\210\206\347\272\242\351\200\201\351\205\215\350\257\246\346\203\205\n    :rtype: pandas.DataFrame\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_23stock_fhps_detail_em = {"stock_fhps_detail_em", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_23stock_fhps_detail_em, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_22stock_fhps_detail_em};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_23stock_fhps_detail_em(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_symbol = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stock_fhps_detail_em (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_symbol,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_kp_s_300073)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 865, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stock_fhps_detail_em") < 0)) __PYX_ERR(0, 865, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_symbol = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stock_fhps_detail_em", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 865, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_fhps_detail_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_symbol), (&PyString_Type), 0, "symbol", 1))) __PYX_ERR(0, 865, __pyx_L1_error)
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_22stock_fhps_detail_em(__pyx_self, __pyx_v_symbol);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_22stock_fhps_detail_em(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_symbol) {
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_big_df = NULL;
  PyObject *__pyx_v_is_null_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stock_fhps_detail_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":875
 *     """
 * 
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "sortColumns": "REPORT_DATE",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_web_eastmoney_c);
  __pyx_v_url = __pyx_kp_s_https_datacenter_web_eastmoney_c;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":877
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
 *     params = {
 *         "sortColumns": "REPORT_DATE",             # <<<<<<<<<<<<<<
 *         "sortTypes": "-1",
 *         "pageSize": "500",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_n_s_REPORT_DATE) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_kp_s_1_3) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_kp_s_500) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_kp_s_1) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPT_SHAREBONUS_DET) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_n_s_ALL) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_quoteColumns, __pyx_kp_s__2) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_js, __pyx_kp_s_data_x_pages_tp) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_client, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 877, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":887
 *         "source": "WEB",
 *         "client": "WEB",
 *         "filter": f"""(SECURITY_CODE="{symbol}")""",             # <<<<<<<<<<<<<<
 *     }
 * 
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_SECURITY_CODE_2);
  __pyx_t_3 += 16;
  __Pyx_GIVEREF(__pyx_kp_u_SECURITY_CODE_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_SECURITY_CODE_2);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_symbol, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__9);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__9);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__9);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_filter, __pyx_t_5) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":890
 *     }
 * 
 *     r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 890, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 890, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_r = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":891
 * 
 *     r = requests.get(url, params=params)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 * 
 *     big_df = pd.DataFrame()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_data_json = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":893
 *     data_json = r.json()
 * 
 *     big_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     is_null_result = data_json["result"] is None
 *     if not is_null_result:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 893, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_big_df = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":894
 * 
 *     big_df = pd.DataFrame()
 *     is_null_result = data_json["result"] is None             # <<<<<<<<<<<<<<
 *     if not is_null_result:
 *         big_df = pd.DataFrame(data_json["result"]["data"])
 */
  __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = (__pyx_t_6 == Py_None);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_is_null_result = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":895
 *     big_df = pd.DataFrame()
 *     is_null_result = data_json["result"] is None
 *     if not is_null_result:             # <<<<<<<<<<<<<<
 *         big_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 */
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_is_null_result); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 895, __pyx_L1_error)
  __pyx_t_9 = (!__pyx_t_8);
  if (__pyx_t_9) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":896
 *     is_null_result = data_json["result"] is None
 *     if not is_null_result:
 *         big_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *     else:
 *         return big_df
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_5};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 896, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_big_df, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":895
 *     big_df = pd.DataFrame()
 *     is_null_result = data_json["result"] is None
 *     if not is_null_result:             # <<<<<<<<<<<<<<
 *         big_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 */
    goto __pyx_L3;
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":898
 *         big_df = pd.DataFrame(data_json["result"]["data"])
 *     else:
 *         return big_df             # <<<<<<<<<<<<<<
 * 
 *     # for page in tqdm(range(1, total_pages + 1), leave=False, disable=True):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_big_df);
    __pyx_r = __pyx_v_big_df;
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":907
 *     #     big_df = pd.concat([big_df, temp_df], ignore_index=True)
 * 
 *     big_df.columns = [             # <<<<<<<<<<<<<<
 *         "_",
 *         "-",
 */
  __pyx_t_6 = PyList_New(30); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_n_s__3);
  __Pyx_GIVEREF(__pyx_n_s__3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_n_s__3)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__72);
  __Pyx_GIVEREF(__pyx_kp_s__72);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 1, __pyx_kp_s__72)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s__3);
  __Pyx_GIVEREF(__pyx_n_s__3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 2, __pyx_n_s__3)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s__3);
  __Pyx_GIVEREF(__pyx_n_s__3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 3, __pyx_n_s__3)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__72);
  __Pyx_GIVEREF(__pyx_kp_s__72);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 4, __pyx_kp_s__72)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__73);
  __Pyx_GIVEREF(__pyx_kp_s__73);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 5, __pyx_kp_s__73)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__74);
  __Pyx_GIVEREF(__pyx_kp_s__74);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 6, __pyx_kp_s__74)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__75);
  __Pyx_GIVEREF(__pyx_kp_s__75);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 7, __pyx_kp_s__75)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__76);
  __Pyx_GIVEREF(__pyx_kp_s__76);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 8, __pyx_kp_s__76)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__77);
  __Pyx_GIVEREF(__pyx_kp_s__77);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 9, __pyx_kp_s__77)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__78);
  __Pyx_GIVEREF(__pyx_kp_s__78);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 10, __pyx_kp_s__78)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__79);
  __Pyx_GIVEREF(__pyx_kp_s__79);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 11, __pyx_kp_s__79)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__22);
  __Pyx_GIVEREF(__pyx_kp_s__22);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 12, __pyx_kp_s__22)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__80);
  __Pyx_GIVEREF(__pyx_kp_s__80);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 13, __pyx_kp_s__80)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__81);
  __Pyx_GIVEREF(__pyx_kp_s__81);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 14, __pyx_kp_s__81)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__82);
  __Pyx_GIVEREF(__pyx_kp_s__82);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 15, __pyx_kp_s__82)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__72);
  __Pyx_GIVEREF(__pyx_kp_s__72);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 16, __pyx_kp_s__72)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__72);
  __Pyx_GIVEREF(__pyx_kp_s__72);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 17, __pyx_kp_s__72)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__72);
  __Pyx_GIVEREF(__pyx_kp_s__72);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 18, __pyx_kp_s__72)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__83);
  __Pyx_GIVEREF(__pyx_kp_s__83);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 19, __pyx_kp_s__83)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__84);
  __Pyx_GIVEREF(__pyx_kp_s__84);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 20, __pyx_kp_s__84)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__85);
  __Pyx_GIVEREF(__pyx_kp_s__85);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 21, __pyx_kp_s__85)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__86);
  __Pyx_GIVEREF(__pyx_kp_s__86);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 22, __pyx_kp_s__86)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__87);
  __Pyx_GIVEREF(__pyx_kp_s__87);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 23, __pyx_kp_s__87)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__65);
  __Pyx_GIVEREF(__pyx_kp_s__65);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 24, __pyx_kp_s__65)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__88);
  __Pyx_GIVEREF(__pyx_kp_s__88);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 25, __pyx_kp_s__88)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__89);
  __Pyx_GIVEREF(__pyx_kp_s__89);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 26, __pyx_kp_s__89)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__72);
  __Pyx_GIVEREF(__pyx_kp_s__72);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 27, __pyx_kp_s__72)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__72);
  __Pyx_GIVEREF(__pyx_kp_s__72);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 28, __pyx_kp_s__72)) __PYX_ERR(0, 907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__72);
  __Pyx_GIVEREF(__pyx_kp_s__72);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 29, __pyx_kp_s__72)) __PYX_ERR(0, 907, __pyx_L1_error);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_big_df, __pyx_n_s_columns, __pyx_t_6) < 0) __PYX_ERR(0, 907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":940
 *     ]
 *     big_df = big_df[
 *         [             # <<<<<<<<<<<<<<
 *             "",
 *             "",
 */
  __pyx_t_6 = PyList_New(19); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_kp_s__22);
  __Pyx_GIVEREF(__pyx_kp_s__22);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_kp_s__22)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__77);
  __Pyx_GIVEREF(__pyx_kp_s__77);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 1, __pyx_kp_s__77)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__73);
  __Pyx_GIVEREF(__pyx_kp_s__73);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 2, __pyx_kp_s__73)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__74);
  __Pyx_GIVEREF(__pyx_kp_s__74);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 3, __pyx_kp_s__74)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__75);
  __Pyx_GIVEREF(__pyx_kp_s__75);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 4, __pyx_kp_s__75)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__76);
  __Pyx_GIVEREF(__pyx_kp_s__76);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 5, __pyx_kp_s__76)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__81);
  __Pyx_GIVEREF(__pyx_kp_s__81);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 6, __pyx_kp_s__81)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__89);
  __Pyx_GIVEREF(__pyx_kp_s__89);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 7, __pyx_kp_s__89)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__83);
  __Pyx_GIVEREF(__pyx_kp_s__83);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 8, __pyx_kp_s__83)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__84);
  __Pyx_GIVEREF(__pyx_kp_s__84);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 9, __pyx_kp_s__84)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__85);
  __Pyx_GIVEREF(__pyx_kp_s__85);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 10, __pyx_kp_s__85)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__86);
  __Pyx_GIVEREF(__pyx_kp_s__86);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 11, __pyx_kp_s__86)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__87);
  __Pyx_GIVEREF(__pyx_kp_s__87);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 12, __pyx_kp_s__87)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__65);
  __Pyx_GIVEREF(__pyx_kp_s__65);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 13, __pyx_kp_s__65)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__88);
  __Pyx_GIVEREF(__pyx_kp_s__88);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 14, __pyx_kp_s__88)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__78);
  __Pyx_GIVEREF(__pyx_kp_s__78);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 15, __pyx_kp_s__78)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__79);
  __Pyx_GIVEREF(__pyx_kp_s__79);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 16, __pyx_kp_s__79)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__80);
  __Pyx_GIVEREF(__pyx_kp_s__80);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 17, __pyx_kp_s__80)) __PYX_ERR(0, 940, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__82);
  __Pyx_GIVEREF(__pyx_kp_s__82);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 18, __pyx_kp_s__82)) __PYX_ERR(0, 940, __pyx_L1_error);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":939
 *         "-",
 *     ]
 *     big_df = big_df[             # <<<<<<<<<<<<<<
 *         [
 *             "",
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_big_df, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_big_df, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":962
 *         ]
 *     ]
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__22); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 962, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 962, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__22, __pyx_t_1) < 0))) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":963
 *     ]
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__77); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 963, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 963, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_dt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_date); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__77, __pyx_t_6) < 0))) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":964
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pd); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__88); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 964, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 964, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__88, __pyx_t_2) < 0))) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":965
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__78); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 965, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__78, __pyx_t_1) < 0))) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":966
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__79); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 966, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 966, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_dt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_date); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__79, __pyx_t_6) < 0))) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":967
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 * 
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pd); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__82); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 967, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 967, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_dt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__82, __pyx_t_2) < 0))) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":969
 *     big_df[""] = pd.to_datetime(big_df[""], errors="coerce").dt.date
 * 
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__73); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 969, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 969, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__73, __pyx_t_1) < 0))) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":970
 * 
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__74); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 970, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 970, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__74, __pyx_t_6) < 0))) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":971
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pd); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__75); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 971, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 971, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__75, __pyx_t_2) < 0))) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":972
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__76); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 972, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 972, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__76, __pyx_t_1) < 0))) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":973
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__89); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 973, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 973, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__89, __pyx_t_6) < 0))) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":974
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pd); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__83); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 974, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 974, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__83, __pyx_t_2) < 0))) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":975
 *     big_df["-"] = pd.to_numeric(big_df["-"], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__84); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 975, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 975, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__84, __pyx_t_1) < 0))) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":976
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__85); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 976, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 976, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__85, __pyx_t_6) < 0))) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":977
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pd); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__86); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 977, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 977, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__86, __pyx_t_2) < 0))) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":978
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")             # <<<<<<<<<<<<<<
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     return big_df
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__87); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 978, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 978, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__87, __pyx_t_1) < 0))) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":979
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")             # <<<<<<<<<<<<<<
 *     return big_df
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_big_df, __pyx_kp_s__65); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 979, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 979, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_big_df, __pyx_kp_s__65, __pyx_t_6) < 0))) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":980
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     big_df[""] = pd.to_numeric(big_df[""], errors="coerce")
 *     return big_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_big_df);
  __pyx_r = __pyx_v_big_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":865
 * 
 * 
 * def stock_fhps_detail_em(symbol: str = "300073") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     ---
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.stock_fhps_detail_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_big_df);
  __Pyx_XDECREF(__pyx_v_is_null_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":983
 * 
 * 
 * def kzz_sh_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sh
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_25kzz_sh_trade_day_info_em(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_24kzz_sh_trade_day_info_em, "\n    https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sh\n\n    https://89.push2.eastmoney.com/api/qt/clist/get\n\n    cb: jQuery112401761656930109523_1721047528021\n    pn: 1\n    pz: 20\n    po: 1\n    np: 1\n    ut: bd1d9ddb04089700cf9c27f6f7426281\n    fltt: 2\n    invt: 2\n    dect: 1\n    wbp2u: |0|0|0|web\n    fid: f3\n    fs: m:1 b:MK0354\n    fields: f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f20,f21,f23,f24,f25,f26,f22,f33,f11,f62,f128,f136,f115,f152\n    _: 1721047529031\n\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_25kzz_sh_trade_day_info_em = {"kzz_sh_trade_day_info_em", (PyCFunction)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_25kzz_sh_trade_day_info_em, METH_NOARGS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_24kzz_sh_trade_day_info_em};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_25kzz_sh_trade_day_info_em(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kzz_sh_trade_day_info_em (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_24kzz_sh_trade_day_info_em(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_24kzz_sh_trade_day_info_em(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_kzz_all_df = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_total_item = NULL;
  PyObject *__pyx_v_total_pages = NULL;
  PyObject *__pyx_v_page = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kzz_sh_trade_day_info_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1007
 *     '''
 *     column_dict = {
 *         'f12': 'bond_code',             # <<<<<<<<<<<<<<
 *         'f14': 'bond_name',
 *         'f4': 'price_change',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f12, __pyx_n_s_bond_code) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f14, __pyx_n_s_bond_name) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f4, __pyx_n_s_price_change) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f3, __pyx_n_s_price_ratio) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f17, __pyx_n_s_open) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f15, __pyx_n_s_high) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f16, __pyx_n_s_low) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f2, __pyx_n_s_close) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f18, __pyx_n_s_pre_close) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f5, __pyx_n_s_volume) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f6, __pyx_n_s_amount) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1020
 *     }
 * 
 *     url = "https://89.push2.eastmoney.com/api/qt/clist/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "pn": "1",
 */
  __Pyx_INCREF(__pyx_kp_s_https_89_push2_eastmoney_com_api);
  __pyx_v_url = __pyx_kp_s_https_89_push2_eastmoney_com_api;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1022
 *     url = "https://89.push2.eastmoney.com/api/qt/clist/get"
 *     params = {
 *         "pn": "1",             # <<<<<<<<<<<<<<
 *         "pz": "200",
 *         "po": "1",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pn, __pyx_kp_s_1) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pz, __pyx_kp_s_200) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_po, __pyx_kp_s_1) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_np, __pyx_kp_s_1) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ut, __pyx_n_s_bd1d9ddb04089700cf9c27f6f7426281) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fltt, __pyx_kp_s_2) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_invt, __pyx_kp_s_2) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dect, __pyx_kp_s_1) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_wbp2u, __pyx_kp_s_0_0_0_web) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fid, __pyx_n_s_f3) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fs, __pyx_kp_s_m_1_b_MK0354) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fields, __pyx_kp_s_f12_f14_f2_f4_f3_f17_f15_f16_f18) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s__3, __pyx_kp_s_1721047529031) < 0) __PYX_ERR(0, 1022, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1038
 *     }
 * 
 *     kzz_all_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1038, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_kzz_all_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1039
 * 
 *     kzz_all_df = pd.DataFrame()
 *     r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 *     total_item = int(data_json["data"]["total"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 1039, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 1039, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_r = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1040
 *     kzz_all_df = pd.DataFrame()
 *     r = requests.get(url, params=params)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 *     total_item = int(data_json["data"]["total"])
 *     total_pages = math.ceil(total_item / int(params['pz']))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_data_json = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1041
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 *     total_item = int(data_json["data"]["total"])             # <<<<<<<<<<<<<<
 *     total_pages = math.ceil(total_item / int(params['pz']))
 *     for page in range(1, total_pages + 1):
 */
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_5, __pyx_n_s_total); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_total_item = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1042
 *     data_json = r.json()
 *     total_item = int(data_json["data"]["total"])
 *     total_pages = math.ceil(total_item / int(params['pz']))             # <<<<<<<<<<<<<<
 *     for page in range(1, total_pages + 1):
 *         params.update({"pn": str(page)})
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_math); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ceil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_params, __pyx_n_s_pz); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyNumber_Divide(__pyx_v_total_item, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1042, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_total_pages = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1043
 *     total_item = int(data_json["data"]["total"])
 *     total_pages = math.ceil(total_item / int(params['pz']))
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pn": str(page)})
 *         r = requests.get(url, params=params)
 */
  __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_total_pages, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1)) __PYX_ERR(0, 1043, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5)) __PYX_ERR(0, 1043, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
    __pyx_t_1 = __pyx_t_5; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1043, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1043, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1043, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1043, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1043, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1043, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1043, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_7(__pyx_t_1);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1043, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_page, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1044
 *     total_pages = math.ceil(total_item / int(params['pz']))
 *     for page in range(1, total_pages + 1):
 *         params.update({"pn": str(page)})             # <<<<<<<<<<<<<<
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 */
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_Str(__pyx_v_page); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_pn, __pyx_t_2) < 0) __PYX_ERR(0, 1044, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1045
 *     for page in range(1, total_pages + 1):
 *         params.update({"pn": str(page)})
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_requests); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_url)) __PYX_ERR(0, 1045, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 1045, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1046
 *         params.update({"pn": str(page)})
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])
 *         temp_df = temp_df[list(column_dict.keys())]
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1046, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_data_json, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1047
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])             # <<<<<<<<<<<<<<
 *         temp_df = temp_df[list(column_dict.keys())]
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1047, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1047, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1047, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_s_diff); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1047, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1047, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_temp_df, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1048
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])
 *         temp_df = temp_df[list(column_dict.keys())]             # <<<<<<<<<<<<<<
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)
 *         # if temp_df.shape[0] < int(params['pz']):
 */
    __pyx_t_8 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1048, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PySequence_ListKeepNew(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1048, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_temp_df, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1048, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_temp_df, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1049
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])
 *         temp_df = temp_df[list(column_dict.keys())]
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)             # <<<<<<<<<<<<<<
 *         # if temp_df.shape[0] < int(params['pz']):
 *         #     break
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pd); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_concat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_v_kzz_all_df);
    __Pyx_GIVEREF(__pyx_v_kzz_all_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_v_kzz_all_df)) __PYX_ERR(0, 1049, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_temp_df);
    __Pyx_GIVEREF(__pyx_v_temp_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 1, __pyx_v_temp_df)) __PYX_ERR(0, 1049, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_8)) __PYX_ERR(0, 1049, __pyx_L1_error);
    __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 1049, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF_SET(__pyx_v_kzz_all_df, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1043
 *     total_item = int(data_json["data"]["total"])
 *     total_pages = math.ceil(total_item / int(params['pz']))
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pn": str(page)})
 *         r = requests.get(url, params=params)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1053
 *         #     break
 * 
 *     kzz_all_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 *     kzz_all_df.insert(2, "date", datetime.strptime(utils.latest_trade_day, '%Y%m%d').date())
 *     cols_to_convert = kzz_all_df.columns[3:]
 */
  __pyx_t_1 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_kzz_all_df, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 1053, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1054
 * 
 *     kzz_all_df.columns = column_dict.values()
 *     kzz_all_df.insert(2, "date", datetime.strptime(utils.latest_trade_day, '%Y%m%d').date())             # <<<<<<<<<<<<<<
 *     cols_to_convert = kzz_all_df.columns[3:]
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_kzz_all_df, __pyx_n_s_insert); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strptime); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_utils); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_latest_trade_day); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_10, __pyx_kp_s_Y_m_d};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_date); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_9, __pyx_int_2, __pyx_n_s_date, __pyx_t_8};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1055
 *     kzz_all_df.columns = column_dict.values()
 *     kzz_all_df.insert(2, "date", datetime.strptime(utils.latest_trade_day, '%Y%m%d').date())
 *     cols_to_convert = kzz_all_df.columns[3:]             # <<<<<<<<<<<<<<
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     kzz_all_df = kzz_all_df[kzz_all_df['close'].notna()]
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_kzz_all_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, 3, 0, NULL, NULL, &__pyx_slice__8, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cols_to_convert = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1056
 *     kzz_all_df.insert(2, "date", datetime.strptime(utils.latest_trade_day, '%Y%m%d').date())
 *     cols_to_convert = kzz_all_df.columns[3:]
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 *     kzz_all_df = kzz_all_df[kzz_all_df['close'].notna()]
 *     return kzz_all_df
 */
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_kzz_all_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_apply); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8)) __PYX_ERR(0, 1056, __pyx_L1_error);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 1056, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_kzz_all_df, __pyx_v_cols_to_convert, __pyx_t_9) < 0))) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1057
 *     cols_to_convert = kzz_all_df.columns[3:]
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     kzz_all_df = kzz_all_df[kzz_all_df['close'].notna()]             # <<<<<<<<<<<<<<
 *     return kzz_all_df
 * 
 */
  __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_kzz_all_df, __pyx_n_s_close); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_notna); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1057, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_kzz_all_df, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF_SET(__pyx_v_kzz_all_df, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1058
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     kzz_all_df = kzz_all_df[kzz_all_df['close'].notna()]
 *     return kzz_all_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_kzz_all_df);
  __pyx_r = __pyx_v_kzz_all_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":983
 * 
 * 
 * def kzz_sh_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sh
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.kzz_sh_trade_day_info_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_kzz_all_df);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_total_item);
  __Pyx_XDECREF(__pyx_v_total_pages);
  __Pyx_XDECREF(__pyx_v_page);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":1061
 * 
 * 
 * def kzz_sz_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sz
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_27kzz_sz_trade_day_info_em(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_26kzz_sz_trade_day_info_em, "\n    https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sz\n\n    https://38.push2.eastmoney.com/api/qt/clist/get\n    ?cb=jQuery112409365434939251478_1721051594755&pn=1&pz=20&po=1&np=1&ut=bd1d9ddb04089700cf9c27f6f7426281\n    &fltt=2&invt=2&dect=1\n    &wbp2u=|0|0|0|web\n    &fid=f3&fs=m:0+b:MK0354\n    &fields=f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f20,f21,f23,f24,f25,f26,f22,f33,f11,f62,f128,f136,f115,f152\n    &_=1721051595125\n\n    cb: jQuery112409365434939251478_1721051594755\n    pn: 1\n    pz: 20\n    po: 1\n    np: 1\n    ut: bd1d9ddb04089700cf9c27f6f7426281\n    fltt: 2\n    invt: 2\n    dect: 1\n    wbp2u: |0|0|0|web\n    fid: f3\n    fs: m:0 b:MK0354\n    fields: f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f20,f21,f23,f24,f25,f26,f22,f33,f11,f62,f128,f136,f115,f152\n    _: 1721051595125\n\n\n\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_27kzz_sz_trade_day_info_em = {"kzz_sz_trade_day_info_em", (PyCFunction)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_27kzz_sz_trade_day_info_em, METH_NOARGS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_26kzz_sz_trade_day_info_em};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_27kzz_sz_trade_day_info_em(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kzz_sz_trade_day_info_em (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_26kzz_sz_trade_day_info_em(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_26kzz_sz_trade_day_info_em(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_kzz_all_df = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_total_item = NULL;
  PyObject *__pyx_v_total_pages = NULL;
  PyObject *__pyx_v_page = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kzz_sz_trade_day_info_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1093
 *     '''
 *     column_dict = {
 *         'f12': 'bond_code',             # <<<<<<<<<<<<<<
 *         'f14': 'bond_name',
 *         'f4': 'price_change',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f12, __pyx_n_s_bond_code) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f14, __pyx_n_s_bond_name) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f4, __pyx_n_s_price_change) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f3, __pyx_n_s_price_ratio) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f17, __pyx_n_s_open) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f15, __pyx_n_s_high) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f16, __pyx_n_s_low) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f2, __pyx_n_s_close) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f18, __pyx_n_s_pre_close) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f5, __pyx_n_s_volume) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_f6, __pyx_n_s_amount) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1106
 *     }
 * 
 *     url = "https://38.push2.eastmoney.com/api/qt/clist/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "pn": "1",
 */
  __Pyx_INCREF(__pyx_kp_s_https_38_push2_eastmoney_com_api);
  __pyx_v_url = __pyx_kp_s_https_38_push2_eastmoney_com_api;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1108
 *     url = "https://38.push2.eastmoney.com/api/qt/clist/get"
 *     params = {
 *         "pn": "1",             # <<<<<<<<<<<<<<
 *         "pz": "200",
 *         "po": "1",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pn, __pyx_kp_s_1) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pz, __pyx_kp_s_200) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_po, __pyx_kp_s_1) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_np, __pyx_kp_s_1) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ut, __pyx_n_s_bd1d9ddb04089700cf9c27f6f7426281) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fltt, __pyx_kp_s_2) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_invt, __pyx_kp_s_2) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dect, __pyx_kp_s_1) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_wbp2u, __pyx_kp_s_0_0_0_web) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fid, __pyx_n_s_f3) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fs, __pyx_kp_s_m_0_b_MK0354) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fields, __pyx_kp_s_f12_f14_f2_f4_f3_f17_f15_f16_f18) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s__3, __pyx_kp_s_1721051595125) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1124
 *     }
 * 
 *     kzz_all_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_kzz_all_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1125
 * 
 *     kzz_all_df = pd.DataFrame()
 *     r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 *     total_item = int(data_json["data"]["total"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 1125, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 1125, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_r = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1126
 *     kzz_all_df = pd.DataFrame()
 *     r = requests.get(url, params=params)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 *     total_item = int(data_json["data"]["total"])
 *     total_pages = math.ceil(total_item / int(params['pz']))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_data_json = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1127
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 *     total_item = int(data_json["data"]["total"])             # <<<<<<<<<<<<<<
 *     total_pages = math.ceil(total_item / int(params['pz']))
 *     for page in range(1, total_pages + 1):
 */
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_5, __pyx_n_s_total); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_total_item = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1128
 *     data_json = r.json()
 *     total_item = int(data_json["data"]["total"])
 *     total_pages = math.ceil(total_item / int(params['pz']))             # <<<<<<<<<<<<<<
 *     for page in range(1, total_pages + 1):
 *         params.update({"pn": str(page)})
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_math); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ceil); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_params, __pyx_n_s_pz); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyNumber_Divide(__pyx_v_total_item, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1128, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_total_pages = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1129
 *     total_item = int(data_json["data"]["total"])
 *     total_pages = math.ceil(total_item / int(params['pz']))
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pn": str(page)})
 *         r = requests.get(url, params=params)
 */
  __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_total_pages, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1)) __PYX_ERR(0, 1129, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5)) __PYX_ERR(0, 1129, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
    __pyx_t_1 = __pyx_t_5; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1129, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1129, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1129, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1129, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1129, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1129, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1129, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_7(__pyx_t_1);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1129, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_page, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1130
 *     total_pages = math.ceil(total_item / int(params['pz']))
 *     for page in range(1, total_pages + 1):
 *         params.update({"pn": str(page)})             # <<<<<<<<<<<<<<
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 */
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_Str(__pyx_v_page); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_pn, __pyx_t_2) < 0) __PYX_ERR(0, 1130, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1131
 *     for page in range(1, total_pages + 1):
 *         params.update({"pn": str(page)})
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_requests); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_url)) __PYX_ERR(0, 1131, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 1131, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1132
 *         params.update({"pn": str(page)})
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])
 *         temp_df = temp_df[list(column_dict.keys())]
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1132, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_data_json, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1133
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])             # <<<<<<<<<<<<<<
 *         temp_df = temp_df[list(column_dict.keys())]
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_s_diff); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_temp_df, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1134
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])
 *         temp_df = temp_df[list(column_dict.keys())]             # <<<<<<<<<<<<<<
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)
 *         # if temp_df.shape[0] < int(params['pz']):
 */
    __pyx_t_8 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PySequence_ListKeepNew(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_temp_df, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_temp_df, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1135
 *         temp_df = pd.DataFrame(data_json["data"]["diff"])
 *         temp_df = temp_df[list(column_dict.keys())]
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)             # <<<<<<<<<<<<<<
 *         # if temp_df.shape[0] < int(params['pz']):
 *         #     break
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pd); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_concat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_v_kzz_all_df);
    __Pyx_GIVEREF(__pyx_v_kzz_all_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_v_kzz_all_df)) __PYX_ERR(0, 1135, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_temp_df);
    __Pyx_GIVEREF(__pyx_v_temp_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 1, __pyx_v_temp_df)) __PYX_ERR(0, 1135, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_8)) __PYX_ERR(0, 1135, __pyx_L1_error);
    __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 1135, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF_SET(__pyx_v_kzz_all_df, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1129
 *     total_item = int(data_json["data"]["total"])
 *     total_pages = math.ceil(total_item / int(params['pz']))
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pn": str(page)})
 *         r = requests.get(url, params=params)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1139
 *         #     break
 * 
 *     kzz_all_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 *     kzz_all_df.insert(2, "date", datetime.strptime(utils.latest_trade_day, '%Y%m%d').date())
 *     cols_to_convert = kzz_all_df.columns[3:]
 */
  __pyx_t_1 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_kzz_all_df, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 1139, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1140
 * 
 *     kzz_all_df.columns = column_dict.values()
 *     kzz_all_df.insert(2, "date", datetime.strptime(utils.latest_trade_day, '%Y%m%d').date())             # <<<<<<<<<<<<<<
 *     cols_to_convert = kzz_all_df.columns[3:]
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_kzz_all_df, __pyx_n_s_insert); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strptime); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_utils); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_latest_trade_day); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_10, __pyx_kp_s_Y_m_d};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_date); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_9, __pyx_int_2, __pyx_n_s_date, __pyx_t_8};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1141
 *     kzz_all_df.columns = column_dict.values()
 *     kzz_all_df.insert(2, "date", datetime.strptime(utils.latest_trade_day, '%Y%m%d').date())
 *     cols_to_convert = kzz_all_df.columns[3:]             # <<<<<<<<<<<<<<
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     kzz_all_df = kzz_all_df[kzz_all_df['close'].notna()]
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_kzz_all_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, 3, 0, NULL, NULL, &__pyx_slice__8, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cols_to_convert = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1142
 *     kzz_all_df.insert(2, "date", datetime.strptime(utils.latest_trade_day, '%Y%m%d').date())
 *     cols_to_convert = kzz_all_df.columns[3:]
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 *     kzz_all_df = kzz_all_df[kzz_all_df['close'].notna()]
 *     return kzz_all_df
 */
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_kzz_all_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_apply); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8)) __PYX_ERR(0, 1142, __pyx_L1_error);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 1142, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_kzz_all_df, __pyx_v_cols_to_convert, __pyx_t_9) < 0))) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1143
 *     cols_to_convert = kzz_all_df.columns[3:]
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     kzz_all_df = kzz_all_df[kzz_all_df['close'].notna()]             # <<<<<<<<<<<<<<
 *     return kzz_all_df
 * 
 */
  __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_kzz_all_df, __pyx_n_s_close); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_notna); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_kzz_all_df, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF_SET(__pyx_v_kzz_all_df, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1144
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     kzz_all_df = kzz_all_df[kzz_all_df['close'].notna()]
 *     return kzz_all_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_kzz_all_df);
  __pyx_r = __pyx_v_kzz_all_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1061
 * 
 * 
 * def kzz_sz_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sz
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.kzz_sz_trade_day_info_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_kzz_all_df);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_total_item);
  __Pyx_XDECREF(__pyx_v_total_pages);
  __Pyx_XDECREF(__pyx_v_page);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":1147
 * 
 * 
 * def kzz_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     kzz_sh_em_df = kzz_sh_trade_day_info_em()
 *     kzz_sz_em_df = kzz_sz_trade_day_info_em()
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_29kzz_trade_day_info_em(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_29kzz_trade_day_info_em = {"kzz_trade_day_info_em", (PyCFunction)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_29kzz_trade_day_info_em, METH_NOARGS, 0};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_29kzz_trade_day_info_em(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kzz_trade_day_info_em (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_28kzz_trade_day_info_em(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_28kzz_trade_day_info_em(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_kzz_sh_em_df = NULL;
  PyObject *__pyx_v_kzz_sz_em_df = NULL;
  PyObject *__pyx_v_kzz_trade_day_df = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kzz_trade_day_info_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1148
 * 
 * def kzz_trade_day_info_em():
 *     kzz_sh_em_df = kzz_sh_trade_day_info_em()             # <<<<<<<<<<<<<<
 *     kzz_sz_em_df = kzz_sz_trade_day_info_em()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_kzz_sh_trade_day_info_em); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_kzz_sh_em_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1149
 * def kzz_trade_day_info_em():
 *     kzz_sh_em_df = kzz_sh_trade_day_info_em()
 *     kzz_sz_em_df = kzz_sz_trade_day_info_em()             # <<<<<<<<<<<<<<
 * 
 *     kzz_trade_day_df = pd.concat([kzz_sh_em_df, kzz_sz_em_df], ignore_index=True)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_kzz_sz_trade_day_info_em); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_kzz_sz_em_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1151
 *     kzz_sz_em_df = kzz_sz_trade_day_info_em()
 * 
 *     kzz_trade_day_df = pd.concat([kzz_sh_em_df, kzz_sz_em_df], ignore_index=True)             # <<<<<<<<<<<<<<
 *     return kzz_trade_day_df
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_concat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_kzz_sh_em_df);
  __Pyx_GIVEREF(__pyx_v_kzz_sh_em_df);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_kzz_sh_em_df)) __PYX_ERR(0, 1151, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_kzz_sz_em_df);
  __Pyx_GIVEREF(__pyx_v_kzz_sz_em_df);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_kzz_sz_em_df)) __PYX_ERR(0, 1151, __pyx_L1_error);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 1151, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 1151, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_kzz_trade_day_df = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1152
 * 
 *     kzz_trade_day_df = pd.concat([kzz_sh_em_df, kzz_sz_em_df], ignore_index=True)
 *     return kzz_trade_day_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_kzz_trade_day_df);
  __pyx_r = __pyx_v_kzz_trade_day_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1147
 * 
 * 
 * def kzz_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     kzz_sh_em_df = kzz_sh_trade_day_info_em()
 *     kzz_sz_em_df = kzz_sz_trade_day_info_em()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.kzz_trade_day_info_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kzz_sh_em_df);
  __Pyx_XDECREF(__pyx_v_kzz_sz_em_df);
  __Pyx_XDECREF(__pyx_v_kzz_trade_day_df);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":1155
 * 
 * 
 * def kzz_basic_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     -
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_31kzz_basic_info_em(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_30kzz_basic_info_em, "\n    \344\270\234\346\226\271\350\264\242\345\257\214-\345\217\257\350\275\254\345\200\272\n    https://datacenter-web.eastmoney.com/api/data/v1/get\n    callback: jQuery112305115732373271307_1721039527135\n    sortColumns: PUBLIC_START_DATE,SECURITY_CODE\n    sortTypes: -1,-1\n    pageSize: 50\n    pageNumber: 1\n    reportName: RPT_BOND_CB_LIST\n    columns: ALL\n    quoteColumns: f2~01~CONVERT_STOCK_CODE~CONVERT_STOCK_PRICE,f235~10~SECURITY_CODE~TRANSFER_PRICE,f236~10~SECURITY_CODE~TRANSFER_VALUE,f2~10~SECURITY_CODE~CURRENT_BOND_PRICE,f237~10~SECURITY_CODE~TRANSFER_PREMIUM_RATIO,f239~10~SECURITY_CODE~RESALE_TRIG_PRICE,f240~10~SECURITY_CODE~REDEEM_TRIG_PRICE,f23~01~CONVERT_STOCK_CODE~PBV_RATIO\n    quoteType: 0\n    source: WEB\n    client: WEB\n    :return:\n    ");
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_31kzz_basic_info_em = {"kzz_basic_info_em", (PyCFunction)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_31kzz_basic_info_em, METH_NOARGS, __pyx_doc_7tbstock_15dataAcquisition_16stockDataCrawler_30kzz_basic_info_em};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_31kzz_basic_info_em(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kzz_basic_info_em (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_30kzz_basic_info_em(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_30kzz_basic_info_em(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_column_dict = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_kzz_all_df = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_data_json = NULL;
  PyObject *__pyx_v_total_pages = NULL;
  PyObject *__pyx_v_page = NULL;
  PyObject *__pyx_v_temp_df = NULL;
  PyObject *__pyx_v_cols_to_convert = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kzz_basic_info_em", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1173
 *     '''
 *     column_dict = {
 *         'SECURITY_CODE': 'bond_code',             # <<<<<<<<<<<<<<
 *         'SECURITY_NAME_ABBR': 'bond_name',
 *         'PUBLIC_START_DATE': 'pub_date',
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_CODE, __pyx_n_s_bond_code) < 0) __PYX_ERR(0, 1173, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_NAME_ABBR, __pyx_n_s_bond_name) < 0) __PYX_ERR(0, 1173, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_PUBLIC_START_DATE, __pyx_n_s_pub_date) < 0) __PYX_ERR(0, 1173, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CONVERT_STOCK_CODE, __pyx_n_s_stock_code) < 0) __PYX_ERR(0, 1173, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_SECURITY_SHORT_NAME, __pyx_n_s_stock_name) < 0) __PYX_ERR(0, 1173, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_ACTUAL_ISSUE_SCALE, __pyx_n_s_bond_scale) < 0) __PYX_ERR(0, 1173, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TRANSFER_PRICE, __pyx_n_s_transfer_price) < 0) __PYX_ERR(0, 1173, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_TRANSFER_VALUE, __pyx_n_s_transfer_value) < 0) __PYX_ERR(0, 1173, __pyx_L1_error)
  __pyx_v_column_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1183
 *     }
 * 
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"             # <<<<<<<<<<<<<<
 *     params = {
 *         "sortColumns": "PUBLIC_START_DATE,SECURITY_CODE",
 */
  __Pyx_INCREF(__pyx_kp_s_https_datacenter_web_eastmoney_c);
  __pyx_v_url = __pyx_kp_s_https_datacenter_web_eastmoney_c;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1185
 *     url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
 *     params = {
 *         "sortColumns": "PUBLIC_START_DATE,SECURITY_CODE",             # <<<<<<<<<<<<<<
 *         "sortTypes": "-1,-1",
 *         "pageSize": "250",
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortColumns, __pyx_kp_s_PUBLIC_START_DATE_SECURITY_CODE) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sortTypes, __pyx_kp_s_1_1) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageSize, __pyx_kp_s_250) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pageNumber, __pyx_kp_s_1) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_reportName, __pyx_n_s_RPT_BOND_CB_LIST) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_n_s_ALL) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_quoteColumns, __pyx_kp_s_f2_01_CONVERT_STOCK_CODE_CONVERT) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_quoteType, __pyx_kp_s_0) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_source, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_client, __pyx_n_s_WEB) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1198
 *     }
 * 
 *     kzz_all_df = pd.DataFrame()             # <<<<<<<<<<<<<<
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_kzz_all_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1199
 * 
 *     kzz_all_df = pd.DataFrame()
 *     r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_url);
  __Pyx_GIVEREF(__pyx_v_url);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 1199, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 1199, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_r = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1200
 *     kzz_all_df = pd.DataFrame()
 *     r = requests.get(url, params=params)
 *     data_json = r.json()             # <<<<<<<<<<<<<<
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_data_json = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1201
 *     r = requests.get(url, params=params)
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])             # <<<<<<<<<<<<<<
 *     for page in range(1, total_pages + 1):
 *         params.update({"pageNumber": page})
 */
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_5, __pyx_n_s_pages); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_total_pages = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1202
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pageNumber": page})
 *         r = requests.get(url, params=params)
 */
  __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_total_pages, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_int_1)) __PYX_ERR(0, 1202, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5)) __PYX_ERR(0, 1202, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_2, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
    __pyx_t_2 = __pyx_t_5; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1202, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1202, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1202, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1202, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1202, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1202, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1202, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_7(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1202, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_page, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1203
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):
 *         params.update({"pageNumber": page})             # <<<<<<<<<<<<<<
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 */
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_pageNumber, __pyx_v_page) < 0) __PYX_ERR(0, 1203, __pyx_L1_error)
    __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1204
 *     for page in range(1, total_pages + 1):
 *         params.update({"pageNumber": page})
 *         r = requests.get(url, params=params)             # <<<<<<<<<<<<<<
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_requests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_url);
    __Pyx_GIVEREF(__pyx_v_url);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_url)) __PYX_ERR(0, 1204, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_params, __pyx_v_params) < 0) __PYX_ERR(0, 1204, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1205
 *         params.update({"pageNumber": page})
 *         r = requests.get(url, params=params)
 *         data_json = r.json()             # <<<<<<<<<<<<<<
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 *         temp_df = temp_df[list(column_dict.keys())]
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_r, __pyx_n_s_json); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_data_json, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1206
 *         r = requests.get(url, params=params)
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["result"]["data"])             # <<<<<<<<<<<<<<
 *         temp_df = temp_df[list(column_dict.keys())]
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data_json, __pyx_n_s_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_temp_df, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1207
 *         data_json = r.json()
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 *         temp_df = temp_df[list(column_dict.keys())]             # <<<<<<<<<<<<<<
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)
 * 
 */
    __pyx_t_8 = __Pyx_PyDict_Keys(__pyx_v_column_dict); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PySequence_ListKeepNew(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_temp_df, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_temp_df, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1208
 *         temp_df = pd.DataFrame(data_json["result"]["data"])
 *         temp_df = temp_df[list(column_dict.keys())]
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)             # <<<<<<<<<<<<<<
 * 
 *     kzz_all_df.columns = column_dict.values()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pd); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_concat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_v_kzz_all_df);
    __Pyx_GIVEREF(__pyx_v_kzz_all_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_v_kzz_all_df)) __PYX_ERR(0, 1208, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_temp_df);
    __Pyx_GIVEREF(__pyx_v_temp_df);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 1, __pyx_v_temp_df)) __PYX_ERR(0, 1208, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_8)) __PYX_ERR(0, 1208, __pyx_L1_error);
    __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_ignore_index, Py_True) < 0) __PYX_ERR(0, 1208, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF_SET(__pyx_v_kzz_all_df, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1202
 *     data_json = r.json()
 *     total_pages = int(data_json["result"]["pages"])
 *     for page in range(1, total_pages + 1):             # <<<<<<<<<<<<<<
 *         params.update({"pageNumber": page})
 *         r = requests.get(url, params=params)
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1210
 *         kzz_all_df = pd.concat([kzz_all_df, temp_df], ignore_index=True)
 * 
 *     kzz_all_df.columns = column_dict.values()             # <<<<<<<<<<<<<<
 *     kzz_all_df["pub_date"] = pd.to_datetime(kzz_all_df["pub_date"], errors="coerce").dt.date
 *     cols_to_convert = kzz_all_df.columns[5:]
 */
  __pyx_t_2 = __Pyx_PyDict_Values(__pyx_v_column_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_kzz_all_df, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1211
 * 
 *     kzz_all_df.columns = column_dict.values()
 *     kzz_all_df["pub_date"] = pd.to_datetime(kzz_all_df["pub_date"], errors="coerce").dt.date             # <<<<<<<<<<<<<<
 *     cols_to_convert = kzz_all_df.columns[5:]
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_datetime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_kzz_all_df, __pyx_n_s_pub_date); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2)) __PYX_ERR(0, 1211, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 1211, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_kzz_all_df, __pyx_n_s_pub_date, __pyx_t_5) < 0))) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1212
 *     kzz_all_df.columns = column_dict.values()
 *     kzz_all_df["pub_date"] = pd.to_datetime(kzz_all_df["pub_date"], errors="coerce").dt.date
 *     cols_to_convert = kzz_all_df.columns[5:]             # <<<<<<<<<<<<<<
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     kzz_all_df = kzz_all_df[kzz_all_df['transfer_value'].notna()]
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_kzz_all_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_5, 5, 0, NULL, NULL, &__pyx_slice__21, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_cols_to_convert = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1213
 *     kzz_all_df["pub_date"] = pd.to_datetime(kzz_all_df["pub_date"], errors="coerce").dt.date
 *     cols_to_convert = kzz_all_df.columns[5:]
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")             # <<<<<<<<<<<<<<
 *     kzz_all_df = kzz_all_df[kzz_all_df['transfer_value'].notna()]
 *     return kzz_all_df
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_kzz_all_df, __pyx_v_cols_to_convert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_to_numeric); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_8)) __PYX_ERR(0, 1213, __pyx_L1_error);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_errors, __pyx_n_s_coerce) < 0) __PYX_ERR(0, 1213, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely((PyObject_SetItem(__pyx_v_kzz_all_df, __pyx_v_cols_to_convert, __pyx_t_3) < 0))) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1214
 *     cols_to_convert = kzz_all_df.columns[5:]
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     kzz_all_df = kzz_all_df[kzz_all_df['transfer_value'].notna()]             # <<<<<<<<<<<<<<
 *     return kzz_all_df
 * 
 */
  __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_kzz_all_df, __pyx_n_s_transfer_value); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_notna); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_kzz_all_df, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_kzz_all_df, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1215
 *     kzz_all_df[cols_to_convert] = kzz_all_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     kzz_all_df = kzz_all_df[kzz_all_df['transfer_value'].notna()]
 *     return kzz_all_df             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_kzz_all_df);
  __pyx_r = __pyx_v_kzz_all_df;
  goto __pyx_L0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1155
 * 
 * 
 * def kzz_basic_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     -
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.kzz_basic_info_em", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_column_dict);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_kzz_all_df);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_data_json);
  __Pyx_XDECREF(__pyx_v_total_pages);
  __Pyx_XDECREF(__pyx_v_page);
  __Pyx_XDECREF(__pyx_v_temp_df);
  __Pyx_XDECREF(__pyx_v_cols_to_convert);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "tbstock/dataAcquisition/stockDataCrawler.py":1218
 * 
 * 
 * def test():             # <<<<<<<<<<<<<<
 *     trade_date = '2024-05-31'
 *     stock_code = "600900"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_33test(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_33test = {"test", (PyCFunction)__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_33test, METH_NOARGS, 0};
static PyObject *__pyx_pw_7tbstock_15dataAcquisition_16stockDataCrawler_33test(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_32test(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7tbstock_15dataAcquisition_16stockDataCrawler_32test(CYTHON_UNUSED PyObject *__pyx_self) {
  CYTHON_UNUSED PyObject *__pyx_v_trade_date = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_stock_code = NULL;
  PyObject *__pyx_v_kzz_trade_day_em_df = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test", 1);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1219
 * 
 * def test():
 *     trade_date = '2024-05-31'             # <<<<<<<<<<<<<<
 *     stock_code = "600900"
 *     # stock_code_back = utils.getFullStockCode(stock_code, '.XX')
 */
  __Pyx_INCREF(__pyx_kp_s_2024_05_31);
  __pyx_v_trade_date = __pyx_kp_s_2024_05_31;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1220
 * def test():
 *     trade_date = '2024-05-31'
 *     stock_code = "600900"             # <<<<<<<<<<<<<<
 *     # stock_code_back = utils.getFullStockCode(stock_code, '.XX')
 * 
 */
  __Pyx_INCREF(__pyx_kp_s_600900);
  __pyx_v_stock_code = __pyx_kp_s_600900;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1258
 *     # print(kzz_em_df)
 * 
 *     kzz_trade_day_em_df = kzz_trade_day_info_em()             # <<<<<<<<<<<<<<
 *     print(kzz_trade_day_em_df)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_kzz_trade_day_info_em); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_kzz_trade_day_em_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1259
 * 
 *     kzz_trade_day_em_df = kzz_trade_day_info_em()
 *     print(kzz_trade_day_em_df)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_kzz_trade_day_em_df); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1218
 * 
 * 
 * def test():             # <<<<<<<<<<<<<<
 *     trade_date = '2024-05-31'
 *     stock_code = "600900"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("tbstock.dataAcquisition.stockDataCrawler.test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_trade_date);
  __Pyx_XDECREF(__pyx_v_stock_code);
  __Pyx_XDECREF(__pyx_v_kzz_trade_day_em_df);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_s_, __pyx_k_, sizeof(__pyx_k_), 0, 0, 1, 0},
    {&__pyx_kp_s_0, __pyx_k_0, sizeof(__pyx_k_0), 0, 0, 1, 0},
    {&__pyx_kp_s_000001, __pyx_k_000001, sizeof(__pyx_k_000001), 0, 0, 1, 0},
    {&__pyx_kp_s_000001_SZ, __pyx_k_000001_SZ, sizeof(__pyx_k_000001_SZ), 0, 0, 1, 0},
    {&__pyx_kp_s_007949902328317804, __pyx_k_007949902328317804, sizeof(__pyx_k_007949902328317804), 0, 0, 1, 0},
    {&__pyx_kp_s_018998368837725255, __pyx_k_018998368837725255, sizeof(__pyx_k_018998368837725255), 0, 0, 1, 0},
    {&__pyx_kp_s_08730299565686817, __pyx_k_08730299565686817, sizeof(__pyx_k_08730299565686817), 0, 0, 1, 0},
    {&__pyx_kp_s_0_0_0_web, __pyx_k_0_0_0_web, sizeof(__pyx_k_0_0_0_web), 0, 0, 1, 0},
    {&__pyx_kp_s_0_2, __pyx_k_0_2, sizeof(__pyx_k_0_2), 0, 0, 1, 0},
    {&__pyx_kp_s_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 0, 1, 0},
    {&__pyx_kp_s_101, __pyx_k_101, sizeof(__pyx_k_101), 0, 0, 1, 0},
    {&__pyx_kp_s_1596700547039, __pyx_k_1596700547039, sizeof(__pyx_k_1596700547039), 0, 0, 1, 0},
    {&__pyx_kp_s_1640157544804, __pyx_k_1640157544804, sizeof(__pyx_k_1640157544804), 0, 0, 1, 0},
    {&__pyx_kp_s_1717261171099, __pyx_k_1717261171099, sizeof(__pyx_k_1717261171099), 0, 0, 1, 0},
    {&__pyx_kp_s_1717298612418, __pyx_k_1717298612418, sizeof(__pyx_k_1717298612418), 0, 0, 1, 0},
    {&__pyx_kp_s_1717298688717, __pyx_k_1717298688717, sizeof(__pyx_k_1717298688717), 0, 0, 1, 0},
    {&__pyx_kp_s_1721047529031, __pyx_k_1721047529031, sizeof(__pyx_k_1721047529031), 0, 0, 1, 0},
    {&__pyx_kp_s_1721051595125, __pyx_k_1721051595125, sizeof(__pyx_k_1721051595125), 0, 0, 1, 0},
    {&__pyx_kp_s_19900101, __pyx_k_19900101, sizeof(__pyx_k_19900101), 0, 0, 1, 0},
    {&__pyx_kp_s_1_1, __pyx_k_1_1, sizeof(__pyx_k_1_1), 0, 0, 1, 0},
    {&__pyx_kp_s_1_2, __pyx_k_1_2, sizeof(__pyx_k_1_2), 0, 0, 1, 0},
    {&__pyx_kp_s_1_3, __pyx_k_1_3, sizeof(__pyx_k_1_3), 0, 0, 1, 0},
    {&__pyx_kp_s_2, __pyx_k_2, sizeof(__pyx_k_2), 0, 0, 1, 0},
    {&__pyx_kp_s_200, __pyx_k_200, sizeof(__pyx_k_200), 0, 0, 1, 0},
    {&__pyx_kp_s_2024_05_31, __pyx_k_2024_05_31, sizeof(__pyx_k_2024_05_31), 0, 0, 1, 0},
    {&__pyx_kp_s_20500101, __pyx_k_20500101, sizeof(__pyx_k_20500101), 0, 0, 1, 0},
    {&__pyx_kp_s_250, __pyx_k_250, sizeof(__pyx_k_250), 0, 0, 1, 0},
    {&__pyx_kp_s_2_2, __pyx_k_2_2, sizeof(__pyx_k_2_2), 0, 0, 1, 0},
    {&__pyx_kp_s_300073, __pyx_k_300073, sizeof(__pyx_k_300073), 0, 0, 1, 0},
    {&__pyx_kp_s_500, __pyx_k_500, sizeof(__pyx_k_500), 0, 0, 1, 0},
    {&__pyx_kp_s_600900, __pyx_k_600900, sizeof(__pyx_k_600900), 0, 0, 1, 0},
    {&__pyx_kp_s_688235, __pyx_k_688235, sizeof(__pyx_k_688235), 0, 0, 1, 0},
    {&__pyx_kp_s_688235_SH, __pyx_k_688235_SH, sizeof(__pyx_k_688235_SH), 0, 0, 1, 0},
    {&__pyx_n_s_ACCUM_DEAL_AMT, __pyx_k_ACCUM_DEAL_AMT, sizeof(__pyx_k_ACCUM_DEAL_AMT), 0, 0, 1, 1},
    {&__pyx_n_s_ACTUAL_ISSUE_SCALE, __pyx_k_ACTUAL_ISSUE_SCALE, sizeof(__pyx_k_ACTUAL_ISSUE_SCALE), 0, 0, 1, 1},
    {&__pyx_n_s_ADD_MARKET_CAP, __pyx_k_ADD_MARKET_CAP, sizeof(__pyx_k_ADD_MARKET_CAP), 0, 0, 1, 1},
    {&__pyx_n_s_ADD_SHARES_REPAIR, __pyx_k_ADD_SHARES_REPAIR, sizeof(__pyx_k_ADD_SHARES_REPAIR), 0, 0, 1, 1},
    {&__pyx_n_s_ALL, __pyx_k_ALL, sizeof(__pyx_k_ALL), 0, 0, 1, 1},
    {&__pyx_n_s_APP_F10_MAINFINADATA, __pyx_k_APP_F10_MAINFINADATA, sizeof(__pyx_k_APP_F10_MAINFINADATA), 0, 0, 1, 1},
    {&__pyx_n_s_AVG_FREESHARES_RATIO, __pyx_k_AVG_FREESHARES_RATIO, sizeof(__pyx_k_AVG_FREESHARES_RATIO), 0, 0, 1, 1},
    {&__pyx_n_s_AVG_FREE_SHARES, __pyx_k_AVG_FREE_SHARES, sizeof(__pyx_k_AVG_FREE_SHARES), 0, 0, 1, 1},
    {&__pyx_n_s_AVG_HOLD_AMT, __pyx_k_AVG_HOLD_AMT, sizeof(__pyx_k_AVG_HOLD_AMT), 0, 0, 1, 1},
    {&__pyx_n_s_BPS, __pyx_k_BPS, sizeof(__pyx_k_BPS), 0, 0, 1, 1},
    {&__pyx_n_s_BUY_AMT, __pyx_k_BUY_AMT, sizeof(__pyx_k_BUY_AMT), 0, 0, 1, 1},
    {&__pyx_n_s_CHANGE_RATE, __pyx_k_CHANGE_RATE, sizeof(__pyx_k_CHANGE_RATE), 0, 0, 1, 1},
    {&__pyx_n_s_CHZZL, __pyx_k_CHZZL, sizeof(__pyx_k_CHZZL), 0, 0, 1, 1},
    {&__pyx_n_s_CHZZTS, __pyx_k_CHZZTS, sizeof(__pyx_k_CHZZTS), 0, 0, 1, 1},
    {&__pyx_n_s_CLOSE_PRICE, __pyx_k_CLOSE_PRICE, sizeof(__pyx_k_CLOSE_PRICE), 0, 0, 1, 1},
    {&__pyx_n_s_CONVERT_STOCK_CODE, __pyx_k_CONVERT_STOCK_CODE, sizeof(__pyx_k_CONVERT_STOCK_CODE), 0, 0, 1, 1},
    {&__pyx_n_s_CQBL, __pyx_k_CQBL, sizeof(__pyx_k_CQBL), 0, 0, 1, 1},
    {&__pyx_n_s_DATE, __pyx_k_DATE, sizeof(__pyx_k_DATE), 0, 0, 1, 1},
    {&__pyx_kp_u_DATE_2, __pyx_k_DATE_2, sizeof(__pyx_k_DATE_2), 0, 1, 0, 0},
    {&__pyx_n_s_DEDU_PARENT_PROFIT, __pyx_k_DEDU_PARENT_PROFIT, sizeof(__pyx_k_DEDU_PARENT_PROFIT), 0, 0, 1, 1},
    {&__pyx_n_s_DIM_DATE, __pyx_k_DIM_DATE, sizeof(__pyx_k_DIM_DATE), 0, 0, 1, 1},
    {&__pyx_kp_s_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM, __pyx_k_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM, sizeof(__pyx_k_DIM_DATE_NEW_ZDF_RZYE_RZYEZB_RZM), 0, 0, 1, 0},
    {&__pyx_n_s_DPNP_YOY_RATIO, __pyx_k_DPNP_YOY_RATIO, sizeof(__pyx_k_DPNP_YOY_RATIO), 0, 0, 1, 1},
    {&__pyx_n_s_DataFrame, __pyx_k_DataFrame, sizeof(__pyx_k_DataFrame), 0, 0, 1, 1},
    {&__pyx_n_s_END_DATE, __pyx_k_END_DATE, sizeof(__pyx_k_END_DATE), 0, 0, 1, 1},
    {&__pyx_n_s_EPSJB, __pyx_k_EPSJB, sizeof(__pyx_k_EPSJB), 0, 0, 1, 1},
    {&__pyx_n_s_EPSKCJB, __pyx_k_EPSKCJB, sizeof(__pyx_k_EPSKCJB), 0, 0, 1, 1},
    {&__pyx_n_s_EPSXS, __pyx_k_EPSXS, sizeof(__pyx_k_EPSXS), 0, 0, 1, 1},
    {&__pyx_n_s_FREEHOLD_RATIO_TOTAL, __pyx_k_FREEHOLD_RATIO_TOTAL, sizeof(__pyx_k_FREEHOLD_RATIO_TOTAL), 0, 0, 1, 1},
    {&__pyx_n_s_FREE_SHARES_RATIO, __pyx_k_FREE_SHARES_RATIO, sizeof(__pyx_k_FREE_SHARES_RATIO), 0, 0, 1, 1},
    {&__pyx_n_s_GROSS_PROFIT, __pyx_k_GROSS_PROFIT, sizeof(__pyx_k_GROSS_PROFIT), 0, 0, 1, 1},
    {&__pyx_n_s_GROSS_PROFIT_RATIO, __pyx_k_GROSS_PROFIT_RATIO, sizeof(__pyx_k_GROSS_PROFIT_RATIO), 0, 0, 1, 1},
    {&__pyx_n_s_HOLDER_TOTAL_NUM, __pyx_k_HOLDER_TOTAL_NUM, sizeof(__pyx_k_HOLDER_TOTAL_NUM), 0, 0, 1, 1},
    {&__pyx_n_s_HOLD_FOCUS, __pyx_k_HOLD_FOCUS, sizeof(__pyx_k_HOLD_FOCUS), 0, 0, 1, 1},
    {&__pyx_n_s_HOLD_MARKET_CAP, __pyx_k_HOLD_MARKET_CAP, sizeof(__pyx_k_HOLD_MARKET_CAP), 0, 0, 1, 1},
    {&__pyx_n_s_HOLD_RATIO_TOTAL, __pyx_k_HOLD_RATIO_TOTAL, sizeof(__pyx_k_HOLD_RATIO_TOTAL), 0, 0, 1, 1},
    {&__pyx_n_s_HOLD_SHARES, __pyx_k_HOLD_SHARES, sizeof(__pyx_k_HOLD_SHARES), 0, 0, 1, 1},
    {&__pyx_n_s_HSF10, __pyx_k_HSF10, sizeof(__pyx_k_HSF10), 0, 0, 1, 1},
    {&__pyx_n_s_INDEX_CHANGE_RATE, __pyx_k_INDEX_CHANGE_RATE, sizeof(__pyx_k_INDEX_CHANGE_RATE), 0, 0, 1, 1},
    {&__pyx_n_s_INDEX_CLOSE_PRICE, __pyx_k_INDEX_CLOSE_PRICE, sizeof(__pyx_k_INDEX_CLOSE_PRICE), 0, 0, 1, 1},
    {&__pyx_kp_u_INTERVAL_TYPE_1, __pyx_k_INTERVAL_TYPE_1, sizeof(__pyx_k_INTERVAL_TYPE_1), 0, 1, 0, 0},
    {&__pyx_kp_u_INTERVAL_TYPE_1_2, __pyx_k_INTERVAL_TYPE_1_2, sizeof(__pyx_k_INTERVAL_TYPE_1_2), 0, 1, 0, 0},
    {&__pyx_n_s_JROA, __pyx_k_JROA, sizeof(__pyx_k_JROA), 0, 0, 1, 1},
    {&__pyx_n_s_JYXJLYYSR, __pyx_k_JYXJLYYSR, sizeof(__pyx_k_JYXJLYYSR), 0, 0, 1, 1},
    {&__pyx_n_s_KCFJCXSYJLR, __pyx_k_KCFJCXSYJLR, sizeof(__pyx_k_KCFJCXSYJLR), 0, 0, 1, 1},
    {&__pyx_n_s_KCFJCXSYJLRTZ, __pyx_k_KCFJCXSYJLRTZ, sizeof(__pyx_k_KCFJCXSYJLRTZ), 0, 0, 1, 1},
    {&__pyx_n_s_KFJLRGDHBZC, __pyx_k_KFJLRGDHBZC, sizeof(__pyx_k_KFJLRGDHBZC), 0, 0, 1, 1},
    {&__pyx_n_s_LD, __pyx_k_LD, sizeof(__pyx_k_LD), 0, 0, 1, 1},
    {&__pyx_n_s_MGJYXJJE, __pyx_k_MGJYXJJE, sizeof(__pyx_k_MGJYXJJE), 0, 0, 1, 1},
    {&__pyx_n_s_MGWFPLR, __pyx_k_MGWFPLR, sizeof(__pyx_k_MGWFPLR), 0, 0, 1, 1},
    {&__pyx_n_s_MGZBGJ, __pyx_k_MGZBGJ, sizeof(__pyx_k_MGZBGJ), 0, 0, 1, 1},
    {&__pyx_n_s_MLR, __pyx_k_MLR, sizeof(__pyx_k_MLR), 0, 0, 1, 1},
    {&__pyx_kp_s_MUTUAL_TYPE_005, __pyx_k_MUTUAL_TYPE_005, sizeof(__pyx_k_MUTUAL_TYPE_005), 0, 0, 1, 0},
    {&__pyx_n_s_NETPROFITRPHBZC, __pyx_k_NETPROFITRPHBZC, sizeof(__pyx_k_NETPROFITRPHBZC), 0, 0, 1, 1},
    {&__pyx_n_s_NET_DEAL_AMT, __pyx_k_NET_DEAL_AMT, sizeof(__pyx_k_NET_DEAL_AMT), 0, 0, 1, 1},
    {&__pyx_n_s_NET_PROFIT_RATIO, __pyx_k_NET_PROFIT_RATIO, sizeof(__pyx_k_NET_PROFIT_RATIO), 0, 0, 1, 1},
    {&__pyx_n_s_NEW, __pyx_k_NEW, sizeof(__pyx_k_NEW), 0, 0, 1, 1},
    {&__pyx_n_s_NOTICE_DATE, __pyx_k_NOTICE_DATE, sizeof(__pyx_k_NOTICE_DATE), 0, 0, 1, 1},
    {&__pyx_n_s_PARENTNETPROFIT, __pyx_k_PARENTNETPROFIT, sizeof(__pyx_k_PARENTNETPROFIT), 0, 0, 1, 1},
    {&__pyx_n_s_PARENTNETPROFITTZ, __pyx_k_PARENTNETPROFITTZ, sizeof(__pyx_k_PARENTNETPROFITTZ), 0, 0, 1, 1},
    {&__pyx_n_s_PC, __pyx_k_PC, sizeof(__pyx_k_PC), 0, 0, 1, 1},
    {&__pyx_n_s_PER_CAPITAL_RESERVE, __pyx_k_PER_CAPITAL_RESERVE, sizeof(__pyx_k_PER_CAPITAL_RESERVE), 0, 0, 1, 1},
    {&__pyx_n_s_PER_NETCASH, __pyx_k_PER_NETCASH, sizeof(__pyx_k_PER_NETCASH), 0, 0, 1, 1},
    {&__pyx_n_s_PER_UNASSIGN_PROFIT, __pyx_k_PER_UNASSIGN_PROFIT, sizeof(__pyx_k_PER_UNASSIGN_PROFIT), 0, 0, 1, 1},
    {&__pyx_n_s_PREDICT_AMC, __pyx_k_PREDICT_AMC, sizeof(__pyx_k_PREDICT_AMC), 0, 0, 1, 1},
    {&__pyx_n_s_PRICE, __pyx_k_PRICE, sizeof(__pyx_k_PRICE), 0, 0, 1, 1},
    {&__pyx_n_s_PUBLIC_START_DATE, __pyx_k_PUBLIC_START_DATE, sizeof(__pyx_k_PUBLIC_START_DATE), 0, 0, 1, 1},
    {&__pyx_kp_s_PUBLIC_START_DATE_SECURITY_CODE, __pyx_k_PUBLIC_START_DATE_SECURITY_CODE, sizeof(__pyx_k_PUBLIC_START_DATE_SECURITY_CODE), 0, 0, 1, 0},
    {&__pyx_n_s_QYCS, __pyx_k_QYCS, sizeof(__pyx_k_QYCS), 0, 0, 1, 1},
    {&__pyx_n_s_REPORT_DATE, __pyx_k_REPORT_DATE, sizeof(__pyx_k_REPORT_DATE), 0, 0, 1, 1},
    {&__pyx_n_s_ROEJQ, __pyx_k_ROEJQ, sizeof(__pyx_k_ROEJQ), 0, 0, 1, 1},
    {&__pyx_n_s_ROE_DILUTED, __pyx_k_ROE_DILUTED, sizeof(__pyx_k_ROE_DILUTED), 0, 0, 1, 1},
    {&__pyx_n_s_RPTA_RZRQ_LSHJ, __pyx_k_RPTA_RZRQ_LSHJ, sizeof(__pyx_k_RPTA_RZRQ_LSHJ), 0, 0, 1, 1},
    {&__pyx_n_s_RPTA_WEB_RZRQ_GGMX, __pyx_k_RPTA_WEB_RZRQ_GGMX, sizeof(__pyx_k_RPTA_WEB_RZRQ_GGMX), 0, 0, 1, 1},
    {&__pyx_n_s_RPT_BOND_CB_LIST, __pyx_k_RPT_BOND_CB_LIST, sizeof(__pyx_k_RPT_BOND_CB_LIST), 0, 0, 1, 1},
    {&__pyx_n_s_RPT_F10_EH_HOLDERNUM, __pyx_k_RPT_F10_EH_HOLDERNUM, sizeof(__pyx_k_RPT_F10_EH_HOLDERNUM), 0, 0, 1, 1},
    {&__pyx_n_s_RPT_F10_FINANCE_MAINFINADATA, __pyx_k_RPT_F10_FINANCE_MAINFINADATA, sizeof(__pyx_k_RPT_F10_FINANCE_MAINFINADATA), 0, 0, 1, 1},
    {&__pyx_n_s_RPT_F10_QTR_MAINFINADATA, __pyx_k_RPT_F10_QTR_MAINFINADATA, sizeof(__pyx_k_RPT_F10_QTR_MAINFINADATA), 0, 0, 1, 1},
    {&__pyx_n_s_RPT_MUTUAL_DEALHISTORY_NEW, __pyx_k_RPT_MUTUAL_DEALHISTORY_NEW, sizeof(__pyx_k_RPT_MUTUAL_DEALHISTORY_NEW), 0, 0, 1, 1},
    {&__pyx_n_s_RPT_MUTUAL_HOLDSTOCKNDATE_STA, __pyx_k_RPT_MUTUAL_HOLDSTOCKNDATE_STA, sizeof(__pyx_k_RPT_MUTUAL_HOLDSTOCKNDATE_STA), 0, 0, 1, 1},
    {&__pyx_n_s_RPT_MUTUAL_STOCK_NORTHSTA, __pyx_k_RPT_MUTUAL_STOCK_NORTHSTA, sizeof(__pyx_k_RPT_MUTUAL_STOCK_NORTHSTA), 0, 0, 1, 1},
    {&__pyx_n_s_RPT_SHAREBONUS_DET, __pyx_k_RPT_SHAREBONUS_DET, sizeof(__pyx_k_RPT_SHAREBONUS_DET), 0, 0, 1, 1},
    {&__pyx_n_s_RQCHL, __pyx_k_RQCHL, sizeof(__pyx_k_RQCHL), 0, 0, 1, 1},
    {&__pyx_n_s_RQJMG, __pyx_k_RQJMG, sizeof(__pyx_k_RQJMG), 0, 0, 1, 1},
    {&__pyx_n_s_RQMCL, __pyx_k_RQMCL, sizeof(__pyx_k_RQMCL), 0, 0, 1, 1},
    {&__pyx_n_s_RQYE, __pyx_k_RQYE, sizeof(__pyx_k_RQYE), 0, 0, 1, 1},
    {&__pyx_n_s_RQYL, __pyx_k_RQYL, sizeof(__pyx_k_RQYL), 0, 0, 1, 1},
    {&__pyx_n_s_RZCHE, __pyx_k_RZCHE, sizeof(__pyx_k_RZCHE), 0, 0, 1, 1},
    {&__pyx_n_s_RZJME, __pyx_k_RZJME, sizeof(__pyx_k_RZJME), 0, 0, 1, 1},
    {&__pyx_n_s_RZMRE, __pyx_k_RZMRE, sizeof(__pyx_k_RZMRE), 0, 0, 1, 1},
    {&__pyx_n_s_RZRQYE, __pyx_k_RZRQYE, sizeof(__pyx_k_RZRQYE), 0, 0, 1, 1},
    {&__pyx_n_s_RZYE, __pyx_k_RZYE, sizeof(__pyx_k_RZYE), 0, 0, 1, 1},
    {&__pyx_n_s_RZYEZB, __pyx_k_RZYEZB, sizeof(__pyx_k_RZYEZB), 0, 0, 1, 1},
    {&__pyx_n_s_SCODE, __pyx_k_SCODE, sizeof(__pyx_k_SCODE), 0, 0, 1, 1},
    {&__pyx_kp_s_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE, __pyx_k_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE, sizeof(__pyx_k_SCODE_SECNAME_DATE_SPJ_ZDF_RZYE), 0, 0, 1, 0},
    {&__pyx_n_s_SD, __pyx_k_SD, sizeof(__pyx_k_SD), 0, 0, 1, 1},
    {&__pyx_n_s_SECNAME, __pyx_k_SECNAME, sizeof(__pyx_k_SECNAME), 0, 0, 1, 1},
    {&__pyx_kp_u_SECUCODE, __pyx_k_SECUCODE, sizeof(__pyx_k_SECUCODE), 0, 1, 0, 0},
    {&__pyx_n_s_SECURITY_CODE, __pyx_k_SECURITY_CODE, sizeof(__pyx_k_SECURITY_CODE), 0, 0, 1, 1},
    {&__pyx_kp_u_SECURITY_CODE_2, __pyx_k_SECURITY_CODE_2, sizeof(__pyx_k_SECURITY_CODE_2), 0, 1, 0, 0},
    {&__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_ABBR, __pyx_k_SECURITY_CODE_SECURITY_NAME_ABBR, sizeof(__pyx_k_SECURITY_CODE_SECURITY_NAME_ABBR), 0, 0, 1, 0},
    {&__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD, __pyx_k_SECURITY_CODE_SECURITY_NAME_TRAD, sizeof(__pyx_k_SECURITY_CODE_SECURITY_NAME_TRAD), 0, 0, 1, 0},
    {&__pyx_kp_s_SECURITY_CODE_SECURITY_NAME_TRAD_2, __pyx_k_SECURITY_CODE_SECURITY_NAME_TRAD_2, sizeof(__pyx_k_SECURITY_CODE_SECURITY_NAME_TRAD_2), 0, 0, 1, 0},
    {&__pyx_n_s_SECURITY_NAME, __pyx_k_SECURITY_NAME, sizeof(__pyx_k_SECURITY_NAME), 0, 0, 1, 1},
    {&__pyx_n_s_SECURITY_NAME_ABBR, __pyx_k_SECURITY_NAME_ABBR, sizeof(__pyx_k_SECURITY_NAME_ABBR), 0, 0, 1, 1},
    {&__pyx_n_s_SECURITY_SHORT_NAME, __pyx_k_SECURITY_SHORT_NAME, sizeof(__pyx_k_SECURITY_SHORT_NAME), 0, 0, 1, 1},
    {&__pyx_n_s_SELL_AMT, __pyx_k_SELL_AMT, sizeof(__pyx_k_SELL_AMT), 0, 0, 1, 1},
    {&__pyx_n_s_SPJ, __pyx_k_SPJ, sizeof(__pyx_k_SPJ), 0, 0, 1, 1},
    {&__pyx_n_s_TAXRATE, __pyx_k_TAXRATE, sizeof(__pyx_k_TAXRATE), 0, 0, 1, 1},
    {&__pyx_n_s_TOAZZL, __pyx_k_TOAZZL, sizeof(__pyx_k_TOAZZL), 0, 0, 1, 1},
    {&__pyx_n_s_TOTALOPERATEREVE, __pyx_k_TOTALOPERATEREVE, sizeof(__pyx_k_TOTALOPERATEREVE), 0, 0, 1, 1},
    {&__pyx_n_s_TOTALOPERATEREVETZ, __pyx_k_TOTALOPERATEREVETZ, sizeof(__pyx_k_TOTALOPERATEREVETZ), 0, 0, 1, 1},
    {&__pyx_n_s_TOTAL_NUM_RATIO, __pyx_k_TOTAL_NUM_RATIO, sizeof(__pyx_k_TOTAL_NUM_RATIO), 0, 0, 1, 1},
    {&__pyx_n_s_TRADE_DATE, __pyx_k_TRADE_DATE, sizeof(__pyx_k_TRADE_DATE), 0, 0, 1, 1},
    {&__pyx_kp_u_TRADE_DATE_2, __pyx_k_TRADE_DATE_2, sizeof(__pyx_k_TRADE_DATE_2), 0, 1, 0, 0},
    {&__pyx_kp_s_TRADE_DATE_NET_DEAL_AMT_BUY_AMT, __pyx_k_TRADE_DATE_NET_DEAL_AMT_BUY_AMT, sizeof(__pyx_k_TRADE_DATE_NET_DEAL_AMT_BUY_AMT), 0, 0, 1, 0},
    {&__pyx_n_s_TRANSFER_PRICE, __pyx_k_TRANSFER_PRICE, sizeof(__pyx_k_TRANSFER_PRICE), 0, 0, 1, 1},
    {&__pyx_n_s_TRANSFER_VALUE, __pyx_k_TRANSFER_VALUE, sizeof(__pyx_k_TRANSFER_VALUE), 0, 0, 1, 1},
    {&__pyx_n_s_WEB, __pyx_k_WEB, sizeof(__pyx_k_WEB), 0, 0, 1, 1},
    {&__pyx_n_s_XJLLB, __pyx_k_XJLLB, sizeof(__pyx_k_XJLLB), 0, 0, 1, 1},
    {&__pyx_n_s_XSJLL, __pyx_k_XSJLL, sizeof(__pyx_k_XSJLL), 0, 0, 1, 1},
    {&__pyx_n_s_XSJXLYYSR, __pyx_k_XSJXLYYSR, sizeof(__pyx_k_XSJXLYYSR), 0, 0, 1, 1},
    {&__pyx_n_s_XSMLL, __pyx_k_XSMLL, sizeof(__pyx_k_XSMLL), 0, 0, 1, 1},
    {&__pyx_n_s_YSZKYYSR, __pyx_k_YSZKYYSR, sizeof(__pyx_k_YSZKYYSR), 0, 0, 1, 1},
    {&__pyx_n_s_YSZKZZL, __pyx_k_YSZKZZL, sizeof(__pyx_k_YSZKZZL), 0, 0, 1, 1},
    {&__pyx_n_s_YSZKZZTS, __pyx_k_YSZKZZTS, sizeof(__pyx_k_YSZKZZTS), 0, 0, 1, 1},
    {&__pyx_n_s_YYZSRGDHBZC, __pyx_k_YYZSRGDHBZC, sizeof(__pyx_k_YYZSRGDHBZC), 0, 0, 1, 1},
    {&__pyx_kp_s_Y_m_d, __pyx_k_Y_m_d, sizeof(__pyx_k_Y_m_d), 0, 0, 1, 0},
    {&__pyx_n_s_ZCFZL, __pyx_k_ZCFZL, sizeof(__pyx_k_ZCFZL), 0, 0, 1, 1},
    {&__pyx_n_s_ZDF, __pyx_k_ZDF, sizeof(__pyx_k_ZDF), 0, 0, 1, 1},
    {&__pyx_n_s_ZZCJLL, __pyx_k_ZZCJLL, sizeof(__pyx_k_ZZCJLL), 0, 0, 1, 1},
    {&__pyx_n_s_ZZCZZTS, __pyx_k_ZZCZZTS, sizeof(__pyx_k_ZZCZZTS), 0, 0, 1, 1},
    {&__pyx_kp_s__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 0, 1, 0},
    {&__pyx_kp_s__11, __pyx_k__11, sizeof(__pyx_k__11), 0, 0, 1, 0},
    {&__pyx_kp_s__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 0, 1, 0},
    {&__pyx_kp_s__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 0, 1, 0},
    {&__pyx_n_s__132, __pyx_k__132, sizeof(__pyx_k__132), 0, 0, 1, 1},
    {&__pyx_kp_s__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 0, 1, 0},
    {&__pyx_kp_s__15, __pyx_k__15, sizeof(__pyx_k__15), 0, 0, 1, 0},
    {&__pyx_kp_s__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 0, 1, 0},
    {&__pyx_kp_s__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 0, 1, 0},
    {&__pyx_kp_s__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 0, 1, 0},
    {&__pyx_kp_s__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 0, 1, 0},
    {&__pyx_kp_s__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 0, 1, 0},
    {&__pyx_kp_s__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 0, 1, 0},
    {&__pyx_kp_s__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 0, 1, 0},
    {&__pyx_kp_s__23, __pyx_k__23, sizeof(__pyx_k__23), 0, 0, 1, 0},
    {&__pyx_kp_s__24, __pyx_k__24, sizeof(__pyx_k__24), 0, 0, 1, 0},
    {&__pyx_kp_s__25, __pyx_k__25, sizeof(__pyx_k__25), 0, 0, 1, 0},
    {&__pyx_kp_s__26, __pyx_k__26, sizeof(__pyx_k__26), 0, 0, 1, 0},
    {&__pyx_kp_s__27, __pyx_k__27, sizeof(__pyx_k__27), 0, 0, 1, 0},
    {&__pyx_kp_s__28, __pyx_k__28, sizeof(__pyx_k__28), 0, 0, 1, 0},
    {&__pyx_kp_s__29, __pyx_k__29, sizeof(__pyx_k__29), 0, 0, 1, 0},
    {&__pyx_n_s__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 1, 1},
    {&__pyx_kp_s__30, __pyx_k__30, sizeof(__pyx_k__30), 0, 0, 1, 0},
    {&__pyx_kp_s__31, __pyx_k__31, sizeof(__pyx_k__31), 0, 0, 1, 0},
    {&__pyx_kp_s__32, __pyx_k__32, sizeof(__pyx_k__32), 0, 0, 1, 0},
    {&__pyx_kp_s__33, __pyx_k__33, sizeof(__pyx_k__33), 0, 0, 1, 0},
    {&__pyx_kp_s__34, __pyx_k__34, sizeof(__pyx_k__34), 0, 0, 1, 0},
    {&__pyx_kp_s__35, __pyx_k__35, sizeof(__pyx_k__35), 0, 0, 1, 0},
    {&__pyx_kp_s__36, __pyx_k__36, sizeof(__pyx_k__36), 0, 0, 1, 0},
    {&__pyx_kp_s__37, __pyx_k__37, sizeof(__pyx_k__37), 0, 0, 1, 0},
    {&__pyx_kp_s__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 0, 1, 0},
    {&__pyx_kp_s__39, __pyx_k__39, sizeof(__pyx_k__39), 0, 0, 1, 0},
    {&__pyx_kp_s__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 0, 1, 0},
    {&__pyx_kp_s__40, __pyx_k__40, sizeof(__pyx_k__40), 0, 0, 1, 0},
    {&__pyx_kp_s__41, __pyx_k__41, sizeof(__pyx_k__41), 0, 0, 1, 0},
    {&__pyx_kp_s__42, __pyx_k__42, sizeof(__pyx_k__42), 0, 0, 1, 0},
    {&__pyx_kp_s__43, __pyx_k__43, sizeof(__pyx_k__43), 0, 0, 1, 0},
    {&__pyx_kp_s__44, __pyx_k__44, sizeof(__pyx_k__44), 0, 0, 1, 0},
    {&__pyx_kp_s__45, __pyx_k__45, sizeof(__pyx_k__45), 0, 0, 1, 0},
    {&__pyx_kp_s__46, __pyx_k__46, sizeof(__pyx_k__46), 0, 0, 1, 0},
    {&__pyx_kp_s__47, __pyx_k__47, sizeof(__pyx_k__47), 0, 0, 1, 0},
    {&__pyx_kp_s__48, __pyx_k__48, sizeof(__pyx_k__48), 0, 0, 1, 0},
    {&__pyx_kp_s__49, __pyx_k__49, sizeof(__pyx_k__49), 0, 0, 1, 0},
    {&__pyx_kp_s__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 0, 1, 0},
    {&__pyx_kp_s__50, __pyx_k__50, sizeof(__pyx_k__50), 0, 0, 1, 0},
    {&__pyx_kp_s__51, __pyx_k__51, sizeof(__pyx_k__51), 0, 0, 1, 0},
    {&__pyx_kp_s__52, __pyx_k__52, sizeof(__pyx_k__52), 0, 0, 1, 0},
    {&__pyx_kp_s__53, __pyx_k__53, sizeof(__pyx_k__53), 0, 0, 1, 0},
    {&__pyx_kp_s__54, __pyx_k__54, sizeof(__pyx_k__54), 0, 0, 1, 0},
    {&__pyx_kp_s__55, __pyx_k__55, sizeof(__pyx_k__55), 0, 0, 1, 0},
    {&__pyx_kp_s__56, __pyx_k__56, sizeof(__pyx_k__56), 0, 0, 1, 0},
    {&__pyx_kp_s__57, __pyx_k__57, sizeof(__pyx_k__57), 0, 0, 1, 0},
    {&__pyx_kp_s__58, __pyx_k__58, sizeof(__pyx_k__58), 0, 0, 1, 0},
    {&__pyx_kp_s__59, __pyx_k__59, sizeof(__pyx_k__59), 0, 0, 1, 0},
    {&__pyx_kp_s__60, __pyx_k__60, sizeof(__pyx_k__60), 0, 0, 1, 0},
    {&__pyx_kp_u__62, __pyx_k__62, sizeof(__pyx_k__62), 0, 1, 0, 0},
    {&__pyx_kp_s__63, __pyx_k__63, sizeof(__pyx_k__63), 0, 0, 1, 0},
    {&__pyx_kp_s__64, __pyx_k__64, sizeof(__pyx_k__64), 0, 0, 1, 0},
    {&__pyx_kp_s__65, __pyx_k__65, sizeof(__pyx_k__65), 0, 0, 1, 0},
    {&__pyx_kp_s__66, __pyx_k__66, sizeof(__pyx_k__66), 0, 0, 1, 0},
    {&__pyx_kp_s__67, __pyx_k__67, sizeof(__pyx_k__67), 0, 0, 1, 0},
    {&__pyx_kp_s__68, __pyx_k__68, sizeof(__pyx_k__68), 0, 0, 1, 0},
    {&__pyx_kp_s__69, __pyx_k__69, sizeof(__pyx_k__69), 0, 0, 1, 0},
    {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
    {&__pyx_kp_s__70, __pyx_k__70, sizeof(__pyx_k__70), 0, 0, 1, 0},
    {&__pyx_kp_s__71, __pyx_k__71, sizeof(__pyx_k__71), 0, 0, 1, 0},
    {&__pyx_kp_s__72, __pyx_k__72, sizeof(__pyx_k__72), 0, 0, 1, 0},
    {&__pyx_kp_s__73, __pyx_k__73, sizeof(__pyx_k__73), 0, 0, 1, 0},
    {&__pyx_kp_s__74, __pyx_k__74, sizeof(__pyx_k__74), 0, 0, 1, 0},
    {&__pyx_kp_s__75, __pyx_k__75, sizeof(__pyx_k__75), 0, 0, 1, 0},
    {&__pyx_kp_s__76, __pyx_k__76, sizeof(__pyx_k__76), 0, 0, 1, 0},
    {&__pyx_kp_s__77, __pyx_k__77, sizeof(__pyx_k__77), 0, 0, 1, 0},
    {&__pyx_kp_s__78, __pyx_k__78, sizeof(__pyx_k__78), 0, 0, 1, 0},
    {&__pyx_kp_s__79, __pyx_k__79, sizeof(__pyx_k__79), 0, 0, 1, 0},
    {&__pyx_kp_s__80, __pyx_k__80, sizeof(__pyx_k__80), 0, 0, 1, 0},
    {&__pyx_kp_s__81, __pyx_k__81, sizeof(__pyx_k__81), 0, 0, 1, 0},
    {&__pyx_kp_s__82, __pyx_k__82, sizeof(__pyx_k__82), 0, 0, 1, 0},
    {&__pyx_kp_s__83, __pyx_k__83, sizeof(__pyx_k__83), 0, 0, 1, 0},
    {&__pyx_kp_s__84, __pyx_k__84, sizeof(__pyx_k__84), 0, 0, 1, 0},
    {&__pyx_kp_s__85, __pyx_k__85, sizeof(__pyx_k__85), 0, 0, 1, 0},
    {&__pyx_kp_s__86, __pyx_k__86, sizeof(__pyx_k__86), 0, 0, 1, 0},
    {&__pyx_kp_s__87, __pyx_k__87, sizeof(__pyx_k__87), 0, 0, 1, 0},
    {&__pyx_kp_s__88, __pyx_k__88, sizeof(__pyx_k__88), 0, 0, 1, 0},
    {&__pyx_kp_s__89, __pyx_k__89, sizeof(__pyx_k__89), 0, 0, 1, 0},
    {&__pyx_kp_u__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 1, 0, 0},
    {&__pyx_n_s__90, __pyx_k__90, sizeof(__pyx_k__90), 0, 0, 1, 1},
    {&__pyx_n_s_accum_net_amount, __pyx_k_accum_net_amount, sizeof(__pyx_k_accum_net_amount), 0, 0, 1, 1},
    {&__pyx_n_s_add_amount, __pyx_k_add_amount, sizeof(__pyx_k_add_amount), 0, 0, 1, 1},
    {&__pyx_n_s_add_volume, __pyx_k_add_volume, sizeof(__pyx_k_add_volume), 0, 0, 1, 1},
    {&__pyx_n_s_akshare_stock_feature_stock_hist, __pyx_k_akshare_stock_feature_stock_hist, sizeof(__pyx_k_akshare_stock_feature_stock_hist), 0, 0, 1, 1},
    {&__pyx_n_s_akshare_utils, __pyx_k_akshare_utils, sizeof(__pyx_k_akshare_utils), 0, 0, 1, 1},
    {&__pyx_n_s_amount, __pyx_k_amount, sizeof(__pyx_k_amount), 0, 0, 1, 1},
    {&__pyx_n_s_apply, __pyx_k_apply, sizeof(__pyx_k_apply), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_avg_amount_pa, __pyx_k_avg_amount_pa, sizeof(__pyx_k_avg_amount_pa), 0, 0, 1, 1},
    {&__pyx_n_s_avg_volume_pa, __pyx_k_avg_volume_pa, sizeof(__pyx_k_avg_volume_pa), 0, 0, 1, 1},
    {&__pyx_n_s_avg_volume_pa_ratio, __pyx_k_avg_volume_pa_ratio, sizeof(__pyx_k_avg_volume_pa_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_bd1d9ddb04089700cf9c27f6f7426281, __pyx_k_bd1d9ddb04089700cf9c27f6f7426281, sizeof(__pyx_k_bd1d9ddb04089700cf9c27f6f7426281), 0, 0, 1, 1},
    {&__pyx_n_s_beg, __pyx_k_beg, sizeof(__pyx_k_beg), 0, 0, 1, 1},
    {&__pyx_n_s_big_df, __pyx_k_big_df, sizeof(__pyx_k_big_df), 0, 0, 1, 1},
    {&__pyx_n_s_bond_code, __pyx_k_bond_code, sizeof(__pyx_k_bond_code), 0, 0, 1, 1},
    {&__pyx_n_s_bond_name, __pyx_k_bond_name, sizeof(__pyx_k_bond_name), 0, 0, 1, 1},
    {&__pyx_n_s_bond_scale, __pyx_k_bond_scale, sizeof(__pyx_k_bond_scale), 0, 0, 1, 1},
    {&__pyx_n_s_bps, __pyx_k_bps, sizeof(__pyx_k_bps), 0, 0, 1, 1},
    {&__pyx_n_s_buy_amount, __pyx_k_buy_amount, sizeof(__pyx_k_buy_amount), 0, 0, 1, 1},
    {&__pyx_n_s_capital_reserve_ps, __pyx_k_capital_reserve_ps, sizeof(__pyx_k_capital_reserve_ps), 0, 0, 1, 1},
    {&__pyx_n_s_cash_flow_ratio, __pyx_k_cash_flow_ratio, sizeof(__pyx_k_cash_flow_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_cb, __pyx_k_cb, sizeof(__pyx_k_cb), 0, 0, 1, 1},
    {&__pyx_n_s_ceil, __pyx_k_ceil, sizeof(__pyx_k_ceil), 0, 0, 1, 1},
    {&__pyx_n_s_ch_zzl, __pyx_k_ch_zzl, sizeof(__pyx_k_ch_zzl), 0, 0, 1, 1},
    {&__pyx_n_s_ch_zzts, __pyx_k_ch_zzts, sizeof(__pyx_k_ch_zzts), 0, 0, 1, 1},
    {&__pyx_n_s_change_rate, __pyx_k_change_rate, sizeof(__pyx_k_change_rate), 0, 0, 1, 1},
    {&__pyx_n_s_change_ratio, __pyx_k_change_ratio, sizeof(__pyx_k_change_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_client, __pyx_k_client, sizeof(__pyx_k_client), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
    {&__pyx_n_s_code, __pyx_k_code, sizeof(__pyx_k_code), 0, 0, 1, 1},
    {&__pyx_n_s_code_id_dict, __pyx_k_code_id_dict, sizeof(__pyx_k_code_id_dict), 0, 0, 1, 1},
    {&__pyx_n_s_code_id_map_em, __pyx_k_code_id_map_em, sizeof(__pyx_k_code_id_map_em), 0, 0, 1, 1},
    {&__pyx_n_s_code_name_map, __pyx_k_code_name_map, sizeof(__pyx_k_code_name_map), 0, 0, 1, 1},
    {&__pyx_n_s_coerce, __pyx_k_coerce, sizeof(__pyx_k_coerce), 0, 0, 1, 1},
    {&__pyx_n_s_cols_to_convert, __pyx_k_cols_to_convert, sizeof(__pyx_k_cols_to_convert), 0, 0, 1, 1},
    {&__pyx_n_s_column_dict, __pyx_k_column_dict, sizeof(__pyx_k_column_dict), 0, 0, 1, 1},
    {&__pyx_n_s_column_name_dict, __pyx_k_column_name_dict, sizeof(__pyx_k_column_name_dict), 0, 0, 1, 1},
    {&__pyx_n_s_columns, __pyx_k_columns, sizeof(__pyx_k_columns), 0, 0, 1, 1},
    {&__pyx_n_s_concat, __pyx_k_concat, sizeof(__pyx_k_concat), 0, 0, 1, 1},
    {&__pyx_n_s_csi, __pyx_k_csi, sizeof(__pyx_k_csi), 0, 0, 1, 1},
    {&__pyx_n_s_csi931151, __pyx_k_csi931151, sizeof(__pyx_k_csi931151), 0, 0, 1, 1},
    {&__pyx_n_s_current_ratio, __pyx_k_current_ratio, sizeof(__pyx_k_current_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
    {&__pyx_n_s_data_json, __pyx_k_data_json, sizeof(__pyx_k_data_json), 0, 0, 1, 1},
    {&__pyx_n_s_data_text, __pyx_k_data_text, sizeof(__pyx_k_data_text), 0, 0, 1, 1},
    {&__pyx_kp_s_data_x_pages_tp, __pyx_k_data_x_pages_tp, sizeof(__pyx_k_data_x_pages_tp), 0, 0, 1, 0},
    {&__pyx_n_s_date, __pyx_k_date, sizeof(__pyx_k_date), 0, 0, 1, 1},
    {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
    {&__pyx_n_s_debt_to_asset_ratio, __pyx_k_debt_to_asset_ratio, sizeof(__pyx_k_debt_to_asset_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
    {&__pyx_n_s_dect, __pyx_k_dect, sizeof(__pyx_k_dect), 0, 0, 1, 1},
    {&__pyx_n_s_demjson, __pyx_k_demjson, sizeof(__pyx_k_demjson), 0, 0, 1, 1},
    {&__pyx_n_s_diff, __pyx_k_diff, sizeof(__pyx_k_diff), 0, 0, 1, 1},
    {&__pyx_n_s_dim_date, __pyx_k_dim_date, sizeof(__pyx_k_dim_date), 0, 0, 1, 1},
    {&__pyx_n_s_dlmkts, __pyx_k_dlmkts, sizeof(__pyx_k_dlmkts), 0, 0, 1, 1},
    {&__pyx_n_s_drop, __pyx_k_drop, sizeof(__pyx_k_drop), 0, 0, 1, 1},
    {&__pyx_n_s_dt, __pyx_k_dt, sizeof(__pyx_k_dt), 0, 0, 1, 1},
    {&__pyx_n_s_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 0, 1, 1},
    {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
    {&__pyx_n_s_end_date, __pyx_k_end_date, sizeof(__pyx_k_end_date), 0, 0, 1, 1},
    {&__pyx_n_s_eps_jb, __pyx_k_eps_jb, sizeof(__pyx_k_eps_jb), 0, 0, 1, 1},
    {&__pyx_n_s_eps_kf, __pyx_k_eps_kf, sizeof(__pyx_k_eps_kf), 0, 0, 1, 1},
    {&__pyx_n_s_eps_xs, __pyx_k_eps_xs, sizeof(__pyx_k_eps_xs), 0, 0, 1, 1},
    {&__pyx_n_s_equity_multiplier, __pyx_k_equity_multiplier, sizeof(__pyx_k_equity_multiplier), 0, 0, 1, 1},
    {&__pyx_n_s_equity_ratio, __pyx_k_equity_ratio, sizeof(__pyx_k_equity_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_errors, __pyx_k_errors, sizeof(__pyx_k_errors), 0, 0, 1, 1},
    {&__pyx_n_s_f116, __pyx_k_f116, sizeof(__pyx_k_f116), 0, 0, 1, 1},
    {&__pyx_n_s_f117, __pyx_k_f117, sizeof(__pyx_k_f117), 0, 0, 1, 1},
    {&__pyx_n_s_f12, __pyx_k_f12, sizeof(__pyx_k_f12), 0, 0, 1, 1},
    {&__pyx_kp_s_f120_f121_f122_f174_f175_f59_f16, __pyx_k_f120_f121_f122_f174_f175_f59_f16, sizeof(__pyx_k_f120_f121_f122_f174_f175_f59_f16), 0, 0, 1, 0},
    {&__pyx_n_s_f127, __pyx_k_f127, sizeof(__pyx_k_f127), 0, 0, 1, 1},
    {&__pyx_n_s_f128, __pyx_k_f128, sizeof(__pyx_k_f128), 0, 0, 1, 1},
    {&__pyx_kp_s_f12_f14_f2_f4_f3_f17_f15_f16_f18, __pyx_k_f12_f14_f2_f4_f3_f17_f15_f16_f18, sizeof(__pyx_k_f12_f14_f2_f4_f3_f17_f15_f16_f18), 0, 0, 1, 0},
    {&__pyx_n_s_f14, __pyx_k_f14, sizeof(__pyx_k_f14), 0, 0, 1, 1},
    {&__pyx_n_s_f15, __pyx_k_f15, sizeof(__pyx_k_f15), 0, 0, 1, 1},
    {&__pyx_n_s_f16, __pyx_k_f16, sizeof(__pyx_k_f16), 0, 0, 1, 1},
    {&__pyx_n_s_f17, __pyx_k_f17, sizeof(__pyx_k_f17), 0, 0, 1, 1},
    {&__pyx_n_s_f18, __pyx_k_f18, sizeof(__pyx_k_f18), 0, 0, 1, 1},
    {&__pyx_n_s_f189, __pyx_k_f189, sizeof(__pyx_k_f189), 0, 0, 1, 1},
    {&__pyx_kp_s_f1_f2_f3_f4_f5, __pyx_k_f1_f2_f3_f4_f5, sizeof(__pyx_k_f1_f2_f3_f4_f5), 0, 0, 1, 0},
    {&__pyx_n_s_f2, __pyx_k_f2, sizeof(__pyx_k_f2), 0, 0, 1, 1},
    {&__pyx_kp_s_f2_01_CONVERT_STOCK_CODE_CONVERT, __pyx_k_f2_01_CONVERT_STOCK_CODE_CONVERT, sizeof(__pyx_k_f2_01_CONVERT_STOCK_CODE_CONVERT), 0, 0, 1, 0},
    {&__pyx_n_s_f3, __pyx_k_f3, sizeof(__pyx_k_f3), 0, 0, 1, 1},
    {&__pyx_n_s_f4, __pyx_k_f4, sizeof(__pyx_k_f4), 0, 0, 1, 1},
    {&__pyx_n_s_f5, __pyx_k_f5, sizeof(__pyx_k_f5), 0, 0, 1, 1},
    {&__pyx_kp_s_f51_f52_f53_f54_f55_f56_f57_f58, __pyx_k_f51_f52_f53_f54_f55_f56_f57_f58, sizeof(__pyx_k_f51_f52_f53_f54_f55_f56_f57_f58), 0, 0, 1, 0},
    {&__pyx_n_s_f57, __pyx_k_f57, sizeof(__pyx_k_f57), 0, 0, 1, 1},
    {&__pyx_n_s_f58, __pyx_k_f58, sizeof(__pyx_k_f58), 0, 0, 1, 1},
    {&__pyx_n_s_f6, __pyx_k_f6, sizeof(__pyx_k_f6), 0, 0, 1, 1},
    {&__pyx_n_s_f84, __pyx_k_f84, sizeof(__pyx_k_f84), 0, 0, 1, 1},
    {&__pyx_n_s_f85, __pyx_k_f85, sizeof(__pyx_k_f85), 0, 0, 1, 1},
    {&__pyx_n_s_fa5fd1943c7b386f172d6893dbfba10b, __pyx_k_fa5fd1943c7b386f172d6893dbfba10b, sizeof(__pyx_k_fa5fd1943c7b386f172d6893dbfba10b), 0, 0, 1, 1},
    {&__pyx_n_s_fid, __pyx_k_fid, sizeof(__pyx_k_fid), 0, 0, 1, 1},
    {&__pyx_n_s_fields, __pyx_k_fields, sizeof(__pyx_k_fields), 0, 0, 1, 1},
    {&__pyx_n_s_fields1, __pyx_k_fields1, sizeof(__pyx_k_fields1), 0, 0, 1, 1},
    {&__pyx_n_s_fields2, __pyx_k_fields2, sizeof(__pyx_k_fields2), 0, 0, 1, 1},
    {&__pyx_n_s_filter, __pyx_k_filter, sizeof(__pyx_k_filter), 0, 0, 1, 1},
    {&__pyx_n_s_finance_mfd_quarter_df, __pyx_k_finance_mfd_quarter_df, sizeof(__pyx_k_finance_mfd_quarter_df), 0, 0, 1, 1},
    {&__pyx_n_s_finance_mfd_report_df, __pyx_k_finance_mfd_report_df, sizeof(__pyx_k_finance_mfd_report_df), 0, 0, 1, 1},
    {&__pyx_n_s_find, __pyx_k_find, sizeof(__pyx_k_find), 0, 0, 1, 1},
    {&__pyx_n_s_float, __pyx_k_float, sizeof(__pyx_k_float), 0, 0, 1, 1},
    {&__pyx_n_s_fltt, __pyx_k_fltt, sizeof(__pyx_k_fltt), 0, 0, 1, 1},
    {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
    {&__pyx_n_s_fqt, __pyx_k_fqt, sizeof(__pyx_k_fqt), 0, 0, 1, 1},
    {&__pyx_n_s_fs, __pyx_k_fs, sizeof(__pyx_k_fs), 0, 0, 1, 1},
    {&__pyx_n_s_full, __pyx_k_full, sizeof(__pyx_k_full), 0, 0, 1, 1},
    {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
    {&__pyx_n_s_gross_profit, __pyx_k_gross_profit, sizeof(__pyx_k_gross_profit), 0, 0, 1, 1},
    {&__pyx_n_s_gross_profit_ratio, __pyx_k_gross_profit_ratio, sizeof(__pyx_k_gross_profit_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_high, __pyx_k_high, sizeof(__pyx_k_high), 0, 0, 1, 1},
    {&__pyx_n_s_hold_amount, __pyx_k_hold_amount, sizeof(__pyx_k_hold_amount), 0, 0, 1, 1},
    {&__pyx_n_s_hold_focus, __pyx_k_hold_focus, sizeof(__pyx_k_hold_focus), 0, 0, 1, 1},
    {&__pyx_n_s_hold_volume, __pyx_k_hold_volume, sizeof(__pyx_k_hold_volume), 0, 0, 1, 1},
    {&__pyx_n_s_hold_volume_ratio, __pyx_k_hold_volume_ratio, sizeof(__pyx_k_hold_volume_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_holder_num, __pyx_k_holder_num, sizeof(__pyx_k_holder_num), 0, 0, 1, 1},
    {&__pyx_n_s_holder_num_ratio, __pyx_k_holder_num_ratio, sizeof(__pyx_k_holder_num_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_hs300_change_ratio, __pyx_k_hs300_change_ratio, sizeof(__pyx_k_hs300_change_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_hs300_close, __pyx_k_hs300_close, sizeof(__pyx_k_hs300_close), 0, 0, 1, 1},
    {&__pyx_n_s_hsgt_history, __pyx_k_hsgt_history, sizeof(__pyx_k_hsgt_history), 0, 0, 1, 1},
    {&__pyx_n_s_hsgt_history_df, __pyx_k_hsgt_history_df, sizeof(__pyx_k_hsgt_history_df), 0, 0, 1, 1},
    {&__pyx_kp_s_http_push2_eastmoney_com_api_qt, __pyx_k_http_push2_eastmoney_com_api_qt, sizeof(__pyx_k_http_push2_eastmoney_com_api_qt), 0, 0, 1, 0},
    {&__pyx_kp_s_https_38_push2_eastmoney_com_api, __pyx_k_https_38_push2_eastmoney_com_api, sizeof(__pyx_k_https_38_push2_eastmoney_com_api), 0, 0, 1, 0},
    {&__pyx_kp_s_https_89_push2_eastmoney_com_api, __pyx_k_https_89_push2_eastmoney_com_api, sizeof(__pyx_k_https_89_push2_eastmoney_com_api), 0, 0, 1, 0},
    {&__pyx_kp_s_https_datacenter_eastmoney_com_s, __pyx_k_https_datacenter_eastmoney_com_s, sizeof(__pyx_k_https_datacenter_eastmoney_com_s), 0, 0, 1, 0},
    {&__pyx_kp_s_https_datacenter_eastmoney_com_s_2, __pyx_k_https_datacenter_eastmoney_com_s_2, sizeof(__pyx_k_https_datacenter_eastmoney_com_s_2), 0, 0, 1, 0},
    {&__pyx_kp_s_https_datacenter_web_eastmoney_c, __pyx_k_https_datacenter_web_eastmoney_c, sizeof(__pyx_k_https_datacenter_web_eastmoney_c), 0, 0, 1, 0},
    {&__pyx_kp_s_https_push2his_eastmoney_com_api, __pyx_k_https_push2his_eastmoney_com_api, sizeof(__pyx_k_https_push2his_eastmoney_com_api), 0, 0, 1, 0},
    {&__pyx_n_s_ignore_index, __pyx_k_ignore_index, sizeof(__pyx_k_ignore_index), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_inplace, __pyx_k_inplace, sizeof(__pyx_k_inplace), 0, 0, 1, 1},
    {&__pyx_n_s_insert, __pyx_k_insert, sizeof(__pyx_k_insert), 0, 0, 1, 1},
    {&__pyx_n_s_invt, __pyx_k_invt, sizeof(__pyx_k_invt), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_n_s_is_null_result, __pyx_k_is_null_result, sizeof(__pyx_k_is_null_result), 0, 0, 1, 1},
    {&__pyx_n_s_item, __pyx_k_item, sizeof(__pyx_k_item), 0, 0, 1, 1},
    {&__pyx_n_s_jQuery1124033485574041163946_159, __pyx_k_jQuery1124033485574041163946_159, sizeof(__pyx_k_jQuery1124033485574041163946_159), 0, 0, 1, 1},
    {&__pyx_n_s_js, __pyx_k_js, sizeof(__pyx_k_js), 0, 0, 1, 1},
    {&__pyx_n_s_json, __pyx_k_json, sizeof(__pyx_k_json), 0, 0, 1, 1},
    {&__pyx_n_s_jyjxjl_to_tor_ratio, __pyx_k_jyjxjl_to_tor_ratio, sizeof(__pyx_k_jyjxjl_to_tor_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
    {&__pyx_n_s_kf_net_profit, __pyx_k_kf_net_profit, sizeof(__pyx_k_kf_net_profit), 0, 0, 1, 1},
    {&__pyx_n_s_kf_net_profit_hb, __pyx_k_kf_net_profit_hb, sizeof(__pyx_k_kf_net_profit_hb), 0, 0, 1, 1},
    {&__pyx_n_s_kf_net_profit_tb, __pyx_k_kf_net_profit_tb, sizeof(__pyx_k_kf_net_profit_tb), 0, 0, 1, 1},
    {&__pyx_n_s_klines, __pyx_k_klines, sizeof(__pyx_k_klines), 0, 0, 1, 1},
    {&__pyx_n_s_klt, __pyx_k_klt, sizeof(__pyx_k_klt), 0, 0, 1, 1},
    {&__pyx_n_s_kzz_all_df, __pyx_k_kzz_all_df, sizeof(__pyx_k_kzz_all_df), 0, 0, 1, 1},
    {&__pyx_n_s_kzz_basic_info_em, __pyx_k_kzz_basic_info_em, sizeof(__pyx_k_kzz_basic_info_em), 0, 0, 1, 1},
    {&__pyx_n_s_kzz_sh_em_df, __pyx_k_kzz_sh_em_df, sizeof(__pyx_k_kzz_sh_em_df), 0, 0, 1, 1},
    {&__pyx_n_s_kzz_sh_trade_day_info_em, __pyx_k_kzz_sh_trade_day_info_em, sizeof(__pyx_k_kzz_sh_trade_day_info_em), 0, 0, 1, 1},
    {&__pyx_n_s_kzz_sz_em_df, __pyx_k_kzz_sz_em_df, sizeof(__pyx_k_kzz_sz_em_df), 0, 0, 1, 1},
    {&__pyx_n_s_kzz_sz_trade_day_info_em, __pyx_k_kzz_sz_trade_day_info_em, sizeof(__pyx_k_kzz_sz_trade_day_info_em), 0, 0, 1, 1},
    {&__pyx_n_s_kzz_trade_day_df, __pyx_k_kzz_trade_day_df, sizeof(__pyx_k_kzz_trade_day_df), 0, 0, 1, 1},
    {&__pyx_n_s_kzz_trade_day_em_df, __pyx_k_kzz_trade_day_em_df, sizeof(__pyx_k_kzz_trade_day_em_df), 0, 0, 1, 1},
    {&__pyx_n_s_kzz_trade_day_info_em, __pyx_k_kzz_trade_day_info_em, sizeof(__pyx_k_kzz_trade_day_info_em), 0, 0, 1, 1},
    {&__pyx_n_s_latest_trade_day, __pyx_k_latest_trade_day, sizeof(__pyx_k_latest_trade_day), 0, 0, 1, 1},
    {&__pyx_n_s_low, __pyx_k_low, sizeof(__pyx_k_low), 0, 0, 1, 1},
    {&__pyx_n_s_lt, __pyx_k_lt, sizeof(__pyx_k_lt), 0, 0, 1, 1},
    {&__pyx_kp_s_m_0_b_MK0354, __pyx_k_m_0_b_MK0354, sizeof(__pyx_k_m_0_b_MK0354), 0, 0, 1, 0},
    {&__pyx_kp_s_m_1_b_MK0354, __pyx_k_m_1_b_MK0354, sizeof(__pyx_k_m_1_b_MK0354), 0, 0, 1, 0},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_map, __pyx_k_map, sizeof(__pyx_k_map), 0, 0, 1, 1},
    {&__pyx_n_s_market_map, __pyx_k_market_map, sizeof(__pyx_k_market_map), 0, 0, 1, 1},
    {&__pyx_n_s_math, __pyx_k_math, sizeof(__pyx_k_math), 0, 0, 1, 1},
    {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_s_net_amount, __pyx_k_net_amount, sizeof(__pyx_k_net_amount), 0, 0, 1, 1},
    {&__pyx_n_s_net_cash_ps, __pyx_k_net_cash_ps, sizeof(__pyx_k_net_cash_ps), 0, 0, 1, 1},
    {&__pyx_n_s_net_profit_ratio, __pyx_k_net_profit_ratio, sizeof(__pyx_k_net_profit_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_n_s_notice_date, __pyx_k_notice_date, sizeof(__pyx_k_notice_date), 0, 0, 1, 1},
    {&__pyx_n_s_notna, __pyx_k_notna, sizeof(__pyx_k_notna), 0, 0, 1, 1},
    {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
    {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
    {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
    {&__pyx_n_s_page, __pyx_k_page, sizeof(__pyx_k_page), 0, 0, 1, 1},
    {&__pyx_n_s_pageNo, __pyx_k_pageNo, sizeof(__pyx_k_pageNo), 0, 0, 1, 1},
    {&__pyx_n_s_pageNum, __pyx_k_pageNum, sizeof(__pyx_k_pageNum), 0, 0, 1, 1},
    {&__pyx_n_s_pageNumber, __pyx_k_pageNumber, sizeof(__pyx_k_pageNumber), 0, 0, 1, 1},
    {&__pyx_n_s_pageSize, __pyx_k_pageSize, sizeof(__pyx_k_pageSize), 0, 0, 1, 1},
    {&__pyx_n_s_pages, __pyx_k_pages, sizeof(__pyx_k_pages), 0, 0, 1, 1},
    {&__pyx_n_s_pandas, __pyx_k_pandas, sizeof(__pyx_k_pandas), 0, 0, 1, 1},
    {&__pyx_n_s_params, __pyx_k_params, sizeof(__pyx_k_params), 0, 0, 1, 1},
    {&__pyx_n_s_parent_net_profit, __pyx_k_parent_net_profit, sizeof(__pyx_k_parent_net_profit), 0, 0, 1, 1},
    {&__pyx_n_s_parent_net_profit_hb, __pyx_k_parent_net_profit_hb, sizeof(__pyx_k_parent_net_profit_hb), 0, 0, 1, 1},
    {&__pyx_n_s_parent_net_profit_tb, __pyx_k_parent_net_profit_tb, sizeof(__pyx_k_parent_net_profit_tb), 0, 0, 1, 1},
    {&__pyx_n_s_pd, __pyx_k_pd, sizeof(__pyx_k_pd), 0, 0, 1, 1},
    {&__pyx_kp_s_pd_DataFrame, __pyx_k_pd_DataFrame, sizeof(__pyx_k_pd_DataFrame), 0, 0, 1, 0},
    {&__pyx_n_s_pn, __pyx_k_pn, sizeof(__pyx_k_pn), 0, 0, 1, 1},
    {&__pyx_n_s_po, __pyx_k_po, sizeof(__pyx_k_po), 0, 0, 1, 1},
    {&__pyx_n_s_pre_close, __pyx_k_pre_close, sizeof(__pyx_k_pre_close), 0, 0, 1, 1},
    {&__pyx_n_s_price, __pyx_k_price, sizeof(__pyx_k_price), 0, 0, 1, 1},
    {&__pyx_n_s_price_change, __pyx_k_price_change, sizeof(__pyx_k_price_change), 0, 0, 1, 1},
    {&__pyx_n_s_price_ratio, __pyx_k_price_ratio, sizeof(__pyx_k_price_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
    {&__pyx_n_s_ps, __pyx_k_ps, sizeof(__pyx_k_ps), 0, 0, 1, 1},
    {&__pyx_n_s_pub_date, __pyx_k_pub_date, sizeof(__pyx_k_pub_date), 0, 0, 1, 1},
    {&__pyx_n_s_pz, __pyx_k_pz, sizeof(__pyx_k_pz), 0, 0, 1, 1},
    {&__pyx_n_s_quick_ratio, __pyx_k_quick_ratio, sizeof(__pyx_k_quick_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_quoteColumns, __pyx_k_quoteColumns, sizeof(__pyx_k_quoteColumns), 0, 0, 1, 1},
    {&__pyx_n_s_quoteType, __pyx_k_quoteType, sizeof(__pyx_k_quoteType), 0, 0, 1, 1},
    {&__pyx_n_s_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 0, 1, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_rc, __pyx_k_rc, sizeof(__pyx_k_rc), 0, 0, 1, 1},
    {&__pyx_n_s_replace, __pyx_k_replace, sizeof(__pyx_k_replace), 0, 0, 1, 1},
    {&__pyx_n_s_reportName, __pyx_k_reportName, sizeof(__pyx_k_reportName), 0, 0, 1, 1},
    {&__pyx_n_s_report_date, __pyx_k_report_date, sizeof(__pyx_k_report_date), 0, 0, 1, 1},
    {&__pyx_n_s_requests, __pyx_k_requests, sizeof(__pyx_k_requests), 0, 0, 1, 1},
    {&__pyx_n_s_reset_index, __pyx_k_reset_index, sizeof(__pyx_k_reset_index), 0, 0, 1, 1},
    {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
    {&__pyx_n_s_return, __pyx_k_return, sizeof(__pyx_k_return), 0, 0, 1, 1},
    {&__pyx_n_s_roe_jzc, __pyx_k_roe_jzc, sizeof(__pyx_k_roe_jzc), 0, 0, 1, 1},
    {&__pyx_n_s_roe_zzc, __pyx_k_roe_zzc, sizeof(__pyx_k_roe_zzc), 0, 0, 1, 1},
    {&__pyx_n_s_rqchl, __pyx_k_rqchl, sizeof(__pyx_k_rqchl), 0, 0, 1, 1},
    {&__pyx_n_s_rqjmg, __pyx_k_rqjmg, sizeof(__pyx_k_rqjmg), 0, 0, 1, 1},
    {&__pyx_n_s_rqmcl, __pyx_k_rqmcl, sizeof(__pyx_k_rqmcl), 0, 0, 1, 1},
    {&__pyx_n_s_rqye, __pyx_k_rqye, sizeof(__pyx_k_rqye), 0, 0, 1, 1},
    {&__pyx_n_s_rqyl, __pyx_k_rqyl, sizeof(__pyx_k_rqyl), 0, 0, 1, 1},
    {&__pyx_n_s_rt, __pyx_k_rt, sizeof(__pyx_k_rt), 0, 0, 1, 1},
    {&__pyx_n_s_rzche, __pyx_k_rzche, sizeof(__pyx_k_rzche), 0, 0, 1, 1},
    {&__pyx_n_s_rzjme, __pyx_k_rzjme, sizeof(__pyx_k_rzjme), 0, 0, 1, 1},
    {&__pyx_n_s_rzmre, __pyx_k_rzmre, sizeof(__pyx_k_rzmre), 0, 0, 1, 1},
    {&__pyx_n_s_rzrq_history, __pyx_k_rzrq_history, sizeof(__pyx_k_rzrq_history), 0, 0, 1, 1},
    {&__pyx_n_s_rzrq_history_df, __pyx_k_rzrq_history_df, sizeof(__pyx_k_rzrq_history_df), 0, 0, 1, 1},
    {&__pyx_n_s_rzrqye, __pyx_k_rzrqye, sizeof(__pyx_k_rzrqye), 0, 0, 1, 1},
    {&__pyx_n_s_rzye, __pyx_k_rzye, sizeof(__pyx_k_rzye), 0, 0, 1, 1},
    {&__pyx_n_s_rzyezb, __pyx_k_rzyezb, sizeof(__pyx_k_rzyezb), 0, 0, 1, 1},
    {&__pyx_kp_u_scode, __pyx_k_scode, sizeof(__pyx_k_scode), 0, 1, 0, 0},
    {&__pyx_n_s_secid, __pyx_k_secid, sizeof(__pyx_k_secid), 0, 0, 1, 1},
    {&__pyx_n_s_sell_amount, __pyx_k_sell_amount, sizeof(__pyx_k_sell_amount), 0, 0, 1, 1},
    {&__pyx_n_s_sh, __pyx_k_sh, sizeof(__pyx_k_sh), 0, 0, 1, 1},
    {&__pyx_n_s_sortColumns, __pyx_k_sortColumns, sizeof(__pyx_k_sortColumns), 0, 0, 1, 1},
    {&__pyx_n_s_sortTypes, __pyx_k_sortTypes, sizeof(__pyx_k_sortTypes), 0, 0, 1, 1},
    {&__pyx_n_s_source, __pyx_k_source, sizeof(__pyx_k_source), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
    {&__pyx_n_s_sr, __pyx_k_sr, sizeof(__pyx_k_sr), 0, 0, 1, 1},
    {&__pyx_n_s_sse_index_change_ratio, __pyx_k_sse_index_change_ratio, sizeof(__pyx_k_sse_index_change_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_sse_index_close, __pyx_k_sse_index_close, sizeof(__pyx_k_sse_index_close), 0, 0, 1, 1},
    {&__pyx_n_s_st, __pyx_k_st, sizeof(__pyx_k_st), 0, 0, 1, 1},
    {&__pyx_n_s_start_date, __pyx_k_start_date, sizeof(__pyx_k_start_date), 0, 0, 1, 1},
    {&__pyx_n_s_stock_all_hsgt_date, __pyx_k_stock_all_hsgt_date, sizeof(__pyx_k_stock_all_hsgt_date), 0, 0, 1, 1},
    {&__pyx_n_s_stock_all_rzrq_date, __pyx_k_stock_all_rzrq_date, sizeof(__pyx_k_stock_all_rzrq_date), 0, 0, 1, 1},
    {&__pyx_n_s_stock_code, __pyx_k_stock_code, sizeof(__pyx_k_stock_code), 0, 0, 1, 1},
    {&__pyx_n_s_stock_fhps_detail_em, __pyx_k_stock_fhps_detail_em, sizeof(__pyx_k_stock_fhps_detail_em), 0, 0, 1, 1},
    {&__pyx_n_s_stock_finance_mfd_quarter_em, __pyx_k_stock_finance_mfd_quarter_em, sizeof(__pyx_k_stock_finance_mfd_quarter_em), 0, 0, 1, 1},
    {&__pyx_n_s_stock_finance_mfd_report_em, __pyx_k_stock_finance_mfd_report_em, sizeof(__pyx_k_stock_finance_mfd_report_em), 0, 0, 1, 1},
    {&__pyx_n_s_stock_gdhs_df, __pyx_k_stock_gdhs_df, sizeof(__pyx_k_stock_gdhs_df), 0, 0, 1, 1},
    {&__pyx_n_s_stock_hsgt_detail, __pyx_k_stock_hsgt_detail, sizeof(__pyx_k_stock_hsgt_detail), 0, 0, 1, 1},
    {&__pyx_n_s_stock_hsgt_df, __pyx_k_stock_hsgt_df, sizeof(__pyx_k_stock_hsgt_df), 0, 0, 1, 1},
    {&__pyx_n_s_stock_hsgt_today_df, __pyx_k_stock_hsgt_today_df, sizeof(__pyx_k_stock_hsgt_today_df), 0, 0, 1, 1},
    {&__pyx_n_s_stock_individual_info_em, __pyx_k_stock_individual_info_em, sizeof(__pyx_k_stock_individual_info_em), 0, 0, 1, 1},
    {&__pyx_n_s_stock_name, __pyx_k_stock_name, sizeof(__pyx_k_stock_name), 0, 0, 1, 1},
    {&__pyx_n_s_stock_rzrq_detail, __pyx_k_stock_rzrq_detail, sizeof(__pyx_k_stock_rzrq_detail), 0, 0, 1, 1},
    {&__pyx_n_s_stock_rzrq_df, __pyx_k_stock_rzrq_df, sizeof(__pyx_k_stock_rzrq_df), 0, 0, 1, 1},
    {&__pyx_n_s_stock_rzrq_today_df, __pyx_k_stock_rzrq_today_df, sizeof(__pyx_k_stock_rzrq_today_df), 0, 0, 1, 1},
    {&__pyx_n_s_stock_zh_a_gdhs_detail_em, __pyx_k_stock_zh_a_gdhs_detail_em, sizeof(__pyx_k_stock_zh_a_gdhs_detail_em), 0, 0, 1, 1},
    {&__pyx_n_s_stock_zh_index_daily_em, __pyx_k_stock_zh_index_daily_em, sizeof(__pyx_k_stock_zh_index_daily_em), 0, 0, 1, 1},
    {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
    {&__pyx_n_s_strptime, __pyx_k_strptime, sizeof(__pyx_k_strptime), 0, 0, 1, 1},
    {&__pyx_n_s_sty, __pyx_k_sty, sizeof(__pyx_k_sty), 0, 0, 1, 1},
    {&__pyx_n_s_svr, __pyx_k_svr, sizeof(__pyx_k_svr), 0, 0, 1, 1},
    {&__pyx_n_s_symbol, __pyx_k_symbol, sizeof(__pyx_k_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_sz, __pyx_k_sz, sizeof(__pyx_k_sz), 0, 0, 1, 1},
    {&__pyx_n_s_tax_rate, __pyx_k_tax_rate, sizeof(__pyx_k_tax_rate), 0, 0, 1, 1},
    {&__pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_k_tbstock_dataAcquisition_stockDat, sizeof(__pyx_k_tbstock_dataAcquisition_stockDat), 0, 0, 1, 0},
    {&__pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_k_tbstock_dataAcquisition_stockDat_2, sizeof(__pyx_k_tbstock_dataAcquisition_stockDat_2), 0, 0, 1, 1},
    {&__pyx_n_s_tbstock_utils, __pyx_k_tbstock_utils, sizeof(__pyx_k_tbstock_utils), 0, 0, 1, 1},
    {&__pyx_n_s_temp_df, __pyx_k_temp_df, sizeof(__pyx_k_temp_df), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_test_2, __pyx_k_test_2, sizeof(__pyx_k_test_2), 0, 0, 1, 1},
    {&__pyx_n_s_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 0, 1, 1},
    {&__pyx_n_s_timeout, __pyx_k_timeout, sizeof(__pyx_k_timeout), 0, 0, 1, 1},
    {&__pyx_n_s_to_datetime, __pyx_k_to_datetime, sizeof(__pyx_k_to_datetime), 0, 0, 1, 1},
    {&__pyx_n_s_to_numeric, __pyx_k_to_numeric, sizeof(__pyx_k_to_numeric), 0, 0, 1, 1},
    {&__pyx_n_s_top_ten_ratio_free, __pyx_k_top_ten_ratio_free, sizeof(__pyx_k_top_ten_ratio_free), 0, 0, 1, 1},
    {&__pyx_n_s_top_ten_ratio_total, __pyx_k_top_ten_ratio_total, sizeof(__pyx_k_top_ten_ratio_total), 0, 0, 1, 1},
    {&__pyx_n_s_total, __pyx_k_total, sizeof(__pyx_k_total), 0, 0, 1, 1},
    {&__pyx_n_s_total_item, __pyx_k_total_item, sizeof(__pyx_k_total_item), 0, 0, 1, 1},
    {&__pyx_n_s_total_operate_revenue, __pyx_k_total_operate_revenue, sizeof(__pyx_k_total_operate_revenue), 0, 0, 1, 1},
    {&__pyx_n_s_total_operate_revenue_hb, __pyx_k_total_operate_revenue_hb, sizeof(__pyx_k_total_operate_revenue_hb), 0, 0, 1, 1},
    {&__pyx_n_s_total_operate_revenue_tb, __pyx_k_total_operate_revenue_tb, sizeof(__pyx_k_total_operate_revenue_tb), 0, 0, 1, 1},
    {&__pyx_n_s_total_pages, __pyx_k_total_pages, sizeof(__pyx_k_total_pages), 0, 0, 1, 1},
    {&__pyx_n_s_trade_date, __pyx_k_trade_date, sizeof(__pyx_k_trade_date), 0, 0, 1, 1},
    {&__pyx_n_s_transfer_price, __pyx_k_transfer_price, sizeof(__pyx_k_transfer_price), 0, 0, 1, 1},
    {&__pyx_n_s_transfer_value, __pyx_k_transfer_value, sizeof(__pyx_k_transfer_value), 0, 0, 1, 1},
    {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
    {&__pyx_n_s_unassign_profit_ps, __pyx_k_unassign_profit_ps, sizeof(__pyx_k_unassign_profit_ps), 0, 0, 1, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_url, __pyx_k_url, sizeof(__pyx_k_url), 0, 0, 1, 1},
    {&__pyx_n_s_ut, __pyx_k_ut, sizeof(__pyx_k_ut), 0, 0, 1, 1},
    {&__pyx_n_s_utils, __pyx_k_utils, sizeof(__pyx_k_utils), 0, 0, 1, 1},
    {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
    {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
    {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
    {&__pyx_n_s_volume, __pyx_k_volume, sizeof(__pyx_k_volume), 0, 0, 1, 1},
    {&__pyx_n_s_wbp2u, __pyx_k_wbp2u, sizeof(__pyx_k_wbp2u), 0, 0, 1, 1},
    {&__pyx_n_s_xsjxjl_to_tor_ratio, __pyx_k_xsjxjl_to_tor_ratio, sizeof(__pyx_k_xsjxjl_to_tor_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_yszk_to_tor_ratio, __pyx_k_yszk_to_tor_ratio, sizeof(__pyx_k_yszk_to_tor_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_yszk_zzl, __pyx_k_yszk_zzl, sizeof(__pyx_k_yszk_zzl), 0, 0, 1, 1},
    {&__pyx_n_s_yszk_zzts, __pyx_k_yszk_zzts, sizeof(__pyx_k_yszk_zzts), 0, 0, 1, 1},
    {&__pyx_n_s_zzc_zzl, __pyx_k_zzc_zzl, sizeof(__pyx_k_zzc_zzl), 0, 0, 1, 1},
    {&__pyx_n_s_zzc_zzts, __pyx_k_zzc_zzts, sizeof(__pyx_k_zzc_zzts), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 147, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 1259, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":160
 *     rzrq_history_df.columns = column_dict.values()
 *     rzrq_history_df["date"] = pd.to_datetime(rzrq_history_df["date"], errors="coerce").dt.date
 *     cols_to_convert = rzrq_history_df.columns[1:]             # <<<<<<<<<<<<<<
 *     rzrq_history_df[cols_to_convert] = rzrq_history_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 * 
 */
  __pyx_slice__6 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__6)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__6);
  __Pyx_GIVEREF(__pyx_slice__6);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":241
 *     stock_rzrq_today_df.columns = column_dict.values()
 *     stock_rzrq_today_df["date"] = pd.to_datetime(stock_rzrq_today_df["date"], errors="coerce").dt.date
 *     cols_to_convert = stock_rzrq_today_df.columns[3:]             # <<<<<<<<<<<<<<
 *     stock_rzrq_today_df[cols_to_convert] = stock_rzrq_today_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return stock_rzrq_today_df
 */
  __pyx_slice__8 = PySlice_New(__pyx_int_3, Py_None, Py_None); if (unlikely(!__pyx_slice__8)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__8);
  __Pyx_GIVEREF(__pyx_slice__8);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":597
 *     stock_gdhs_df["notice_date"] = pd.to_datetime(stock_gdhs_df["notice_date"], errors="coerce").dt.date
 * 
 *     cols_to_convert = stock_gdhs_df.columns[5:]             # <<<<<<<<<<<<<<
 *     stock_gdhs_df[cols_to_convert] = stock_gdhs_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 * 
 */
  __pyx_slice__21 = PySlice_New(__pyx_int_5, Py_None, Py_None); if (unlikely(!__pyx_slice__21)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__21);
  __Pyx_GIVEREF(__pyx_slice__21);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":807
 *     finance_mfd_report_df["notice_date"] = pd.to_datetime(finance_mfd_report_df["notice_date"], errors="coerce").dt.date
 * 
 *     cols_to_convert = finance_mfd_report_df.columns[4:]             # <<<<<<<<<<<<<<
 *     finance_mfd_report_df[cols_to_convert] = finance_mfd_report_df[cols_to_convert].apply(pd.to_numeric, errors="coerce")
 *     return finance_mfd_report_df
 */
  __pyx_slice__61 = PySlice_New(__pyx_int_4, Py_None, Py_None); if (unlikely(!__pyx_slice__61)) __PYX_ERR(0, 807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__61);
  __Pyx_GIVEREF(__pyx_slice__61);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":17
 * 
 * 
 * def stock_zh_index_daily_em(             # <<<<<<<<<<<<<<
 *         symbol: str = "csi931151",
 *         start_date: str = "19900101",
 */
  __pyx_tuple__91 = PyTuple_Pack(12, __pyx_n_s_symbol, __pyx_n_s_start_date, __pyx_n_s_end_date, __pyx_n_s_market_map, __pyx_n_s_url, __pyx_n_s_secid, __pyx_n_s_params, __pyx_n_s_r, __pyx_n_s_data_text, __pyx_n_s_data_json, __pyx_n_s_temp_df, __pyx_n_s_item); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);
  __pyx_codeobj__92 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__91, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_zh_index_daily_em, 17, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__92)) __PYX_ERR(0, 17, __pyx_L1_error)
  __pyx_tuple__93 = PyTuple_Pack(3, ((PyObject*)__pyx_n_s_csi931151), ((PyObject*)__pyx_kp_s_19900101), ((PyObject*)__pyx_kp_s_20500101)); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":81
 * 
 * 
 * def rzrq_history(mode='new') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/rzrq/total.html
 */
  __pyx_tuple__94 = PyTuple_Pack(11, __pyx_n_s_mode, __pyx_n_s_column_dict, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_rzrq_history_df, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_total_pages, __pyx_n_s_page, __pyx_n_s_temp_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__94)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__94);
  __Pyx_GIVEREF(__pyx_tuple__94);
  __pyx_codeobj__95 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__94, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_rzrq_history, 81, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__95)) __PYX_ERR(0, 81, __pyx_L1_error)
  __pyx_tuple__96 = PyTuple_Pack(1, ((PyObject*)__pyx_n_s_new)); if (unlikely(!__pyx_tuple__96)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__96);
  __Pyx_GIVEREF(__pyx_tuple__96);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":167
 * 
 * 
 * def stock_all_rzrq_date(trade_date='2024-05-31') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */
  __pyx_tuple__97 = PyTuple_Pack(11, __pyx_n_s_trade_date, __pyx_n_s_column_dict, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_stock_rzrq_today_df, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_total_pages, __pyx_n_s_page, __pyx_n_s_temp_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);
  __pyx_codeobj__98 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_all_rzrq_date, 167, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__98)) __PYX_ERR(0, 167, __pyx_L1_error)
  __pyx_tuple__99 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_s_2024_05_31)); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":246
 * 
 * 
 * def stock_rzrq_detail(mode='new', symbol='000001') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/rzrq/stock/600900.html
 */
  __pyx_tuple__100 = PyTuple_Pack(12, __pyx_n_s_mode, __pyx_n_s_symbol, __pyx_n_s_column_dict, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_stock_rzrq_df, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_total_pages, __pyx_n_s_page, __pyx_n_s_temp_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__100)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__100);
  __Pyx_GIVEREF(__pyx_tuple__100);
  __pyx_codeobj__101 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__100, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_rzrq_detail, 246, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__101)) __PYX_ERR(0, 246, __pyx_L1_error)
  __pyx_tuple__102 = PyTuple_Pack(2, ((PyObject*)__pyx_n_s_new), ((PyObject*)__pyx_kp_s_000001)); if (unlikely(!__pyx_tuple__102)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__102);
  __Pyx_GIVEREF(__pyx_tuple__102);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":331
 * 
 * 
 * def hsgt_history(mode='new') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     mode = 'new':50
 */
  __pyx_tuple__103 = PyTuple_Pack(11, __pyx_n_s_mode, __pyx_n_s_column_dict, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_hsgt_history_df, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_total_pages, __pyx_n_s_page, __pyx_n_s_temp_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);
  __pyx_codeobj__104 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__103, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_hsgt_history, 331, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__104)) __PYX_ERR(0, 331, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":398
 * 
 * 
 * def stock_all_hsgt_date(trade_date='2024-05-31') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */
  __pyx_tuple__105 = PyTuple_Pack(11, __pyx_n_s_trade_date, __pyx_n_s_column_dict, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_stock_hsgt_today_df, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_total_pages, __pyx_n_s_page, __pyx_n_s_temp_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);
  __pyx_codeobj__106 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__105, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_all_hsgt_date, 398, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__106)) __PYX_ERR(0, 398, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":462
 * 
 * 
 * def stock_hsgt_detail(mode='new', symbol: str = "000001") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/hsgt/StockHdDetail/601899.html
 */
  __pyx_tuple__107 = PyTuple_Pack(12, __pyx_n_s_mode, __pyx_n_s_symbol, __pyx_n_s_column_dict, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_stock_hsgt_df, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_total_pages, __pyx_n_s_page, __pyx_n_s_temp_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);
  __pyx_codeobj__108 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__107, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_hsgt_detail, 462, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__108)) __PYX_ERR(0, 462, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":528
 * 
 * 
 * def stock_zh_a_gdhs_detail_em(symbol: str = "000001.SZ") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     https://emweb.securities.eastmoney.com/pc_hsf10/pages/index.html?type=web&code=SZ300342&color=b#/gdyj
 */
  __pyx_tuple__109 = PyTuple_Pack(9, __pyx_n_s_symbol, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_column_dict, __pyx_n_s_column_name_dict, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_stock_gdhs_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);
  __pyx_codeobj__110 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__109, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_zh_a_gdhs_detail_em, 528, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__110)) __PYX_ERR(0, 528, __pyx_L1_error)
  __pyx_tuple__111 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_s_000001_SZ)); if (unlikely(!__pyx_tuple__111)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":603
 * 
 * 
 * def stock_finance_mfd_quarter_em(symbol: str = "688235.SH", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */
  __pyx_tuple__112 = PyTuple_Pack(9, __pyx_n_s_symbol, __pyx_n_s_timeout, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_column_dict, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_finance_mfd_quarter_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__112)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);
  __pyx_codeobj__113 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__112, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_finance_mfd_quarter_em, 603, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__113)) __PYX_ERR(0, 603, __pyx_L1_error)
  __pyx_tuple__114 = PyTuple_Pack(2, ((PyObject*)__pyx_kp_s_688235_SH), Py_None); if (unlikely(!__pyx_tuple__114)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__114);
  __Pyx_GIVEREF(__pyx_tuple__114);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":678
 * 
 * 
 * def stock_finance_mfd_report_em(symbol: str = "688235.SH", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */
  __pyx_tuple__115 = PyTuple_Pack(10, __pyx_n_s_symbol, __pyx_n_s_timeout, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_column_dict, __pyx_n_s_column_name_dict, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_finance_mfd_report_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__115)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__115);
  __Pyx_GIVEREF(__pyx_tuple__115);
  __pyx_codeobj__116 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__115, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_finance_mfd_report_em, 678, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__116)) __PYX_ERR(0, 678, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":812
 * 
 * 
 * def stock_individual_info_em(symbol: str = "688235", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     --
 */
  __pyx_tuple__117 = PyTuple_Pack(9, __pyx_n_s_symbol, __pyx_n_s_timeout, __pyx_n_s_code_id_dict, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_temp_df, __pyx_n_s_code_name_map); if (unlikely(!__pyx_tuple__117)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);
  __pyx_codeobj__118 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__117, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_individual_info_em, 812, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__118)) __PYX_ERR(0, 812, __pyx_L1_error)
  __pyx_tuple__119 = PyTuple_Pack(2, ((PyObject*)__pyx_kp_s_688235), Py_None); if (unlikely(!__pyx_tuple__119)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__119);
  __Pyx_GIVEREF(__pyx_tuple__119);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":865
 * 
 * 
 * def stock_fhps_detail_em(symbol: str = "300073") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     ---
 */
  __pyx_tuple__120 = PyTuple_Pack(7, __pyx_n_s_symbol, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_big_df, __pyx_n_s_is_null_result); if (unlikely(!__pyx_tuple__120)) __PYX_ERR(0, 865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);
  __pyx_codeobj__121 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__120, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_stock_fhps_detail_em, 865, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__121)) __PYX_ERR(0, 865, __pyx_L1_error)
  __pyx_tuple__122 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_s_300073)); if (unlikely(!__pyx_tuple__122)) __PYX_ERR(0, 865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__122);
  __Pyx_GIVEREF(__pyx_tuple__122);

  /* "tbstock/dataAcquisition/stockDataCrawler.py":983
 * 
 * 
 * def kzz_sh_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sh
 */
  __pyx_tuple__123 = PyTuple_Pack(11, __pyx_n_s_column_dict, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_kzz_all_df, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_total_item, __pyx_n_s_total_pages, __pyx_n_s_page, __pyx_n_s_temp_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(0, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);
  __pyx_codeobj__124 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__123, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_kzz_sh_trade_day_info_em, 983, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__124)) __PYX_ERR(0, 983, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1061
 * 
 * 
 * def kzz_sz_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sz
 */
  __pyx_codeobj__125 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__123, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_kzz_sz_trade_day_info_em, 1061, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__125)) __PYX_ERR(0, 1061, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1147
 * 
 * 
 * def kzz_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     kzz_sh_em_df = kzz_sh_trade_day_info_em()
 *     kzz_sz_em_df = kzz_sz_trade_day_info_em()
 */
  __pyx_tuple__126 = PyTuple_Pack(3, __pyx_n_s_kzz_sh_em_df, __pyx_n_s_kzz_sz_em_df, __pyx_n_s_kzz_trade_day_df); if (unlikely(!__pyx_tuple__126)) __PYX_ERR(0, 1147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__126);
  __Pyx_GIVEREF(__pyx_tuple__126);
  __pyx_codeobj__127 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__126, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_kzz_trade_day_info_em, 1147, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__127)) __PYX_ERR(0, 1147, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1155
 * 
 * 
 * def kzz_basic_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     -
 */
  __pyx_tuple__128 = PyTuple_Pack(10, __pyx_n_s_column_dict, __pyx_n_s_url, __pyx_n_s_params, __pyx_n_s_kzz_all_df, __pyx_n_s_r, __pyx_n_s_data_json, __pyx_n_s_total_pages, __pyx_n_s_page, __pyx_n_s_temp_df, __pyx_n_s_cols_to_convert); if (unlikely(!__pyx_tuple__128)) __PYX_ERR(0, 1155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__128);
  __Pyx_GIVEREF(__pyx_tuple__128);
  __pyx_codeobj__129 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__128, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_kzz_basic_info_em, 1155, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__129)) __PYX_ERR(0, 1155, __pyx_L1_error)

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1218
 * 
 * 
 * def test():             # <<<<<<<<<<<<<<
 *     trade_date = '2024-05-31'
 *     stock_code = "600900"
 */
  __pyx_tuple__130 = PyTuple_Pack(3, __pyx_n_s_trade_date, __pyx_n_s_stock_code, __pyx_n_s_kzz_trade_day_em_df); if (unlikely(!__pyx_tuple__130)) __PYX_ERR(0, 1218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__130);
  __Pyx_GIVEREF(__pyx_tuple__130);
  __pyx_codeobj__131 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__130, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_tbstock_dataAcquisition_stockDat, __pyx_n_s_test, 1218, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__131)) __PYX_ERR(0, 1218, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  __pyx_umethod_PyDict_Type_keys.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_keys.method_name = &__pyx_n_s_keys;
  __pyx_umethod_PyDict_Type_update.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_update.method_name = &__pyx_n_s_update;
  __pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_values.method_name = &__pyx_n_s_values;
  __pyx_umethod_PyString_Type_find.type = (PyObject*)&PyString_Type;
  __pyx_umethod_PyString_Type_find.method_name = &__pyx_n_s_find;
  __pyx_umethod_PyString_Type_replace.type = (PyObject*)&PyString_Type;
  __pyx_umethod_PyString_Type_replace.method_name = &__pyx_n_s_replace;
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_25 = PyInt_FromLong(25); if (unlikely(!__pyx_int_25)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_50 = PyInt_FromLong(50); if (unlikely(!__pyx_int_50)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_500 = PyInt_FromLong(500); if (unlikely(!__pyx_int_500)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  return 0;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_stockDataCrawler(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_stockDataCrawler},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "stockDataCrawler",
      __pyx_k_Date_2023_8_11_11_44_Desc_https, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initstockDataCrawler(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initstockDataCrawler(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_stockDataCrawler(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_stockDataCrawler(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_stockDataCrawler(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'stockDataCrawler' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("stockDataCrawler", __pyx_methods, __pyx_k_Date_2023_8_11_11_44_Desc_https, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "stockDataCrawler" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_stockDataCrawler(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_tbstock__dataAcquisition__stockDataCrawler) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "tbstock.dataAcquisition.stockDataCrawler")) {
      if (unlikely((PyDict_SetItemString(modules, "tbstock.dataAcquisition.stockDataCrawler", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  (void)__Pyx_modinit_type_init_code();
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "tbstock/dataAcquisition/stockDataCrawler.py":8
 * https://quote.eastmoney.com/concept/sh603777.html?from=classic
 * """
 * import pandas as pd             # <<<<<<<<<<<<<<
 * import requests
 * from tbstock.utils import utils
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_pandas, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pd, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":9
 * """
 * import pandas as pd
 * import requests             # <<<<<<<<<<<<<<
 * from tbstock.utils import utils
 * from akshare.stock_feature.stock_hist_em import code_id_map_em
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_requests, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_requests, __pyx_t_2) < 0) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":10
 * import pandas as pd
 * import requests
 * from tbstock.utils import utils             # <<<<<<<<<<<<<<
 * from akshare.stock_feature.stock_hist_em import code_id_map_em
 * from akshare.utils import demjson
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_utils);
  __Pyx_GIVEREF(__pyx_n_s_utils);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_utils)) __PYX_ERR(0, 10, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_tbstock_utils, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_utils); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_utils, __pyx_t_2) < 0) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":11
 * import requests
 * from tbstock.utils import utils
 * from akshare.stock_feature.stock_hist_em import code_id_map_em             # <<<<<<<<<<<<<<
 * from akshare.utils import demjson
 * from datetime import datetime
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_code_id_map_em);
  __Pyx_GIVEREF(__pyx_n_s_code_id_map_em);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_code_id_map_em)) __PYX_ERR(0, 11, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_akshare_stock_feature_stock_hist, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_code_id_map_em); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_code_id_map_em, __pyx_t_3) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":12
 * from tbstock.utils import utils
 * from akshare.stock_feature.stock_hist_em import code_id_map_em
 * from akshare.utils import demjson             # <<<<<<<<<<<<<<
 * from datetime import datetime
 * import math
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_demjson);
  __Pyx_GIVEREF(__pyx_n_s_demjson);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_demjson)) __PYX_ERR(0, 12, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_akshare_utils, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_demjson); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_demjson, __pyx_t_2) < 0) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":13
 * from akshare.stock_feature.stock_hist_em import code_id_map_em
 * from akshare.utils import demjson
 * from datetime import datetime             # <<<<<<<<<<<<<<
 * import math
 * 
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_datetime);
  __Pyx_GIVEREF(__pyx_n_s_datetime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_datetime)) __PYX_ERR(0, 13, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_datetime, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_datetime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_3) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":14
 * from akshare.utils import demjson
 * from datetime import datetime
 * import math             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_math, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_math, __pyx_t_2) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":17
 * 
 * 
 * def stock_zh_index_daily_em(             # <<<<<<<<<<<<<<
 *         symbol: str = "csi931151",
 *         start_date: str = "19900101",
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_symbol, __pyx_n_s_str) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_start_date, __pyx_n_s_str) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_end_date, __pyx_n_s_str) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_1stock_zh_index_daily_em, 0, __pyx_n_s_stock_zh_index_daily_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__92)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__93);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_zh_index_daily_em, __pyx_t_3) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":81
 * 
 * 
 * def rzrq_history(mode='new') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/rzrq/total.html
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 81, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_3rzrq_history, 0, __pyx_n_s_rzrq_history, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__95)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__96);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_rzrq_history, __pyx_t_2) < 0) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":167
 * 
 * 
 * def stock_all_rzrq_date(trade_date='2024-05-31') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 167, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_5stock_all_rzrq_date, 0, __pyx_n_s_stock_all_rzrq_date, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__98)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__99);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_all_rzrq_date, __pyx_t_3) < 0) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":246
 * 
 * 
 * def stock_rzrq_detail(mode='new', symbol='000001') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/rzrq/stock/600900.html
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 246, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_7stock_rzrq_detail, 0, __pyx_n_s_stock_rzrq_detail, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__101)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__102);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_rzrq_detail, __pyx_t_2) < 0) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":331
 * 
 * 
 * def hsgt_history(mode='new') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     mode = 'new':50
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 331, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_9hsgt_history, 0, __pyx_n_s_hsgt_history, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__104)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__96);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_hsgt_history, __pyx_t_3) < 0) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":398
 * 
 * 
 * def stock_all_hsgt_date(trade_date='2024-05-31') -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 398, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_11stock_all_hsgt_date, 0, __pyx_n_s_stock_all_hsgt_date, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__106)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__99);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_all_hsgt_date, __pyx_t_2) < 0) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":462
 * 
 * 
 * def stock_hsgt_detail(mode='new', symbol: str = "000001") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 *     https://data.eastmoney.com/hsgt/StockHdDetail/601899.html
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_symbol, __pyx_n_s_str) < 0) __PYX_ERR(0, 462, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 462, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_13stock_hsgt_detail, 0, __pyx_n_s_stock_hsgt_detail, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__108)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__102);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_hsgt_detail, __pyx_t_3) < 0) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":528
 * 
 * 
 * def stock_zh_a_gdhs_detail_em(symbol: str = "000001.SZ") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     https://emweb.securities.eastmoney.com/pc_hsf10/pages/index.html?type=web&code=SZ300342&color=b#/gdyj
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_symbol, __pyx_n_s_str) < 0) __PYX_ERR(0, 528, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 528, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_15stock_zh_a_gdhs_detail_em, 0, __pyx_n_s_stock_zh_a_gdhs_detail_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__110)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__111);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_zh_a_gdhs_detail_em, __pyx_t_2) < 0) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":603
 * 
 * 
 * def stock_finance_mfd_quarter_em(symbol: str = "688235.SH", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_symbol, __pyx_n_s_str) < 0) __PYX_ERR(0, 603, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_timeout, __pyx_n_s_float) < 0) __PYX_ERR(0, 603, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 603, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_17stock_finance_mfd_quarter_em, 0, __pyx_n_s_stock_finance_mfd_quarter_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__113)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__114);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_finance_mfd_quarter_em, __pyx_t_3) < 0) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":678
 * 
 * 
 * def stock_finance_mfd_report_em(symbol: str = "688235.SH", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     '''
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_symbol, __pyx_n_s_str) < 0) __PYX_ERR(0, 678, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_timeout, __pyx_n_s_float) < 0) __PYX_ERR(0, 678, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 678, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_19stock_finance_mfd_report_em, 0, __pyx_n_s_stock_finance_mfd_report_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__116)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__114);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_finance_mfd_report_em, __pyx_t_2) < 0) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":812
 * 
 * 
 * def stock_individual_info_em(symbol: str = "688235", timeout: float = None) -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     --
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_symbol, __pyx_n_s_str) < 0) __PYX_ERR(0, 812, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_timeout, __pyx_n_s_float) < 0) __PYX_ERR(0, 812, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 812, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_21stock_individual_info_em, 0, __pyx_n_s_stock_individual_info_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__118)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__119);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_individual_info_em, __pyx_t_3) < 0) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":865
 * 
 * 
 * def stock_fhps_detail_em(symbol: str = "300073") -> pd.DataFrame:             # <<<<<<<<<<<<<<
 *     """
 *     ---
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_symbol, __pyx_n_s_str) < 0) __PYX_ERR(0, 865, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_kp_s_pd_DataFrame) < 0) __PYX_ERR(0, 865, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_23stock_fhps_detail_em, 0, __pyx_n_s_stock_fhps_detail_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__121)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__122);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stock_fhps_detail_em, __pyx_t_2) < 0) __PYX_ERR(0, 865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":983
 * 
 * 
 * def kzz_sh_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sh
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_25kzz_sh_trade_day_info_em, 0, __pyx_n_s_kzz_sh_trade_day_info_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__124)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_kzz_sh_trade_day_info_em, __pyx_t_2) < 0) __PYX_ERR(0, 983, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1061
 * 
 * 
 * def kzz_sz_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     https://quote.eastmoney.com/center/gridlist.html#bond_convertible_sz
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_27kzz_sz_trade_day_info_em, 0, __pyx_n_s_kzz_sz_trade_day_info_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__125)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_kzz_sz_trade_day_info_em, __pyx_t_2) < 0) __PYX_ERR(0, 1061, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1147
 * 
 * 
 * def kzz_trade_day_info_em():             # <<<<<<<<<<<<<<
 *     kzz_sh_em_df = kzz_sh_trade_day_info_em()
 *     kzz_sz_em_df = kzz_sz_trade_day_info_em()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_29kzz_trade_day_info_em, 0, __pyx_n_s_kzz_trade_day_info_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__127)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_kzz_trade_day_info_em, __pyx_t_2) < 0) __PYX_ERR(0, 1147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1155
 * 
 * 
 * def kzz_basic_info_em():             # <<<<<<<<<<<<<<
 *     '''
 *     -
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_31kzz_basic_info_em, 0, __pyx_n_s_kzz_basic_info_em, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__129)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_kzz_basic_info_em, __pyx_t_2) < 0) __PYX_ERR(0, 1155, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1218
 * 
 * 
 * def test():             # <<<<<<<<<<<<<<
 *     trade_date = '2024-05-31'
 *     stock_code = "600900"
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_7tbstock_15dataAcquisition_16stockDataCrawler_33test, 0, __pyx_n_s_test, NULL, __pyx_n_s_tbstock_dataAcquisition_stockDat_2, __pyx_d, ((PyObject *)__pyx_codeobj__131)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1262
 * 
 * 
 * if __name__ == "__main__":             # <<<<<<<<<<<<<<
 *     test()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_n_s_main, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1263
 * 
 * if __name__ == "__main__":
 *     test()             # <<<<<<<<<<<<<<
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_test); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "tbstock/dataAcquisition/stockDataCrawler.py":1262
 * 
 * 
 * if __name__ == "__main__":             # <<<<<<<<<<<<<<
 *     test()
 */
  }

  /* "tbstock/dataAcquisition/stockDataCrawler.py":1
 * # -*- coding:utf-8 -*-             # <<<<<<<<<<<<<<
 * # !/usr/bin/env python
 * """
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_2, __pyx_t_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init tbstock.dataAcquisition.stockDataCrawler", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init tbstock.dataAcquisition.stockDataCrawler");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value);
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* UnpackUnboundCMethod */
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
     METH_VARARGS | METH_KEYWORDS,
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #else
    if (likely(!__Pyx_CyOrPyCFunction_Check(method)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            target->method = unbound_method;
        }
    }
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if ((PY_VERSION_HEX >= 0x030600B1) && flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            #else
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            #endif
        } else if ((PY_VERSION_HEX >= 0x030700A0) && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 0;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a != b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) != 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 1;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 1;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal != 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a != (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    if (likely(cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
            return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, args, 2);
            #else
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
            #endif
        }
        #if PY_VERSION_HEX >= 0x030700A0
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
        #endif
    }
    return __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(3);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 1, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 2, arg2);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(3, self, arg1, arg2);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a + (unsigned long)b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op2);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* CallUnboundCMethod0 */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* py_dict_keys */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Keys(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_keys, d);
    else
        return PyDict_Keys(d);
}

/* py_dict_values */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_values, d);
    else
        return PyDict_Values(d);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__90;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__62);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if PY_VERSION_HEX >= 0x030d00A4
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name_2);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_n_s__132);
    }
    return name;
}
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
